<?php

//	eto__chron_ssi_0.php 20140325 (c) Copyright 2014 A.S.Petrie. All rights reserved.
//
//	SSI -- Date / Time service option settings, common variables and functions
//           (Using the PEAR Date / Time package.)
//

// PEAR Date / Time class.
require_once 'Date.php';

// common variables ...

// "Current" date/time (for the entire HTTP client request) ...

global $crn_time_nix_secs;

global $crn_dtime_utc;
global $crn_date_utc;
global $crn_dow_utc;

global $crn_dtime_loc;
global $crn_date_loc;
global $crn_offset_loc;

const ETO_DTIME_FMT = 'Y-m-d H:i:s';
const DTIME_0_ISO   = '0000-00-00 00:00:00'; // null date/time in ISO 'yyyy-mm-dd hh:mm:ss' format (MySQL DATETIME compatible).

// current server time in seconds from start of unix epoch.
   $crn_time_nix_secs = time();

// GMT / UTC date/time ...

// null date/time.
   const CRN_DTIME_0_UTC = DTIME_0_ISO;

   $crn_dtime_utc = gmdate(ETO_DTIME_FMT, $crn_time_nix_secs); // current GMT / UTC date/time in ISO 'yyyy-mm-dd hh:mm:ss' format (MySQL DATETIME compatible).

// Testing session expire / delete conditions in <>.
//  (Set to appropriate future date/time +1 sec. for session under test to expire / become deletable.)
// $crn_dtime_utc = '0000-00-00 00:00:00';
// $crn_dtime_utc = '2010-06-29 11:45:57';

   $crn_date_utc  = etoDate($crn_dtime_utc);

   $crn_dow_utc   = gmdate('D', $crn_time_nix_secs); // 'D' -- day of week (Mon, Tue, etc.) for current GMT / UTC date/time

// ... GMT / UTC date/time.

// server local date/time ...

// null date/time.
   const CRN_DTIME_0_LOC = DTIME_0_ISO;

   $crn_dtime_loc = date(ETO_DTIME_FMT, $crn_time_nix_secs); // current server local date/time in ISO 'yyyy-mm-dd hh:mm:ss' format (MySQL DATETIME compatible).

   $crn_date_loc  = etoDate($crn_dtime_loc);

   $crn_offset_loc = date('O', $crn_time_nix_secs); // 'O' -- difference (+hhmm / -hhmm) to UTC/GMT time.

// ... server local date/time..

// ... "Current" date/time.

// ... common variables.

// functions ...

   function etoDate($dt) // date/time in date(...) / gmdate(...) format.
   {
//    date/time in ISO 'yyyy-mm-dd hh:mm:ss' format.
      return(substr($dt, 0, 10));
   }

   function addSecs($dt, $si = 0 ) // date/time in ISO 'yyyy-mm-dd hh:mm:ss' format, time increment in seconds.
   {
      $dtime_pear = new Date();              // PEAR Date object (PHP won't allow static object definition?).

      static $dtime_iso = CRN_DTIME_0_ISO;   // date/time in ISO 'yyyy-mm-dd hh:mm:ss' format (MySQL DATETIME compatible).

      $dtime_pear -> setDate($dt, DATE_FORMAT_ISO); // set pear date to parm value.
      $dtime_pear -> addSeconds($si);               // add seconds from parm value.

      $dtime_iso = $dtime_pear -> getDate(DATE_FORMAT_ISO); // result in ISO 'yyyy-mm-dd hh:mm:ss' format (MySQL DATETIME compatible).

//    destroy the date object.
      unset($dtime_pear);

      return ($dtime_iso);
   }

// input parm: date/time in ISO 'yyyy-mm-dd hh:mm:ss' format.
   function etoDateYear($dt)  { return (substr($dt, 0,  4)); } // yyyy.
   function etoDateMonth($dt) { return (substr($dt, 5,  2)); } // mm (month).
   function etoDateDay($dt)   { return (substr($dt, 8,  2)); } // dd.

   function etoDateSum($dt) // date/time in ISO 'yyyy-mm-dd hh:mm:ss' format:
   {
//    return integer sum of date/time components.
//
//     0    0  0  1  1  1 )  sub-
//     0    5  8  1  4  7 ) scriot
//    'yyyy-mm-dd hh:mm:ss' 
//
      return
      (
         (int) etoDateYear($dt)
         +
         (int) etoDateMonth($dt)
         +
         (int) etoDateDay($dt)
         +
         (int) substr($dt, 11, 2) // hh.
         +
         (int) substr($dt, 14, 2) // mm (minutes).
         +
         (int) substr($dt, 17, 2) // ss.
      );
   }

   function etoBuildDate($y, $m, $d) // year ('yyyy'), month ('mm'), day ('dd').
   {
//    date/time in ISO 'yyyy-mm-dd hh:mm:ss' format.
      return
      (
         $y  . '-' .
         $m  . '-' .
         $d  .
         ' ' .
         '00:00:00'
      );
   }

// returns bool: ((date of $dt0) after (date of $dt1)).
   function etoAfterDate($dt0, $dt1) // two: date/time in ISO 'yyyy-mm-dd hh:mm:ss' format.
   {
      $tmp_return_val = true;

      $tmp_y0 = etoDateYear($dt0);
      $tmp_y1 = etoDateYear($dt1);

      $tmp_m0 = '';
      $tmp_m1 = '';

      $tmp_d0 = '';
      $tmp_d1 = '';

      if ($tmp_y0 < $tmp_y1)
      {
         $tmp_return_val = false;
      }
      else
      {
         if ($tmp_y0 == $tmp_y1)
         {
            $tmp_m0 = etoDateMonth($dt0);
            $tmp_m1 = etoDateMonth($dt1);

            if ($tmp_m0 < $tmp_m1)
            {
               $tmp_return_val = false;
            }
            else
            {
               if ($tmp_m0 == $tmp_m1)
               {
                  $tmp_d0 = etoDateDay($dt0);
                  $tmp_d1 = etoDateDay($dt1);

                  if ($tmp_d0 <= $tmp_d1)
                  {
                  $tmp_return_val = false;
                  }
               }
            }
         }
      }

/*
// Testing ...

  $tst_diag = '';
  $tst_diag .= ( '##etoAfterDate(#1)##  ' );

  $tst_diag .= ( '**$dt0<' . $dt0 . '>**  ' );
  $tst_diag .= ( '**$dt1<' . $dt1 . '>**  ' );

  $tst_diag .= ( '**$tmp_y0<' . $tmp_y0 . '>**  ' );
  $tst_diag .= ( '**$tmp_y1<' . $tmp_y1 . '>**  ' );

  $tst_diag .= ( '**$tmp_m0<' . $tmp_m0 . '>**  ' );
  $tst_diag .= ( '**$tmp_m1<' . $tmp_m1 . '>**  ' );

  $tst_diag .= ( '**$tmp_d0<' . $tmp_d0 . '>**  ' );
  $tst_diag .= ( '**$tmp_d1<' . $tmp_d1 . '>**  ' );

  $tst_diag .= ( '**$tmp_return_val<' . $tmp_return_val . '>**  ' );

  echo htmlspecialchars($tst_diag, ENT_QUOTES);

// ... Testing.
*/

      return ($tmp_return_val);
   }

// adds an integer to a year.
   function etoBumpYear($y, $i) // year (string 'yyyy'), increment (int).
   {
      $tmp_bumped_year_str
      =
      (string)
      (
         (int) $y
         +
         $i
      );

      return
      (
         substr
         (
            $tmp_bumped_year_str,

 //         start.
            (strlen($tmp_bumped_year_str) - 4),

 //         length.
            4
         )
      );
   }

// adds an integer to a year.
   function etoIsLeapYear($y) // year (string 'yyyy')t).
   {
      $tmp_return_val = false;

      $tmp_year_int = (int) $y;

//    evenly divided by 4?
      if
      (
         ($tmp_year_int % 4)
         ==
         0
      )
//    yes -- evenly divided by 4.
      {
//       evenly divided by 100?
         if
         (
            ($tmp_year_int % 100)
            ==
            0
         )
//       yes -- evenly divided by 100.
         {
//          evenly divided by 400?
            if
            (
               ($tmp_year_int % 400)
               ==
               0
            )
//          yes -- evenly divided by 100.
            {
               $tmp_return_val = true;
            }
         }
         else
//       no -- NOT evenly divided by 100.
         {
            $tmp_return_val = true;
         }
      }

      return ($tmp_return_val);
   }

// .. functions..

?>
