<?php

//	eto__sql_pg_ssi_0.php 20151011 (c) Copyright 2015 A.S.Petrie. All rights reserved.
//
//	SSI -- SQL services (using PHP pg_* API) -- common variables and functions.
//

// *** CONTINUE EDITING HERE FOR CHANGES FROM MYSQLI TO PG_ ***
// @@@

//       *** IMPORTANT NOTE -- SECURITY -- SQL INJECTION ***
//
//  SQL injection attacks are blocked
//     by using PREPARED STATEMENTS EXCLUSIVELY
//     for all SQL queries carrying content from
//     UNTRUSTED EXTERNAL SOURCES.
//
//  SQL prepared statements clearly and completely separate
//     the SQL request's COMMAND and CONTROL constructs,
//     from its visitor-supplied passive DATA,
//     which data is subject ONLY to storage / retrievel
//     when prepared statements are used.
//
//  @@@
//

//       *** IMPORTANT NOTE -- PREPARED STATEMENTS -- max_allowed_packet ***
//
//  Currently the prepared statement logic does not explicitly
//    check if the size of a field parameter value exceeds the
//    "max_allowed_packet" limit specified in the "my.ini" file.
//
//  As of the date above, the operative value for max_allowed_packet = 1M,
//    so should not be a problem, as the longest field size currently
//    used = 2000 characters.
//
//  Can add in future logic to prepared statement handling,
//     to query max_allowed_packet, if large TEXT or BLOB fields
//     used (be sure to see cautionary note re: client character set
//     encoding interference with binary data, in web page:
//     <www.phpf1.com -- mysqli-stmt-send-long-data - 20110225.html>).
//
//
//  @@@
//

//       *** IMPORTANT NOTE -- TESTING ***
//
//  Tests for abends in requirer <eto_verify_img.php> (e.g. etoSQLdbOpen() fails() ...
//
//  (When testing <eto_verify_img.php>:
//     MUST disable PHP error display
//     in <...\xampp\php\php.ini> with <display_errors = Off>,
//     otherwise the e.g. mysqli_connect(...) failure generates
//     a php warning message that corrupts the image served,
//     and ETO cannot serve its 'xxABEND' diagnostic image to browser.)
//
//  ... Tests for abends in requirer <eto_verify_img.php>.
//
//  Echoing debugging output to the http page from <eto__sql_ssi_0.php>,
//     causes <eto_verify_img.php> to fail to generate http image.
//     Therefore, when using debugging echos in <>, wrap then in a conditional
//     of the form shown here:
//
//
//   // Testing ...
//     global $sys_exit_code;
//     global $sys_script_id;
//     global $sql_diag;
//
//   if ($sys_script_id != 'eto_verify_img.php')
//   {
//     $tst_diag = '';
//     $tst_diag .= ( '##etoSQLreadRow_session_www(...)##  ' );
//
//     echo htmlspecialchars($tst_diag, ENT_QUOTES);
//
//   }
//   // ... Testing.
//

//	Option settings, variables and common functions.
// require '../eto_php/eto__chron_ssi_0.php';

//
// List of functions (defined in this SSI, including: under construction == "@", obsolete = x, future = f) ...
//
//    etoSQLinitCall                    ()
//    etoSQLgetStatusVars               ()
//    etoSQLinitBuff_session_www        ()
//    etoSQLinitBuff_club_member        ()
//    etoSQLgetRowBuf_session_www       ()
//
//    etoSQLinitTargData_session_www    ()
//    etoSQLputTargData_session_www     ()
//    etoSQLputTargGrp0_session_www     ($ba)
//    etoSQLputTargGrp0a_session_www    ($lk) 
//    etoSQLputTargGrp0b_session_www    ($si, @@@)
//    etoSQLputTargGrp1_session_www     ($ts, $tf, $tl, $te, $tm, $ta, $tc, $tn, $tb)
//    etoSQLputTargGrp2_session_www     ($tp)
//    etoSQLgetTargHandle_session_www   ($g)
//    etoSQLgetNullTargGrp0_session_www ()
//    etoSQLgetNullTargGrp0a_session_www()
//    etoSQLgetNullTargGrp0b_session_www()
//    etoSQLgetTargGrp0_session_www     ()
//    etoSQLgetTargGrp0a_session_www    ()
//    etoSQLgetTargGrp0b_session_www    ()
//    etoSQLgetNullTargGrp1_session_www ()
//    etoSQLgetTargGrp1_session_www     ()
//    etoSQLgetNullTargGrp2_session_www ()
//    etoSQLgetTargGrp2_session_www     ()
//    etoSQLgetTargData_session_www     ()
//
//    etoSQLtickTockExp_session_www     ($st0)
//    etoSQLtickTockDel_session_www     ($st0, $st1)
//    etoSQLtickTockSet_session_www     ($st0, $st1)
//    etoSQLhashSeqnoDate_session_www   ($sq, $dt)
//    etoSQLgetMysqliStateClass         ()
//    etoSQLgetMysqliDiag               ()
//    etoSQLstmtGetMysqliDiag           ()
//    etoSQLgetPostgresSqlState         ($ac, $xo, $ro)
//    etoSQLformatDiag                  ()
//
//    etoSQLdbOpen                      ($ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK, $co = SQL_NOAUTOCOMMIT)
//    etoSQLcheckQuery                  ($ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK)
//    etoSQLget_mysqli_insert_id        ()
//    etoSQLmysqli_query                ($qs = '')
//    etoSQLpostgres_query              ($qs = '', $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK)
//    etoSQLqueryExecSuccess            ()
//    etoSQLquery                       ($ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK)
//    etoSQLstmtAbendSubCode            ($ac, $sc, $xo, $ro)
//    etoSQLstmtOpen                    ($qs = '', $qb, $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK)
//    etoSQLstmtDo                      ($rb, $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK)
// f  etoSQLstmtFetch                   (@@@)
//    etoSQLstmtClose                   ($ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK)
//    etoSQLdbClose                     ($ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK, $co = SQL_COMMIT)
//    etoSQLtrxRollback                 ($ac, $xo)
//
// obsolete ...
//    etoSQLreadRow_visitor_ses         ($sc, $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK, $lo = SQL_NOLOCK)
//    etoSQLwriteRow_visitor_ses        ($sc, $vc, $st0 = 0, $st1 = 0, $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK)
//    etoSQLreWriteRow_visitor_ses      ($ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK)
//    etoSQLdeleteRow_visitor_ses       ($sc, $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK)
//    etoSQLsetState_visitor_ses        ($sc, $ss, $st0 = 0, $st1 = 0, $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK)
//    etoSQLgetMinSerno_visitor_ses     ($ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK)
//    etoSQLgetLimRowcnt_visitor_ses    ($sk)
//    etoSQLgetLimSerno_visitor_ses     ($sn, $sk)
//    etoSQLpruneRows_visitor_ses       ($sk, $ac, $xo, $ro)
//    etoSQLexpireRows_visitor_ses      ($hm, $sk, $ac, $xo, $ro)
//    etoSQLtickTock_visitor_ses        ($hm, $sk = 0, $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK)
// ... obsolete.
//
//    etoSQLreadRow_session_www         ($sc, $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK, $lo = SQL_NOLOCK)
//    etoSQLstmtWriteRow_session_www    ($sc, $vc, $st0 = 0, $st1 = 0, $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK)
// x  etoSQLwriteRow_session_www        ($sc, $vc, $st0 = 0, $st1 = 0, $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK)
//    etoSQLstmtReWriteRow_session_www  ($ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK)
// x  etoSQLreWriteRow_session_www      ($ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK)
//    etoSQLdeleteRow_session_www       ($sc, $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK)
//    etoSQLsetState_session_www        ($ss, $st0 = 0, $st1 = 0, $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK)
//    etoSQLgetMinSerno_session_www     ($ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK)
//    etoSQLgetLimRowcnt_session_www    ($sk)
//    etoSQLgetLimSerno_session_www     ($sn, $sk)
//    etoSQLpruneRows_session_www       ($sk, $ac, $xo, $ro)
//    etoSQLexpireRows_session_www      ($hm, $sk, $ac, $xo, $ro)
//    etoSQLtickTock_session_www        ($hm, $sk = 0, $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK)
//
//
//    etoSQLgetRowBuf_contact_msg       ()
//    etoSQLstmtWriteRow_contact_msg    (&$cn, &$ce, &$cs, &$cv, &$cm, $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK)
//
//
//    etoSQLreadRow_club_member         ($ms, $me, $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK, $lo = SQL_NOLOCK)
//    etoSQLstmtWriteRow_club_member    (&$mz, &$mp, &$sc, &$vc, &$mf, &$ml, &$me, &$mr, &$mi, &$mc, &$mw, &$mb, $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK)
//    etoSQLstmtReWriteRow_club_member  ($ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK)
// f  etoSQLdeleteRow_club_member       ($sc, $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK)
//    etoSQLsetState_club_member        ($sc, $ss, $st0 = 0, $st1 = 0, $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK)
//    etoSQLgetMaxSerno_club_member     ($ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK)
//    etoSQLgetRowBuf_club_member       ()
//
// ... List of functions.

// Common variables ...

  const SQL_DB = 'eto_sql_db';

// Test for abend in requirer -- etoSQLdbOpen() fails.
// const SQL_DB = 'eto_sql_dbX';

// Parameter for pgsql pg_set_client_encoding(...) function.
  const SQL_CHARSET_CLIENT = 'LATIN1'; // @@@??? ==> cp1252 West European (== ISO-8859-1 with extra symbols assigned to unused values in ISO-8859-1).

// Test for abend in in requirer -- etoSQLdbOpen() fails.
// const SQL_CHARSET_CLIENT = 'LATIN1X';

  const SQL_CONN_TIMEOUT = 1; // [seconds] pg_connect(... connect_timeout= ...) == time in seconds to wait to make a connection before terminating the connection attempt.
  
  const SQL_QUERY_TIMEOUT = 1; // [seconds] pg_send_query(...) == total time in seconds to wait in loop to complete a query before terminating the query attempt.
  const SQL_QUERY_WAITCNT = 5; // [count] == number of times to pause, before each check of the query status.

// [microseconds] usleep($sql_query_loopwait) == time in microseconds to pause in each cycle of the query wait loop.
  $sql_query_loopwait
  =
  (integer)
  ceil
  (
     (
       ((double) 1000000)
       *
       ((double) SQL_QUERY_TIMEOUT)
     )
     /
     ((double) SQL_QUERY_WAITCNT)
  );

 // minimum postgresql server version required.
  const SQL_PG_MIN_VERSION = '9.3'; // Current Win XP.
// const SQL_PG_MIN_VERSION = '9.3X'; // test abend.

  $sql_min_version = SQL_PG_MIN_VERSION;
  $sql_srv_version = ''; // pg_parameter_status($sql_conn, 'server_version').

// ... sql server minimum version.

  $sql_conn = false; // pg_connect(...).
  $sql_conn_type = '';

//
// Return values from function pg_connection_status(...);
//
// (NULL) = connection resource is null.
// (int) 0 = PGSQL_CONNECTION_OK
// (int) 1? = PGSQL_CONNECTION_BAD
//
  $sql_connection_status      = ''; // PostgreSQL function pg_connection_status(...).
  $sql_connection_status_type = '';

  $sql_result_error      = ''; // PostgreSQL function pg_result_error (...).
  $sql_result_error_type = '';

  $sql_result_error_field_str = ''; // function etoSQLgetPostgresDiagResultFields();

//
// Return value types from function pg_last_error(...);
//
// (string) last error message string of a connection.
// (FALSE) an error occurred.
//
  $sql_last_error      = ''; // PostgreSQL function pg_last_error(...).
  $sql_last_error_type = '';

//
// Global value maintained by function etoSQLsetPostgresErrorVerbosity(...),
//    which passes the current value to function pg_set_error_verbosity(...).
//
//    The value is maintained in this variable $sql_error_verbosity,
//       to be available for testing, because it appears that
//       there is no non-destructive way to test the current value
//       set for the connection in the postgres server.
//
  $sql_error_verbosity = PGSQL_ERRORS_TERSE;
// $sql_error_verbosity = PGSQL_ERRORS_DEFAULT;
// $sql_error_verbosity = PGSQL_ERRORS_VERBOSE;

//
// Return values from function pg_result_status($sql_result, PGSQL_STATUS_LONG);
//
// 0 = PGSQL_EMPTY_QUERY
// 1 = PGSQL_COMMAND_OK
// 2 = PGSQL_TUPLES_OK
// 3 = PGSQL_COPY_TO
// 4 = PGSQL_COPY_FROM
// 5 = PGSQL_BAD_RESPONSE
// 6 = PGSQL_NONFATAL_ERROR
// 7 = PGSQL_FATAL_ERROR
// 8 = PGRES_COPY_BOTH (PostgreSQL 9.4)
// 9 = PGRES_SINGLE_TUPLE (PostgreSQL 9.4)
//
  $sql_result_status_long      = ''; // PostgreSQL function pg_result_status(..., PGSQL_STATUS_LONG).
  $sql_result_status_long_type = '';

  $sql_result_status_string      = ''; // PostgreSQL function pg_result_status (..., PGSQL_STATUS_STRING).
  $sql_result_status_string_type = '';

// PostgreSQL function pg_result_error_field(...).
  $pg_result_error_fieldcode_ary 
  =
  array
  (
     "PGSQL_DIAG_SEVERITY",          "PGSQL_DIAG_SQLSTATE",
     "PGSQL_DIAG_MESSAGE_PRIMARY",   "PGSQL_DIAG_MESSAGE_DETAIL",
     "PGSQL_DIAG_MESSAGE_HINT",      "PGSQL_DIAG_STATEMENT_POSITION",
     "PGSQL_DIAG_INTERNAL_POSITION", "PGSQL_DIAG_INTERNAL_QUERY",
     "PGSQL_DIAG_CONTEXT",           "PGSQL_DIAG_SOURCE_FILE",
     "PGSQL_DIAG_SOURCE_LINE",       "PGSQL_DIAG_SOURCE_FUNCTION"
  );

//
// Return values from function pg_transaction_status($sql_conn);
// 
// 0 = PGSQL_TRANSACTION_IDLE    (connection is currently idle, not in a transaction)
// 1 = PGSQL_TRANSACTION_ACTIVE  (command in progress on the connection, a query has been sent via the connection and not yet completed)
// 2 = PGSQL_TRANSACTION_INTRANS (idle, in a transaction block)
// 3 = PGSQL_TRANSACTION_INERROR (idle, in a failed transaction block)
// 4 = PGSQL_TRANSACTION_UNKNOWN (the connection is bad)
//
  $sql_transaction_status      = -1;
  $sql_transaction_status_type = '';

  $sql_state       = ''; // ANSI/ISO SQLSTATE status.
  $sql_state_type  = '';
  $sql_state_class = ''; // ANSI/ISO SQLSTATE status class == substr($sql_state, 0, 2).

  $sql_state_proxy       = ''; // Function etoSQLgetPostgresSqlState(...).
  $sql_state_class_proxy = ''; // Function etoSQLgetPostgresSqlState(...).

  $sql_diag        = ''; // formatted comprehensive diagnostic string.

  $sql_query            = '';

//
// Constants for defining the threshold of query success / UNsuccess
//    in function etoSQLcheckQuery(...).
//
// Named as follows:
//
//  e.g. const SQL_NASUM_GE1_DUP
//                 || |   |  |
//                 || |   |  = DO allow (SQLSTATE == '23505') -- duplicate error (aka "unique_violation"), otherwise (if _DUP suffix absent), DO NOT allow duplicate error.
//                 || |   |
//                 || |   = (NASUM >= 1) conditional arithmetic threshold for query success.
//                 || |   
//                 || = ($sql_row_count + $sql_afec_row_count)
//                 ||   
//                 |= $sql_afec_row_count = pg_affected_rows($sql_result);
//                 |
//                 = $sql_row_count = pg_num_rows($sql_result);
//
//----------------------------------------------------------------------------------------
//                                ----------------------------------------------------------------------
//                             //         |   $sql_row_count    |   DUPLICATE KEY | NO DATA |           
//                             // default |        +            |      ALLOWED    | ALLOWED | ROLLBACK 
//                             //    ?    | $sql_afec_row_count |         ?       |    ?    |     ?    
//                             // -------   -------------------     -------------     ---        ---   
//                                                                                           
  const SQL_NASUM_EQ0     = 0; //    -            == 0                  N  (1)         Y          N (3) 
  const SQL_NASUM_GE0     = 1; //    -            >= 0                  N  (1)         Y          N (3) 
  const SQL_NASUM_GE1     = 2; //    Y            >= 1                  N  (1)         Y          N (3) 
//
  const SQL_NASUM_EQ0_DUP = 3; //    -            == 0                  Y  (2)         Y          N (3) 
  const SQL_NASUM_GE0_DUP = 4; //    -            >= 0                  Y  (2)         Y          N (3) 
  const SQL_NASUM_GE1_DUP = 5; //    -            >= 1                  Y  (2)         Y          N (3) 
//
  const SQL_ROLLBACK      = 6; //    -            ----                  -              -          Y (4)
//------------------------------------------------------------------------------------------------------
//       (1) = sqlstate duplicate NOT allowed, sqlstate strict success required.
//       (2) = sqlstate duplicate allowed, NOT required.
//       (3) = sqlstate rollback NOT allowed.
//       (4) = sqlstate rollback required.
//----------------------------------------------------------------------------------------

// @@@ ... remove?
  $sql_statement        = false;
  $sql_stmt_meta_result = false;
  $sql_stmt_is_abending = false;
// ... @@@

  $sql_result           = false;
  $sql_result_type      = '';
  $sql_row_count        = 0; // pg_num_rows($sql_result).
  $sql_afec_row_count   = 0; // pg_affected_rows($sql_result).
  $sql_fetch            = '';
  $sql_fetch_count      = 0;

// SQL auto-increment row serno ...
//
// See function etoSQLget_mysqli_insert_id().

const SQL_NUL_ROW_SERNO = 0;
const SQL_MAX_ROW_SERNO = 2147483647; // Maximum possible row serno value for both: (1) MySQL (signed) INT data type and (2) PHP 32-bit (signed) integer).

// ... SQL auto-increment row serno.

// Option parameters for functions in this SSI.
const SQL_NOLOCK       = false;
const SQL_LOCK         = true;
const SQL_NOCOMMIT     = false;
const SQL_COMMIT       = true;

// Dummy parameter for calling function etoSQLstmtResult().
$DUMMY_BIND_ARY = array(); // empty dummy array (not allowed as constant).

// Table column variables ...

// $session_www_type valid values.
const SES_TYPE_UNKNOWN   = -1; // session type . UNKNOWN.
const SES_TYPE_NULL      =  0; // session type . session does NOT EXIST.
const SES_TYPE_CONTACT   =  1; // contact message form session.
const SES_TYPE_CLUB      =  2; // Club ETO member form session.

// sql row states ...

// sql row state valid values ...

const ROW_STATE_NULL            =  0; // sql row . does NOT EXIST.

const ROW_STATE_LOGIN           =  1; // sql row . in LOGIN state.
const ROW_STATE_PASSWORD        =  2; // sql row . in PASSWORD state.
// const ROW_STATE_EMAIL_LOGIN     =  3; // sql row . in EMAIL_LOGIN state.
const ROW_STATE_EMAIL_LINK      =  3; // sql row . in EMAIL_LINK state.
// const ROW_STATE_EMAIL_PASSWORD  =  4; // sql row . in EMAIL_PASSWORD state.
const ROW_STATE_EMAIL_LOGIN     =  4; // sql row . in EMAIL_LOGIN state.
const ROW_STATE_INFO            =  5; // sql row . in INFO state.

const ROW_STATE_ACTIVE          =  6; // sql row . in ACTIVE state.
const ROW_STATE_COMPLETE        =  7; // sql row . in COMPLETE state.
const ROW_STATE_EXPIRED         =  8; // sql row . in EXPIRED state.
const ROW_STATE_ABENDED         =  9; // sql row . in ABENDED state (currently unused(?)).

const ROW_STATE_PAUSED          = 10; // sql row . in PAUSED state.
const ROW_STATE_RESIGNED        = 11; // sql row . in RESIGNED state.
const ROW_STATE_NON_MEMBER      = 12; // sql row . in NON-MEMBER state.
const ROW_STATE_REVOKED         = 13; // sql row . in REVOKED state.

// ... sql row state valid values.

// row state text strings ...

$row_state_text_ary
= array
(
  ROW_STATE_NULL        => 'NOT MEMBER',

  ROW_STATE_LOGIN       => 'LOGIN',
  ROW_STATE_PASSWORD    => 'PASSWORD',
  ROW_STATE_EMAIL_LINK  => 'EMAIL LINK',
  ROW_STATE_EMAIL_LOGIN => 'EMAIL LOGIN',
  ROW_STATE_INFO        => 'INFO',

  ROW_STATE_ACTIVE      => 'ACTIVE',
  ROW_STATE_COMPLETE    => 'COMPLETE',
  ROW_STATE_EXPIRED     => 'EXPIRED',
  ROW_STATE_ABENDED     => 'ABENDED',

  ROW_STATE_PAUSED      => 'PAUSED',
  ROW_STATE_RESIGNED    => 'RESIGNED',
  ROW_STATE_NON_MEMBER  => 'NOT MEMBER',
  ROW_STATE_REVOKED     => 'REVOKED'
);

// ... row state text strings.

//
// valid sql row states ...
//
//      sql table:        eto_sql_tb_session_www   eto_sql_tb_club_member   eto_sql_tb_contact_msg
// row buf column:          $session_www_state          $member_status            (n/a)
//                          ------------------          --------------             ---
//
// ROW_STATE_NULL                 NULL                      NULL                    --
//
// ROW_STATE_LOGIN                LOGIN                      --                     --
// ROW_STATE_PASSWORD             PASSWORD                   --                     --
// ROW_STATE_EMAIL_LINK           EMAIL_LINK                 --                     --
// ROW_STATE_EMAIL_LOGIN          EMAIL_LOGIN                --                     --
// ROW_STATE_INFO                 INFO                       --                     --
//
// ROW_STATE_ACTIVE               ACTIVE                    ACTIVE                 ACTIVE
// ROW_STATE_COMPLETE             COMPLETE                   --                    COMPLETE
// ROW_STATE_EXPIRED              EXPIRED                   EXPIRED                EXPIRED
// ROW_STATE_ABENDED              ABENDED                    --                     --
//
// ROW_STATE_PAUSED                --                       PAUSED                  --
// ROW_STATE_RESIGNED              --                       RESIGNED                --
// ROW_STATE_REVOKED               --                       REVOKED                 --
// ROW_STATE_NON_MEMBER            --                       NON_MEMBER              --
//
//
// ... valid sql row states.
//
// ... sql row states.

/* pre-Club ETO version.
//  eto_sql_tb_visitor_ses row buffer.
$visitor_ses_code       = '';
$visitor_ses_state      = SES_STATE_NULL;
$visitor_verify_code    = '';
$visitor_ses_serno      = '0'; // *** CAUTION *** Using STRING representation (mysqli_insert_id(...) returns string type if PHP int precision exceeded).
$visitor_ses_init_utc   = CRN_DTIME_0_UTC;
$visitor_ses_last_utc   = CRN_DTIME_0_UTC;
$visitor_ses_expiry_utc = CRN_DTIME_0_UTC;
$visitor_ses_delete_utc = CRN_DTIME_0_UTC;
$visitor_ses_hit_count  = 0;
*/

//  eto_sql_tb_session_www row buffer.
$session_www_code       = '';
$session_www_type       = 0;
$session_www_state      = ROW_STATE_NULL;
$session_verify_code    = '';
$session_www_serno      = SQL_NUL_ROW_SERNO;
$session_target_serno   = SQL_NUL_ROW_SERNO;
$session_target_data    = '';
$session_www_init_utc   = CRN_DTIME_0_UTC;
$session_www_last_utc   = CRN_DTIME_0_UTC;
$session_www_expiry_utc = CRN_DTIME_0_UTC;
$session_www_delete_utc = CRN_DTIME_0_UTC;
$session_www_hit_count  = 0;
$session_www_act_seqno  = 0;

//  eto_sql_tb_session_www derived row value.
$session_www_act_seqhsh = '';

//  eto_sql_tb_session_www table row, $session_target_data column buffer ...

// FORMAT OF target data string, as stored (0 = 0/1, n = 0..9, a = ascii char, x = binary byte):
//
//   0. NOT a fully generalized facility (e.g. fetch of a string data item value, strips trailing whitespace, except for last item in last group).
//   1. A null string is allowed, for convenience.
//   2. Three target data groups can be stored independently in the target data string (group 0, group 1, group 2).
//   3. If a group's data is stored, its data length is fixed, except for the last data group, whose data length is allowed to vary.
//   4. Each target data group begins with a flag character, indicating presence / absence of group data:
//
//       flag
//      value  flag means       group string format
//      -----  --------------  --------------------...
//       '0'   group is empty  '0' . '' (only the group flag is present)
//       '1'   group has data ' 1' . 'xxx...xxx' (both group flag and group data are present)
//
//       thus:
//          - the length of each data group is either 1 or 1 + (0 or 1) + group data length,
//          - '000' == the shortest non-empty target data string (all 3 groups are empty),
//          - e.g. if only target data group 0 (zero) data is present, the target data string format is:
//              '1' . 'nnnnn' . 'aaa...aaa,aaa...aaa,aaa...' . '0' . '0'
//          - the format of the longest target data string is shown in the following table:
//
//   field in string        length  field format
// -----------------------  ------  ------------...
//
// targ_grp_0_flag             1    0 .
//   targ_grp_0_count          1    n .
//   targ_submit_button_list  0+    aaaaaaaaaaaaaaaaaaaaaaaaaaaaaa . ... .
//
// targ_grp_0a_flag            1    0 .
//   targ_html_link_id        32    aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa .
//
// targ_grp_0b_flag            1    0 .
//   targ_src_script_id       0+    aaaaaaaaaaaa...aaaaaaaaaaaaaaa .
//
// targ_grp_1_flag             1    0 .
//   targ_status              10      nnnnnnnnnn .
//   targ_first_name          30      aaaaaaaaaaaaaaaaaaaaaaaaaaaaaa .
//   targ_last_name           30      aaaaaaaaaaaaaaaaaaaaaaaaaaaaaa .
//   (email addr len)          3      nnn (3 == TARG_SIZE_EMAIL_LEN)
//   targ_email_addr      1..320      aaaaaaaaaaaa...aaaaaaaaaaaaaaa .
//   targ_ref_by_member       10      nnnnnnnnnn .
//   targ_inf_by_advert       10      nnnnnnnnnn .
//   targ_reserve_coop_spot    1      0 .
//   targ_request_news_email   1      0 .
//   targ_block_email_login    1      0 .
// targ_grp_2_flag             1    0 .
//   targ_password            0+      xxxxxxxxxxxx...xxxxxxxxxxxxxxx
// -----------------------  ------  ------------...

// $session_target_data maximum length:
//
//   ses_targ_grp_0_len == 272
//   ==
//   1 +   // (flag0)
//   1 +   // (count0)
// 270     // submit button name list (max len == (9*30) (9 names * 30 chars)
//
//   ses_targ_grp_0a_len == 7
//   ==
//   1 +   // (flag0a)
//   6     // html link id (1st. 6 chars of random 32-digit hex number alpha-encoded 0..9, A..F)
////   ses_targ_grp_0a_len == 33
////   ==
////   1 +   // (flag0a)
////  32     // html link id (random 32-digit hex number alpha-encoded 0..9, A..F)
//
//   ses_targ_grp_0b_len == 31
//   ==
//   1 +   // (flag0b)
//  30     // source script id (string) e.g. 'eto_club_eto_act_1.php'.
//
//   ses_targ_grp_1_len == 424
//
//   ses_targ_grp_2_len ==  61
//   ==
//   1 +   // (flag2)
//  60     // password
//                        -----
//                     ==  795 (say 1,000)
////                     ==  785 (say 1,000)
////                     ==  811 (say 1,000)
//
// function usage ...
//
// initialize target data.
//   etoSQLinitTargData_session_www()
//
// atore target data values.
//   etoSQLputTargGrp0_session_www()  // user MUST call these functions EXPLICITELY,
//   etoSQLputTargGrp0a_session_www() //   to store target data values in:
//   etoSQLputTargGrp1_session_www()  //   target data context, data item buffer fields,
//   etoSQLputTargGrp2_session_www()  //   and in column buffer $session_target_data.
//
// store row in database.
//   etoSQLstmtWriteRow_session_www()   // these functions ONLY store,
//   etoSQLstmtReWriteRow_session_www() //  in the SQL database row,
//   etoSQLsetState_session_www()       //  the column buffer value $session_target_data.
// ... store row in database.
//
// retrieve target data values.
//   etoSQLgetTargData_session_www() // <= this function is AUTOMATICALLY called by
//   etoSQLreadRow_session_www()     // <=  this function.
//
// ... function usage.
//
// target data flow ...
//
//    CALL etoSQLputTargGrpX_session_www(...)
//                 |
//                 V
//           $ses_targ_X...       // TARGET DATA ITEM VALUE(S).
//                 |
//                 V
//        $ses_targ_grp_X_string  // TARGET DATA CONTEXT.
//                 |
//                 V
//        $session_target_data    // TARGET COLUMN BUFFER STRING.
//                 |
//                 V
//    CALL etoSQLgetTargData_session_www()
//                 |
//                 V
//        $ses_targ_grp_X_string  // TARGET DATA CONTEXT.
//                 |
//                 V
//           $ses_targ_X...       // TARGET DATA ITEM VALUE(S).
//
// ... target data flow.

const TARG_SIZE_INT       = 10; // Maximum possible PHP 32-bit (signed) integer VALUE == 2147483647.
const TARG_SIZE_NAME      = 30;
const TARG_SIZE_EMAIL     = 320;
const TARG_SIZE_EMAIL_LEN = 3;

// target data group contexts ...

// generalized handle into $session_target_data.
$ses_targ_handle_ndx = 0;
$ses_targ_handle_len = 0;

// target group ids.
const SES_TARG_GRP_0  = '0';
const SES_TARG_GRP_0a = '0a';
const SES_TARG_GRP_0b = '0b';
const SES_TARG_GRP_1  = '1';
const SES_TARG_GRP_2  = '2';
/* obsolete ...
const SES_TARG_GRP_0 = 0;
const SES_TARG_GRP_1 = 1;
const SES_TARG_GRP_2 = 2;
... obsolete. */

// target group 0 ...
$ses_targ_grp_0_flag   = false;
$ses_targ_grp_0_string = '';
$ses_targ_grp_0_count  = 0;
// $SES_TARG_GRP_0_LEN
// ... target group 0.

// target group 0a ...
$ses_targ_grp_0a_flag     = false;
$ses_targ_grp_0a_string   = '';
$SES_TARG_GRP_0a_LEN      = NAV_ID_CODE_SIZE;
// const SES_TARG_GRP_0a_LEN = 6; // == NAV_ID_CODE_SIZE (but php won't allow const value derined as const name)
// const SES_TARG_GRP_0a_LEN = 32;
// ... target group 0a.

// target group 0b...
const SCRIPT_NULL_CONTEXT  = '0';
const SCRIPT_CHECK_CONTEXT = '1';

$ses_targ_grp_0b_flag   = false;
$ses_targ_grp_0b_string = '';

// ... target group 0b.

// target group 1 ...
$ses_targ_grp_1_flag   = false;
$ses_targ_grp_1_string = '';

// obsolete ...
/*
$SES_TARG_GRP_1_LEN
=
(
   TARG_SIZE_INT +   // status.
   TARG_SIZE_NAME +  // first_name.
   TARG_SIZE_NAME +  // last_name.
   TARG_SIZE_EMAIL + // email_addr.
   TARG_SIZE_INT +   // ref_by_member.
   TARG_SIZE_INT +   // inf_by_advert.
   1 +               // reserve_coop_spot.
   1 +               // request_news_email.
   1                 // block_email_login.
);
*/
// ... obsolete.

$ses_targ_grp_1_len           = 0;
$ses_targ_grp_1_email_len     = 0;
$ses_targ_grp_1_email_len_str = '000';

// ... target group 1.

// target group 2 ...
$ses_targ_grp_2_flag   = false;
$ses_targ_grp_2_string = '';
// ... target group 2.

// ... target data group contexts.

// target data item velues ...                      // $ses_targ_grp...
                                                    // ----------------
$ses_targ_submit_button_ary  = array();             // _0
                                                    //
$ses_targ_html_link_id       = '';                  // 0a
                                                    //
$ses_targ_src_script_id      = '';                  // 0b
$ses_targ_src_context        = SCRIPT_NULL_CONTEXT; // 0b
                                                    //
$ses_targ_serno              = SQL_NUL_ROW_SERNO;   // _1
$ses_targ_status             = ROW_STATE_NULL;      // _1
$ses_targ_first_name         = '';                  // _1
$ses_targ_last_name          = '';                  // _1
$ses_targ_email_addr         = '';                  // _1
$ses_targ_ref_by_member      = 0;                   // _1
$ses_targ_inf_by_advert      = 0;                   // _1
$ses_targ_reserve_coop_spot  = false;               // _1
$ses_targ_request_news_email = false;               // _1
$ses_targ_block_email_login  = false;               // _1
                                                    //
$ses_targ_password           = '';                  // _2

// ... target data item values.

// ... eto_sql_tb_session_www table row, $session_target_data column buffer.

// $contact_privacy valid values.
const MSG_DISCLOSE_NULL      = 0; // disclosure setting - unknown.
const MSG_DISCLOSE_PUBLIC    = 1; // disclosure setting - public.
const MSG_DISCLOSE_ANONYMOUS = 2; // disclosure setting - anonymous.
const MSG_DISCLOSE_PRIVATE   = 3; // disclosure setting - private.

// message privacy text strings ...

$msg_disclose_text_ary
=
array
(
  MSG_DISCLOSE_NULL      => 'NONE PROVIDED',

  MSG_DISCLOSE_PUBLIC    => 'PUBLIC',
  MSG_DISCLOSE_ANONYMOUS => 'ANONYMOUS',
  MSG_DISCLOSE_PRIVATE   => 'PRIVATE'
);

// ... message privacy text strings.

/* pre-Club ETO version.
//  eto_sql_tb_contact_msg row buffer.
$contact_msg_serno    = '0'; // *** CAUTION *** Using STRING representation (mysqli_insert_id(...) returns string type if PHP int precision exceeded).
$contact_name         = '';
$contact_email_addr   = '';
$contact_msg_subject  = '';
$contact_verify_code  = '';
$contact_message      = '';
$contact_msg_init_utc = CRN_DTIME_0_UTC;
*/

//  eto_sql_tb_contact_msg row buffer.
$contact_msg_serno    = SQL_NUL_ROW_SERNO;
$contact_msg_status   = ROW_STATE_NULL;
$contact_session_code = '';
$contact_verify_code  = '';
$contact_source_serno = SQL_NUL_ROW_SERNO;
$contact_privacy      = MSG_DISCLOSE_NULL;
$contact_first_name   = '';
$contact_last_name    = '';
$contact_email_addr   = '';
$contact_msg_subject  = '';
$contact_message      = '';
$contact_msg_init_utc = CRN_DTIME_0_UTC;

//  eto_sql_tb_club_member row buffer.
$club_member_serno         = SQL_NUL_ROW_SERNO;
$member_status             = ROW_STATE_NULL;
$member_password           = '';
$member_session_code       = '';
$member_verify_code        = '';
$member_first_name         = '';
$member_last_name          = '';
$member_email_addr         = '';
$member_ref_by_member      = 0;
$member_inf_by_advert      = 0;
$member_reserve_coop_spot  = false;
$member_request_news_email = false;
$member_block_email_login  = false;
$club_member_init_utc      = CRN_DTIME_0_UTC;
$club_member_last_utc      = CRN_DTIME_0_UTC;
$club_member_expiry_utc    = CRN_DTIME_0_UTC;
$club_member_notified_utc  = CRN_DTIME_0_UTC;

// ... Table column variables.


// ... Common variables.

// Functions ...

// Access to ETO database ...

function etoSQLinitCall()
{
  global $sql_transaction_status;
  global $sql_transaction_status_type;

  global $sql_last_error;
  global $sql_last_error_type;

  global $sql_result_status_long;
  global $sql_result_status_long_type;

  global $sql_result_status_string;
  global $sql_result_status_string_type;

  global $sql_state;
  global $sql_state_type;
  global $sql_state_class;

  global $sql_state_proxy;
  global $sql_state_class_proxy;

  global $sql_result;
  global $sql_result_type;

  global $sql_row_count;
  global $sql_afec_row_count;

  global $sql_fetch;
  global $sql_fetch_coun;
 
  global $sql_diag; 
  global $sql_result_error_field_str;

  $sql_transaction_status      = -1;
  $sql_transaction_status_type = '';

  $sql_last_error      = '';
  $sql_last_error_type = '';
  
  $sql_result_status_long      = '';
  $sql_result_status_long_type = '';

  $sql_result_status_string      = '';
  $sql_result_status_string_type = '';

  $sql_state       = '';
  $sql_state_type  = '';
  $sql_state_class = '';

  $sql_state_proxy       = '';
  $sql_state_class_proxy = '';
  
  $sql_result      = false;
  $sql_result_type = '';

  $sql_row_count      = false;
  $sql_afec_row_count = false;

  $sql_fetch       = '';
  $sql_fetch_count = false;

  $sql_diag                   = ''; 
  $sql_result_error_field_str = '';

  return;
}

// Access to ETO database ...

function etoSQLgetStatusVars()
{
  global $sql_connection_status;

  global $sql_state;

  global $sql_last_error;
  global $sql_result_error;

  global $sql_result_status_long;
  global $sql_result_status_string;

  global $sql_query;
  global $sql_row_count;
  global $sql_afec_row_count;

  global $sys_log_line_end;

  $tmp_sql_db = SQL_DB;

  return
  (
     addcslashes
     (
        etoExit_sys_log_indent_det
        (
           '##etoSQLgetStatusVars()<'
        ) .

           "\$sql_connection_status<" . $sql_connection_status . '> ' .

           "SQL_DB<"      . $tmp_sql_db . '> ' .
           "\$sql_state<" . $sql_state  . '> ' .

           "\$sql_last_error<"   . $sql_last_error   . '> ' .
           "\$sql_result_error<" . $sql_result_error . '> ' .

           "\$sql_result_status_long<"   . $sql_result_status_long   . '> ' .
           "\$sql_result_status_string<" . $sql_result_status_string . '> ' .

           "\$sql_query<"          . $sql_query          . '> ' .
           "\$sql_row_count<"      . $sql_row_count      . '> ' .
           "\$sql_afec_row_count<" . $sql_afec_row_count . '>'  .

        '>',

         "\\\t\n\v\f\r"
      )
  );
}

/*
function etoSQLgetStatusVars()
{
  global $sql_errno;
  global $sql_error;
  global $sql_state;

  global $sql_query;
  global $sql_row_count;
  global $sql_afec_row_count;

  global $sys_log_line_end;

  $tmp_sql_db = SQL_DB;

  return
  (
     addcslashes
     (
        etoExit_sys_log_indent_det
        (
           '##etoSQLgetStatusVars()<'
        ) .

           "SQL_DB<"               . $tmp_sql_db         . '> ' .

           "\$sql_errno<"          . $sql_errno          . '> ' .
           "\$sql_error<"          . $sql_error          . '> ' .
           "\$sql_state<"          . $sql_state          . '> ' .

           "\$sql_query<"          . $sql_query          . '> ' .
           "\$sql_row_count<"      . $sql_row_count      . '> ' .
           "\$sql_afec_row_count<" . $sql_afec_row_count . '>'  .

        '>',

         "\\\t\n\v\f\r"
      )
  );
}
*/

function etoSQLinitBuff_session_www()
{

  global $session_www_code;
  global $session_www_type;
  global $session_www_state;
  global $session_verify_code;
  global $session_www_serno;
  global $session_target_serno;
  global $session_target_data;
  global $session_www_init_utc;
  global $session_www_last_utc;
  global $session_www_expiry_utc;
  global $session_www_delete_utc;
  global $session_www_hit_count;
  global $session_www_act_seqno;

//  eto_sql_tb_session_www row buffer.
  $session_www_code       = '';
  $session_www_type       = 0;
  $session_www_state      = ROW_STATE_NULL;
  $session_verify_code    = '';
  $session_www_serno      = SQL_NUL_ROW_SERNO;
  $session_target_serno   = SQL_NUL_ROW_SERNO;
  $session_target_data    = '';
  $session_www_init_utc   = CRN_DTIME_0_UTC;
  $session_www_last_utc   = CRN_DTIME_0_UTC;
  $session_www_expiry_utc = CRN_DTIME_0_UTC;
  $session_www_delete_utc = CRN_DTIME_0_UTC;
  $session_www_hit_count  = 0;
  $session_www_act_seqno  = 0;

  etoSQLgetTargData_session_www();

  return;
}

function etoSQLinitBuff_club_member()
{
	global $club_member_serno;
	global $member_status;
	global $member_password;
   global $member_session_code;
   global $member_verify_code;
   global $member_first_name;
   global $member_last_name;
   global $member_email_addr;
   global $member_ref_by_member;
   global $member_inf_by_advert;
   global $member_reserve_coop_spot;
   global $member_request_news_email;
   global $member_block_email_login;
   global $club_member_init_utc;
   global $club_member_last_utc;
   global $club_member_expiry_utc;
   global $club_member_notified_utc;

//  eto_sql_tb_club_member row buffer.
   $club_member_serno         = SQL_NUL_ROW_SERNO;
   $member_status             = ROW_STATE_NULL;
   $member_password           = '';
   $member_session_code       = '';
   $member_verify_code        = '';
   $member_first_name         = '';
   $member_last_name          = '';
   $member_email_addr         = '';
   $member_ref_by_member      = 0;
   $member_inf_by_advert      = 0;
   $member_reserve_coop_spot  = false;
   $member_request_news_email = false;
   $member_block_email_login  = false;
   $club_member_init_utc      = CRN_DTIME_0_UTC;
   $club_member_last_utc      = CRN_DTIME_0_UTC;
   $club_member_expiry_utc    = CRN_DTIME_0_UTC;
   $club_member_notified_utc  = CRN_DTIME_0_UTC;

  return;
}

function etoSQLgetRowBuf_session_www()
{
  global $session_www_code;
  global $session_www_type;
  global $session_www_state;
  global $session_verify_code;
  global $session_www_serno;
  global $session_target_serno;
  global $session_target_data;
  global $session_www_init_utc;
  global $session_www_last_utc;
  global $session_www_expiry_utc;
  global $session_www_delete_utc;
  global $session_www_hit_count;
  global $session_www_act_seqno;

  global $sys_log_line_end;

  return
  (
     addcslashes
     (
        etoExit_sys_log_indent_det
        (
        '   ##etoSQLgetRowBuf_session_www()<'
        ) .

        "\$session_www_code<"       . $session_www_code . '> ' .
        "\$session_www_type<"       . $session_www_type . '> ' .
        "\$session_www_state<"      . $session_www_state . '> ' .

        "\$session_verify_code<"    . $session_verify_code . '> ' .
        "\$session_www_serno<"      . $session_www_serno . '> ' .
        "\$session_target_serno<"   . $session_target_serno . '> ' .
        "\$session_target_data<"    . $session_target_data . '> ' .

        "\$session_www_init_utc<"   . $session_www_init_utc . '> ' .
        "\$session_www_last_utc<"   . $session_www_last_utc . '> ' .
        "\$session_www_expiry_utc<" . $session_www_expiry_utc . '> ' .
        "\$session_www_delete_utc<" . $session_www_delete_utc . '> ' .
        "\$session_www_hit_count<"  . $session_www_hit_count . '> ' .
        "\$session_www_act_seqno<"  . $session_www_act_seqno . '>' .

        '>',

         "\\\t\n\v\f\r"
     )
  );
}

function etoSQLinitTargData_session_www()
{
   global $session_target_data;

// initialize the target data string as null.
   $session_target_data = '';

// refresh the target data "get" buffer.
   etoSQLgetTargData_session_www();

   return;
}

function etoSQLputTargData_session_www()
{
   global $session_target_data;

   global $ses_targ_grp_0_flag;
   global $ses_targ_grp_0_string;
   global $ses_targ_grp_0_count;

   global $ses_targ_grp_0a_flag;
   global $ses_targ_grp_0a_string;

   global $ses_targ_grp_0b_flag;
   global $ses_targ_grp_0b_string;

   global $ses_targ_grp_1_flag;
   global $ses_targ_grp_1_string;

   global $ses_targ_grp_2_flag;
   global $ses_targ_grp_2_string;

   $tmp_grp_0_count_str = (string)$ses_targ_grp_0_count;
   $tmp_grp_0_count_str = substr($tmp_grp_0_count_str, (strlen($tmp_grp_0_count_str) - 1), 1);

   $session_target_data
   =
   (
      (
         ($ses_targ_grp_0_flag)
         ?
         ('1' . $tmp_grp_0_count_str . $ses_targ_grp_0_string)
         :
         ('0')
      )
      .
      (
         ((($ses_targ_grp_0a_flag) ? '1' : '0') . $ses_targ_grp_0a_string)
      )
      .
      (
         ((($ses_targ_grp_0b_flag) ? '1' : '0') . $ses_targ_grp_0b_string)
      )
      .
      (
         ((($ses_targ_grp_1_flag)  ? '1' : '0') . $ses_targ_grp_1_string)
      )
      .
      (
         ((($ses_targ_grp_2_flag)  ? '1' : '0') . $ses_targ_grp_2_string)
      )
   );

   return;
}

function etoSQLputTargGrp0_session_www($ba) // array of arrays of submit button name(s).
{
//       *** WARNING ***
//
// THERE IS NO PARAMETER CHECKING !!!
//
// The caller is responsible for ensuring that:
//  - there are from 1 to 9 string entries in total in the array,
//  - each string entry from 1 to TARG_SIZE_NAME in length.
//
//  See variable $htm_submit_buttons_ary in module eto_session_ssi_0.php, for array synamic structure.
//

   global $ses_targ_grp_0_flag;
   global $ses_targ_grp_0_string;
   global $ses_targ_grp_0_count;

   global $ses_targ_submit_button_ary;

   $ses_targ_grp_0_flag = false;

   $ses_targ_grp_0_string = '';
   $ses_targ_grp_0_count  = 0;

   $ses_targ_submit_button_ary = array();

// create the group 0 string ...
   $tmp_button_line_count = count($ba);

   for ($i = 0; $i < $tmp_button_line_count; $i++)
   {
      $ses_targ_grp_0_flag = true;

      $tmp_button_count = count($ba[$i]);

      for ($j = 0; $j < $tmp_button_count; $j++)
      {
         $tmp_button_name = $ba[$i][$j];

         $ses_targ_grp_0_string        .= str_pad($tmp_button_name, TARG_SIZE_NAME, ' ');
         $ses_targ_submit_button_ary[]  = $tmp_button_name;

         ++$ses_targ_grp_0_count;
      }
   }
// ... create the group 0 string.

// refresh target data string.
   etoSQLputTargData_session_www();

   return;
}

function etoSQLputTargGrp0a_session_www($lk) // html link id.
{
   global $ses_targ_grp_0a_flag;
   global $ses_targ_grp_0a_string;

   global $ses_targ_html_link_id;

   $ses_targ_grp_0a_flag  = true;

   $ses_targ_html_link_id = $lk;

// create the group 0a string.
   $ses_targ_grp_0a_string = $ses_targ_html_link_id;

// refresh target data string.
   etoSQLputTargData_session_www();

   return;
}

function etoSQLputTargGrp0b_session_www($si = '', $sc = SCRIPT_NULL_CONTEXT) // source script id (string), source context (string).
{
   global $ses_targ_grp_0b_flag;
   global $ses_targ_grp_0b_string;

   global $ses_targ_src_script_id;
   global $ses_targ_src_context;

   $ses_targ_grp_0b_flag = true;

// store the data values ...

   $ses_targ_src_script_id
   =
   (strlen($si) > TARG_SIZE_NAME)
   ? substr($si, 0, TARG_SIZE_NAME)
   : $si;

   $ses_targ_src_context
   =
   (strlen($sc) > 1)
   ? substr($sc, 0, 1)
   : $sc;

// ... store the data values.

// create the group 0b string).
   $ses_targ_grp_0b_string
   =
   (
      str_pad($ses_targ_src_script_id, TARG_SIZE_NAME, ' ')
      .
      $ses_targ_src_context
   );

// refresh target data string.
   etoSQLputTargData_session_www();

   return;
}

function etoSQLtargGrp1_lengths($el) // email addr len (int).
{
   global $ses_targ_grp_1_len;
   global $ses_targ_grp_1_email_len;
   global $ses_targ_grp_1_email_len_str;

   $ses_targ_grp_1_email_len = $el;

// email_addr len ...
   $ses_targ_grp_1_email_len_str =(string)$ses_targ_grp_1_email_len;
   (strlen($ses_targ_grp_1_email_len_str) < TARG_SIZE_EMAIL_LEN) ? ($ses_targ_grp_1_email_len_str = str_pad($ses_targ_grp_1_email_len_str, TARG_SIZE_EMAIL_LEN, '0', STR_PAD_LEFT)) : false; // pad to TARG_SIZE_EMAIL_LEN.

   $ses_targ_grp_1_email_len_str = substr($ses_targ_grp_1_email_len_str, (strlen($ses_targ_grp_1_email_len_str) - TARG_SIZE_EMAIL_LEN)); // defensive programming (should NEVER exceed TARG_SIZE_EMAIL_LEN digits).
// ... email_addr len.

// length of entire group 1 ...
   $ses_targ_grp_1_len
   =
   (
      TARG_SIZE_INT  + // serno.
      TARG_SIZE_INT  + // status.
      TARG_SIZE_NAME + // first_name.
      TARG_SIZE_NAME + // last_name.
      TARG_SIZE_EMAIL_LEN +       // email_addr len.
      $ses_targ_grp_1_email_len + // email_addr.
      TARG_SIZE_INT + // ref_by_member.
      TARG_SIZE_INT + // inf_by_advert.
      1 +             // reserve_coop_spot.
      1 +             // request_news_email.
      1               // block_email_login.
   );
// ... length of entire group 1.

   return;
}

function etoSQLputTargGrp1_session_www($tn, $ts, $tf, $tl, $te, $tm, $ta, $tc, $tw, $tb) // serno(int),  status(int), first name(string), last name(string), email addr(string), ref by member(int), inf by advert(int), reserve coop spot(bool), request news email(bool), block email login(bool).
//function etoSQLputTargGrp1_session_www($ts, $tf, $tl, $te, $tm, $ta, $tc, $tn, $tb) // status(int), first name(string), last name(string), email addr(string), ref by member(int), inf by advert(int), reserve coop spot(bool), request news email(bool), block email login(bool).
{
   global $ses_targ_grp_1_flag;
   global $ses_targ_grp_1_string;
   global $ses_targ_grp_1_len;
   global $ses_targ_grp_1_email_len;
   global $ses_targ_grp_1_email_len_str;

   global $ses_targ_serno;
   global $ses_targ_status;
   global $ses_targ_first_name;
   global $ses_targ_last_name;
   global $ses_targ_email_addr;
   global $ses_targ_ref_by_member;
   global $ses_targ_inf_by_advert;
   global $ses_targ_reserve_coop_spot;
   global $ses_targ_request_news_email;
   global $ses_targ_block_email_login;

   $ses_targ_grp_1_flag = true;

   $ses_targ_serno              = $tn;
   $ses_targ_status             = $ts;
   $ses_targ_first_name         = $tf;
   $ses_targ_last_name          = $tl;
   $ses_targ_email_addr         = $te;
   $ses_targ_ref_by_member      = $tm;
   $ses_targ_inf_by_advert      = $ta;
   $ses_targ_reserve_coop_spot  = $tc;
   $ses_targ_request_news_email = $tw;
   $ses_targ_block_email_login  = $tb;

   etoSQLtargGrp1_lengths(strlen($te));

// create the group 1 string.
   $ses_targ_grp_1_string
   =
   (
      str_pad((string)$ses_targ_serno,         TARG_SIZE_INT,   '0', STR_PAD_LEFT) . //    serno.
      str_pad((string)$ses_targ_status,        TARG_SIZE_INT,   '0', STR_PAD_LEFT) . //    status.
      str_pad($ses_targ_first_name,            TARG_SIZE_NAME,  ' ') .               //    first_name.
      str_pad($ses_targ_last_name,             TARG_SIZE_NAME,  ' ') .               //    last_name.

      $ses_targ_grp_1_email_len_str .                                                //    email_addr len.
      $ses_targ_email_addr .                                                         //    email_addr.

      str_pad((string)$ses_targ_ref_by_member, TARG_SIZE_INT,   '0', STR_PAD_LEFT) . //    ref_by_member.
      str_pad((string)$ses_targ_inf_by_advert, TARG_SIZE_INT,   '0', STR_PAD_LEFT) . //    inf_by_advert.
      (($ses_targ_reserve_coop_spot)  ? '1' : '0') .                                 //    reserve_coop_spot.
      (($ses_targ_request_news_email) ? '1' : '0') .                                 //    request_news_email.
      (($ses_targ_block_email_login)  ? '1' : '0')                                   //    block_email_login.
   );

// refresh target data string.
   etoSQLputTargData_session_www();

   return;
}

function etoSQLputTargGrp2_session_www($tp) // password.
{
   global $ses_targ_grp_2_flag;
   global $ses_targ_grp_2_string;

   global $ses_targ_password;

   $ses_targ_grp_2_flag = true;

   $ses_targ_password = $tp;

// create the group 2 string.
   $ses_targ_grp_2_string = $ses_targ_password;

// refresh target data string.
   etoSQLputTargData_session_www();

   return;
}

function etoSQLnullTargHandle_session_www()
{
   global $ses_targ_handle_ndx;
   global $ses_targ_handle_len;

   $ses_targ_handle_ndx = 0;
   $ses_targ_handle_len = 0;

   return;
}

function etoSQLgetTargHandle_session_www($g) // data group id no.
{
//       *** WARNING ***
//
//  CALLER MUST CHECK RETURN VALUE !!!
//         ----
//
//  To determine if handle valid
//   (true == valid, false == invalid),
//   before using handle
//   to access $session_target_data.
//
//   ($ses_targ_handle_len == 0)
//    also indicates invalid handle.
//
   global $SES_TARG_GRP_0a_LEN;

   global $session_target_data;

   global $ses_targ_handle_ndx;
   global $ses_targ_handle_len;

   global $ses_targ_grp_1_len;

// null target data string?
   if ($session_target_data == '')
// yes - null target data string.
   {
      etoSQLnullTargHandle_session_www();
   }
   else
// no - NOT null target data string.
   {
// group 0 ...

//     point to group 0.
       $ses_targ_handle_ndx = 0;

//     group 0 data in target data string?
       if ($session_target_data[$ses_targ_handle_ndx++] == '1')
//     yes - group 0 data in target data string.
       {
          $ses_targ_handle_len
          =
          (
             (
               (int)($session_target_data[$ses_targ_handle_ndx++]) // count of button names.
             )
             *
             TARG_SIZE_NAME
          );
       }
       else
//     no - NO group 0 data in target data string.
       {
          $ses_targ_handle_len = 0;
       }

// ... group 0.

//     NOT group 0 parm?
       if
       ($g != SES_TARG_GRP_0)
//     yes - NOT group 0 parm.
       {
//        point to group 0a.
          $ses_targ_handle_ndx += $ses_targ_handle_len;

//        group 0a data in target data string?
          if ($session_target_data[$ses_targ_handle_ndx++] == '1')
//        yes - group 0a data in target data string.
          {
             $ses_targ_handle_len = $SES_TARG_GRP_0a_LEN;
//           $ses_targ_handle_len = SES_TARG_GRP_0a_LEN;
          }
          else
//        no - NO group 0a data in target data string.
          {
             $ses_targ_handle_len = 0;
          }

//        NOT group 0a parm?
          if
          ($g != SES_TARG_GRP_0a)
//        yes - NOT group 0a parm.
          {
//           point to group 0b.
             $ses_targ_handle_ndx += $ses_targ_handle_len;

//           group 0b data in target data string?
             if ($session_target_data[$ses_targ_handle_ndx++] == '1')
//           yes - group 0b data in target data string.
             {
                $ses_targ_handle_len = (TARG_SIZE_NAME + 1);
             }
             else
//           no - NO group 1 data in target data string.
             {
                $ses_targ_handle_len = 0;
             }

//           NOT group 0b parm?
             if
             ($g != SES_TARG_GRP_0b)
//           yes - NOT group 0b parm.
             {
//              point to group 1.
                $ses_targ_handle_ndx += $ses_targ_handle_len;
             
//              group 1 data in target data string?
                if ($session_target_data[$ses_targ_handle_ndx++] == '1')
//              yes - group 1 data in target data string.
                {
                   etoSQLtargGrp1_lengths
                   (
//                    parse out the email length string.
                      (int)
                      substr
                      (
                         $session_target_data,
             
                         (
                            $ses_targ_handle_ndx + // 1st. char.
                            TARG_SIZE_INT +        // serno.
                            TARG_SIZE_INT +        // status.
                            TARG_SIZE_NAME +       // first_name.
                            TARG_SIZE_NAME         // last_name.
                         ),
             
                         TARG_SIZE_EMAIL_LEN
                      )
                   );
             
                   $ses_targ_handle_len = $ses_targ_grp_1_len;
                }
                else
//              no - NO group 1 data in target data string.
                {
                   $ses_targ_handle_len = 0;
                }
             
//              NOT group 1 parm?
                if
                ($g != SES_TARG_GRP_1)
//              yes - NOT group 1 parm.
                {
//                 group 2 handle parm?
                   if ($g == SES_TARG_GRP_2)
//                 yes - group 2 parm.
                   {
//                    point to group 2
                      $ses_targ_handle_ndx += $ses_targ_handle_len;
             
//                    group 2 data in target data string?
                      if ($session_target_data[$ses_targ_handle_ndx++] == '1')
//                    yes - group 2 data in target data string.
                      {
                         $ses_targ_handle_len = (strlen($session_target_data) - $ses_targ_handle_ndx);
                      }
                      else
//                    no - NO group 2 data in target data string.
                      {
                         $ses_targ_handle_len = 0;
                      }
                   }
                   else
//                 no - NOT group 2 -- INvalid group id parm.
                   {
                      etoSQLnullTargHandle_session_www();
                   }
                }
             }
          }
       }
   }

   return (($ses_targ_handle_len) ? true : false);
}

function etoSQLgetNullTargGrp0_session_www()
{
   global $ses_targ_grp_0_flag;
   global $ses_targ_grp_0_string;
   global $ses_targ_grp_0_count;

   global $ses_targ_submit_button_ary;

   $ses_targ_grp_0_flag   = false;
   $ses_targ_grp_0_string = '';
   $ses_targ_grp_0_count  = 0;

   $ses_targ_submit_button_ary = array();

   return;
}

function etoSQLgetTargGrp0_session_www()
{
   global $session_target_data;

   global $ses_targ_handle_ndx;
   global $ses_targ_handle_len;

   global $ses_targ_grp_0_flag;
   global $ses_targ_grp_0_string;
   global $ses_targ_grp_0_count;

   global $ses_targ_submit_button_ary;

// is there group 0 data?
   if (etoSQLgetTargHandle_session_www(SES_TARG_GRP_0))
// yes - there is group 0 data.
   {
      $ses_targ_grp_0_flag = true;

//    fetch group 0 data string.
      $ses_targ_grp_0_string = substr($session_target_data, $ses_targ_handle_ndx, $ses_targ_handle_len);

//    fetch data items ...
      $ses_targ_submit_button_ary = array();

      for
      (
         $tmp_ndx = 0;

         $tmp_ndx < $ses_targ_handle_len;

         $tmp_ndx += TARG_SIZE_NAME
      )
      {
         $ses_targ_submit_button_ary[rtrim(substr($ses_targ_grp_0_string, $tmp_ndx, TARG_SIZE_NAME))] = '';
      }
//    ...fetch data items.

      $ses_targ_grp_0_count = count($ses_targ_submit_button_ary);
   }
   else
// no - there is NO group 0 data.
   {
      etoSQLgetNullTargGrp0_session_www();
   }

   return;
}

function etoSQLgetNullTargGrp0a_session_www()
{
   global $ses_targ_grp_0a_flag;
   global $ses_targ_grp_0a_string;

   global $ses_targ_html_link_id;

   $ses_targ_grp_0a_flag   = false;
   $ses_targ_grp_0a_string = '';

   $ses_targ_html_link_id = $ses_targ_grp_0a_string;

   return;
}

function etoSQLgetTargGrp0a_session_www()
{
   global $session_target_data;

   global $ses_targ_handle_ndx;
   global $ses_targ_handle_len;

   global $ses_targ_grp_0a_flag;
   global $ses_targ_grp_0a_string;

   global $ses_targ_html_link_id;

// is there group 0 data?
   if (etoSQLgetTargHandle_session_www(SES_TARG_GRP_0a))
// yes - there is group 0 data.
   {
      $ses_targ_grp_0a_flag = true;

//    fetch group 0a data string.
      $ses_targ_grp_0a_string = substr($session_target_data, $ses_targ_handle_ndx, $ses_targ_handle_len);
   }
   else
// no - there is NO group 0 data.
   {
      etoSQLgetNullTargGrp0a_session_www();
   }

   $ses_targ_html_link_id = $ses_targ_grp_0a_string;

   return;
}

function etoSQLgetNullTargGrp0b_session_www()
{
   global $ses_targ_grp_0b_flag;
   global $ses_targ_grp_0b_string;

   global $ses_targ_src_script_id;
   global $ses_targ_src_context;

   $ses_targ_grp_0b_flag   = false;
   $ses_targ_grp_0b_string = '';

   $ses_targ_src_script_id = '';
   $ses_targ_src_context   = SCRIPT_NULL_CONTEXT;

   return;
}

function etoSQLgetTargGrp0b_session_www()
{
   global $session_target_data;

   global $ses_targ_handle_ndx;
   global $ses_targ_handle_len;

   global $ses_targ_grp_0b_flag;
   global $ses_targ_grp_0b_string;

   global $ses_targ_src_script_id;
   global $ses_targ_src_context;

// is there group 0b data?
   if (etoSQLgetTargHandle_session_www(SES_TARG_GRP_0b))
// yes - there is group 0b data.
   {
      $ses_targ_grp_0b_flag = true;

//    fetch group 0b data string.
      $ses_targ_grp_0b_string = substr($session_target_data, $ses_targ_handle_ndx, $ses_targ_handle_len);

//    fetch data items ...
      $tmp_grp_0b_ndx         = 0;
      $ses_targ_src_script_id = rtrim(substr($ses_targ_grp_0b_string, $tmp_grp_0b_ndx, TARG_SIZE_NAME));

      $tmp_grp_0b_ndx         += TARG_SIZE_NAME;
      $ses_targ_src_context   = substr($ses_targ_grp_0b_string, $tmp_grp_0b_ndx, 1);
//    ... fetch data items.
   }
   else
// no - there is NO group 0b data.
   {
      etoSQLgetNullTargGrp0b_session_www();
   }

   return;
}

function etoSQLgetNullTargGrp1_session_www()
{
   global $ses_targ_grp_1_flag;
   global $ses_targ_grp_1_string;
   global $ses_targ_grp_1_len;
   global $ses_targ_grp_1_email_len;
   global $ses_targ_grp_1_email_len_str;

   global $ses_targ_serno;
   global $ses_targ_status;
   global $ses_targ_first_name;
   global $ses_targ_last_name;
   global $ses_targ_email_addr;
   global $ses_targ_ref_by_member;
   global $ses_targ_inf_by_advert;
   global $ses_targ_reserve_coop_spot;
   global $ses_targ_request_news_email;
   global $ses_targ_block_email_login;

   $ses_targ_grp_1_flag          = false;
   $ses_targ_grp_1_string        = '';
   $ses_targ_grp_1_len           = 0;
   $ses_targ_grp_1_email_len     = 0;
   $ses_targ_grp_1_email_len_str = '000';

   $ses_targ_serno              = SQL_NUL_ROW_SERNO;
   $ses_targ_status             = ROW_STATE_NULL;
   $ses_targ_first_name         = '';
   $ses_targ_last_name          = '';
   $ses_targ_email_addr         = '';
   $ses_targ_ref_by_member      = 0;
   $ses_targ_inf_by_advert      = 0;
   $ses_targ_reserve_coop_spot  = false;
   $ses_targ_request_news_email = false;
   $ses_targ_block_email_login  = false;

   return;
}

function etoSQLgetTargGrp1_session_www()
{
   global $session_target_data;

   global $ses_targ_handle_ndx;
   global $ses_targ_handle_len;

   global $ses_targ_grp_1_flag;
   global $ses_targ_grp_1_string;
   global $ses_targ_grp_1_email_len;

   global $ses_targ_serno;
   global $ses_targ_status;
   global $ses_targ_first_name;
   global $ses_targ_last_name;
   global $ses_targ_email_addr;
   global $ses_targ_ref_by_member;
   global $ses_targ_inf_by_advert;
   global $ses_targ_reserve_coop_spot;
   global $ses_targ_request_news_email;
   global $ses_targ_block_email_login;

// is there group 1 data?
   if (etoSQLgetTargHandle_session_www(SES_TARG_GRP_1))
// yes - there is group 1 data.
   {
      $ses_targ_grp_1_flag = true;

//    fetch group 1 data string.
      $ses_targ_grp_1_string = substr($session_target_data, $ses_targ_handle_ndx, $ses_targ_handle_len);

//    fetch data items ...
      $tmp_grp_1_ndx               = 0;
      $ses_targ_serno              = (int) substr($ses_targ_grp_1_string, $tmp_grp_1_ndx, TARG_SIZE_INT);

      $tmp_grp_1_ndx               += TARG_SIZE_INT;
      $ses_targ_status             = (int) substr($ses_targ_grp_1_string, $tmp_grp_1_ndx, TARG_SIZE_INT);

      $tmp_grp_1_ndx               += TARG_SIZE_INT;
      $ses_targ_first_name         = rtrim(substr($ses_targ_grp_1_string, $tmp_grp_1_ndx, TARG_SIZE_NAME));

      $tmp_grp_1_ndx               += TARG_SIZE_NAME;
      $ses_targ_last_name          = rtrim(substr($ses_targ_grp_1_string, $tmp_grp_1_ndx, TARG_SIZE_NAME));

      $tmp_grp_1_ndx               += TARG_SIZE_NAME + TARG_SIZE_EMAIL_LEN;

      $ses_targ_email_addr         = substr($ses_targ_grp_1_string, $tmp_grp_1_ndx, $ses_targ_grp_1_email_len);

      $tmp_grp_1_ndx               += $ses_targ_grp_1_email_len;
      $ses_targ_ref_by_member      = (int) substr($ses_targ_grp_1_string, $tmp_grp_1_ndx, TARG_SIZE_INT);

      $tmp_grp_1_ndx               += TARG_SIZE_INT;
      $ses_targ_inf_by_advert      = (int) substr($ses_targ_grp_1_string, $tmp_grp_1_ndx, TARG_SIZE_INT);

      $tmp_grp_1_ndx               += TARG_SIZE_INT;
      $ses_targ_reserve_coop_spot  = ((substr($ses_targ_grp_1_string, $tmp_grp_1_ndx, 1) == '0') ? false : true);

      $tmp_grp_1_ndx               += 1;
      $ses_targ_request_news_email = ((substr($ses_targ_grp_1_string, $tmp_grp_1_ndx, 1) == '0') ? false : true);

      $tmp_grp_1_ndx               += 1;
      $ses_targ_block_email_login  = ((substr($ses_targ_grp_1_string, $tmp_grp_1_ndx, 1) == '0') ? false : true);
//    ... fetch data items.
   }
   else
// no - group 1 data NOT in target data string.
   {
      etoSQLgetNullTargGrp1_session_www();
   }

   return;
}

function etoSQLgetNullTargGrp2_session_www()
{
   global $ses_targ_grp_2_flag;
   global $ses_targ_grp_2_string;

   global $ses_targ_password;

   $ses_targ_grp_2_flag   = false;
   $ses_targ_grp_2_string = '';

   $ses_targ_password = '';

   return;
}

function etoSQLgetTargGrp2_session_www()
{
   global $session_target_data;

   global $ses_targ_handle_ndx;
   global $ses_targ_handle_len;

   global $ses_targ_grp_2_flag;
   global $ses_targ_grp_2_string;

   global $ses_targ_password;

// is there group 2 data?
   if (etoSQLgetTargHandle_session_www(SES_TARG_GRP_2))
// yes - group 2 data in target data string.
   {
      $ses_targ_grp_2_flag = true;

//    fetch group 2 data string.
      $ses_targ_grp_2_string = substr($session_target_data, $ses_targ_handle_ndx, $ses_targ_handle_len);

//    fetch data item (does NOT truncate trailing whitespace).
      $ses_targ_password = $ses_targ_grp_2_string;
   }
   else
// no - group 2 data NOT in target data string.
   {
      etoSQLgetNullTargGrp2_session_www();
   }

   return;
}

function etoSQLgetTargData_session_www()
{
   etoSQLgetTargGrp0_session_www();
   etoSQLgetTargGrp0a_session_www();
   etoSQLgetTargGrp0b_session_www();
   etoSQLgetTargGrp1_session_www();
   etoSQLgetTargGrp2_session_www();

   return;
}

function etoSQLtickTockExp_session_www($st0) // session expiry delta time.
{
  global $crn_dtime_utc;

  return (addSecs($crn_dtime_utc, ($st0 * 60))); // convert mins to secs.
}

function etoSQLtickTockDel_session_www($st0, $st1) // session expiry delta time, session delete delta time.
{
  global $crn_dtime_utc;

  return (addSecs($crn_dtime_utc, (($st0 + $st1) * 60))); // convert mins to secs.
}

function etoSQLtickTockSet_session_www($st0, $st1) // session expiry delta time, session delete delta time.
{
  global $session_www_expiry_utc;
  global $session_www_delete_utc;

// Set session expiry time.
  $session_www_expiry_utc = etoSQLtickTockExp_session_www($st0);

// Set session delete time.
  $session_www_delete_utc = etoSQLtickTockDel_session_www($st0, $st1);

   return;
}

function etoSQLhashSeqnoDate_session_www($sq, $dt) // session action seq no (int), date/time (in ISO 'yyyy-mm-dd hh:mm:ss' format):
{
// Compute a repeatable hash of:
//
//   -- session action seq no (int), and
//   -- session initiation data/time (UTC/GMT).
//
// *** NOTE ***
//
// See comment re: mt_rand() - not guaranteed to repeat same sequence of pseudo-random numbers when same seed value used.
//
//   "In some cases it is necessary to be able to create same sequence of pseudo-random numbers. E.g. to run repeatable simulation run with different parameters. Since php 5.2.1 it is not possible even using same seed in mt_srand function. For such cases use srand instead.".
//     (Joe posting in www.php.net -- function.mt-srand - 20130130.htm);
//
// See comment re: srand() and mt_srand() -  not guaranteed to repeat same sequence of pseudo-random numbers when same seed value used.
//
//    "Keep in mind that the Suhosin patch which is installed by default on many PHP-installs such as Debian and DirectAdmin completely disables the srand and mt_srand functions for encryption security reasons. To generate reproducible random numbers from a fixed seed on a Suhosin-hardened server you will need to include your own pseudorandom generator code." by "Niels Keurentjes"
//      (in php.net -- function.srand - 20130208.htm);
//

   return
   (
      substr
      (
         strtoupper
         (
            md5
            (
               ((string) $sq)
               .
               ((string) etoDateSum($dt))
            )
         ),

         0,

         NAV_ID_CODE_SIZE
      )

//    strtoupper
//    (
//       md5
//       (
//          ((string) $sq)
//          .
//          ((string) etoDateSum($dt))
//       )
//    )
   );
}

function etoSQLsetPostgresErrorVerbosity($vb) // error verbosity.
{
  global $sql_conn;

  global $sql_error_verbosity;

  $sql_error_verbosity = $vb;

  pg_set_error_verbosity($sql_conn, $sql_error_verbosity);

  return;
}

function etoSQLgetPostgresStateClass()
{
  global $sql_state;

  return ((strlen($sql_state) > 1) ? substr($sql_state, 0, 2) : '');
}

/*
function etoSQLgetMysqliStateClass()
{
  global $sql_state;

  return ((strlen($sql_state) > 1) ? substr($sql_state, 0, 2) : '');
}
*/

function etoSQLgetPostgresSqlState($ac, $xo, $ro) // abend code, abend exit option, abend SQL rollback option.
{
  global $sql_result;

  global $sql_state;
  global $sql_state_type;
  global $sql_state_class;

  global $sql_state_proxy;
  global $sql_state_class_proxy;

//  global $sys_exit_code; // $ac mapping: ($ac+0) ... ($ac+2) => 3 slots.
  global $sys_exit_msg;

  $return_value = true;
  $abend_inc    = 0;

//
// Testing ...

  global $pg_result_error_fieldcode_ary;

  $tst_diag .= ( '##etoSQLgetPostgresSqlState(#0) ##' );

  foreach($pg_result_error_fieldcode_ary as $sql_fieldcode)
  {
     $result_error_field      = pg_result_error_field($sql_result, constant($sql_fieldcode));
     $result_error_field_type = gettype($result_error_field);

     $tst_diag
     .=
     (
        '!!!' .
        "$sql_fieldcode" .
        '<' .
           constant($sql_fieldcode) .
        '>  '
        .
        '$result_error_field' .
        '<' .
           $result_error_field .
        '>  '
        .
        '$result_error_field_type' .
        '<' .
           $result_error_field_type .
        '>  '
     );
  }

  echo htmlspecialchars($tst_diag, ENT_QUOTES);
// ... Testing.
//

  $sql_state = pg_result_error_field($sql_result, PGSQL_DIAG_SQLSTATE);

  $sql_state_type = gettype($sql_state);

// Did pg_result_error_field(...) return type NULL or type string?
  if
  (
     ($sql_state_type === 'NULL')
     ||
     ($sql_state_type === 'string')
  )
// yes -- pg_result_error_field(...) returned NULL or string.
  {
//   Is a PostgreSQL SQLSTATE value available?
     if ($sql_state_type === 'string')
//   yes -- PostgreSQL SQLSTATE value available.
     {
        $sql_state_class = etoSQLgetPostgresStateClass();

//      Use PostgreSQL SQLSTATE for proxy values.
        $sql_state_proxy       = $sql_state;
        $sql_state_class_proxy = $sql_state_class;
     }
     else
//   no -- PostgreSQL SQLSTATE value UNavailable ($sql_state_type === 'NULL').
     {
//      Force PostgreSQL NULL SQLSTATE to proxy value '00000'.
        $sql_state_proxy       = '00000';
        $sql_state_class_proxy = '00';
     }
  
//   Is SQLSTATE class acceptable?
     if
     (
        ($sql_state_class_proxy === '00') || // success.
//      ($sql_state_class_proxy === '01') || // warning (e.g. dynamic_result_sets_returned).
        ($sql_state_class_proxy === '02') || // no data.
        ($sql_state_class_proxy === '23') || // integrity constraint violation (e.g. duplicate key).
        ($sql_state_class_proxy === '40')    // transaction rollback.
     )
//   yes -- SQLSTATE class acceptable.
     {
//      See Table A-1. PostgreSQL Error Codes <http://www.postgresql.org/docs/9.3/static/errcodes-appendix.html>.
  
//      Is SQLSTATE UNacceptable? 
        if
        (
           !(
//                                         // Postgres Condition Name.
               ($sql_state_proxy === '00000') || // successful_completion.
//             ($sql_state_proxy === '0100C') || // dynamic_result_sets_returned.
               ($sql_state_proxy === '02000') || // no_data.
//             ($sql_state_proxy === '02001') || // no_additional_dynamic_result_sets_returned.
               ($sql_state_proxy === '23505') || // unique_violation.
               ($sql_state_proxy === '40000')    // transaction_rollback.
            )
        )
//      yes -- SQLSTATE UNacceptable.
        {
           $return_value = false;
           $abend_inc    = 0;
        }
     }
     else
//   no -- SQLSTATE class UNacceptable.
     {
        $return_value = false;
        $abend_inc    = 1;
     }
  }
  else
// no -- pg_result_error_field(...) DID NOT return NULL or string.
  {
     $return_value = false;
     $abend_inc    = 2;
  }

// Are we abending?
  if (!$return_value)
// yes -- abending.
   {
      etoSQLsetPostgresErrorVerbosity(PGSQL_ERRORS_VERBOSE);

      etoSQLgetPostgresDiag();

      $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

      etoAbendSubCode($ac, $abend_inc, $xo, $ro); // Abend $ac + $abend_inc -- Query - did NOT complete and deliver a resource result.
   }

  return $return_value;
}

function etoSQLgetPostgresDiagResultFields()
{
  global $sql_result;

  global $pg_result_error_fieldcode_ary;

  global $sql_result_error_field_str;

  foreach($pg_result_error_fieldcode_ary as $sql_fieldcode)
  {
     $sql_result_error_field_str
     .=
     (
//      '!!!' .
        "$sql_fieldcode" .
        '<' .
           pg_result_error_field($sql_result, constant($sql_fieldcode)) .
        '>'
     );
  }

  return $sql_result_error_field_str;
}

function etoSQLgetPostgresDiagResult()
{
  global $sql_result;

  global $sql_result_error;
  global $sql_result_error_type;

  global $sql_result_status_long;
  global $sql_result_status_long_type;

  global $sql_result_status_string;
  global $sql_result_status_string_type;

  global $sql_error_verbosity;

  $sql_result_error      = pg_result_error($sql_result);
  $sql_result_error_type = gettype($sql_result_error);

  $sql_result_status_long        = pg_result_status($sql_result, PGSQL_STATUS_LONG);
  $sql_result_status_long_type   = gettype($sql_result_status_long);

  $sql_result_status_string      = pg_result_status($sql_result, PGSQL_STATUS_STRING);
  $sql_result_status_string_type = gettype($sql_result_status_string);

  if ($sql_error_verbosity == PGSQL_ERRORS_VERBOSE)
  {
     etoSQLgetPostgresDiagResultFields();
  }

  return;
}

function etoSQLgetPostgresDiagConn()
{
  global $sql_conn;
  global $sql_conn_type;

  global $sql_last_error;
  global $sql_last_error_type;

  global $sql_connection_status;
  global $sql_connection_status_type;

   global $sql_transaction_status;
   global $sql_transaction_status_type;

  $sql_conn_type = gettype($sql_conn);

  $sql_last_error      = pg_last_error($sql_conn);
  $sql_last_error_type = gettype($sql_last_error);

  $sql_connection_status      = pg_connection_status($sql_conn);
  $sql_connection_status_type = gettype($sql_connection_status);

   $sql_transaction_status      = pg_transaction_status($sql_conn);
   $sql_transaction_status_type = gettype($sql_transaction_status);

  return;
}

function etoSQLgetPostgresDiag()
{
  global $sql_result_type;

  etoSQLgetPostgresDiagConn();

// Did pg_get_result return result resource?
  if ($sql_result_type === 'resource')
// yes -- pg_get_result returned result resource.
  {
     etoSQLgetPostgresDiagResult();
  }

  return;
}

/*
function etoSQLgetMysqliDiag()
{

  global $sql_link;

  global $sql_errno;
  global $sql_error;
  global $sql_state;
  global $sql_state_class;

  $sql_errno = mysqli_errno($sql_link);
  $sql_error = mysqli_error($sql_link);

  $sql_state       = mysqli_sqlstate($sql_link);
  $sql_state_class = etoSQLgetMysqliStateClass();

  return;
}
*/

function etoSQLstmtGetMysqliDiag()
{
  global $sql_statement;

  global $sql_errno;
  global $sql_error;
  global $sql_state;
  global $sql_state_class;

  $sql_errno = mysqli_stmt_errno($sql_statement);
  $sql_error = mysqli_stmt_error($sql_statement);

  $sql_state       = mysqli_stmt_sqlstate($sql_statement);
  $sql_state_class = etoSQLgetMysqliStateClass();

  return;
}

function etoSQLformatPostgresDiagResult()
{
  global $sql_result_error;
  global $sql_result_error_type;

  global $sql_result_status_long;
  global $sql_result_status_long_type;

  global $sql_result_status_string;
  global $sql_result_status_string_type;

  global $sql_result_error_field_str;

  return
  (
     '$sql_result_error<'      . $sql_result_error . '> ' .
     '$sql_result_error_type<' . $sql_result_error_type . '> '
     .
     '$sql_result_status_long<'      . $sql_result_status_long . '> ' .
     '$sql_result_status_long_type<' . $sql_result_status_long_type . '> '
     .
     '$sql_result_status_string<'      . $sql_result_status_string . '> ' .
     '$sql_result_status_string_type<' . $sql_result_status_string_type . '> '
     .
     '$sql_result_error_field_str<'      . $sql_result_error_field_str . '> '
  );
}

function etoSQLformatPostgresDiagConn()
{
  global $sql_conn_type;

  global $sql_state;
  global $sql_state_type;

  global $sql_last_error;
  global $sql_last_error_type;

  global $sql_connection_status;
  global $sql_connection_status_type;

  global $sql_transaction_status;
  global $sql_transaction_status_type;

  return
  (
     '$sql_conn_type<' . $sql_conn_type . '> '
     .
     '$sql_state<'      . $sql_state . '> ' .
     '$sql_state_type<' . $sql_state_type . '> '
     .
     '$sql_last_error<'      . $sql_last_error . '> ' .
     '$sql_last_error_type<' . $sql_last_error_type . '> '
     .
     '$sql_connection_status<'      . $sql_connection_status . '> ' .
     '$sql_connection_status_type<' . $sql_connection_status_type . '> '
     .
     '$sql_transaction_status<'      . $sql_transaction_status . '> ' .
     '$sql_transaction_status_type<' . $sql_transaction_status_type . '> '
  );
}

function etoSQLformatDiag()
{
  global $sql_result;
  global $sql_result_type;

  global $sql_diag;

  $sql_diag
  =
  (
     'sql_diag<'
     .  
        etoSQLformatPostgresDiagConn()
        .
        '$sql_result<'      . $sql_result . '> ' .
        '$sql_result_type<' . $sql_result_type . '> '
        .
        (
           ($sql_result_type === 'resource')
           ? etoSQLformatPostgresDiagResult()
           : ''
        )
     .
     '>'
  );

  return $sql_diag;
}

/*
function etoSQLformatDiag()
{
  global $sql_errno;
  global $sql_error;
  global $sql_state;
  global $sql_diag;

  $sql_diag = 'sql_diag<'
              .  'sql_errno<' . $sql_errno . '> '
              .  'sql_state<' . $sql_state . '> '
              .  'sql_error<' . $sql_error . '>'
            . '>';

  return $sql_diag;
}
*/

function etoSQLdbOpen($ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK, $bo = SQL_BEGIN) // abend code, abend exit option, abend SQL rollback option, SQL BEGIN; transaction block option.
// function etoSQLdbOpen($ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK, $co = SQL_NOAUTOCOMMIT) // abend code, abend exit option, abend SQL rollback option, SQL autocommit option.
{
  global $sql_conn;
  global $sql_conn_type;
  global $sql_connection_status;
  global $sql_connection_status_type;

  global $sql_transaction_status;

  global $sql_query;

  global $sql_min_version;
  global $sql_srv_version;

// Abend code allocation ...

//  slots  function
//  -----  --------
//
//   11     etoSQLdbOpen(...)   => this function.
//
//   14     etoSQLquery(...)    => called by this function.
//  -----
//   25

// ... Abend code allocation.

// global $sys_exit_code; // $ac mapping: ($ac+0) ... ($ac+25-1) => 25 slots.
  global $sys_exit_msg;

  $return_val = true;
  $sql_abend_inc = 0; // abend sub_code increment.

  etoSQLinitCall();

// Connect to sql database server and verify minimum version available ...

   $sql_conn
   =
   pg_connect
   (
      (
         "host="   . getenv('eto_sql_host') . ' ' .
         "dbname=" . getenv('eto_sql_db') . ' ' .

         "user="     . getenv('eto_sql_user') . ' ' .
         "password=" . getenv('eto_sql_pw') . ' ' .

         "connect_timeout=" . (string) SQL_CONN_TIMEOUT
      ),

      PGSQL_CONNECT_FORCE_NEW
   );

// Did connection attempt return a resource?
   if
   (
      ($sql_conn_type = gettype($sql_conn))
      ===
      'resource'
   )
// yes -- connection attempt returned resource.
   {
      $sql_connection_status = pg_connection_status($sql_conn);
   
//    Is connection status an integer?
      if
      (
         ($sql_connection_status_type = gettype($sql_connection_status))
         ===
         'integer'
      )
//    yes -- connection status an integer.
      {
//       Is connection status OK?
         if ($sql_connection_status == PGSQL_CONNECTION_OK)
//       yes -- connection status OK.
         {
// Check for sql database server minimum version ...

//          Is minimum sql server version value given?
            if ($sql_min_version != '')
//          yes -- minimum sql server version value given.
            {
               $sql_srv_version = pg_parameter_status($sql_conn, 'server_version');
            
//             Did pg_parameter_status(...) return a string?
               if (gettype($sql_srv_version) == 'string')
//             yes -- pg_parameter_status(...) returned string.
               {
//                Is string non-null?
                  if ($sql_srv_version != '')
//                yes -- string is non-null.
                  {
//                   is function version_compare(...) available?
                      if (function_exists('version_compare'))
//                    yes -- function version_compare(...) available.
                      {
//                       is sql database server version earlier than minimum?
                         if
                         (
                            version_compare
                            (
                               strtolower
                               (
//                                strip trailing non-numeric part (e.g.'-log' of '5.1.41-log)'.
                                  substr
                                  (
                                     $sql_srv_version,
                                     0,
                                     strspn($sql_srv_version, '0123456789.')
                                  )
                               ),
                         
                               strtolower($sql_min_version),
                         
                               '<'
                            )
                         )
                         
//                       if (version_compare(strtolower($sql_srv_version), strtolower($sql_min_version), '<'))
//                       yes -- sql database server version earlier than minimum.
                         {
                            $return_val    = false;
                            $sql_abend_inc = 6;
                         }
                      }
                      else
//                    no -- function version_compare(...) NOT available.
                      {
                         $return_val    = false;
                         $sql_abend_inc = 5;
                      }
                  }
                  else
//                no -- string is  null.
                  {
                     $return_val    = false;
                     $sql_abend_inc = 4;
                  }
               }
               else
//             no -- pg_parameter_status(...) DID NOT return string.
               {
                  $return_val    = false;
                  $sql_abend_inc = 3;
               }
            }
// ... Check for sql database server minimum version.
         }
         else
//       no -- connection status NOT OK.
         {
            $return_val    = false;
            $sql_abend_inc = 2;
         }
      }
      else
//    no -- connection status NOT an integer.
      {
            $return_val    = false;
            $sql_abend_inc = 1;
      }
   }
   else
// no -- connection attempt DID NOT return resource.
   {
      $return_val    = false;
      $sql_abend_inc = 0;
   }

// ... Connect to sql database server and verify minimum version available.


// Configure SQL database server ...

// Still running?
   if ($return_val)
// yes -- still running.
   {
      etoSQLsetPostgresErrorVerbosity(PGSQL_ERRORS_TERSE);
//    etoSQLsetPostgresErrorVerbosity(PGSQL_ERRORS_VERBOSE);

//    pg_set_client_encoding(...) successful?
      if (pg_set_client_encoding($sql_conn, SQL_CHARSET_CLIENT) == 0)
//    yes -- pg_set_client_encoding(...) successful.
      {
//       Is current client encoding correct?
         if (pg_client_encoding($sql_conn) == SQL_CHARSET_CLIENT)
//       yes -- current client encoding correct.
         {
//          Does caller want to BEGIN; a transaction block?
            if ($bo)
//          yes -- BEGIN; a transaction block?
            {
               $sql_query = 'BEGIN;';
//             $sql_query = 'BEGINX;'; // testing -- force abend.
               
//             Is BEGIN; query successful?
               if (etoSQLquery(($ac+Yia), $xo, $ro, SQL_NASUM_EQ0))
//             yes -- BEGIN; query successful.
               {
//                Is transaction status INcorrect? (correct status == idle in a transaction block).
                  if
                  (
                     !(
                         ($sql_transaction_status = pg_transaction_status($sql_conn))
                         ==
                         PGSQL_TRANSACTION_INTRANS
                     )
                  )
//                yes -- transaction status INcorrect.
                  {
                     $return_val    = false;
                     $sql_abend_inc = 7;
                  }
               }
               else
//             no -- BEGIN; query UNsuccessful.
               {
                  $return_val    = false;
                  $sql_abend_inc = 8;
               }
            }
         }
         else
//       no -- current client encoding INcorrect.
         {
            $return_val    = false;
            $sql_abend_inc = 9;
         }
      }
      else
//    no -- pg_set_client_encoding(...) UNsuccessful.
      {
         $return_val    = false;
         $sql_abend_inc = 10;
      }
   }

// were connect, version check or configure UNsuccessful?
  if (!$return_val)
// yes -- UNsuccessful.
  {
//   were version check or configure UNsuccessful?
     if ($sql_abend_inc > 2)
//   yes -- version check or configure UNsuccessful?
     {
        etoSQLsetPostgresErrorVerbosity(PGSQL_ERRORS_VERBOSE);

        etoSQLgetPostgresDiag();
     }
  }

//
// Testing ...

  global $sql_result;
  global $sql_result_type;

  global $sql_state;
  global $sql_state_type;
  global $sql_state_class;

  global $sql_state_proxy;
  global $sql_state_class_proxy;

  global $sql_transaction_status_type;

  global $sql_result_status_long;
  global $sql_result_status_long_type;
  global $sql_result_status_string;
  global $sql_result_status_string_type;
  global $sql_result_error;
  global $sql_result_error_type;
  global $sql_result_error_field_str;
  global $sql_last_error;
  global $sql_last_error_type;

  $tst_diag = '';
  $tst_diag .= ( '##etoSQLdbOpen(#9) ##' );

  $tst_diag .= ( '$return_val<'    . $return_val . '>**  ' );
  $tst_diag .= ( '$sql_abend_inc<' . $sql_abend_inc . '>**  ' );

  $tst_diag .= ( 'getenv(\'eto_sql_host\')<' . getenv('eto_sql_host') . '>**  ' );
  $tst_diag .= ( 'getenv(\'eto_sql_user\')<' . getenv('eto_sql_user') . '>**  ' );
  $tst_diag .= ( 'getenv(\'eto_sql_pw\')<'   . '******' . '>**  ' );
  $tst_diag .= ( 'getenv(\'eto_sql_db\')<'   . getenv('eto_sql_db') . '>**  ' );

  $tst_diag .= ( '$sql_conn<'      . $sql_conn . '>**  ' );
  $tst_diag .= ( '$sql_conn_type<' . $sql_conn_type . '>**  ' );

  $tst_diag .= ( '$sql_connection_status<'      . $sql_connection_status . '>**  ' );
  $tst_diag .= ( '$sql_connection_status_type<' . $sql_connection_status_type . '>**  ' );

  $tst_diag .= ( '$sql_min_version<' . $sql_min_version . '>**  ' );
  $tst_diag .= ( '$sql_srv_version<' . $sql_srv_version . '>**  ' );

  $tst_diag .= ( '$sql_query<'       . $sql_query . '>**  ' );

  $tst_diag .= ( '$sql_result<'      . $sql_result . '>**  ' );
  $tst_diag .= ( '$sql_result_type<' . $sql_result_type . '>**  ' );

  $tst_diag .= ( '$sql_state<'       . $sql_state . '>**  ' );
  $tst_diag .= ( '$sql_state_type<'  . $sql_state_type . '>**  ' );
  $tst_diag .= ( '$sql_state_class<' . $sql_state_class . '>**  ' );

  $tst_diag .= ( '$sql_state_proxy<'       . $sql_state_proxy . '>**  ' );
  $tst_diag .= ( '$sql_state_class_proxy<' . $sql_state_class_proxy . '>**  ' );

  $tst_diag .= ( '$sql_transaction_status<'        . $sql_transaction_status . '>**  ' );
  $tst_diag .= ( '$sql_transaction_status_type<'   . $sql_transaction_status_type . '>**  ' );
  $tst_diag .= ( '$sql_result_status_long<'        . $sql_result_status_long . '>**  ' );
  $tst_diag .= ( '$sql_result_status_long_type<'   . $sql_result_status_long_type . '>**  ' );
  $tst_diag .= ( '$sql_result_status_string<'      . $sql_result_status_string . '>**  ' );
  $tst_diag .= ( '$sql_result_status_string_type<' . $sql_result_status_string_type . '>**  ' );
  $tst_diag .= ( '$sql_result_error<'              . $sql_result_error . '>**  ' );
  $tst_diag .= ( '$sql_result_error_type<'         . $sql_result_error_type . '>**  ' );
  $tst_diag .= ( '$sql_result_error_field_str<'    . $sql_result_error_field_str . '>**  ' );
  $tst_diag .= ( '$sql_last_error<'                . $sql_last_error . '>**  ' );
  $tst_diag .= ( '$sql_last_error_type<'           . $sql_last_error_type . '>**  ' );

  echo htmlspecialchars($tst_diag, ENT_QUOTES);
// ... Testing.
//

// connect, version check or configure UNsuccessful?
if (!$return_val)
// yes -- UNsuccessful.
{
   $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

   etoAbendSubCode($ac, $sql_abend_inc, $xo, $ro); // Abend $ac + 0..@@@11 -- connect, version check or configure UNsuccessful.
}

  return $return_val;
}

function etoSQLcheckQuery($qt = SQL_NASUM_GE1, $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK) // query success threshold, abend code, abend exit option, abend SQL rollback option.
// function etoSQLcheckQuery($qo = SQL_NASUM_GE1) // query success threshold.
// function etoSQLcheckQuery()
// function etoSQLcheckQuery($ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK) // abend code, abend exit option, abend SQL rollback option.
{
//                   ** CAUTION **
//
//    THIS FUNCTION SERVES AS A CONVENIENCE ONLY!
//
// IT IS THE RESPONSIBILITY OF THE CODER OF THE SQL QUERY TO KNOW THE EXPECTED EFFECTS,
//   IN TERMS OF ROWS RETURNED AND / OR ROWS AFFECTED BY THE QUERY,
//   AND TO INTERPRET THE BOOLEAN $return_val OF THIS FUNCTION APPROPRIATELY.
//
// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
//
//
// Express query result in a simple $return_val true/false boolean,
//   as function of:
//
//   (A) $qo -- query success threshold:
//
//      ------------------------------------------------------------------
//             function                      DUPLICATE  NO DATA
//       etoSQLcheckQuery($qo)                ALLOWED   ALLOWED  ROLLBACK
//         called with $qo =         NASUM       ?         ?         ?
//      ------------------------   ------------ ---       ---       ---
//      const SQL_NASUM_EQ0     ==> NASUM == 0   N         Y         N (3)
//      const SQL_NASUM_GE0     ==> NASUM >= 0   N         Y         N (3)
//      const SQL_NASUM_GE1     ==> NASUM >= 1   N         Y         N (3)
//      const SQL_NASUM_EQ0_DUP ==> NASUM == 0   Y         Y         N (3)
//      const SQL_NASUM_GE0_DUP ==> NASUM >= 0   Y         Y         N (3)
//      const SQL_NASUM_GE1_DUP ==> NASUM >= 1   Y         Y         N (3)
//      const SQL_ROLLBACK      ==> ----------   -         -         Y (4)
//      ------------------------------------------------------------------
//       (1) = sqlstate duplicate NOT allowed, sqlstate strict success required.
//       (2) = sqlstate duplicate allowed, NOT required.
//       (3) = sqlstate rollback NOT allowed.
//       (4) = sqlstate rollback required.
//      ------------------------------------------
//
//   (A.1) $sql_state_proxy value:
//
//       $sql_state_proxy
//       ----------------  ----------------------------------
//           '00000'     => strict success.
//           '02000'     => no data.
//           '23505'     => unique violation (duplicate key).
//           '40000'     => transaction rollback.
//           -------     => (other).
//       ----------------  ----------------------------------
//
//
// ------------------------------------------------------------------------------
//    ($qo X SQLSTATE) ==> $return_val -- MAPPING TABLE.
// ------------------------------------------------------------------------------
//                            .................. $sql_state_proxy ...............
//       function             strict      no      unique    transaction         
//   etoSQLcheckQuery($qo)    success    data    violation   rollback
//     called with $qo =      '00000'   '02000'   '23505'    '40000'     (other)
//   ---------------------    -------   -------   -------    -------     -------
//      SQL_NASUM_EQ0            1         1         0          0           0
//      SQL_NASUM_GE0            1         1         0          0           0
//      SQL_NASUM_GE1            1         1         0          0           0
//
//      SQL_NASUM_EQ0_DUP        1         1         1          0           0
//      SQL_NASUM_GE0_DUP        1         1         1          0           0
//      SQL_NASUM_GE1_DUP        1         1         1          0           0
//
//      SQL_ROLLBACK             0         0         0          1           0
// ------------------------------------------------------------------------------
//
//
//   (A.2) sum of two SQL row counts:
//
//         NASUM = ($sql_row_count + $sql_afec_row_count).
//
// ---------------------------------------------------
//    ($qo X NASUM) ==> $return_val -- MAPPING TABLE.
// ---------------------------------------------------
//                            (    $sql_row_count   )
//                            (          +          )
//       function             ( $sql_afec_row_count )
//   etoSQLcheckQuery($qo)    -----------------------
//     called with $qo =      (== 0)  (> 0)    (>= 1)
//   ---------------------    ------  ------   ------
//      SQL_NASUM_EQ0            1      0        -
//      SQL_NASUM_GE0            1      1        -
//      SQL_NASUM_GE1            0      1        -
//
//      SQL_NASUM_EQ0_DUP        1      0        -
//      SQL_NASUM_GE0_DUP        1      1        -
//      SQL_NASUM_GE1_DUP        0      1        -
//
//      SQL_ROLLBACK             1      -        -
// ---------------------------------------------------
//
   global $sql_state_proxy;    // set by caller.
   global $sql_state_class;    // set by caller.
   global $sql_row_count;      // set by caller.
   global $sql_afec_row_count; // set by caller.

//  global $sys_exit_code; // $ac mapping: ($ac+0) => 1 slot.
   global $sys_exit_msg;

   $return_val = true;   

   $sql_nasum = ($sql_row_count+ $sql_afec_row_count);

    switch ($qt)
   {
      case  SQL_NASUM_EQ0:     {if (!( ($sql_nasum == 0) && (($sql_state_proxy == '00000') || ($sql_state_proxy == '02000'))) )                                  {$return_val = false;} break;}
      case  SQL_NASUM_GE0:     {if (!( ($sql_nasum >= 0) && (($sql_state_proxy == '00000') || ($sql_state_proxy == '02000'))) )                                  {$return_val = false;} break;}
      case  SQL_NASUM_GE1:     {if (!( ($sql_nasum >= 1) && (($sql_state_proxy == '00000') || ($sql_state_proxy == '02000'))) )                                  {$return_val = false;} break;}

      case  SQL_NASUM_EQ0_DUP: {if (!( ($sql_nasum == 0) && (($sql_state_proxy == '00000') || ($sql_state_proxy == '02000') || ($sql_state_proxy == '23505'))) ) {$return_val = false;} break;}
      case  SQL_NASUM_GE0_DUP: {if (!( ($sql_nasum >= 0) && (($sql_state_proxy == '00000') || ($sql_state_proxy == '02000') || ($sql_state_proxy == '23505'))) ) {$return_val = false;} break;}
      case  SQL_NASUM_GE1_DUP: {if (!( ($sql_nasum >= 1) && (($sql_state_proxy == '00000') || ($sql_state_proxy == '02000') || ($sql_state_proxy == '23505'))) ) {$return_val = false;} break;}

      case  SQL_ROLLBACK:      {if (!(($sql_state_proxy == '40000')))                                                                                {$return_val = false;} break;}

      default:
      {
         $return_val = false;

         $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

         etoAbendSubCode($ac, 0, $xo, $ro); // Abend $ac + 0 -- Invalid $qt parameter value.

         break;
      }
   }

/*
// Testing ...
   global $sql_query;
   global $sql_result;

   global $sys_exit_code;

  $tst_diag = '';
  $tst_diag .= ( '##etoSQLcheckQuery(#1)##  ' );
  $tst_diag .= ( '**$sql_query<' . $sql_query . '>**  ' );

  $tst_diag .= ( '**$sql_row_count<' . $sql_row_count . '>**  ' );
  $tst_diag .= ( '**$sql_afec_row_count<' . $sql_afec_row_count . '>**  ' );
  $tst_diag .= ( '**$sql_nasum<' . $sql_nasum . '>**  ' );

  $tst_diag .= ( '**is_bool($sql_result)<' . is_bool($sql_result) . '>**  ' );
  $tst_diag .= ( '**$sql_state<' . $sql_state . '>**  ' );
  $tst_diag .= ( '**$sql_state_proxy<' . $sql_state_proxy . '>**  ' );

  $tst_diag .= ( '**$sys_exit_code<' . $sys_exit_code . '>**  ' );
  $tst_diag .= ( '**$return_val<' . $return_val . '>**  ' );

  echo htmlspecialchars($tst_diag, ENT_QUOTES);
// ... Testing.
*/

  return $return_val;
}

function etoSQLget_mysqli_insert_id()
{
// ---------------------     ------------------------------
// mysqli_insert_id(...)  =>         $return_val
// ---------------------     ------------------------------
//     int type           =>     mysqli_insert_id(...)
//
//    (other type)        =>    '        0
// ---------------------     ------------------------------

  global $sql_link;

  $insert_id_tmp = mysqli_insert_id($sql_link); // if int should NEVER == 0 (SQL auto inc column);

// int rep?
   if (is_int($insert_id_tmp))
// yes -- int rep.
   {
      $return_val = $insert_id_tmp;
   }
   else
// no -- NOT int rep.
   {
     $return_val = (int)0;
   }

  return $return_val;
}

function etoSQLwaitPostgresQuery()
{
   global $sql_conn;

   global $sql_query_loopwait;

   $return_val = false;

   for ($i = 0; $i < SQL_QUERY_WAITCNT; $i++)
   {
//    Wait for $sql_query_loopwait microseconds.
      usleep($sql_query_loopwait);

//    Has query completed?
      if (!pg_connection_busy($sql_conn))
//    yes -- query complete.
      {
         $return_val = true;

         break;
      }
   }

   return $return_val;
}

function etoSQLpostgres_query($qs = '', $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK) // query string, abend code, abend exit option, abend SQL rollback option.
{
//         ** CAUTION **
//
// *** THIS FUNCTION etoSQLpostgres_query(...) DOES **NOT** CALL pg_free_result(...). ***
//
//  IT IS THE RESPONSIBILITY OF THE CALLER,
//    TO DESTROY ANY (NON-BOOLEAN) RESULT OBJECT CREATED BY THE QUERY:
//

// @@@Abend code allocation ...

//  slots  function
//  -----  --------
//
//    @@@8     etoSQLpostgres_query(...)      => this function.
//
//    3     etoSQLgetPostgresSqlState(...) => called by this function.
//  -----
//   @@@11

// ... Abend code allocation.

// global $sys_exit_code; // $ac mapping: ($ac+0) ... ($ac+@@@11-1) => @@@11 slots.

  global $sys_exit_msg;

  global $sql_conn;

  global $sql_result;
  global $sql_result_type;

  global $sql_result_status_long;
  global $sql_result_status_long_type;

  global $sql_state;
  global $sql_state_type;
  global $sql_state_class;

  global $sys_exit_msg;

  $return_value = true;
  $abend_inc    = 0;

// Is pg_send_query(...) successful?
   if (pg_send_query($sql_conn, $qs))
// yes -- pg_send_query(...) successful.
   {
//    Is query still in progress?
      if (pg_connection_busy($sql_conn))
//    yes -- query still in progress.
      {
//       Wait for query to complete (or time out).
//       Did query time out?
         if (!($return_val = etoSQLwaitPostgresQuery()))
//       yes -- query timed out.
         {
            $return_value = false;
            $abend_inc    = 0;
         }
      }
   }
   else
// no -- pg_send_query(...) UNsuccessful.
   {
      $return_value = false;
      $abend_inc    = 1;
   }

// Still running?
   if ($return_value)
// yes -- still running (query completed).
   {
      $sql_result      = pg_get_result($sql_conn);
      $sql_result_type = gettype($sql_result);

//    Is query result of expected type?
      if
      (
         ($sql_result_type == 'resource')
         ||
         ($sql_result_type == 'NULL')
      )
//    yes -- query result is of expected type (resource or NULL).
      {
         $sql_result_status_long = pg_result_status($sql_result, PGSQL_STATUS_LONG);
         
//       Is $sql_result_status_long an integer?
         if
         (
            ($sql_result_status_long_type = gettype($sql_result_status_long))
            ===
            'integer'
         )
//       yes -- $sql_result_status_long an integer.
         {
             switch ($sql_result_status_long)
             {
//              valid -- query has completed (expected).
                case PGSQL_COMMAND_OK:
                case PGRES_SINGLE_TUPLE: // PostgreSQL 9.4.
                case PGSQL_TUPLES_OK:
                case PGSQL_COPY_TO:
                case PGSQL_COPY_FROM:
                {
//                 Did pg_get_result return result resource?
                   if ($sql_result_type === 'resource')
//                 yes -- pg_get_result returned result resource.
                   {
//                    Is SqlState UNacceptab;e?
                      if (!etoSQLgetPostgresSqlState($ac+Yfa, $xo, $ro))
//                    yes -- SqlState UNacceptab;e.
                      {
                         $return_value = false;
                         $abend_inc    = 2;
                      }
                   }
                   else
//                 no -- pg_get_result DID NOT return result resource.
                   {
                      $return_value = false;
                      $abend_inc    = 3;
                   }

                   break;
                }

//              valid -- query has failed to complete (unexpected).
                case PGSQL_EMPTY_QUERY:
                case PGSQL_BAD_RESPONSE:
                case PGSQL_FATAL_ERROR:
                {
//                 Did pg_get_result return result resource?
                   if ($sql_result_type === 'resource')
//                 yes -- pg_get_result returned result resource.
                   {
//                    Is SqlState UNacceptab;e?
                      if (!etoSQLgetPostgresSqlState($ac+Yfa, $xo, $ro))
//                    Yes -- SqlState UNacceptable.
                      {
                         $return_value = false;
                         $abend_inc    = 4;
                      }
                   }
                   else
//                 no -- pg_get_result DID NOT return result resource.
                   {
                      $return_value = false;
                      $abend_inc    = 5;
                   }

                   break;
                }

//              valid -- UNexpected in ordinary application.
                case PGSQL_NONFATAL_ERROR:
                case PGRES_COPY_BOTH: // PostgreSQL 9.4.
                {
                   $return_value = false;
                   $abend_inc    = 6;

                   break;
                }

//              INvalid.
                default:
                {
                   $return_value = false;
                   $abend_inc    = 7;

                   break;
                }
             }
         }
         else
//       no -- $sql_result_status_long NOT an integer.
         {
            $return_value = false;
            $abend_inc    = 8;
         }
      }
      else
//    no -- query result is of UNexpected type  (NOT resource or NULL).
      {
         $return_value = false;
         $abend_inc    = 9;
      }
   }

// Still running?
   if ($return_value)
// yes -- still running.
   {
      etoSQLgetPostgresDiag();
   }
   else
// no -- abending.
   {
      etoSQLsetPostgresErrorVerbosity(PGSQL_ERRORS_VERBOSE);

      etoSQLgetPostgresDiag();

      $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

      etoAbendSubCode($ac, $abend_inc, $xo, $ro); // Abend $ac + $abend_inc -- Query - did NOT complete and deliver a resource result.
   }

   return $return_value;
}

/*
function etoSQLmysqli_query($qs = '') // query string.
{
//         ** CAUTION **
//
//  IT IS THE RESPONSIBILITY OF THE CALLER,
//    TO DESTROY ANY (NON-BOOLEAN) RESULT OBJECT CREATED BY THE QUERY,
//    THIS FUNCTION etoSQLquery(...) DOES NOT CALL mysqli_free-result(...).
//
//
  global $sql_link;
  global $sql_result;

  $sql_result = mysqli_query($sql_link, $qs);

  etoSQLgetMysqliDiag();

  return $sql_result;
}
*/

/*
function etoSQLqueryExecSuccess()
{
  global $sql_state_class;

  return
  (
      ($sql_state_class == '00') // success.
      ||
      ($sql_state_class == '02') // no data (SQL operation completed successfully but found no data).
      ||
      ($sql_state_class == '23') // integrity constraint violation (e.g. duplicate key).
  );
}
*/

function etoSQLquery($ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK, $qt = SQL_NASUM_GE1) // abend code, abend exit option, abend SQL rollback option, query success threshold.
// function etoSQLquery($ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK) // abend code, abend exit option, abend SQL rollback option.
{
//         ** CAUTION **
//
//  IT IS THE RESPONSIBILITY OF THE CALLER,
//    TO DESTROY ANY (NON-BOOLEAN) RESULT OBJECT CREATED BY THE QUERY,
//    THIS FUNCTION etoSQLquery(...) DOES NOT CALL mysqli_free-result(...).
//

  global $sql_query;
  global $sql_result;

  global $sql_row_count;
  global $sql_afec_row_count;

// Abend code allocation ...

//  slots  function
//  -----  --------
//
//    2     etoSQLquery(...)          => this function.
//
//   11     etoSQLpostgres_query(...) => called by this function.
//    1     etoSQLcheckQuery(...)     => called by this function.
//  -----
//   14

// ... Abend code allocation.

// global $sys_exit_code; // $ac mapping: ($ac+0) ... ($ac+14-1) => 14 slots.
  global $sys_exit_msg;

  $return_val = true;

  etoSQLinitCall();

// Did query complete and return result resource?
   if (etoSQLpostgres_query($sql_query, ($ac+Yha), $xo, $ro))
// yes -- query completed with result resource.
   {
       $sql_afec_row_count = pg_affected_rows($sql_result);

//     Was a result set expected?
        if (pg_num_fields($sql_result) > 0)
//      yes -- result set expected.
        {
           $sql_row_count = pg_num_rows($sql_result);
        }

//      Was etoSQLcheckQuery() UNsuccessful?
        if (!etoSQLcheckQuery($qt, ($ac+Yha+Yf), $xo, $ro))
//      yes -- etoSQLcheckQuery() UNsuccessful.
        {
           $return_val = false;

           $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

           etoAbendSubCode($ac, 0, $xo, $ro); // Abend $ac + 0 -- Query DID NOT complete with result resource.
        }
   }
   else
// no -- query DID NOT complete with result resource.
   {
      $return_val = false;

      $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

      etoAbendSubCode($ac, 1, $xo, $ro); // Abend $ac + 0 -- Query DID NOT complete with result resource.
   }

/*
// Testing ...
   global $sql_errno;
   global $sql_state;
   global $sys_exit_code;

  $tst_diag = '';
  $tst_diag .= ( '##etoSQLquery()##  ' );
  $tst_diag .= ( '**$sql_query<' . $sql_query . '>**  ' );

  $tst_diag .= ( '**pg_num_fields($sql_result)<' . pg_num_fields($sql_result) . '>**  ' );
  $tst_diag .= ( '**\$sql_afec_row_count<' . $sql_afec_row_count . '>**  ' );
  $tst_diag .= ( '**\$sql_row_count<' . $sql_row_count . '>**  ' );

  $tst_diag .= ( '**is_bool($sql_result)<' . is_bool($sql_result) . '>**  ' );
  $tst_diag .= ( '**$sql_errno<' . $sql_errno . '>**  ' );
  $tst_diag .= ( '**$sql_state<' . $sql_state . '>**  ' );

  $tst_diag .= ( '**$sys_exit_code<' . $sys_exit_code . '>**  ' );
  $tst_diag .= ( '**$return_val<' . $return_val . '>**  ' );

  echo htmlspecialchars($tst_diag, ENT_QUOTES);
// ... Testing.
*/

  return $return_val;
}

/*
function etoSQLquery($ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK)
{
//         ** CAUTION **
//
//  IT IS THE RESPONSIBILITY OF THE CALLER,
//    TO DESTROY ANY (NON-BOOLEAN) RESULT OBJECT CREATED BY THE QUERY,
//    THIS FUNCTION etoSQLquery(...) DOES NOT CALL mysqli_free-result(...).
//
//
  global $sql_link;
  global $sql_query;
  global $sql_result;

  global $sql_row_count;
  global $sql_afec_row_count;

// Abend code allocation ...

//  slots  function
//  -----  --------
//
//    3     etoSQLquery(...)      => this function.
//
//    4     etoSQLcheckQuery(...) => called by this function.
//  -----
//    7

// ... Abend code allocation.

// global $sys_exit_code; // $ac mapping: ($ac+0) ... ($ac+7-1) => 7 slots.
  global $sys_exit_msg;

  $return_val = true;

  etoSQLinitCall();

// @@@ no abends in function etoSQLmysqli_query(...)?
   $sql_result = etoSQLmysqli_query($sql_query);

// Is SQLSTATE success?
   if
   (
      $return_val
      =
      etoSQLqueryExecSuccess()
   )
// yes - success.
   {
//   Did the query complete (i.e. mysqli_query() "successful" per php doc)? ($sql_result = either (boolean == true) or (result object)).
     if ($sql_result)
//   yes -- query complete.
     {
        $sql_afec_row_count = mysqli_affected_rows($sql_link);

//     Was a result set expected?
        if (mysqli_field_count($sql_link))
//      yes -- result set expected.
        {
//         Was a result set obtained?
           if (is_object($sql_result))
//         yes -- result set obtained.
           {
              $sql_row_count = mysqli_num_rows($sql_result);
           }
           else
//         no -- result set NOT obtained.
           {
              $return_val = false;

              $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

              etoAbendSubCode($ac, 0, $xo, $ro); // Abend $ac + 0 -- Query - expected result set not obtained.
           }
        }

        $return_val = etoSQLcheckQuery($ac+X2a, $xo, $ro);
//      $return_val = etoSQLcheckQuery($ac+2, $xo, $ro);
     }
     else
//   no -- query INcomplete.
     {
        $return_val = false;

        $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

        etoAbendSubCode($ac, 1, $xo, $ro); // Abend $ac + 1 -- Query INcomplete.

     }
  }
  else
// no - SQLSTATE NOT success.
  {
     $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

     etoAbendSubCode($ac, 2, $xo, $ro); // Abend $ac + 2 -- mysqli_query() - SQLSTATE NOT success.
  }
*/

/*
// Testing ...
   global $sql_errno;
   global $sql_state;
   global $sys_exit_code;

  $tst_diag = '';
  $tst_diag .= ( '##etoSQLquery()##  ' );
  $tst_diag .= ( '**$sql_query<' . $sql_query . '>**  ' );

  $tst_diag .= ( '**mysqli_field_count($sql_link)<' . mysqli_field_count($sql_link) . '>**  ' );
  $tst_diag .= ( '**\$sql_afec_row_count<' . $sql_afec_row_count . '>**  ' );
  $tst_diag .= ( '**\$sql_row_count<' . $sql_row_count . '>**  ' );

  $tst_diag .= ( '**is_bool($sql_result)<' . is_bool($sql_result) . '>**  ' );
  $tst_diag .= ( '**$sql_errno<' . $sql_errno . '>**  ' );
  $tst_diag .= ( '**$sql_state<' . $sql_state . '>**  ' );

  $tst_diag .= ( '**$sys_exit_code<' . $sys_exit_code . '>**  ' );
  $tst_diag .= ( '**$return_val<' . $return_val . '>**  ' );

  echo htmlspecialchars($tst_diag, ENT_QUOTES);
// ... Testing.
*/

/*
  return $return_val;
}
*/

/*
// old version.
function etoSQLstmtDo
(
  $qs = '', // query parameter(s) type specification.

  $qb,      // query parameter(s) bind array.

  $rb,      // result parameter(s) bind array.

  $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK // abend code, abend exit option, abend SQL rollback option.
)
{
  global $sql_link;
  global $sql_query;
  global $sql_statement;

  global $sql_result;

  global $sql_row_count;
  global $sql_afec_row_count;

  global $sys_exit_code; // $ac mapping: ($ac+0) ... ($ac+@@@12) => 13 slots.
  global $sys_exit_msg;

  $sql_afec_row_count = false;
  $sql_row_count      = false;

  $return_val = true;

  etoSQLinitCall();

// Is the mysqli_ query statement object created?
  if ($sql_statement = mysqli_stmt_init($sql_link))
// yes -- statement object created.
  {
     $return_val = ($sql_statement -> prepare($sql_query));

     etoSQLgetMysqliDiag();

//   Did query statement prepare OK?
     if ($return_val)
//   yes -- prepared OK.
     {
//      Bind the sql statement parameters to the reference(s) passed via array.
        switch (strlen($qs))
        {
           case  0: { break; }

           case  1: { $return_val = ($sql_statement -> bind_param($qs, $qb[0])); break; }

           case  2: { $return_val = ($sql_statement -> bind_param($qs, $qb[0], $qb[1])); break; }

           case  3: { $return_val = ($sql_statement -> bind_param($qs, $qb[0], $qb[1], $qb[2])); break; }

           case  4: { $return_val = ($sql_statement -> bind_param($qs, $qb[0], $qb[1], $qb[2], $qb[3])); break; }

           case  5: { $return_val = ($sql_statement -> bind_param($qs, $qb[0], $qb[1], $qb[2], $qb[3], $qb[4])); break; }

           case  6: { $return_val = ($sql_statement -> bind_param($qs, $qb[0], $qb[1], $qb[2], $qb[3], $qb[4], $qb[5])); break; }

           case  7: { $return_val = ($sql_statement -> bind_param($qs, $qb[0], $qb[1], $qb[2], $qb[3], $qb[4], $qb[5], $qb[6])); break; }

           case  8: { $return_val = ($sql_statement -> bind_param($qs, $qb[0], $qb[1], $qb[2], $qb[3], $qb[4], $qb[5], $qb[6], $qb[7])); break; }

           case  9: { $return_val = ($sql_statement -> bind_param($qs, $qb[0], $qb[1], $qb[2], $qb[3], $qb[4], $qb[5], $qb[6], $qb[7], $qb[8])); break; }

           case 10: { $return_val = ($sql_statement -> bind_param($qs, $qb[0], $qb[1], $qb[2], $qb[3], $qb[4], $qb[5], $qb[6], $qb[7], $qb[8], $qb[9])); break; }

           default:
           {
              $return_val = false;

              $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

              etoAbendSubCode($ac, 0, $xo, $ro); // Abend $ac + 0 -- Statement -- Cannot bind_param() - Invalid count of query parameter type specifications.

              break;
           }
        }

        etoSQLgetMysqliDiag();

//      Was bind_param() successful?
        if ($return_val)
//      yes -- bind_param() successful.
        {
//         Execute the sql statement.
           $return_val = ($sql_statement -> execute());

           etoSQLgetMysqliDiag();

//         Did statement execute succeed?
           if ($return_val)
//         yes -- execution success.
           {
              $sql_row_count      = mysqli_stmt_num_rows($sql_statement);
              $sql_afec_row_count = mysqli_stmt_affected_rows($sql_statement);

              $return_val = etoSQLcheckQuery($ac+9, $xo, $ro); // abend code, abend exit option, SQL @@@abend rollback option.

//            NOT abending?
              if (!$sys_exit_code)
//            yes -- not abending.
              {
//               Was a result set expected?
                 if (mysqli_field_count($sql_link))
//               yes -- result set expected.
                 {
                    $return_val = ($sql_statement -> store_result());

//                  Was store_result() successful?
                    if ($return_val)
//                  yes -- store_result() successful.
                    {
//                        Were 1+ row(s) returned?
                          if ($return_val)
//                        yes -- 1+ row(s) returned.
                          {
//                           Bind the sql statement result to the storage parameter references passed via array.
                             switch (count($rb))
                             {
                                case  0: { break; }

                                case  1: { $return_val = ($sql_statement -> bind_result($rb[0])); break; }

                                case  2: { $return_val = ($sql_statement -> bind_result($rb[0], $rb[1])); break; }

                                case  3: { $return_val = ($sql_statement -> bind_result($rb[0], $rb[1], $rb[2])); break; }

                                case  4: { $return_val = ($sql_statement -> bind_result($rb[0], $rb[1], $rb[2], $rb[3])); break; }

                                case  5: { $return_val = ($sql_statement -> bind_result($rb[0], $rb[1], $rb[2], $rb[3], $rb[4])); break; }

                                case  6: { $return_val = ($sql_statement -> bind_result($rb[0], $rb[1], $rb[2], $rb[3], $rb[4], $rb[5])); break; }

                                case  7: { $return_val = ($sql_statement -> bind_result($rb[0], $rb[1], $rb[2], $rb[3], $rb[4], $rb[5], $rb[6])); break; }

                                case  8: { $return_val = ($sql_statement -> bind_result($rb[0], $rb[1], $rb[2], $rb[3], $rb[4], $rb[5], $rb[6], $rb[7])); break; }

                                case  9: { $return_val = ($sql_statement -> bind_result($rb[0], $rb[1], $rb[2], $rb[3], $rb[4], $rb[5], $rb[6], $rb[7], $rb[8])); break; }

                                case 10: { $return_val = ($sql_statement -> bind_result($rb[0], $rb[1], $rb[2], $rb[3], $rb[4], $rb[5], $rb[6], $rb[7], $rb[8], $rb[9])); break; }

                                default:
                                {
                                   $return_val = false;

                                   $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

                                   etoAbendSubCode($ac, 1, $xo, $ro); // Abend $ac + 1 -- Statement -- Cannot bind_result() - Invalid count of storage parameter references in bind array.

                                   break;
                                }
                             }

                             etoSQLgetMysqliDiag();

//                           Was bind_result() UNsucessful?
                             if (!$return_val)
//                           yes -- bind_result() UNsuccessful.
                             {
//                              NOT already abending?
                                if (!$sys_exit_code)
//                              yes -- NOT abending.
                                {
                                   $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

                                   etoAbendSubCode($ac, 2, $xo, $ro); // Abend $ac + 2 -- Statement -- bind_result() failed.
                                }
                             }
                             else
//                           no -- 0 rows returned.
                             {
                                $return_val = mysqli_stmt_close($sql_statement);

//                              Was statement close UNsuccessful?
                                if (!$return_val)
//                              yes -- close UNsuccessful.
                                {
                                   $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

                                   etoAbendSubCode($ac, 3, $xo, $ro); // Abend $ac + 3 -- Statement -- mysqli_stmt_close() failed.
                                }
                             }
                          }
                    }
                    else
//                  no -- store_result() UNsuccessful.
                    {
                       $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

                       etoAbendSubCode($ac, 4, $xo, $ro); // Abend $ac + 4 -- Statement -- store_result() failed.
                    }
                 }
//               no -- result set NOT expected.
                 {
                    $sql_afec_row_count = mysqli_stmt_affected_rows($sql_statement);

                    $return_val = etoSQLcheckQuery($ac+9, $xo, $ro); // abend code, abend exit option, SQL @@@abend rollback option.

//                  NOT already abending?
                    if(!$sys_exit_code)
//                  yes --- not abending.
                    {
                        $return_val = mysqli_stmt_close($sql_statement);

//                      Was statement close UNsuccessful?
                        if (!$return_val)
//                      yes -- close UNsuccessful.
                        {
                           $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

                           etoAbendSubCode($ac, 5, $xo, $ro); // Abend $ac + 5 -- Statement -- mysqli_stmt_close() failed.
                        }
                    }
                    else
//                  no -- already abending.
                    {
                       mysqli_stmt_close($sql_statement);
                    }
                 }
              }
           }
           else
//         no -- execution failure.
           {
              $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

              etoAbendSubCode($ac, 6, $xo, $ro); // Abend $ac + 6 -- Statement -- execute() failed.
           }
        }
        else
//      no -- bind_param() failed.
        {
           $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

           etoAbendSubCode($ac, 7, $xo, $ro); // Abend $ac + 7 -- Statement -- bind_param() failed.
        }
     }
     else
//    no -- prepare failed.
     {
        $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

        etoAbendSubCode($ac, 8, $xo, $ro); // Abend $ac + 8 -- Statement -- prepare() failed.
     }
  }
  else
// no -- statement object creation failed.
  {
     $return_val = false;

     $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

     etoAbendSubCode($ac, @@@8, $xo, $ro); // Abend $ac + 8 -- Statement -- prepare() failed.
  }

/*
// Testing ...
   global $sql_errno;
   global $sql_state;
   global $sys_exit_code;

  $tst_diag = '';
  $tst_diag .= ( '##etoSQLstmtDo()##  ' );
  $tst_diag .= ( '**$sql_query<' . $sql_query . '>**  ' );

  $tst_diag .= ( '**mysqli_field_count($sql_link)<' . mysqli_field_count($sql_link) . '>**  ' );

  $tst_diag .= ( '**is_bool($sql_result)<' . is_bool($sql_result) . '>**  ' );
  $tst_diag .= ( '**$sql_errno<' . $sql_errno . '>**  ' );
  $tst_diag .= ( '**$sql_state<' . $sql_state . '>**  ' );

  $tst_diag .= ( '**$sys_exit_code<' . $sys_exit_code . '>**  ' );
  $tst_diag .= ( '**$return_val<' . $return_val . '>**  ' );

  echo htmlspecialchars($tst_diag, ENT_QUOTES);
// ... Testing.
*/ /*

  return $return_val;
}
*/

// etoSQLstmtXxxxx (SQL statement processing) ...

function etoSQLstmtAbendSubCode($ac, $sc, $xo, $ro)
{
  global $sql_stmt_is_abending;

  $sql_stmt_is_abending = true;

// Cleanup -- terminate and free dynamically-allocated objects.
  etoSQLstmtClose($ac, $xo, $ro); // Parameters are DUMMY (functon etoSQLstmtClose(...) will NOT call function etoAbendSubCode(...) when called from here).

  etoAbendSubCode($ac, $sc, $xo, $ro);

  return;

}

function etoSQLstmtOpen
(
  $qs = '', // query parameter(s) type specification.

  $qb,      // query parameter(s) bind array.

  $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK // abend code, abend exit option, abend SQL rollback option.
)
{
  global $sql_link;
  global $sql_query;

  global $sql_state_class;
  global $sql_row_count;
  global $sql_afec_row_count;

  global $sql_statement;
  global $sql_stmt_meta_result;
  global $sql_stmt_is_abending;

//  global $sys_exit_code; // $ac mapping: ($ac+0) ... ($ac+4) => 5 slots.
  global $sys_exit_msg;

  $return_val = true;

  $sql_row_count        = 0;
  $sql_afec_row_count   = 0;

  $sql_statement        = false;
  $sql_stmt_meta_result = false;
  $sql_result           = false;
  $sql_stmt_is_abending = false;

/*
// Testing ...
   global $sql_errno;
   global $sql_state;
   global $sys_exit_code;

  $tst_diag = '';
  $tst_diag .= ( '##etoSQLstmtOpen() (#1) ##  ' );
  $tst_diag .= ( '**$qs<' . $qs . '>**  ' );
  $tst_diag .= ( '**$ac<' . $ac . '>**  ' );

  $tst_diag .= ( '**$sql_query<' . $sql_query . '>**  ' );
  $tst_diag .= ( '**$sql_stmt_is_abending<' . $sql_stmt_is_abending . '>**  ' );

  $tst_diag .= ( '**$sql_errno<' . $sql_errno . '>**  ' );
  $tst_diag .= ( '**$sql_state<' . $sql_state . '>**  ' );

  $tst_diag .= ( '**$sys_exit_code<' . $sys_exit_code . '>**  ' );
  $tst_diag .= ( '**$return_val<' . $return_val . '>**  ' );

  echo htmlspecialchars($tst_diag, ENT_QUOTES);
// ... Testing.
*/

// Is the mysqli_ query statement object created?
  if ($sql_statement = mysqli_stmt_init($sql_link))
// yes -- statement object created.
  {
// @@@    {$return_val = ($sql_statement -> prepare($sql_query));
     $return_val = ($sql_statement -> prepare($sql_query));
//     $return_val = mysqli_stmt_prepare($sql_statement, $sql_query);

     etoSQLstmtGetMysqliDiag();

//   Is SQLSTATE success?
     if ($sql_state_class == '00')
//   yes - success.
     {
//      Did query statement prepare OK?
        if ($return_val)
//      yes -- prepared OK.
        {
//         Bind the sql statement parameters to the reference(s) passed via array.
           switch (strlen($qs))
           {
              case  0: { break; }

              case  1: { $return_val = mysqli_stmt_bind_param($sql_statement, $qs, $qb[0]); break; }

              case  2: { $return_val = mysqli_stmt_bind_param($sql_statement, $qs, $qb[0], $qb[1]); break; }

              case  3: { $return_val = mysqli_stmt_bind_param($sql_statement, $qs, $qb[0], $qb[1], $qb[2]); break; }

              case  4: { $return_val = mysqli_stmt_bind_param($sql_statement, $qs, $qb[0], $qb[1], $qb[2], $qb[3]); break; }

              case  5: { $return_val = mysqli_stmt_bind_param($sql_statement, $qs, $qb[0], $qb[1], $qb[2], $qb[3], $qb[4]); break; }

              case  6: { $return_val = mysqli_stmt_bind_param($sql_statement, $qs, $qb[0], $qb[1], $qb[2], $qb[3], $qb[4], $qb[5]); break; }

              case  7: { $return_val = mysqli_stmt_bind_param($sql_statement, $qs, $qb[0], $qb[1], $qb[2], $qb[3], $qb[4], $qb[5], $qb[6]); break; }

              case  8: { $return_val = mysqli_stmt_bind_param($sql_statement, $qs, $qb[0], $qb[1], $qb[2], $qb[3], $qb[4], $qb[5], $qb[6], $qb[7]); break; }

              case  9: { $return_val = mysqli_stmt_bind_param($sql_statement, $qs, $qb[0], $qb[1], $qb[2], $qb[3], $qb[4], $qb[5], $qb[6], $qb[7], $qb[8]); break; }

              case 10: { $return_val = mysqli_stmt_bind_param($sql_statement, $qs, $qb[0], $qb[1], $qb[2], $qb[3], $qb[4], $qb[5], $qb[6], $qb[7], $qb[8], $qb[9]); break; }

              case 11: { $return_val = mysqli_stmt_bind_param($sql_statement, $qs, $qb[0], $qb[1], $qb[2], $qb[3], $qb[4], $qb[5], $qb[6], $qb[7], $qb[8], $qb[9], $qb[10]); break; }

              case 12: { $return_val = mysqli_stmt_bind_param($sql_statement, $qs, $qb[0], $qb[1], $qb[2], $qb[3], $qb[4], $qb[5], $qb[6], $qb[7], $qb[8], $qb[9], $qb[10], $qb[11]); break; }

              case 13: { $return_val = mysqli_stmt_bind_param($sql_statement, $qs, $qb[0], $qb[1], $qb[2], $qb[3], $qb[4], $qb[5], $qb[6], $qb[7], $qb[8], $qb[9], $qb[10], $qb[11], $qb[12]); break; }

              case 14: { $return_val = mysqli_stmt_bind_param($sql_statement, $qs, $qb[0], $qb[1], $qb[2], $qb[3], $qb[4], $qb[5], $qb[6], $qb[7], $qb[8], $qb[9], $qb[10], $qb[11], $qb[12], $qb[13]); break; }

              case 15: { $return_val = mysqli_stmt_bind_param($sql_statement, $qs, $qb[0], $qb[1], $qb[2], $qb[3], $qb[4], $qb[5], $qb[6], $qb[7], $qb[8], $qb[9], $qb[10], $qb[11], $qb[12], $qb[13], $qb[14]); break; }

              case 16: { $return_val = mysqli_stmt_bind_param($sql_statement, $qs, $qb[0], $qb[1], $qb[2], $qb[3], $qb[4], $qb[5], $qb[6], $qb[7], $qb[8], $qb[9], $qb[10], $qb[11], $qb[12], $qb[13], $qb[14], $qb[15]); break; }

              case 17: { $return_val = mysqli_stmt_bind_param($sql_statement, $qs, $qb[0], $qb[1], $qb[2], $qb[3], $qb[4], $qb[5], $qb[6], $qb[7], $qb[8], $qb[9], $qb[10], $qb[11], $qb[12], $qb[13], $qb[14], $qb[15], $qb[16]); break; }

              default:
              {
                 $return_val = false;

                 etoSQLstmtGetMysqliDiag();
                 $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

                 etoSQLstmtAbendSubCode($ac, 0, $xo, $ro); // Abend $ac + 0 -- Statement -- Cannot bind_param() - Invalid count of query parameter type specifications.

                 break;
              }
           }

           etoSQLstmtGetMysqliDiag();

//         Did bind_param() succeed?
           if ($return_val)
//         yes -- bind_param() succeeded.
           {
//            Metsdata available right after prepare (false return means no result expected by query).
              $sql_stmt_meta_result = mysqli_stmt_result_metadata($sql_statement);
           }
//         no -- bind_param() failed.
           else
           {
              $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

              etoSQLstmtAbendSubCode($ac, 1, $xo, $ro); // Abend $ac + 1 -- Statement -- mysqli_stmt_bind_param() failed.
           }
        }
//      no -- prepare failed.
        else
        {
           $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

           etoSQLstmtAbendSubCode($ac, 2, $xo, $ro); // Abend $ac + 2 -- Statement -- mysqli_stmt_prepare() failed.
        }
     }
//   no - NOT success.
     else
     {
        $return_val = false;

        etoSQLstmtGetMysqliDiag();
        $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

        etoSQLstmtAbendSubCode($ac, 3, $xo, $ro); // Abend $ac + 3 -- Statement -- Cannot bind_param() - Invalid count of query parameter type specifications.
     }
  }
  else
// no -- statement object creation failed.
  {
     $return_val = false;

     $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

//   Can safely call directly -- nothing allocated.
     etoAbendSubCode($ac, 4, $xo, $ro); // Abend $ac + 4 -- Statement -- mysqli_stmt_init() failed.
  }

/*
// Testing ...
   global $sql_errno;
   global $sql_state;
   global $sys_exit_code;

  $tst_diag = '';
  $tst_diag .= ( '##etoSQLstmtOpen()(#2)##  ' );
  $tst_diag .= ( '**$sql_query<' . $sql_query . '>**  ' );
  $tst_diag .= ( '**$sql_stmt_is_abending<' . $sql_stmt_is_abending . '>**  ' );

  $tst_diag .= ( '**$sql_errno<' . $sql_errno . '>**  ' );
  $tst_diag .= ( '**$sql_state<' . $sql_state . '>**  ' );

  $tst_diag .= ( '**$sys_exit_code<' . $sys_exit_code . '>**  ' );
  $tst_diag .= ( '**$return_val<' . $return_val . '>**  ' );

  echo htmlspecialchars($tst_diag, ENT_QUOTES);
// ... Testing.
*/

   return $return_val;
}

function etoSQLstmtDo
(
  $rb,      // result parameter(s) bind array.

  $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK // abend code, abend exit option, abend SQL rollback option.
)
{
  global $sql_link;

  global $sql_statement;
  global $sql_stmt_meta_result;

  global $sql_row_count;
  global $sql_afec_row_count;

// @@@Abend code allocation ...

//  slots  function
//  -----  --------
//
//    5     etoSQLstmtDo(...)     => this function.
//
//    4     @@@etoSQLcheckQuery(...) => called by this function.
//  -----
//    9

// ... Abend code allocation.

  global $sys_exit_code; // $ac mapping: ($ac+0) ... ($ac+5+4-1) => 9 slots.

  global $sys_exit_msg;

  $return_val = false;

// execute sql statement.
   $return_val = mysqli_stmt_execute($sql_statement);

   etoSQLstmtGetMysqliDiag();

// Was sql statement execute successful?
   if ($return_val)
// yes -- execute successful.
   {
//    Is SQLSTATE success?
      if
      (
         $return_val
         =
         etoSQLqueryExecSuccess()
      )
//    yes - SQLSTATE success.
      {
         $sql_row_count      = mysqli_stmt_num_rows($sql_statement);
         $sql_afec_row_count = mysqli_stmt_affected_rows($sql_statement);

         $return_val = etoSQLcheckQuery($ac+X4a, $xo, $ro); // abend code, abend exit option, SQL abend rollback option.
//       $return_val = etoSQLcheckQuery($ac+5, $xo, $ro); // abend code, abend exit option, SQL abend rollback option.

//       NOT abending?
         if (!$sys_exit_code)
//       yes -- not abending.
         {
//          Were rows selected / affected?
            if ($return_val)
//          yes -- rows selected / affected.
            {
//             Is a result set expected?
               if ($sql_stmt_meta_result)
//             yes -- result set expected.
               {
                  $return_val = mysqli_stmt_store_result($sql_statement);

//                Is store_result() successful?
                  if ($return_val)
//                yes -- store_result() successful.
                  {
//                   Were 1+ row(s) returned?
                     if ($sql_row_count)
//                   yes -- 1+ row(s) returned.
                     {
//                      Bind the sql statement result to the storage parameter references passed via array.
                        switch (count($rb))
                        {
                           case  0: { break; }

                           case  1: { $return_val = mysqli_stmt_bind_result($rb[0]); break; }

                           case  2: { $return_val = mysqli_stmt_bind_result($rb[0], $rb[1]); break; }

                           case  3: { $return_val = mysqli_stmt_bind_result($rb[0], $rb[1], $rb[2]); break; }

                           case  4: { $return_val = mysqli_stmt_bind_result($rb[0], $rb[1], $rb[2], $rb[3]); break; }

                           case  5: { $return_val = mysqli_stmt_bind_result($rb[0], $rb[1], $rb[2], $rb[3], $rb[4]); break; }

                           case  6: { $return_val = mysqli_stmt_bind_result($rb[0], $rb[1], $rb[2], $rb[3], $rb[4], $rb[5]); break; }

                           case  7: { $return_val = mysqli_stmt_bind_result($rb[0], $rb[1], $rb[2], $rb[3], $rb[4], $rb[5], $rb[6]); break; }

                           case  8: { $return_val = mysqli_stmt_bind_result($rb[0], $rb[1], $rb[2], $rb[3], $rb[4], $rb[5], $rb[6], $rb[7]); break; }

                           case  9: { $return_val = mysqli_stmt_bind_result($rb[0], $rb[1], $rb[2], $rb[3], $rb[4], $rb[5], $rb[6], $rb[7], $rb[8]); break; }

                           case 10: { $return_val = mysqli_stmt_bind_result($rb[0], $rb[1], $rb[2], $rb[3], $rb[4], $rb[5], $rb[6], $rb[7], $rb[8], $rb[9]); break; }

                           case 11: { $return_val = mysqli_stmt_bind_result($rb[0], $rb[1], $rb[2], $rb[3], $rb[4], $rb[5], $rb[6], $rb[7], $rb[8], $rb[9], $rb[10]); break; }

                           case 12: { $return_val = mysqli_stmt_bind_result($rb[0], $rb[1], $rb[2], $rb[3], $rb[4], $rb[5], $rb[6], $rb[7], $rb[8], $rb[9], $rb[10], $rb[11]); break; }

                           case 13: { $return_val = mysqli_stmt_bind_result($rb[0], $rb[1], $rb[2], $rb[3], $rb[4], $rb[5], $rb[6], $rb[7], $rb[8], $rb[9], $rb[10], $rb[11], $rb[12]); break; }

                           case 14: { $return_val = mysqli_stmt_bind_result($rb[0], $rb[1], $rb[2], $rb[3], $rb[4], $rb[5], $rb[6], $rb[7], $rb[8], $rb[9], $rb[10], $rb[11], $rb[12], $rb[13]); break; }

                           default:
                           {
                              $return_val = false;

                              $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

                              etoSQLstmtAbendSubCode($ac, 0, $xo, $ro); // Abend $ac + 0 -- Statement -- Cannot bind_result() - Invalid count of storage parameter references in bind array.

                              break;
                           }
                        }

//                      Was bind_result() UNsucessful?
                        if (!$return_val)
//                      yes -- bind_result() UNsuccessful.
                        {
//                         NOT already abending?
                           if (!$sys_exit_code)
//                         yes -- NOT abending.
                           {
                              $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

                              etoSQLstmtAbendSubCode($ac, 1, $xo, $ro); // Abend $ac + 1 -- Statement -- bind_result() failed.
                           }
                        }
                     }
                  }
                  else
//                no -- store_result() UNsuccessful.
                  {
                     $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

                     etoSQLstmtAbendSubCode($ac, 2, $xo, $ro); // Abend $ac + 2 -- Statement -- store_result() failed.
                  }
               }
            }
         }
      }
//    no - SQLSTATE NOT success.
      else
      {
         $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

         etoSQLstmtAbendSubCode($ac, 3, $xo, $ro); // Abend $ac + 3 -- Statement -- mysqli_stmt_execute() - SQLSTATE NOT success.
      }
   }
   else
// no -- execute UNsuccessful.
   {
      $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

      etoSQLstmtAbendSubCode($ac, 4, $xo, $ro); // Abend $ac + 4 -- Statement -- execute() failed.
   }

/*
// Testing ...
   global $sql_errno;
   global $sql_state;
   global $sys_exit_code;

  $tst_diag = '';
  $tst_diag .= ( '##etoSQLstmtDo()##  ' );
  $tst_diag .= ( '**$sql_query<' . $sql_query . '>**  ' );
  $tst_diag .= ( '**$sql_row_count<' . $sql_row_count . '>**  ' );
  $tst_diag .= ( '**$sql_afec_row_count<' . $sql_afec_row_count . '>**  ' );

  $tst_diag .= ( '**$sql_errno<' . $sql_errno . '>**  ' );
  $tst_diag .= ( '**$sql_state<' . $sql_state . '>**  ' );

  $tst_diag .= ( '**$sys_exit_code<' . $sys_exit_code . '>**  ' );
  $tst_diag .= ( '**$return_val<' . $return_val . '>**  ' );

  echo htmlspecialchars($tst_diag, ENT_QUOTES);
// ... Testing.
*/

   return $return_val;
}

/* function etoSQLstmtFetch(@@@) */

function etoSQLstmtClose($ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK) // abend code, abend sub-code, abend exit option, abend SQL rollback option.
{
  global $sql_state_class;

  global $sql_statement;
  global $sql_stmt_meta_result;
  global $sql_stmt_is_abending;

// global $sys_exit_code; // $ac mapping: ($ac+0) => 1 slot.
  global $sys_exit_msg;

  $return_val = true;

// Does a statement object exist?
  if (is_object($sql_statement))
// yes -- statement object exists.
  {
//  Does a statement result metsdata object exist?
     if (is_object($sql_stmt_meta_result))
//   yes -- result metadata object exists;
     {
//      Then free the data result set object created by mysqli_stmt_store_result(...) call in etoSQLstmtDo(...).
        mysqli_stmt_free_result($sql_statement);

//      Free the statement metadata result object;
        mysqli_free_result($sql_stmt_meta_result);
     }

//   Close the statement and free the statement object.
     $return_val = mysqli_stmt_close($sql_statement);

//   etoSQLstmtGetMysqliDiag(); // CAN'T DO THIS -- statement has already been destroyed!

//   Statement close UNsuccessful?
     if (!$return_val)
//   yes -- close UNsuccessful.
     {
//      NOT already abending?
        if (!$sql_stmt_is_abending)
//      yes -- NOT already abending.
        {
           $sys_exit_msg = '(' . '** NO SQL DIAGNOSTIC AVAILABLE -- mysqli_stmt_close(..) returned false value **' . ')';
//         $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

//         Can safely call directly -- already in etoSQLstmtClose(...).
           etoAbendSubCode($ac, 0, $xo, $ro); // Abend $ac + 0 Statement -- etoSQLstmtClose() -- mysqli_stmt_close() failed.
        }
     }
  }

/*
// Testing ...
   global $sql_errno;
   global $sql_state;
   global $sys_exit_code;

  $tst_diag = '';
  $tst_diag .= ( '##etoSQLstmtClose()##  ' );
  $tst_diag .= ( '**$sql_stmt_is_abending<' . $sql_stmt_is_abending . '>**  ' );

  $tst_diag .= ( '**$sql_errno<' . $sql_errno . '>**  ' );
  $tst_diag .= ( '**$sql_state<' . $sql_state . '>**  ' );

  $tst_diag .= ( '**$sys_exit_code<' . $sys_exit_code . '>**  ' );
  $tst_diag .= ( '**$return_val<' . $return_val . '>**  ' );

  echo htmlspecialchars($tst_diag, ENT_QUOTES);
// ... Testing.
*/

  return $return_val;
}

/*
function etoSQLstmtFetch
@@@
(
  $qs, // query parameter(s) type specification.

  $rs, // result parameter(s) type specification.

  $qb, // query parameter(s) bind array.

  $rb, // result parameter(s) bind array.

  $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK // abend code, abend exit option, abend SQL rollback option.
)
{
  global $sql_link;
  global $sql_query;
  global $sql_statement;
  global $sql_result;
  global $sql_row_count;
  global $sql_afec_row_count;
  global $sql_fetch_count;

  $return_val = true;

  $sql_row_count_type      = IS_OTHER;
  $sql_afec_row_count_type = IS_OTHER;

  etoSQLinitCall();

  @@@ fetch next row with each call.
  @@@ how to detect END?
  @@@ return false at END
  @@@ close statement at END.

  @@@


// Did the query complete? (i.e. valid SQL statement, no MySQL internal problems.)
  if ($sql_result)
// yes -- query complete.
  {
  }
  @@@

  @@@
    // fetch value
    $stmt->fetch();

    printf("%s is in district %s\n", $city, $district);

    //close statement
    $stmt->close();
@@@

  return $return_val;
}
@@@
// ... etoSQLstmtResult(...), etoSQLstmtFetch(...).
*/

// ... etoSQLstmtXxxxx.


function etoSQLdbClose($ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK, $co = SQL_COMMIT) // abend code, abend exit option, abend SQL rollback option, SQL commit option.
{
// Abend code allocation ...

//  slots  function
//  -----  --------
//
//    7     etoSQLdbClose(...) => this function.
//
//    9     etoSQLquery(...)   => called by this function.
//    9     etoSQLquery(...)   => called by this function.
//  -----
//   25

// ... Abend code allocation.

  global $sys_exit_code; // $ac mapping: ($ac+0) ... ($ac+25-1) => 25 slots.
  global $sys_exit_msg;

  global $sql_conn;
  global $sql_query;

  global $sql_transaction_status;

  $return_val = true;
  $sql_abend_inc = 0; // abend sub_code increment.

  etoSQLinitCall();

// Commit requested?
  if ($co)
// yes -- commit requested.
  {
//   Did function etoSQLdbOpen(...) BEGIN; a transaction block?
     if ($sql_transaction_status == PGSQL_TRANSACTION_INTRANS)
//   yes -- in a transaction block.
     {
        $sql_query = 'END;';
        
//      Is END; query successful?
        if (etoSQLquery(($ac+Yja), $xo, $ro, SQL_NASUM_EQ0))
//      yes -- END; query successful.
        {
//         Is pg_close (...) UNsuccessful?
           if (!pg_close ($sql_conn))
           {
              $return_val    = false;
              $sql_abend_inc = 0; // pg_close (...) UNsuccessful;
           }
        }
        else
//      no -- END; query UNsuccessful.
        {
           $return_val    = false;
           $sql_abend_inc = 1;
        
//         Is pg_close (...) UNsuccessful?
           if (!pg_close ($sql_conn))
           {
              $return_val    = false;
              $sql_abend_inc = 2; // END; query & pg_close (...) BOTH UNsuccessful;
           }
        }
     }
     else
//   no -- NOT in a transaction block.
     {
        $return_val    = false;
        $sql_abend_inc = 3; // END; query & pg_close (...) BOTH UNsuccessful;
     }
  }
  else
// no -- commit NOT requested.
  {
// @@@...
//  Test abend in requirer -- etoSQLdbClose() fails.
//      (does not generate any mysqli diagnostics).
//  $sql_link = '';
// ...@@@

//   Did function etoSQLdbOpen(...) BEGIN; a transaction block?
     if ($sql_transaction_status == PGSQL_TRANSACTION_INTRANS)
//   yes -- in a transaction block.
     {
        $sql_query = 'ROLLBACK;';
        
//      Is ROLLBACK; query successful?
        if (etoSQLquery(($ac+Yja+Yh), $xo, $ro, SQL_NASUM_EQ0))
//      yes -- ROLLBACK; query successful.
        {
//         Is pg_close (...) UNsuccessful?
           if (!pg_close ($sql_conn))
           {
              $return_val    = false;
              $sql_abend_inc = 4; // pg_close (...) UNsuccessful;
           }
        }
        else
//      no -- ROLLBACK; query UNsuccessful.
        {
           $return_val    = false;
           $sql_abend_inc = 5;
        
//         Is pg_close (...) UNsuccessful?
           if (!pg_close ($sql_conn))
           {
              $return_val    = false;
              $sql_abend_inc = 6; // ROLLBACK; query & pg_close (...) BOTH UNsuccessful;
           }
        }
     }
  }

// Was a commit, rollback or close UNsuccessful?
  if (!$return_val)
// yes -- UNsuccessful.
  {
//   NOT already abending? (i.e. etoSQLdbClose(...) NOT called from etoAbendReal(...)).
     if (!$sys_exit_code)
//   yes -- NOT already abending.
     {
        etoSQLgetMysqliDiag();

        $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

        etoAbendSubCode($ac, $sql_abend_inc, $xo, $ro); // Abend $ac + 0..2 --  mysqli_commit(...) or mysqli_close(...) UNsuccessful.
     }
  }

  return $return_val;
}

function etoSQLtrxRollback($ac, $xo) // abend code, abend exit option.
{
  global $sys_exit_code; // $ac mapping: ($ac+0) ... ($ac+0) => 1 slot.

  global $sql_link;

  $return_val = true;

  etoSQLinitCall();

  $return_val = mysqli_rollback($sql_link);

// Was rollback UNsuccessful?
  if (!$return_val)
// yes -- rollback UNsuccessful.
  {
//   NOT already abending? (i.e. etoSQLtrxRollback(...) NOT called from etoAbendReal(...)).
     if (!$sys_exit_code)
//   yes -- NOT already abending.
     {
        etoSQLgetMysqliDiag();

        $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

        etoAbend($ac, $xo); // Abend $ac -- mysqli_rollback(...) UNsuccessful.
     }
  }

  return $return_val;
}

// function etoSQLreadRow_visitor_ses($sc, $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK, $lo = SQL_NOLOCK) // session code, abend code, abend exit option, abend SQL rollback option, SQL row lock option.
function etoSQLreadRow_session_www($sc, $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK, $lo = SQL_NOLOCK) // session code, abend code, abend exit option, abend SQL rollback option, SQL row lock option.
{
   global $sql_query;
   global $sql_result;
	global $sql_fetch;

   global $sql_errno;
   global $sql_state;
   global $sql_state_class;

	global $session_www_code;
	global $session_www_type;
	global $session_www_state;
   global $session_verify_code;
   global $session_www_serno;
   global $session_target_serno;
   global $session_target_data;
   global $session_www_init_utc;
   global $session_www_last_utc;
   global $session_www_expiry_utc;
   global $session_www_delete_utc;
   global $session_www_hit_count;
   global $session_www_act_seqno;

	global $session_www_act_seqhsh;

// Abend code allocation ...

//  slots  function
//  -----  --------
//
//    2     etoSQLreadRow_session_www(...)     => this function.
//
//    7     etoSQLquery(...) => called by this function.
//  -----
//    9

// ... Abend code allocation.

   global $sys_exit_code; // $ac mapping: ($ac+0) ... ($ac+2+7-1) => 9 slots.
   global $sys_exit_msg;

   $return_val = true;

   etoSQLinitCall();

   $sql_query = "SELECT session_www_code, session_www_type, session_www_state, session_verify_code, session_www_serno, session_target_serno, session_target_data, session_www_init_utc, session_www_last_utc, session_www_expiry_utc, session_www_delete_utc, session_www_hit_count, session_www_act_seqno FROM eto_sql_tb_session_www WHERE session_www_code = '$sc'";
// $sql_query = "SELECT session_www_code, session_www_type, session_www_state, session_verify_code, session_www_serno, session_target_serno, session_target_data, session_www_init_utc, session_www_last_utc, session_www_expiry_utc, session_www_delete_utc, session_www_hit_count FROM eto_sql_tb_session_www WHERE session_www_code = '$sc'";

// Test abend $ac + 0 (invalid table name.)
// $sql_query = "SELECT session_www_code, session_www_type, session_www_state, session_verify_code, session_www_serno, session_target_serno, session_target_data, session_www_init_utc, session_www_last_utc, session_www_expiry_utc, session_www_delete_utc, session_www_hit_count FROM eto_sql_tb_session_wwwX WHERE session_www_code = '$sc'";

// Lock the row?
   if ($lo)
// yes -- lock row.
   {
      $sql_query .= " FOR UPDATE";
//
//    Presumably could obtain here, or stimulate subsequent occurrences of, e.g. the following MySQL errors:
//      (MySQL Error: 1205 SQLSTATE: HY000 (ER_LOCK_WAIT_TIMEOUT), MySQL Message: Lock wait timeout exceeded; try restarting transaction.
//          Saw the 1205 in a MySQL command line lock imeout test.)
//      (MySQL Error: 1206 SQLSTATE: HY000 (ER_LOCK_TABLE_FULL),   MySQL Message: The total number of locks exceeds the lock table size).
//      (MySQL Error: 1213 SQLSTATE: 40001 (ER_LOCK_DEADLOCK),     MySQL Message: Deadlock found when trying to get lock; try restarting transaction ).
//
//    See also PHP function mysqli_options(...) function
//       with MYSQLI_READ_DEFAULT_FILE option
//       to direct MySQL to read its options from named option file instead of my.cnf
   }

// Does the SELECT return at least 1 row?
   if ($return_val = etoSQLquery($ac+X9a, $xo, $ro)) // Abend ($ac+2)+ -- etoSQLquery() failed to deliver row (not missing key).
// if ($return_val = etoSQLquery($ac+2, $xo, $ro)) // Abend ($ac+2)+ -- etoSQLquery() failed to deliver row from $sql_result (not missing key).
// yes -- row(s) available.
   {
     $sql_fetch = mysqli_fetch_row($sql_result);

     mysqli_free_result($sql_result);

//   Test abend $ac + 1
//   (new empty variable as result parm.)
//   (MUST start Apache with no PHP warning messages, to get "xxABEND" image displayed when testing eto_contact_img.php.)
//   $sql_fetch = mysqli_fetch_row($sql_resultX);

//   Was the fetch row successful? (defensive programming -- should ALWAYS succeed.)
	  if ($sql_fetch)
//   yes -- fetch successful.
     {
	   	$session_www_code       =      $sql_fetch[0];
	   	$session_www_type       = (int)$sql_fetch[1];
	   	$session_www_state      = (int)$sql_fetch[2];
         $session_verify_code    =      $sql_fetch[3];
         $session_www_serno      = (int)$sql_fetch[4];
         $session_target_serno   = (int)$sql_fetch[5];
         $session_target_data    =      $sql_fetch[6];
         $session_www_init_utc   =      $sql_fetch[7];
         $session_www_last_utc   =      $sql_fetch[8];
         $session_www_expiry_utc =      $sql_fetch[9];
         $session_www_delete_utc =      $sql_fetch[10];
         $session_www_hit_count  = (int)$sql_fetch[11];
         $session_www_act_seqno  = (int)$sql_fetch[12];

         etoSQLgetTargData_session_www();

         $session_www_act_seqhsh = etoSQLhashSeqnoDate_session_www($session_www_act_seqno, $session_www_init_utc);
	  }
//   no -- fetch UNsuccessful.
	  else
	  {
   	    $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

   	    etoAbendSubCode($ac, 0, $xo, $ro); // Abend $ac + 0 -- Failed to fetch row from $sql_result (not missing key).

        $return_val = false;
     }
   }
// no -- NO row(s) available.
   else
   {

/*
// Testing ...
  global $sys_exit_code;
  global $sys_script_id;
  global $sql_state;
  global $sql_diag;

if ($sys_script_id != 'eto_verify_img.php')
{
  $tst_diag = '';
  $tst_diag .= ( '##etoSQLreadRow_session_www(#1)##  ' );
  $tst_diag .= ( '**$sc<' . $sc . '>**  ' );
  $tst_diag .= ( '**$session_www_code<' . $session_www_code . '>**  ' );

  $tst_diag .= ( '**$sql_errno<' . $sql_errno . '>**  ' );
  $tst_diag .= ( '**$sql_state<' . $sql_state . '>**  ' );
  $tst_diag .= ( '**$sql_diag<' . $sql_diag . '>**  ' );

  $tst_diag .= ( '**$sys_exit_code<' . $sys_exit_code . '>**  ' );
  $tst_diag .= ( '**$sys_exit_msg<' . $sys_exit_msg . '>**  ' );
  $tst_diag .= ( '**$return_val<' . $return_val . '>**  ' );

  echo htmlspecialchars($tst_diag, ENT_QUOTES);
}
// ... Testing.
*/

//    NOT Abending?
      if (!$sys_exit_code)
//    yes -- NOT abending.
      {
//       Did the query complete?
//       if ($sql_errno == 0)       // true.
//       if ($sql_state == '00000') // true(?).
//       if ($sql_state_class == '02') // No data.
         if
         (
            ($sql_state == '00000')
            ||
            ($sql_state_class == '02') // No data.
         )
//       yes -- query complete => missing key in table.
         {
	   	   etoSQLinitBuff_session_www();
         }
         else
//       no -- query INcomplete.
         {
             $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

   	       etoAbendSubCode($ac, 1, $xo, $ro); // Abend $ac + 1 -- Select failed on table eto_sql_tb_session_www (query INcomplete).
         }
      }
   }

/*
// Testing ...
  global $sys_exit_code;
  global $sys_script_id;
  global $sql_diag;

if ($sys_script_id != 'eto_verify_img.php')
{
  $tst_diag = '';
  $tst_diag .= ( '##etoSQLreadRow_session_www(#2)##  ' );
  $tst_diag .= ( '**$sc<' . $sc . '>**  ' );
  $tst_diag .= ( '**$session_www_code<' . $session_www_code . '>**  ' );

  $tst_diag .= ( '**$session_www_state<' . $session_www_state . '>**  ' );
  $tst_diag .= ( '**is_int($session_www_state)<' . is_int($session_www_state) . '>**  ' );
  $tst_diag .= ( '**is_string($session_www_state)<' . is_string($session_www_state) . '>**  ' );

  $tst_diag .= ( '**$session_verify_code<' . $session_verify_code . '>**  ' );

  $tst_diag .= ( '**$session_target_serno<' . $session_target_serno . '>**  ' );
  $tst_diag .= ( '**is_int($session_target_serno)<' . is_int($session_target_serno) . '>**  ' );
  $tst_diag .= ( '**is_string($session_target_serno)<' . is_string($session_target_serno) . '>**  ' );

  $tst_diag .= ( '**$session_www_init_utc<' . $session_www_init_utc . '>**  ' );
  $tst_diag .= ( '**$session_www_last_utc<' . $session_www_last_utc . '>**  ' );
  $tst_diag .= ( '**$session_www_expiry_utc<' . $session_www_expiry_utc . '>**  ' );
  $tst_diag .= ( '**$session_www_delete_utc<' . $session_www_delete_utc . '>**  ' );
  $tst_diag .= ( '**$session_www_hit_count<' . $session_www_hit_count . '>**  ' );
  $tst_diag .= ( '**$session_www_act_seqno<' . $session_www_act_seqno . '>**  ' );

  $tst_diag .= ( '**$sql_errno<' . $sql_errno . '>**  ' );
  $tst_diag .= ( '**$sql_state<' . $sql_state . '>**  ' );
  $tst_diag .= ( '**$sql_diag<' . $sql_diag . '>**  ' );

  $tst_diag .= ( '**$sys_exit_code<' . $sys_exit_code . '>**  ' );
  $tst_diag .= ( '**$sys_exit_msg<' . $sys_exit_msg . '>**  ' );
  $tst_diag .= ( '**$return_val<' . $return_val . '>**  ' );

  echo htmlspecialchars($tst_diag, ENT_QUOTES);
}
// ... Testing.
*/

  return ($return_val);
}

/* OBSOLETE FUNCTION - DO NOT USE -- exposed to disruption by accidental SQL injection in $session_target_data

// function etoSQLwriteRow_visitor_ses($sc, $vc, $st0 = 0, $st1 = 0, $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK) // session code, verify code, session expiry delta time, session delete delta time, abend code, abend exit option, abend SQL rollback option.
function etoSQLwriteRow_session_www($sc, $st, $ss, $vc, $ts, $td, $st0 = 0, $st1 = 0, $hm, $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK) // session code, session type, session state, verify code, target serno, target data, session expiry delta mins, session delete delta mins, max. ses. hit count, abend code, abend exit option, abend SQL rollback option.
{
  global $sql_link;

  global $sql_query;
  global $sql_fetch;
  global $sql_result;

  global $sql_errno;
  global $sql_state;

  global $session_www_code;
  global $session_www_type;
  global $session_www_state;
  global $session_verify_code;
  global $session_www_serno;
  global $session_target_serno;
  global $session_target_data;
  global $session_www_init_utc;
  global $session_www_last_utc;
  global $session_www_expiry_utc;
  global $session_www_delete_utc;
  global $session_www_hit_count;

  global $sys_exit_code; // $ac mapping: ($ac+0) ... ($ac+6) => 7 slots.
  global $sys_exit_msg;

  global $crn_dtime_utc;

  $return_val = true;

  $tmp_session_www_expiry_utc = addSecs($crn_dtime_utc, ($st0 * 60));          // convert mins to secs.

  $tmp_session_www_delete_utc = addSecs($crn_dtime_utc, (($st0 + $st1) * 60)); // convert mins to secs.

  etoSQLinitCall();

//
//   INSERT INTO eto_sql_tb_session_www
//
//      (
//         session_www_code,
//         session_www_type,
//         session_www_state,
//         session_verify_code,
//         session_target_serno,
//         session_target_data,
//         session_www_init_utc,
//         session_www_last_utc,
//         session_www_expiry_utc,
//         session_www_delete_utc,
//         session_www_hit_count
//      )
//
//      VALUES
//      (
//         '$sc',
//         '$st',
//         '$ss',
//         '$vc',
//         '$ts',
//         '$td',
//         '$crn_dtime_utc',
//         '$crn_dtime_utc',
//         '$tmp_session_www_expiry_utc',
//         '$tmp_session_www_delete_utc',
//         '$hm'
//      )
//

  $sql_query = "INSERT INTO eto_sql_tb_session_www (session_www_code, session_www_type, session_www_state, session_verify_code, session_target_serno, session_target_data, session_www_init_utc, session_www_last_utc, session_www_expiry_utc, session_www_delete_utc, session_www_hit_count ) VALUES('$sc', '$st', '$ss', '$vc', '$ts', '$td', '$crn_dtime_utc', '$crn_dtime_utc', '$tmp_session_www_expiry_utc', '$tmp_session_www_delete_utc', '$hm')";

// Test abend $ac + 1 (invalid table name.)
// $sql_query = "INSERT INTO eto_sql_tb_session_wwwX (session_www_code, session_www_type, session_www_state, session_verify_code, session_target_serno, session_target_data, session_www_init_utc, session_www_last_utc, session_www_expiry_utc, session_www_delete_utc, session_www_hit_count ) VALUES('$sc', '$st', '$ss', '$vc', '$ts', '$td', '$crn_dtime_utc', '$crn_dtime_utc', '$tmp_session_www_expiry_utc', '$tmp_session_www_delete_utc', '$hm')";

// Is attempt to insert row into eto_sql_tb_swession_www table successful?
   if (etoSQLquery($ac+1, $xo, $ro)) // Abend ($ac+1)+ -- etoSQLquery() failed to insert row into table eto_sql_tb_session_www.
// yes -- row insert successful.
   {
      $session_www_code       = $sc;
      $session_www_type       = $st;
      $session_www_state      = $ss;
      $session_verify_code    = $vc;
      $session_www_serno      = etoSQLgetString_insert_id();
      $session_target_serno   = $ts;
      $session_target_data    = $td;
      $session_www_init_utc   = $crn_dtime_utc;
      $session_www_last_utc   = $crn_dtime_utc;
      $session_www_expiry_utc = $tmp_session_www_expiry_utc;
      $session_www_delete_utc = $tmp_session_www_delete_utc;
      $session_www_hit_count  = $hm;
   }
   else
// no -- row insert UNsuccessful.
   {
      $return_val = false;

//    NOT Abending?
      if (!$sys_exit_code)
//    yes -- NOT abending.
      {
//       Was insert failure NOT due to duplicate key?
//       (MySQL Error: 1022, ANSI/ISO SQLSTATE: 23000 (ER_DUP_KEY),     MySQL Message: Can't write; duplicate key in table '%s').
//       (MySQL Error: 1062, ANSI/ISO SQLSTATE: 23000 ((ER_DUP_ENTRY)), MySQL Message: Duplicate entry '%s' for key %d).

//       if (!$sql_errno == 1022)    // false.
//       if (!$sql_errno == 1062)    // true.
   	   if (!$sql_state == '23000') // true.
//       yes -- NOT duplicate key.
         {
            $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

            etoAbend($ac, $xo, $ro); // Abend -- Failed to insert row into table eto_sql_tb_session_www (not duplicate key error).
   	   }
   	}
   }

/*
// Testing ...
  global $sys_exit_code;
  $tst_diag = '';
  $tst_diag .= ( '##etoSQLwriteRow_session_www(...)##  ' );
  $tst_diag .= ( '**$sc<' . $sc . '>**  ' );
  $tst_diag .= ( '**$session_www_code<' . $session_www_code . '>**  ' );
  $tst_diag .= ( '**$session_www_state<' . $session_www_state . '>**  ' );
  $tst_diag .= ( '**$session_verify_code<' . $session_verify_code . '>**  ' );

  $tst_diag .= ( '**$session_www_init_utc<' . $session_www_init_utc . '>**  ' );
  $tst_diag .= ( '**$session_www_last_utc<' . $session_www_last_utc . '>**  ' );
  $tst_diag .= ( '**$session_www_expiry_utc<' . $session_www_expiry_utc . '>**  ' );
  $tst_diag .= ( '**$session_www_delete_utc<' . $session_www_delete_utc . '>**  ' );
  $tst_diag .= ( '**$session_www_hit_count<' . $session_www_hit_count . '>**  ' );

  $tst_diag .= ( '**$sql_errno<' . $sql_errno . '>**  ' );
  $tst_diag .= ( '**$sql_state<' . $sql_state . '>**  ' );

  $tst_diag .= ( '**$sys_exit_code<' . $sys_exit_code . '>**  ' );
  $tst_diag .= ( '**$return_val<' . $return_val . '>**  ' );

  echo htmlspecialchars($tst_diag, ENT_QUOTES);
// ... Testing.
// \*\/

  return ($return_val);
}
*/

function etoSQLstmtWriteRow_session_www(&$sc, &$st, &$ss, &$vc, &$ts, &$td, $st0 = 0, $st1 = 0, &$hm, $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK) // session code, session type, session state, verify code, target serno, target data, session expiry delta mins, session delete delta mins, max. ses. hit count, abend code, abend exit option, abend SQL rollback option.
{
   global $sql_link;
   global $sql_query;

   global $sql_state_class;

   global $DUMMY_BIND_ARY;

   global $session_www_code;
   global $session_www_type;
   global $session_www_state;
   global $session_verify_code;
   global $session_www_serno;
   global $session_target_serno;
   global $session_target_data;
   global $session_www_init_utc;
   global $session_www_last_utc;
   global $session_www_expiry_utc;
   global $session_www_delete_utc;
   global $session_www_hit_count;
   global $session_www_act_seqno;

   global $session_www_act_seqhsh;

   global $crn_dtime_utc;

// Abend code allocation ...

//  slots  function
//  -----  --------
//
//    5     etoSQLstmtWriteRow_session_www(...) => this function.
//
//    5     etoSQLstmtOpen(...)                 => called by this function.
//    9     etoSQLstmtDo(...)                   => called by this function.
//    2     etoSQLstmtClose(...)                => called by this function.
//  -----
//   21

// ... Abend code allocation.

   global $sys_exit_code; // $ac mapping: ($ac+0) ... ($ac+19) => 20 slots.
   global $sys_exit_msg;

   $return_val = true;

   $tmp_session_www_expiry_utc = etoSQLtickTockExp_session_www($st0);

   $tmp_session_www_delete_utc = etoSQLtickTockDel_session_www($st0, $st1);

   etoSQLinitCall();

//
//  $sql_query = "INSERT INTO eto_sql_tb_session_www
//
//  (                               $query_param_bind_ary                etoSQLstmtWriteRow_session_www()
//                                  ----------------------------------   --------------------------------
//  session_www_code,         ?,    0 => $sc,                            &$sc,   session code,
//  session_www_type,         ?,    1 => $st,                            &$st,   session type,
//  session_www_state,        ?,    2 => $ss,                            &$ss,   session state,
//  session_verify_code,      ?,    3 => $vc,                            &$vc,   verify code,
//  session_www_serno,        NULL,
//  session_target_serno,     ?,    4 => $ts                             &$ts,   target serno,
//  session_target_data,      ?,    5 => $td,                            &$td,   target data,
//  session_www_init_utc,     ?,    6 => &$crn_dtime_utc,
//  session_www_last_utc,     ?,    7 => &$crn_dtime_utc,
//  session_www_expiry_utc,   ?,    8 => &$tmp_session_www_expiry_utc,
//  session_www_delete_utc,   ?,    9 => &$tmp_session_www_delete_utc,
//  session_www_hit_count,    ?,    10 => $hm                            &$hm,   max. ses. hit count,
//  session_www_act_seqno     NULL
//  )
//  VALUES(?, ?, ?, ?, NULL, ?, ?, ?, ?, ?, ?, ?)";
//
//
//  (Effect of query.)
//
//   INSERT INTO eto_sql_tb_session_www
//
//      (
//         session_www_code,
//         session_www_type,
//         session_www_state,
//         session_verify_code,
//         session_www_serno,
//         session_target_serno,
//         session_target_data,
//         session_www_init_utc,
//         session_www_last_utc,
//         session_www_expiry_utc,
//         session_www_delete_utc,
//         session_www_hit_count,
//         session_www_act_seqno
//      )
//
//      VALUES
//      (
//         '$sc',
//         '$st',
//         '$ss',
//         '$vc',
//          NULL,
//         '$ts',
//         '$td',
//         '$crn_dtime_utc',
//         '$crn_dtime_utc',
//         '$tmp_session_www_expiry_utc',
//         '$tmp_session_www_delete_utc',
//         '$hm',
//          NULL
//      )
//

   $sql_query = "INSERT INTO eto_sql_tb_session_www (session_www_code, session_www_type, session_www_state, session_verify_code, session_www_serno, session_target_serno, session_target_data, session_www_init_utc, session_www_last_utc, session_www_expiry_utc, session_www_delete_utc, session_www_hit_count, session_www_act_seqno) VALUES(?, ?, ?, ?, NULL, ?, ?, ?, ?, ?, ?, ?, NULL)";
// $sql_query = "INSERT INTO eto_sql_tb_session_www (session_www_code, session_www_type, session_www_state, session_verify_code, session_www_serno, session_target_serno, session_target_data, session_www_init_utc, session_www_last_utc, session_www_expiry_utc, session_www_delete_utc, session_www_hit_count ) VALUES(?, ?, ?, ?, NULL, ?, ?, ?, ?, ?, ?, ?)";
// $sql_query = "INSERT INTO eto_sql_tb_session_www (session_www_code, session_www_type, session_www_state, session_verify_code, session_www_serno, session_target_serno, session_target_data, session_www_init_utc, session_www_last_utc, session_www_expiry_utc, session_www_delete_utc, session_www_hit_count ) VALUES(?, ?, ?, ?, ?, NULL, ?, ?, ?, ?, ?, ?)";
// $sql_query = "INSERT INTO eto_sql_tb_session_www (session_www_code, session_www_type, session_www_state, session_verify_code, session_target_serno, session_target_data, session_www_init_utc, session_www_last_utc, session_www_expiry_utc, session_www_delete_utc, session_www_hit_count ) VALUES('$sc', '$st', '$ss', '$vc', '$ts', '$td', '$crn_dtime_utc', '$crn_dtime_utc', '$tmp_session_www_expiry_utc', '$tmp_session_www_delete_utc', '$hm')";

// Test abend $ac + 1 (invalid table name.)
// $sql_query = "INSERT INTO eto_sql_tb_session_www (session_www_code, session_www_type, session_www_state, session_verify_code, session_www_serno, session_target_serno, session_target_data, session_www_init_utc, session_www_last_utc, session_www_expiry_utc, session_www_delete_utc, session_www_hit_count ) VALUES(?, ?, ?, ?, ?, NULL, ?, ?, ?, ?, ?, ?)";

   $query_param_bind_ary
   =
   array
   (
       0 => $sc,
       1 => $st,
       2 => $ss,
       3 => $vc,
       4 => $ts,
       5 => $td,
       6 => &$crn_dtime_utc,
       7 => &$crn_dtime_utc,
       8 => &$tmp_session_www_expiry_utc,
       9 => &$tmp_session_www_delete_utc,
      10 => $hm
   );

// Is statement open successful?
   if
   (
      $return_val
      =
      etoSQLstmtOpen
      (

//       'sssssssssss',         // query parameter type specification (s=string).
         'siisisssssi',         // query parameter type specification (i=integer, s=string).

         $query_param_bind_ary, // query parameter(s) bind array.

         ($ac+Xaa), $xo, $ro      // abend code, abend exit option, abend SQL rollback option.
//       ($ac+4), $xo, $ro      // abend code, abend exit option, abend SQL rollback option.
      )
   )
// yes -- statement open successful.
   {
//    Is statement do successful?
      if
      (
         $return_val
         =
         etoSQLstmtDo
         (
            $DUMMY_BIND_ARY,     // result parameter(s) bind array.

            ($ac+Xaa+X3), $xo, $ro   // abend code, abend exit option, abend SQL rollback option.
//          ($ac+4+5), $xo, $ro   // abend code, abend exit option, abend SQL rollback option.
         )
      )
//    yes -- statement do successful.
      {
//       Is SQLSTATE class acceptable?
         if
         (
            ($sql_state_class == '00') // success.
            ||
            ($sql_state_class == '23') // integrity constraint violation (e.g. duplicate key).
         )
//       yes -- SQLSTATE class acceptable.
         {
//          Wes insert successful?
            if ($sql_state_class == '00')
//          yes -- insert successful.
            {
               $tmp_session_www_serno = etoSQLget_mysqli_insert_id();

//             did serno of inserted row exceed int precision?
               if (!$tmp_session_www_serno)
//             yes - exceeded int precision.
               {
                  $return_val = false;

                  $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

                  etoAbendSubCode($ac, 0, $xo, $ro); // Abend $ac + 0 -- etoSQLstmtDo(...) serno of inserted row exceeded int precision.
               }
            }
            else
//          no -- insert UNsuccessful.
            {
                $return_val = false;
            }

   //       Is statement close successful?
            if (etoSQLstmtClose(($ac+Xaa+X3+X4), $xo, $ro))
//          if (etoSQLstmtClose(($ac+4+5+9), $xo, $ro))
   //       yes -- statement close successful.
            {
//             @@@ test for successful insert
               $session_www_code       = $sc;
               $session_www_type       = $st;
               $session_www_state      = $ss;
               $session_verify_code    = $vc;
               $session_www_serno      = $tmp_session_www_serno;
               $session_target_serno   = $ts;
               $session_target_data    = $td;
               $session_www_init_utc   = $crn_dtime_utc;
               $session_www_last_utc   = $crn_dtime_utc;
               $session_www_expiry_utc = $tmp_session_www_expiry_utc;
               $session_www_delete_utc = $tmp_session_www_delete_utc;
               $session_www_hit_count  = $hm;
               $session_www_act_seqno  = 0;

               $session_www_act_seqhsh = etoSQLhashSeqnoDate_session_www($session_www_act_seqno, $session_www_init_utc);
            }
            else
   //       no -- statement close failed.
            {
   //          NOT already bending?
               if (!$sys_exit_code)
   //          yes -- NOT already abending.
               {
                  $return_val = false;

                  $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

                  etoAbendSubCode($ac, 1, $xo, $ro); // Abend $ac + 1 -- etoSQLstmtClose(...) failed.
               }
            }
         }
         else
//       no -- SQLSTATE class NOT acceptable.
         {
            $return_val = false;

            $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

            etoAbendSubCode($ac, 2, $xo, $ro); // Abend $ac + 2 -- etoSQLstmtDo(...) SQLSTATE class NOT acceptable.
         }
      }
      else
//    no -- statement do failed.
      {
//       NOT already abending?
         if (!$sys_exit_code)
//       yes -- NOT already abending.
         {
            $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

            etoAbendSubCode($ac, 3, $xo, $ro); // Abend $ac + 3 -- etoSQLstmtDo(...) failed.
         }
      }
   }
   else
// no -- statement open failed.
   {
//    NOT already bending?
      if (!$sys_exit_code)
//    yes -- NOT already abending.
      {
         $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

         etoAbendSubCode($ac, 4, $xo, $ro); // Abend $ac + 4 -- etoSQLstmtOpen(...) failed.
      }
   }

/*
// Testing ...
  global $sql_errno;
  global $sql_state;
  global $sys_exit_code;

  $tst_diag = '';
  $tst_diag .= ( '##etoSQLstmtWriteRow_session_www(...)##  ' );
  $tst_diag .= ( '**$sc<' . $sc . '>**  ' );
  $tst_diag .= ( '**$st<' . $st . '>**  ' );
  $tst_diag .= ( '**$ss<' . $ss . '>**  ' );
  $tst_diag .= ( '**$vc<' . $vc . '>**  ' );
  $tst_diag .= ( '**$ts<' . $ts . '>**  ' );
  $tst_diag .= ( '**$td<' . $td . '>**  ' );
  $tst_diag .= ( '**$hm<' . $hm . '>**  ' );

  $tst_diag .= ( '**$session_www_code<' . $session_www_code . '>**  ' );
  $tst_diag .= ( '**$session_www_type<' . $session_www_type . '>**  ' );
  $tst_diag .= ( '**$session_www_state<' . $session_www_state . '>**  ' );
  $tst_diag .= ( '**$session_verify_code<' . $session_verify_code . '>**  ' );
  $tst_diag .= ( '**$session_www_serno<' . $session_www_serno . '>**  ' );
  $tst_diag .= ( '**$session_target_serno<' . $session_target_serno . '>**  ' );
  $tst_diag .= ( '**$session_target_data<' . $session_target_data . '>**  ' );
  $tst_diag .= ( '**$session_www_init_utc<' . $session_www_init_utc . '>**  ' );
  $tst_diag .= ( '**$session_www_last_utc<' . $session_www_last_utc . '>**  ' );
  $tst_diag .= ( '**$session_www_expiry_utc<' . $session_www_expiry_utc . '>**  ' );
  $tst_diag .= ( '**$session_www_delete_utc<' . $session_www_delete_utc . '>**  ' );
  $tst_diag .= ( '**$session_www_hit_count<' . $session_www_hit_count . '>**  ' );
  $tst_diag .= ( '**$session_www_act_seqno<' . $session_www_act_seqno . '>**  ' );

  $tst_diag .= ( '**$sql_errno<' . $sql_errno . '>**  ' );
  $tst_diag .= ( '**$sql_state<' . $sql_state . '>**  ' );

  $tst_diag .= ( '**$sys_exit_code<' . $sys_exit_code . '>**  ' );
  $tst_diag .= ( '**$return_val<' . $return_val . '>**  ' );

  echo htmlspecialchars($tst_diag, ENT_QUOTES);
// ... Testing.
*/

  return ($return_val);
}

/*
// obsolete function ...
// function etoSQLreWriteRow_visitor_ses($ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK) // abend code, abend exit option, abend SQL rollback option.
function etoSQLreWriteRow_session_www($ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK) // abend code, abend exit option, abend SQL rollback option.
{
  global $sql_query;
  global $sql_errno;
  global $sql_state;
  global $sql_afec_row_count;

  global $session_www_code;
  global $session_www_type;
  global $session_www_state;
  global $session_verify_code;
  global $session_target_serno;
  global $session_target_data;
  global $session_www_init_utc;
  global $session_www_last_utc;
  global $session_www_expiry_utc;
  global $session_www_delete_utc;
  global $session_www_hit_count;

  global $sys_exit_code; // $ac mapping: ($ac+0) ... ($ac+8) => 9 slots.
  global $sys_exit_msg;

  global $crn_dtime_utc;

  $return_val = true;

  $session_www_last_utc     = $crn_dtime_utc;
  --$session_www_hit_count;

//
//  (Effect of query.)
//
//   UPDATE eto_sql_tb_session_www
//
//     SET
//         session_www_type       = $session_www_type,
//         session_www_state      = $session_www_state,
//         session_verify_code    = '$session_verify_code',
//         session_target_serno   = '$session_target_serno',
//         session_target_data    = '$session_target_data',
//         session_www_last_utc   = '$session_www_last_utc',
//         session_www_expiry_utc = '$session_www_expiry_utc',
//         session_www_delete_utc = '$session_www_delete_utc',
//         session_www_hit_count  = $session_www_hit_count
//
//     WHERE (session_www_code = '$session_www_code')
//

   $sql_query = "UPDATE eto_sql_tb_session_www SET session_www_type = $session_www_type, session_www_state = $session_www_state, session_verify_code = '$session_verify_code', session_target_serno = '$session_target_serno', session_target_data = '$session_target_data', session_www_last_utc = '$session_www_last_utc', session_www_expiry_utc = '$session_www_expiry_utc', session_www_delete_utc = '$session_www_delete_utc', session_www_hit_count = $session_www_hit_count WHERE (session_www_code = '$session_www_code')";

// Test abend $ac + 0 (invalid table name.)
// $sql_query = "UPDATE eto_sql_tb_session_wwwX SET session_www_type = $session_www_type, session_www_state = $session_www_state, session_verify_code = '$session_verify_code', session_target_serno = '$session_target_serno', session_target_data = '$session_target_data', session_www_last_utc = '$session_www_last_utc', session_www_expiry_utc = '$session_www_expiry_utc', session_www_delete_utc = '$session_www_delete_utc', session_www_hit_count = $session_www_hit_count WHERE (session_www_code = '$session_www_code')";

// Does query UPDATE 1+ row(s) in eto_sql_tb_session_www table?
   if (etoSQLquery($ac+3, $xo, $ro)) // Abend ($ac+3)+ -- etoSQLquery() failed to update row(s) in table eto_sql_tb_session_www (not missing key).
// yes -- 1+ row(s) UPDATEd.
   {
//    Did UPDATE NOT modify exactly 1 row?
      if ($sql_afec_row_count != 1)
//    yes -- bad row count.
      {
         $return_val = false;

         $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

         etoAbendSubCode($ac, 0, $xo, $ro); // Abend $ac + 0 -- Modified more than 1 row in table eto_sql_tb_session_www.
     }
   }
   else
// no -- 0 row(s) UPDATEd.
   {
      $return_val = false;

//    NOT Abending?
      if (!$sys_exit_code)
//    yes -- NOT abending.
      {
         $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

//       Did the query complete?
//       if ($sql_errno == 0)
         if ($sql_state == '00000')
//       yes -- UPDATE query complete => missing key in table.
         {
            etoAbendSubCode($ac, 1, $xo, $ro); // Abend $ac + 1 -- Failed to update row in table eto_sql_tb_session_www (query complete => missing key in table).
         }
         else
//       no -- UPDATE query INcomplete.
         {
            etoAbendSubCode($ac, 2, $xo, $ro); // Abend $ac + 2 -- Failed to update row in table eto_sql_tb_session_www (query INcomplete).
         }
      }
   }

  return ($return_val);
}
// ... obsolete function.
*/

// function etoSQLreWriteRow_visitor_ses($ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK) // abend code, abend exit option, abend SQL rollback option.
function etoSQLstmtReWriteRow_session_www($ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK) // abend code, abend exit option, abend SQL rollback option.
{
  global $sql_query;
  global $sql_errno;
  global $sql_state_class;
  global $sql_afec_row_count;

  global $DUMMY_BIND_ARY;

  global $session_www_code;
  global $session_www_type;
  global $session_www_state;
  global $session_verify_code;
  global $session_target_serno;
  global $session_target_data;
  global $session_www_last_utc;
  global $session_www_expiry_utc;
  global $session_www_delete_utc;
  global $session_www_hit_count;
  global $session_www_act_seqno;

// Abend code allocation ...

//  slots  function
//  -----  --------
//
//    4     etoSQLstmtReWriteRow_session_www(...) => this function.
//
//    5     etoSQLstmtOpen(...)                 => called by this function.
//    9     etoSQLstmtDo(...)                   => called by this function.
//    1     etoSQLstmtClose(...)                => called by this function.
//  -----
//   19

// ... Abend code allocation.

  global $sys_exit_code; // $ac mapping: ($ac+0) ... ($ac+19) => 20 slots.
  global $sys_exit_msg;

  global $crn_dtime_utc;

  $return_val = true;

  $session_www_last_utc = $crn_dtime_utc;

  --$session_www_hit_count;
  ++$session_www_act_seqno;

//
//  (Effect of query.)
//
//   UPDATE eto_sql_tb_session_www
//
//     SET
//         session_www_type       = $session_www_type,
//         session_www_state      = $session_www_state,
//         session_verify_code    = '$session_verify_code',
//         session_target_serno   = '$session_target_serno',
//         session_target_data    = '$session_target_data',
//         session_www_last_utc   = '$session_www_last_utc',
//         session_www_expiry_utc = '$session_www_expiry_utc',
//         session_www_delete_utc = '$session_www_delete_utc',
//         session_www_hit_count  = $session_www_hit_countm,
//         session_www_act_seqno  = $session_www_act_seqno
//
//     WHERE (session_www_code = '$session_www_code')
//

  $sql_query = "UPDATE eto_sql_tb_session_www SET session_www_type = ?, session_www_state = ?, session_verify_code = ?, session_target_serno = ?, session_target_data = ?, session_www_last_utc = ?, session_www_expiry_utc = ?, session_www_delete_utc = ?, session_www_hit_count = ?, session_www_act_seqno = ? WHERE (session_www_code = ?)";
//$sql_query = "UPDATE eto_sql_tb_session_www SET session_www_type = ?, session_www_state = ?, session_verify_code = ?, session_target_serno = ?, session_target_data = ?, session_www_last_utc = ?, session_www_expiry_utc = ?, session_www_delete_utc = ?, session_www_hit_count = ? WHERE (session_www_code = ?)";
// $sql_query = "UPDATE eto_sql_tb_session_www SET session_www_type = $session_www_type, session_www_state = $session_www_state, session_verify_code = '$session_verify_code', session_target_serno = '$session_target_serno', session_target_data = '$session_target_data', session_www_last_utc = '$session_www_last_utc', session_www_expiry_utc = '$session_www_expiry_utc', session_www_delete_utc = '$session_www_delete_utc', session_www_hit_count = $session_www_hit_count WHERE (session_www_code = '$session_www_code')";

// Test abend $ac + 0 (invalid table name.)
// $sql_query = "UPDATE eto_sql_tb_session_wwwX SET session_www_type = ?, session_www_state = ?, session_verify_code = ?, session_target_serno = ?, session_target_data = ?, session_www_last_utc = ?, session_www_expiry_utc = ?, session_www_delete_utc = ?, session_www_hit_count = ? WHERE (session_www_code = ?)";
// $sql_query = "UPDATE eto_sql_tb_session_wwwX SET session_www_type = $session_www_type, session_www_state = $session_www_state, session_verify_code = '$session_verify_code', session_target_serno = '$session_target_serno', session_target_data = '$session_target_data', session_www_last_utc = '$session_www_last_utc', session_www_expiry_utc = '$session_www_expiry_utc', session_www_delete_utc = '$session_www_delete_utc', session_www_hit_count = $session_www_hit_count WHERE (session_www_code = '$session_www_code')";

   $query_param_bind_ary
   =
   array
   (
       0 => &$session_www_type,
       1 => &$session_www_state,
       2 => &$session_verify_code,
       3 => &$session_target_serno,
       4 => &$session_target_data,
       5 => &$session_www_last_utc,
       6 => &$session_www_expiry_utc,
       7 => &$session_www_delete_utc,
       8 => &$session_www_hit_count,
       9 => &$session_www_act_seqno,
      10 => &$session_www_code
   );

// Is statement open successful?
   if
   (
      $return_val
      =
      etoSQLstmtOpen
      (
         'iisissssiis',         // query parameter type specification (i=integer, s=string).
//       'iisissssis',          // query parameter type specification (i=integer, s=string).
//       'ssssssssss',          // query parameter type specification (s=string).

         $query_param_bind_ary, // query parameter(s) bind array.

         ($ac+Xba), $xo, $ro      // abend code, abend exit option, abend SQL rollback option.
//       ($ac+4), $xo, $ro      // abend code, abend exit option, abend SQL rollback option.
      )
   )
// yes -- statement open successful.
   {
//    Is statement do successful?
      if
      (
         $return_val
         =
         etoSQLstmtDo
         (
            $DUMMY_BIND_ARY,     // result parameter(s) bind array.

            ($ac+Xba+X3), $xo, $ro   // abend code, abend exit option, abend SQL rollback option.
//          ($ac+4+5), $xo, $ro   // abend code, abend exit option, abend SQL rollback option.
         )
      )
//    yes -- statement do successful.
      {
//       Is SQLSTATE class acceptable?
         if ($sql_state_class == '00') // success.
//       yes -- SQLSTATE class acceptable.
         {
//          Is statement close successful?
            if
            (
               $return_val
               =
               etoSQLstmtClose(($ac+Xba+X3+X4), $xo, $ro)
//             etoSQLstmtClose(($ac+4+5+9), $xo, $ro)
            )
//          yes -- statement close successful.
            {
//             do nothing.
            }
            else
//          no -- statement close failed.
            {
//             NOT already bending?
               if (!$sys_exit_code)
//             yes -- NOT already abending.
               {
                  $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

                  etoAbendSubCode($ac, 0, $xo, $ro); // Abend $ac + 0 -- etoSQLstmtClose(...) failed.
              }
            }
         }
         else
//       no -- SQLSTATE class UNacceptable.
         {
            $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

            etoAbendSubCode($ac, 1, $xo, $ro); // Abend $ac + 1 -- etoSQLstmtDo(...) failed, SQLSTATE class UNacceptable.
         }
      }
      else
//    no -- statement do failed.
      {
//       NOT already bending?
         if (!$sys_exit_code)
//       yes -- NOT already abending.
         {
            etoSQLstmtGetMysqliDiag();

            $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

            etoAbendSubCode($ac, 2, $xo, $ro); // Abend $ac + 2 -- etoSQLstmtDo(...) failed.
         }
      }
   }
   else
// no -- statement open failed.
   {
//    NOT already bending?
      if (!$sys_exit_code)
//    yes -- NOT already abending.
      {
         etoSQLstmtGetMysqliDiag();

         $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

         etoAbendSubCode($ac, 3, $xo, $ro); // Abend $ac + 3 -- etoSQLstmtOpen(...) failed.
      }
   }

  return ($return_val);
}

// function etoSQLdeleteRow_visitor_ses($sc, $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK) // session code, abend code, abend exit option, abend SQL rollback option.
function etoSQLdeleteRow_session_www($sc, $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK) // session code, abend code, abend exit option, abend SQL rollback option.
{
  global $sql_query;

  global $sys_exit_code;
  global $sys_exit_msg;

// Abend code allocation ...

//  slots  function
//  -----  --------
//
//    1     etoSQLdeleteRow_session_www(...) => this function.
//
//    7     etoSQLquery(...)                 => called by this function.
//  -----
//    8

// ... Abend code allocation.

// global $sys_exit_code; // $ac mapping: ($ac+0) ... ($ac+1+7-1) => 8 slots.

  $return_val = true;

  etoSQLinitCall();

  $sql_query = "DELETE FROM eto_sql_tb_session_www WHERE (session_www_code = '$sc')";

// Test abend $ac (invalid table name.)
//  $sql_query = "DELETE FROM eto_sql_tb_session_wwwX WHERE (session_www_code = '$sc')";

// Is attempt to delete row in eto_sql_tb_session_www table UNsuccessful?
   if (!etoSQLquery($ac+Xca, $xo, $ro)) // Abend ($ac+1)+ -- etoSQLquery() failed to delete row(s) in table eto_sql_tb_session_www (not missing key).
// if (!etoSQLquery($ac+1, $xo, $ro)) // Abend ($ac+1)+ -- etoSQLquery() failed to delete row(s) in table eto_sql_tb_session_www (not missing key).
// yes -- row delete UNsuccessful.
   {
      $return_val = false;

//    NOT Abending?
      if (!$sys_exit_code)
//    yes -- NOT abending.
      {
         $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

         etoAbend($ac, $xo, $ro); // Abend -- Failed to delete row in table eto_sql_tb_session_www.
      }
   }

/*
// Testing ...
	global $session_www_code;
  global $session_verify_code;
  global $session_www_init_utc;
  global $session_www_last_utc;
  global $session_www_expiry_utc;
  global $session_www_hit_count;
  global $session_www_act_seqno;
  global $sql_errno;
  global $sql_state;
  global $sys_exit_code;

  $tst_diag = '';
  $tst_diag .= ( '##etoSQLdeleteRow_session_www(...)##  ' );
  $tst_diag .= ( '**$sc<' . $sc . '>**  ' );
  $tst_diag .= ( '**$session_www_code<' . $session_www_code . '>**  ' );
  $tst_diag .= ( '**$session_verify_code<' . $session_verify_code . '>**  ' );

  $tst_diag .= ( '**$session_www_init_utc<' . $session_www_init_utc . '>**  ' );
  $tst_diag .= ( '**$session_www_last_utc<' . $session_www_last_utc . '>**  ' );
  $tst_diag .= ( '**$session_www_expiry_utc<' . $session_www_expiry_utc . '>**  ' );
  $tst_diag .= ( '**$session_www_hit_count<' . $session_www_hit_count . '>**  ' );
  $tst_diag .= ( '**$session_www_act_seqno<' . $session_www_act_seqno . '>**  ' );

  $tst_diag .= ( '**$sql_errno<' . $sql_errno . '>**  ' );
  $tst_diag .= ( '**$sql_state<' . $sql_state . '>**  ' );

  $tst_diag .= ( '**$sys_exit_code<' . $sys_exit_code . '>**  ' );
  $tst_diag .= ( '**$return_val<' . $return_val . '>**  ' );

  echo htmlspecialchars($tst_diag, ENT_QUOTES);
// ... Testing.
*/

  return ($return_val);
}

function etoSQLsetState_session_www($ss, $st0 = 0, $st1 = 0, $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK) // session state, session expiry delta mins, session delete delta mins, abend code, abend exit option, abend SQL rollback option.
{
  global $session_www_code;
  global $session_www_state;
  global $session_www_delete_utc;

  global $crn_dtime_utc;

//
// *** ABEND CODE MANAGEMENT ***
//
// Each session state target case
//  using function:
//
//    etoSQLreWriteRow_session_www(), or
//
//    etoSQLdeleteRow_session_www()
//
//   maps to a unique range of abend codes,
//   allocated according to the following table:
//
//    -------------------------------------------------------------------
//                    ABEND CODE RANGE TABLE
//    -------------------------------------------------------------------
//                                            function
//                                ----------abend code range-----------
//    session state target     =>     ac_min               ac_max
//    --------------------        --------------       ----------------
//
//                                    etoSQLdeleteRow_session_www()
//    ROW_STATE_NULL           =>     $ac+10       ...      $ac+10+8
//    --------------------        --------------       ----------------
//
//                                 etoSQLstmtReWriteRow_session_www
//    ROW_STATE_LOGIN          => $ac+11+8 +(0*19)  ...  $ac+11+8 +(1*19)-1
//    ROW_STATE_PASSWORD       => $ac+11+8 +(1*19)  ...  $ac+11+8 +(2*19)-1
//    ROW_STATE_EMAIL_LINK     => $ac+11+8 +(2*19)  ...  $ac+11+8 +(3*19)-1
//    ROW_STATE_EMAIL_LOGIN    => $ac+11+8 +(3*19)  ...  $ac+11+8 +(4*19)-1
//    ROW_STATE_INFO           => $ac+11+8 +(4*19)  ...  $ac+11+8 +(5*19)-1
//    ROW_STATE_ACTIVE         => $ac+11+8 +(5*19)  ...  $ac+11+8 +(6*19)-1
//    ROW_STATE_COMPLETE       => $ac+11+8 +(6*19)  ...  $ac+11+8 +(7*19)-1
//    ROW_STATE_EXPIRED        => $ac+11+8 +(7*19)  ...  $ac+11+8 +(8*19)-1
//    ROW_STATE_ABENDED        => $ac+11+8 +(8*19)  ...  $ac+11+8 +(9*19)-1
//    ---------------------------------------------------------------------
//
//  where 11 == count of etoAbendSubCode()s
//   generated by this function (+0..+10),
//
//  and 8 == count of etoAbendSubCode()s
//   generated by function etoSQLdeleteRow_session_www() (+0..+7).
//
//  and 20 == the count of etoAbendSubCode()s
//   generated by function etoSQLstmtReWriteRow_session_www() (+0..+19).
//

// global $sys_exit_code; // $ac mapping: ($ac+0) ... ($ac+198) == ($ac+10+8+(8*20)-1) => 199 slots.

  $return_val = true;

/*
// Testing ...
  global $session_verify_code;
  global $sql_errno;
  global $sql_state;
  global $sys_exit_code;

  $tst_diag = '';
  $tst_diag .= ( '##etoSQLsetState_session_www(#1)##  ' );
  $tst_diag .= ( '**$ss<' . $ss . '>**  ' );

  $tst_diag .= ( '**$session_www_state<' . $session_www_state . '>**  ' );

  $tst_diag .= ( '**$sys_exit_code<' . $sys_exit_code . '>**  ' );
  $tst_diag .= ( '**$return_val<' . $return_val . '>**  ' );

  echo htmlspecialchars($tst_diag, ENT_QUOTES);
// ... Testing.
*/

  switch ($ss)
  {
      case ROW_STATE_NULL:
      {
//       Is row in valid current state?
         if
         (
            ( $session_www_state == ROW_STATE_COMPLETE )
            ||
            ( $session_www_state == ROW_STATE_EXPIRED )
         )
//       yes -- valid current state.
         {
//          Delete row.
            $return_val = etoSQLdeleteRow_session_www($session_www_code, $ac+Xda, $xo, $ro);
//          $return_val = etoSQLdeleteRow_session_www($session_www_code, $ac+10, $xo, $ro);

//          Was delete successful?
            if ($return_val)
//          yes -- delete successful.
            {
               etoSQLinitBuff_session_www();
            }
            else
//          no -- delete UNsuccessful.
            {
//             NOT Abending?
               if (!$sys_exit_code)
//             yes -- NOT abending.
               {
                  etoAbendSubCode($ac, 0, $xo, $ro); // Abend $ac + 0 -- Failed to delete row in table eto_sql_tb_session_www.
               }
            }
         }
//       no -- INvalid current state.
         else
         {
            $return_val = false;

            etoAbendSubCode($ac, 1, $xo, $ro); // Abend $ac + 1 -- INvalid current $session_www_state for transition to ROW_STATE_NULL.
         }

         break;
      }

      case ROW_STATE_LOGIN:
      {
//       Is row in valid current state?
         if
         (
            ($session_www_state == ROW_STATE_LOGIN)
            ||
            ($session_www_state == ROW_STATE_PASSWORD)
         )
//       yes -- valid current state.
         {
//          Set session state.
            $session_www_state = ROW_STATE_LOGIN;

            etoSQLtickTockSet_session_www($st0, $st1);

//          Rewrite row.
            $return_val = etoSQLstmtReWriteRow_session_www($ac+Xda+Xc+(0*Xb), $xo, $ro);
//          $return_val = etoSQLstmtReWriteRow_session_www($ac+10+8+(0*20), $xo, $ro);
         }
//       no -- INvalid current state.
         else
         {
            $return_val = false;

            etoAbendSubCode($ac, 2, $xo, $ro); // Abend $ac + 2 -- INvalid current $session_www_state for transition to ROW_STATE_LOGIN.
         }

         break;
      }

      case ROW_STATE_PASSWORD:
      {
//       Is row in valid current state?
         if
         (
            ($session_www_state == ROW_STATE_LOGIN)
            ||
            ($session_www_state == ROW_STATE_PASSWORD)
            ||
            ($session_www_state == ROW_STATE_ACTIVE)
         )
//       yes -- valid current state.
         {
//          Set session state.
            $session_www_state = ROW_STATE_PASSWORD;

            etoSQLtickTockSet_session_www($st0, $st1);

//          Rewrite row.
            $return_val = etoSQLstmtReWriteRow_session_www($ac+Xda+Xc+(1*Xb), $xo, $ro);
//          $return_val = etoSQLstmtReWriteRow_session_www($ac+10+8+(1*20), $xo, $ro);
         }
//       no -- INvalid current state.
         else
         {
            $return_val = false;

            etoAbendSubCode($ac, 3, $xo, $ro); // Abend $ac + 3 -- INvalid current $session_www_state for transition to ROW_STATE_PASSWORD.
         }

         break;
      }

      case ROW_STATE_EMAIL_LINK:
      {
//       Is row in valid current state?
         if
         (
            ($session_www_state == ROW_STATE_PASSWORD)
//          ($session_www_state == ROW_STATE_LOGIN)
            ||
            ($session_www_state == ROW_STATE_ACTIVE)
         )
//       yes -- valid current state.
         {
//          Set session state.
            $session_www_state = ROW_STATE_EMAIL_LINK;

            etoSQLtickTockSet_session_www($st0, $st1);

//          Rewrite row.
            $return_val = etoSQLstmtReWriteRow_session_www($ac+Xda+Xc+(2*Xb), $xo, $ro);
//          $return_val = etoSQLstmtReWriteRow_session_www($ac+10+8+(2*20), $xo, $ro);
         }
//       no -- INvalid current state.
         else
         {
            $return_val = false;

            etoAbendSubCode($ac, 4, $xo, $ro); // Abend $ac + 4 -- INvalid current $session_www_state for transition to ROW_STATE_EMAIL_LINK.
         }

         break;
      }

      case ROW_STATE_EMAIL_LOGIN:
      {
//       Is row in valid current state?
         if
         (
            ($session_www_state == ROW_STATE_EMAIL_LINK)
            ||
            ($session_www_state == ROW_STATE_EMAIL_LOGIN)
         )
//       yes -- valid current state.
         {
//          Set session state.
            $session_www_state = ROW_STATE_EMAIL_LOGIN;

            etoSQLtickTockSet_session_www($st0, $st1);

//          Rewrite row.
            $return_val = etoSQLstmtReWriteRow_session_www($ac+Xda+Xc+(3*Xb), $xo, $ro);
//          $return_val = etoSQLstmtReWriteRow_session_www($ac+10+8+(3*20), $xo, $ro);
         }
//       no -- INvalid current state.
         else
         {
            $return_val = false;

            etoAbendSubCode($ac, 5, $xo, $ro); // Abend $ac + 5 -- INvalid current $session_www_state for transition to RROW_STATE_EMAIL_LOGIN.
         }

         break;
      }

      case ROW_STATE_INFO:
      {
//       Is row in valid current state?
         if
         (
             ($session_www_state == ROW_STATE_PASSWORD)
             ||
             ($session_www_state == ROW_STATE_EMAIL_LOGIN)
             ||
             ($session_www_state == ROW_STATE_ACTIVE)
         )
//       yes -- valid current state.
         {
//          Set session state.
            $session_www_state = ROW_STATE_INFO;

            etoSQLtickTockSet_session_www($st0, $st1);

//          Rewrite row.
            $return_val = etoSQLstmtReWriteRow_session_www($ac+Xda+Xc+(4*Xb), $xo, $ro);
//          $return_val = etoSQLstmtReWriteRow_session_www($ac+10+8+(3*20), $xo, $ro);
         }
//       no -- INvalid current state.
         else
         {
            $return_val = false;

            etoAbendSubCode($ac, 6, $xo, $ro); // Abend $ac + 6 -- INvalid current $session_www_state for transition to ROW_STATE_INFO.
         }

         break;
      }

      case ROW_STATE_ACTIVE:
      {
//       Is row in valid current state?
         if
         (
            ($session_www_state == ROW_STATE_LOGIN)
            ||
            ($session_www_state == ROW_STATE_EMAIL_LOGIN)
            ||
            ($session_www_state == ROW_STATE_PASSWORD)
            ||
            ($session_www_state == ROW_STATE_INFO)
            ||
            ($session_www_state == ROW_STATE_ACTIVE)
         )
//       yes -- valid current state.
         {
//          Set session state.
            $session_www_state = ROW_STATE_ACTIVE;

            etoSQLtickTockSet_session_www($st0, $st1);

//          Rewrite row.
            $return_val = etoSQLstmtReWriteRow_session_www($ac+Xda+Xc+(5*Xb), $xo, $ro);
//          $return_val = etoSQLstmtReWriteRow_session_www($ac+10+8+(4*20), $xo, $ro);
         }
//       no -- INvalid current state.
         else
         {
            $return_val = false;

            etoAbendSubCode($ac, 7, $xo, $ro); // Abend $ac + 7 -- INvalid current $session_www_state for transition to ROW_STATE_ACTIVE.
         }

         break;
      }

      case ROW_STATE_COMPLETE:
      {
//       Is row in valid current state?
         if
         (
            ($session_www_state == ROW_STATE_ACTIVE)
            ||
            ($session_www_state == ROW_STATE_PASSWORD)
            ||
            ($session_www_state == ROW_STATE_INFO)
            ||
            ($session_www_state == ROW_STATE_LOGIN)
            ||
            ($session_www_state == ROW_STATE_EMAIL_LOGIN)
         )
//       yes -- valid current state.
         {
//          Set session state.
            $session_www_state = ROW_STATE_COMPLETE;

//          Set session delete time.
            $session_www_delete_utc = addSecs($crn_dtime_utc, ($st1 * 60)); // convert mins to secs.

//          Rewrite row.
            $return_val = etoSQLstmtReWriteRow_session_www($ac+Xda+Xc+(6*Xb), $xo, $ro);
//          $return_val = etoSQLstmtReWriteRow_session_www($ac+10+8+(5*20), $xo, $ro);
         }
//       no -- INvalid current state.
         else
         {
            $return_val = false;

            etoAbendSubCode($ac, 8, $xo, $ro); // Abend $ac + 8 -- INvalid current $session_www_state for transition to ROW_STATE_COMPLETE.
         }

         break;
      }

      case ROW_STATE_EXPIRED:
      {
//       Is row in valid current state?
         if
         (
            ($session_www_state == ROW_STATE_LOGIN)
            ||
            ($session_www_state == ROW_STATE_PASSWORD)
            ||
            ($session_www_state == ROW_STATE_EMAIL_LINK)
            ||
            ($session_www_state == ROW_STATE_EMAIL_LOGIN)
            ||
            ($session_www_state == ROW_STATE_INFO)
            ||
            ($session_www_state == ROW_STATE_ACTIVE)
         )
//       yes -- valid current state.
         {
//          Set session state.
            $session_www_state = ROW_STATE_EXPIRED;

//          Session delete time already set.
//             (be conistent with function etoSQLexpireRows_session_www().
//          $session_www_delete_utc = addSecs($session_www_expiry_utc, ($st1 * 60)); // NOT necessary here -- already done in <case ROW_STATE_ACTIVE> and in function etoSQLwriteRow_session_www().

//          Rewrite row.
            $return_val = etoSQLstmtReWriteRow_session_www($ac+Xda+Xc+(7*Xb), $xo, $ro);
//          $return_val = etoSQLstmtReWriteRow_session_www($ac+10+8+(6*20), $xo, $ro);
         }
//       no -- INvalid current state.
         else
         {
            $return_val = false;

            etoAbendSubCode($ac, 9, $xo, $ro); // Abend $ac + 9 -- INvalid current $session_www_state for transition to ROW_STATE_EXPIRED.
         }

         break;
      }

      case ROW_STATE_ABENDED:
      {
//       Set session state.
         $session_www_state = ROW_STATE_ABENDED;

//       Rewrite row.
         $return_val = etoSQLstmtReWriteRow_session_www($ac+Xda+Xc+(8*Xb), $xo, $ro);
//       $return_val = etoSQLstmtReWriteRow_session_www($ac+10+8+(7*20), $xo, $ro);

         break;
      }

      default:
      {
         $return_val = false;

         etoAbendSubCode($ac, 10, $xo, $ro); // Abend $ac + 10 -- INvalid target value for transition of $session_www_state.

         break;
      }
  }

  return ($return_val);
}

// Advance clock on table eto_sql_tb_session_www ...

// Get the MINIMUM session_www_serno value (i.e. serno of OLDEST row in table eto_sql_tb_session_www) ...

// function etoSQLgetMinSerno_visitor_ses($ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK) // abend code, abend exit option, abend SQL rollback option.
function etoSQLgetMinSerno_session_www($ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK) // abend code, abend exit option, abend SQL rollback option.
{
// global $sql_errno;
// global $sql_state;
   global $sql_state_class;

   global $sql_query;
   global $sql_result;
   global $sql_fetch;

// Abend code allocation ...

//  slots  function
//  -----  --------
//
//    3     etoSQLgetMinSerno_session_www(...) => this function.
//
//    7     etoSQLquery(...)                 => called by this function.
//  -----
//   10

// ... Abend code allocation.

   global $sys_exit_code; // $ac mapping: ($ac+0) ... ($ac+9) => 10 slots.
   global $sys_exit_msg;

   $min_session_www_serno = '';

   $sql_query = "SELECT min(session_www_serno) FROM eto_sql_tb_session_www";

// Test abend $ac + 5 (invalid table name.)
// $sql_query = "SELECT min(session_www_serno) FROM eto_sql_tb_session_wwwX";

// Does the SELECT return a value?
   if (etoSQLquery($ac+Xea, $xo, $ro)) // Abend ($ac+3)+ -- etoSQLquery() failed to deliver result from table eto_sql_tb_session_www.
// if (etoSQLquery($ac+3, $xo, $ro)) // Abend ($ac+3)+ -- etoSQLquery() failed to deliver result from table eto_sql_tb_session_www.
// yes -- value available.
   {
     $sql_fetch = mysqli_fetch_row($sql_result);

     mysqli_free_result($sql_result);

//   Test abend $ac + 0
//   (new empty variable as result parm.)
//   sql_fetch = mysqli_fetch_row($sql_resultX);

//   Was the fetch row successful? (defensive programming -- should ALWAYS succeed.)
	   if ($sql_fetch)
//   yes -- fetch successful.
     {
	     $min_session_www_serno = $sql_fetch[0];

//      MySQL returns null string if 0 rows in table eto_sql_tb_session_www.
	     if ($min_session_www_serno == '')
        {
           $min_session_www_serno = SQL_NUL_ROW_SERNO;
        }
	  }
//   no -- fetch UNsuccessful.
	   else
     {
        $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

   	    etoAbendSubCode($ac, 0, $xo, $ro); // Abend $ac + 0 -- Failed to fetch row from $sql_result.
     }
  }
// no -- NO value available.
  else
  {
//   NOT Abending?
     if (!$sys_exit_code)
//   yes -- NOT abending.
     {
//      Was the query complete?
//      if ($sql_errno == 0)
//      if ($sql_state == '00000') // true(?).
        if ($sql_state_class == '02') // No data.
//      yes -- query complete.
        {
           $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

           etoAbendSubCode($ac, 1, $xo, $ro); // Abend $ac + 1 -- SELECT min(session_www_serno) failed on table eto_sql_tb_session_www (query complete).
        }
        else
//      no -- query INcomplete.
        {
           $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

           etoAbendSubCode($ac, 2, $xo, $ro); // Abend $ac + 2 -- SELECT min(session_www_serno) failed on table eto_sql_tb_session_www (query INcomplete).
        }
     }
  }

   return($min_session_www_serno);
}

// ... Get the MINIMUM session_www_serno value.

// function etoSQLgetLimRowcnt_visitor_ses($sk) // session skip count.
function etoSQLgetLimRowcnt_session_www($sk) // session skip count.
{
   return( ($sk + 1) * 2 );
}

// function etoSQLgetLimSerno_visitor_ses($sn, $rc) // min. visitor ses serno, row count limit.
function etoSQLgetLimSerno_session_www($sn, $rc) // min. session__www serno, row count limit.
{
   $return_val = 0;

   $rc_minus_1 = ($rc-1);

// Is limit value BELOW wrap point?
//
//  e.g. *** BELOW WRAP POINT ***
//        SQL_MAX_ROW_SERNO == 1000, $sn == 991, $rc_minus_1 == 9:
//       (1000 - 991) == 9  >= 9 (return 1000)
//
//  e.g. *** AT WRAP POINT ***
//       SQL_MAX_ROW_SERNO == 1000, $sn == 992, $rc_minus_1 == 9:
//       (1000 - 992) == 8 !>= 9 (return 0).
//
   if ((SQL_MAX_ROW_SERNO - $sn) >= $rc_minus_1)
// yes -- limit value BELOW wrap.
   {
      $return_val = ($sn + $rc_minus_1);
   }

   return($return_val);
}

// Transition EXPIRED and COMPLETE rows => NULL ...

// function etoSQLpruneRows_visitor_ses($sk, $ac, $xo, $ro) // session skip count, abend code, abend exit option, abend SQL rollback option.
function etoSQLpruneRows_session_www($sk, $ac, $xo, $ro) // session skip count, abend code, abend exit option, abend SQL rollback option.
{
   global $sql_errno;
// global $sql_state;
   global $sql_state_class;

   global $sql_query;
   global $sql_result;
   global $sql_row_count;
   global $sql_fetch;

   global $crn_dtime_utc;

// Abend code allocation ...

//  slots  function
//  -----  --------
//
//    4     etoSQLpruneRows_session_www(...)   => this function.
//
//   10     etoSQLgetMinSerno_session_www(...) => called by this function.
//    7     etoSQLquery(...)                   => called by this function.
//    7     etoSQLquery(...)                   => called by this function.
//  -----
//   28

// ... Abend code allocation.

   global $sys_exit_code; // $ac mapping: ($ac+0) ... ($ac+15) == ($ac+4+10+7+7-1) => 28 slots.
   global $sys_exit_msg;

   $return_val = true;

   $min_session_www_serno = etoSQLgetMinSerno_session_www($ac+Xfa, $xo, $ro); // abend code, abend exit option, abend SQL rollback option.
// $min_session_www_serno = etoSQLgetMinSerno_session_www($ac+4, $xo, $ro); // abend code, abend exit option, abend SQL rollback option.

// Abending?
   if ($sys_exit_code)
// yes -- abending.
   {
      $return_val = false;
   }
   else
// no -- NOT abending.
   {
//    Is session_www table NOT empty?
      if ($min_session_www_serno)
//    yes -- NOT empty
      {
         $lim_row_count         = etoSQLgetLimRowcnt_session_www($sk); // session skip count.

         $lim_session_www_serno = etoSQLgetLimSerno_session_www($min_session_www_serno, $lim_row_count); // min. session_www serno, row count limit.

//       Was a NON-zero serno limit returned?
         if ($lim_session_www_serno)
//       yes -- returned NON-zero serno limit (i.e. NO wrap).
         {
            $tmp_ses_state_complete = ROW_STATE_COMPLETE;
            $tmp_ses_state_expired  = ROW_STATE_EXPIRED;

//
//          SELECT session_www_code FROM eto_sql_tb_session_www
//
//             WHERE
//             (
//                (
//                   (session_www_serno >= '$min_session_www_serno')
//                   AND
//                   (session_www_serno <= '$lim_session_www_serno')
//                )
//                AND
//                (
//                   (session_www_state = $tmp_ses_state_complete)
//                   OR
//                   (session_www_state = $tmp_ses_state_expired)
//                )
//                AND
//                (session_www_delete_utc < $crn_dtime_utc)
//             )
//
//             FOR UPDATE
//

            $sql_query = "SELECT session_www_code FROM eto_sql_tb_session_www WHERE (((session_www_serno >= '$min_session_www_serno') AND (session_www_serno <= '$lim_session_www_serno')) AND ((session_www_state = $tmp_ses_state_complete) OR (session_www_state = $tmp_ses_state_expired)) AND (session_www_delete_utc < '$crn_dtime_utc')) FOR UPDATE";

//          Test abend $ac + 2 (invalid table name.)
//          $sql_query = "SELECT session_www_code FROM eto_sql_tb_session_wwwX WHERE (((session_www_serno >= '$min_session_www_serno') AND (session_www_serno <= '$lim_session_www_serno')) AND ((session_www_state = $tmp_ses_state_complete) OR (session_www_state = $tmp_ses_state_expired)) AND (session_www_delete_utc < '$crn_dtime_utc')) FOR UPDATE";

//           Does the SELECT return at least 1 row?
             if (etoSQLquery($ac+Xfa+Xe, $xo, $ro)) // Abend ($ac+4+9)+ -- etoSQLquery() failed to deliver result from table eto_sql_tb_session_www.
//           if (etoSQLquery($ac+4+6, $xo, $ro)) // Abend ($ac+4+9)+ -- etoSQLquery() failed to deliver result from table eto_sql_tb_session_www.
//           yes -- row(s) available.
             {
//
//             DELETE FROM to_sql_tb_session_www
//
//                WHERE
//                (
//                   (session_www_code = '$tmp_session_www_code')
//                   OR
//                   (session_www_code = '$tmp_session_www_code')
//                   OR
//                    ...
//                   OR
//                  (session_www_code = '$tmp_session_www_code')
//                )
//

                $sql_query = "DELETE FROM eto_sql_tb_session_www WHERE (";

//              Test abend ac+2 (invalid table name).
//              $sql_query = "DELETE FROM eto_sql_tb_session_wwwX WHERE (";

                for ($i = 1; $i <= $sql_row_count; $i++)
                {
                   $sql_fetch = mysqli_fetch_row($sql_result);

//                 Test abend $ac + 0
//                  (new empty variable as result parm.)
//                 $sql_fetch = mysqli_fetch_row($sql_resultX);

//                 Is the fetch row successful? (defensive programming -- should ALWAYS succeed.)
	                if ($sql_fetch)
//                 yes -- fetch successful.
                   {
                      $tmp_session_www_code = $sql_fetch[0];

	             	      $sql_query .= "(session_www_code = '$tmp_session_www_code')";

	             	      (($i < $sql_row_count) ? ($sql_query .= ' OR ') : false);
	                 }
//                  no -- fetch UNsuccessful.
	                 else
	                 {
             	        $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

//             	     Is control exiting?
                       if ($xo == ABEND_EXIT)
//                     yes -- control exiting.
                       {
                          mysqli_free_result($sql_result);
                       }

             	        etoAbendSubCode($ac, 0, $xo, $ro); // Abend $ac + 0 -- Failed to fetch row from $sql_result.

                       $return_val = false;

                       break;
                    }
                }

                mysqli_free_result($sql_result); // @@@ what about other path(s) to exit?

//              NOT Abending?
                if (!$sys_exit_code)
//              yes -- NOT abending.
                {
                   $sql_query .= ')';

//                 Is attempt to delete row(s) in eto_sql_tb_session_www table UNsuccessful?
                   if (!etoSQLquery($ac+Xfa+Xe+X2, $xo, $ro)) // Abend ($ac+4+9+6)+ -- etoSQLquery() failed to delete row(s) in table eto_sql_tb_session_www.
//                 if (!etoSQLquery($ac+4+6+3, $xo, $ro)) // Abend ($ac+4+9+6)+ -- etoSQLquery() failed to delete row(s) in table eto_sql_tb_session_www.
//                 yes -- row(s) delete UNsuccessful.
                   {
                      $return_val = false;

//                    NOT Abending?
                      if (!$sys_exit_code)
//                    yes -- NOT abending.
                      {
                         $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

                         etoAbendSubCode($ac, 1, $xo, $ro); // Abend $ac + 1 -- etoSQLquery() failed to delete row(s) in table eto_sql_tb_session_www.
                      }
                   }
                }
             }
//           no -- NO row(s) available (could happen if (an)other session_www(s) process deleted it/them, between our call to etoSQLgetMinSerno_session_www() and our SELECT ... FOR UPDATE).
             else
             {
//              Abending?
                if ($sys_exit_code)
//              yes -- abending.
                {
                   $return_val = false;
                }
                else
//              no -- NOT abending.
                {
//                 Was the query INcomplete?
//                 if ($sql_errno != 0)
//                 if ($sql_state != '00000') // false.
                   if
                   (
                      ($sql_state_class != '00') // NOT Success (MySQL returns '00' on no data).
                      &&
                      ($sql_state_class != '02') // NOT No data.
                   )
//                 if ($sql_state_class != '02') // NOT No data.
//                 yes -- query INcomplete.
                   {
                       $return_val = false;

                       $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

             	        etoAbendSubCode($ac, 2, $xo, $ro); // Abend $ac + 2 -- SELECT failed on table eto_sql_tb_session_www (query INcomplete).
                   }
                }
             }
         }
         else
//       no -- returned ZERO serno limit (i.e. WRAP detected).
         {
            $return_val = false;

            $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

            etoAbendSubCode($ac, 3, $xo, $ro); // Abend $ac + 3 -- WRAP detected on $lim_session_www_serno.
         }
      }
   }

/*
// Testing ...

  global $sql_state;

  $tst_diag = '';
  $tst_diag .= ( '##etoSQLpruneRows_session_www(...)##  ' );

  $tst_diag .= ( '**$crn_dtime_utc<' . $crn_dtime_utc . '>**  ' );
  $tst_diag .= ( '**$sk<' . $sk . '>**  ' );

  $tst_diag .= ( '**$min_session_www_serno<' . $min_session_www_serno . '>**  ' );
  $tst_diag .= ( '**$lim_session_www_serno<' . $lim_session_www_serno . '>**  ' );
  $tst_diag .= ( '**$lim_row_count<' . $lim_row_count . '>**  ' );

  $tst_diag .= ( '**$sql_query' . $sql_query . '>**  ' );
  $tst_diag .= ( '**$sql_row_count<' . $sql_row_count . '>**  ' );
  $tst_diag .= ( '**$sql_errno<' . $sql_errno . '>**  ' );
  $tst_diag .= ( '**$sql_state<' . $sql_state . '>**  ' );


  $tst_diag .= ( '**$sys_exit_msg<' . $sys_exit_msg . '>**  ' );
  $tst_diag .= ( '**$sys_exit_code<' . $sys_exit_code . '>**  ' );
  $tst_diag .= ( '**$return_val<' . $return_val . '>**  ' );

  echo htmlspecialchars($tst_diag, ENT_QUOTES);

// ... Testing.
*/

   return($return_val);
}

// ... Transition EXPIRED and COMPLETE rows => NULL.

// Transition ACTIVE row(s) => EXPIRED row(s) ...

// function etoSQLexpireRows_visitor_ses($hm, $sk, $ac, $xo, $ro) // max. ses. hit count, session skip count, abend code, abend exit option, abend SQL rollback option.
function etoSQLexpireRows_session_www($sk, $ac, $xo, $ro) // max. ses. hit count, session skip count, abend code, abend exit option, abend SQL rollback option.
{
// global $sql_state;
   global $sql_state_class;

   global $sql_query;
   global $sql_result;
   global $sql_row_count;
   global $sql_afec_row_count;
   global $sql_fetch;

   global $crn_dtime_utc;

// Abend code allocation ...

//  slots  function
//  -----  --------
//
//    6     etoSQLexpireRows_session_www(...)  => this function.
//
//   10     etoSQLgetMinSerno_session_www(...) => called by this function.
//    7     etoSQLquery(...)                   => called by this function.
//    7     etoSQLquery(...)                   => called by this function.
//  -----
//   30

// ... Abend code allocation.

   global $sys_exit_code; // $ac mapping: ($ac+0) ... ($ac+30-1) == ($ac+6+6+3+3-1) => 30 slots.
   global $sys_exit_msg;

   $return_val = true;

   $min_session_www_serno = etoSQLgetMinSerno_session_www($ac+Xga, $xo, $ro); // abend code, abend exit option, abend SQL rollback option.
// $min_session_www_serno = etoSQLgetMinSerno_session_www($ac+6, $xo, $ro); // abend code, abend exit option, abend SQL rollback option.

// Abending?
   if ($sys_exit_code)
// yes -- abending.
   {
      $return_val = false;
   }
   else
// no -- NOT abending.
   {
//    Is session_www table NOT empty?
      if ($min_session_www_serno)
//    yes -- NOT empty
      {
         $lim_row_count         = etoSQLgetLimRowcnt_session_www($sk); // session skip count.

         $lim_session_www_serno = etoSQLgetLimSerno_session_www($min_session_www_serno, $lim_row_count); // min. session_www serno, row count limit.

//       Was a NON-zero serno limit returned?
         if ($lim_session_www_serno)
//       yes -- returned NON-zero serno limit (i.e. NO wrap).
         {
            $tmp_ses_state_login       = ROW_STATE_LOGIN;
            $tmp_ses_state_password    = ROW_STATE_PASSWORD;
            $tmp_ses_state_email_link  = ROW_STATE_EMAIL_LINK;
            $tmp_ses_state_email_login = ROW_STATE_EMAIL_LOGIN;
            $tmp_ses_state_info        = ROW_STATE_INFO;
            $tmp_ses_state_active      = ROW_STATE_ACTIVE;

//          SELECT session_www_code FROM eto_sql_tb_session_www
//
//             WHERE
//             (
//                (
//                   (session_www_serno >= '$min_session_www_serno')
//                   AND
//                   (session_www_serno <= '$lim_session_www_serno')
//                )
//                AND
//                (
//                   (session_www_state = $tmp_ses_state_login)
//                   OR
//                   (session_www_state = $tmp_ses_state_password)
//                   OR
//                   (session_www_state = $tmp_ses_state_active)
//                )
//                AND
//                (
//                   (session_www_expiry_utc < '$crn_dtime_utc')
//                   OR
//                   (session_www_hit_count < 1)
//                )
//             )
//
//             FOR UPDATE

            $sql_query = "SELECT session_www_code FROM eto_sql_tb_session_www WHERE (((session_www_serno >= '$min_session_www_serno') AND (session_www_serno <= '$lim_session_www_serno')) AND ((session_www_state = $tmp_ses_state_login) OR (session_www_state = $tmp_ses_state_password) OR (session_www_state = $tmp_ses_state_email_link) OR (session_www_state = $tmp_ses_state_email_login) OR (session_www_state = $tmp_ses_state_info) OR (session_www_state = $tmp_ses_state_active)) AND ((session_www_expiry_utc < '$crn_dtime_utc') OR (session_www_hit_count < 1))) FOR UPDATE";
//          $sql_query = "SELECT session_www_code FROM eto_sql_tb_session_www WHERE (((session_www_serno >= '$min_session_www_serno') AND (session_www_serno <= '$lim_session_www_serno')) AND ((session_www_state = $tmp_ses_state_login) OR (session_www_state = $tmp_ses_state_password) OR (session_www_state = $tmp_ses_state_active)) AND ((session_www_expiry_utc < '$crn_dtime_utc') OR (session_www_hit_count < 1))) FOR UPDATE";

//          Test abend $ac + 2 (invalid table name.)
//          $sql_query = "SELECT session_www_code FROM eto_sql_tb_session_wwwX WHERE (((session_www_serno >= '$min_session_www_serno') AND (session_www_serno <= '$lim_session_www_serno')) AND ((session_www_state = $tmp_ses_state_login) OR (session_www_state = $tmp_ses_state_password) OR (session_www_state = $tmp_ses_state_active)) AND ((session_www_expiry_utc < '$crn_dtime_utc') OR (session_www_hit_count < 1))) FOR UPDATE";

//           Does the SELECT return at least 1 row?
             if (etoSQLquery($ac+Xga+Xe, $xo, $ro)) // Abend ($ac+5+9)+ -- etoSQLquery() failed to deliver result from table eto_sql_tb_session_www.
//           if (etoSQLquery($ac+6+6, $xo, $ro)) // Abend ($ac+5+9)+ -- etoSQLquery() failed to deliver result from table eto_sql_tb_session_www.
//           yes -- row(s) available.
             {
//
//              UPDATE eto_sql_tb_session_www
//
//                 SET
//
//                    session_www_state    = $tmp_ses_state_expired,
//                    session_www_last_utc = '$crn_dtime_utc'
//
//                 WHERE
//                 (
//                    (session_www_code = '$tmp_session_www_code')
//                    OR
//                    (session_www_code = '$tmp_session_www_code')
//                    OR
//                    ...
//                    OR
//                    (session_www_code = '$tmp_session_www_code')
//                 )
//
//
//              NOTE: In order to update columns with ROW-SPECIFIC VALUES,
//
//                (e.g. $session_www_delete_utc = addSecs($session_www_expiry_utc, $st)).
//
//                (e.g. ++$session_www_hit_count).
//
//                MUST include the columns in the (above) SELECT query and
//                     invent (if possible) SQL UPDATE syntax that updates multiple rows,
//                        with multi-valued columns,
//                        with one SQL UPDATE query.
//
//                HOWEVER, the complications entailed in such a refinement are not justified,
//                     because the value of session_www_delete_utc, as originally set by
//                     the last transition to session ACTIVE state, is actually more legitimate.

                $tmp_ses_state_expired = ROW_STATE_EXPIRED;

                $sql_query = "UPDATE eto_sql_tb_session_www SET session_www_state = $tmp_ses_state_expired, session_www_last_utc = '$crn_dtime_utc' WHERE (";

//              Test abend $ac + 0 (invalid table name.)
//              $sql_query = "UPDATE eto_sql_tb_session_wwwX SET session_www_state = $tmp_ses_state_expired, session_www_last_utc = '$crn_dtime_utc' WHERE (";

                for ($i = 1; $i <= $sql_row_count; $i++)
                {
                   $sql_fetch = mysqli_fetch_row($sql_result);

//                 Test abend $ac + 0
//                  (new empty variable as result parm.)
//                 $sql_fetch = mysqli_fetch_row($sql_resultX);

//                 Is the fetch row successful? (defensive programming -- should ALWAYS succeed.)
	                if ($sql_fetch)
//                 yes -- fetch successful.
                   {
                      $tmp_session_www_code = $sql_fetch[0];

	             	      $sql_query .= "(session_www_code = '$tmp_session_www_code')";

	             	      (($i < $sql_row_count) ? ($sql_query .= ' OR ') : false);
	                 }
//                  no -- fetch UNsuccessful.
	                 else
	                 {
             	        $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

//             	     Is control exiting?
                       if ($xo == ABEND_EXIT)
//                     yes -- control exiting.
                       {
                          mysqli_free_result($sql_result);
                       }

             	        etoAbendSubCode($ac, 0, $xo, $ro); // Abend $ac + 0 -- Failed to fetch row from $sql_result.

                       $return_val = false;

                       break;
                    }
                }

                mysqli_free_result($sql_result); // @@@ what about other path(s) to exit?

//              NOT Abending?
                if (!$sys_exit_code)
//              yes -- NOT abending.
                {
	             	 $sql_query .= ')';

                   $tmp_sql_row_count = $sql_row_count;

//                 Does query UPDATE + row(s) in eto_sql_tb_session_www table?
                   if (etoSQLquery($ac+Xga+Xe+X2, $xo, $ro)) // Abend ($ac+5+9+6)+ -- etoSQLquery() failed to update row(s) in table eto_sql_tb_session_www (not missing key).
//                 if (etoSQLquery($ac+6+6+3, $xo, $ro)) // Abend ($ac+5+9+6)+ -- etoSQLquery() failed to update row(s) in table eto_sql_tb_session_www (not missing key).
//                 yes -- 1+ row(s) UPDATEd.
                   {
//                    Did UPDATE NOT modify expected count of rows?
                      if ($sql_afec_row_count != $tmp_sql_row_count)
//                    yes -- bad row count.
                      {
                         $return_val = false;

                         $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

                         etoAbendSubCode($ac, 1, $xo, $ro); // Abend $ac + 1 -- UPDATEd wrong number of rows in table eto_sql_tb_session_www.
                      }
                   }
                   else
//                 no -- 0 row(s) UPDATEd.
                   {
                      $return_val = false;

//                    NOT Abending?
                      if (!$sys_exit_code)
//                    yes -- NOT abending.
                      {
                         $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

//                       Did the query complete?
//                       if ($sql_errno == 0)
//                       if ($sql_state == '00000')
                         if ($sql_state_class == '02')
//                       yes -- UPDATE query complete => missing key in table.
                         {
                            etoAbendSubCode($ac, 2, $xo, $ro); // Abend $ac + 2 -- Failed to update row(s) in table eto_sql_tb_session_www (query complete => missing key in table).
                         }
                         else
//                       no -- UPDATE query INcomplete.
                         {
                            etoAbendSubCode($ac, 3, $xo, $ro); // Abend $ac + 3 -- Failed to update row(s) in table eto_sql_tb_session_www (query INcomplete).
                         }
                      }
                   }
                }
             }
             else
//           no -- NO row(s) available.
             {
//              Query INcomplete?
                if
                (
                   ($sql_state_class != '00') // NOT Success (MySQL returns '00' on no data).
                   &&
                   ($sql_state_class != '02') // NOT No data.
                )
//              yes -- query INcomplete.
                {
                   $return_val = false;

                   $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

                   etoAbendSubCode($ac, 4, $xo, $ro); // Abend $ac + 4 -- SELECT failed on table eto_sql_tb_session_www (query INcomplete).
                }
             }
         }
         else
//       no -- returned ZERO serno limit (i.e. WRAP detected).
         {
            $return_val = false;

            $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

            etoAbendSubCode($ac, 5, $xo, $ro); // Abend $ac + 5 -- WRAP detected on $lim_session_www_serno.
         }
      }
   }

/*
// Testing ...

  global $sql_errno;

  $tst_diag = '';
  $tst_diag .= ( '##etoSQLexpireRows_session_www(...)##  ' );

  $tst_diag .= ( '**$crn_dtime_utc<' . $crn_dtime_utc . '>**  ' );
  $tst_diag .= ( '**$hm<' . $hm . '>**  ' );
  $tst_diag .= ( '**$st<' . $st . '>**  ' );
  $tst_diag .= ( '**$sk<' . $sk . '>**  ' );
  $tst_diag .= ( '**$min_session_www_serno<' . $min_session_www_serno . '>**  ' );
  $tst_diag .= ( '**$lim_session_www_serno<' . $lim_session_www_serno . '>**  ' );
  $tst_diag .= ( '**$lim_row_count<' . $lim_row_count . '>**  ' );

  $tst_diag .= ( '**$sql_query' . $sql_query . '>**  ' );
  $tst_diag .= ( '**$sql_row_count<' . $sql_row_count . '>**  ' );
  $tst_diag .= ( '**$sql_afec_row_count<' . $sql_afec_row_count . '>**  ' );
  $tst_diag .= ( '**$tmp_sql_row_count<' . $tmp_sql_row_count . '>**  ' );
  $tst_diag .= ( '**$sql_errno<' . $sql_errno . '>**  ' );
  $tst_diag .= ( '**$sql_state<' . $sql_state . '>**  ' );

  $tst_diag .= ( '**$sys_exit_msg<' . $sys_exit_msg . '>**  ' );
  $tst_diag .= ( '**$sys_exit_code<' . $sys_exit_code . '>**  ' );
  $tst_diag .= ( '**$return_val<' . $return_val . '>**  ' );

  echo htmlspecialchars($tst_diag, ENT_QUOTES);

// ... Testing.
*/

   return($return_val);
}

// ... Transition ACTIVE row(s) => EXPIRED row(s).

// function etoSQLtickTock_visitor_ses($hm, $sk = 0, $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK) // max. ses. hit count, session skip count, abend code, abend exit option, abend SQL rollback option.
function etoSQLtickTock_session_www($sk = 0, $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK) // session skip count, abend code, abend exit option, abend SQL rollback option.
{
// Abend code allocation ...

//  slots  function
//  -----  --------
//
//   28     etoSQLpruneRows_session_www(...)  => called by this function.
//   30     etoSQLexpireRows_session_www(...) => called by this function.
//  -----
//   58

// ... Abend code allocation.

   global $sys_exit_code; // $ac mapping: ($ac+0) ... ($ac+28+30-1) == ($ac+16+18-1) => 58 slots.

   $return_val = true;

   etoSQLinitCall();

   etoSQLpruneRows_session_www($sk, $ac, $xo, $ro); // session skip count, abend code, abend exit option, abend SQL rollback option.

// Abending?
   if ($sys_exit_code)
// yes -- abending.
   {
      $return_val = false;
   }
   else
// no -- NOT abending.
   {
      etoSQLexpireRows_session_www($sk, $ac+Xf, $xo, $ro); // session skip count, abend code, abend exit option, abend SQL rollback option.
//    etoSQLexpireRows_session_www($sk, $ac+18, $xo, $ro); // session skip count, abend code, abend exit option, abend SQL rollback option.

//    Abending?
      if ($sys_exit_code)
//    yes -- abending.
      {
         $return_val = false;
      }
   }

/*
// Testing ...
  global $sql_errno;
  global $sql_state;

  $tst_diag = '';
  $tst_diag .= ( '##eetoSQLtickTock_session_www(...)##  ' );

  $tst_diag .= ( '**$crn_dtime_utc<' . $crn_dtime_utc . '>**  ' );
  $tst_diag .= ( '**$hm<' . $hm . '>**  ' );
  $tst_diag .= ( '**$st<' . $st . '>**  ' );
  $tst_diag .= ( '**$sk<' . $sk . '>**  ' );

  $tst_diag .= ( '**$sql_errno<' . $sql_errno . '>**  ' );
  $tst_diag .= ( '**$sql_state<' . $sql_state . '>**  ' );

  $tst_diag .= ( '**$sys_exit_code<' . $sys_exit_code . '>**  ' );
  $tst_diag .= ( '**$return_val<' . $return_val . '>**  ' );

  echo htmlspecialchars($tst_diag, ENT_QUOTES);
// ... Testing.
*/

   return ($return_val);
}

// ... Advance clock on table eto_sql_tb_session_www

function etoSQLgetRowBuf_contact_msg()
{
  global $contact_msg_serno;
  global $contact_msg_status;
  global $contact_session_code;
  global $contact_verify_code;
  global $contact_source_serno;
  global $contact_privacy;
  global $contact_first_name;
  global $contact_last_name;
  global $contact_email_addr;
  global $contact_msg_subject;
  global $contact_message;
  global $contact_msg_init_utc;

  return
  (
     (
        addcslashes
        (
           etoExit_sys_log_indent_det
           (
              '##etoSQLgetRowBuf_contact_msg()<'
           ) .

           "\$contact_msg_serno<"    . $contact_msg_serno . '> ' .

           "\$contact_msg_status<"   . $contact_msg_status . '> ' .

           "\$contact_session_code<" . $contact_session_code . '> ' .
           "\$contact_verify_code<"  . $contact_verify_code . '> ' .

           "\$contact_source_serno<" . $contact_source_serno . '> ' .
           "\$contact_privacy<"      . $contact_privacy . '> ' .

           "\$contact_first_name<"   . $contact_first_name . '> ' .
           "\$contact_last_name<"    . $contact_last_name . '> ' .
           "\$contact_email_addr<"   . $contact_email_addr . '> ' .

           "\$contact_msg_subject<"  . $contact_msg_subject . '> ' .
           "\$contact_message<"      . $contact_message . '> ' .

           "\$contact_msg_init_utc<" . $contact_msg_init_utc . '>'  .

           '>',

           "\\\t\n\v\f\r"
        )
     )
  );
}

function etoSQLstmtWriteRow_contact_msg(&$cst, &$csc, &$cvc, &$csn, &$cpv, &$cfn, &$cln, &$cea, &$csb, &$cmb, $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK) // msg status, msg session code, msg verify code, msg source serno, msg privacy, msg first name, msg last name, msg email addr, msg subject, msg body, abend code, abend exit option, abend SQL rollback option.
// function etoSQLstmtWriteRow_contact_msg(&$cf, &$cl, &$ce, &$cs, &$cv, &$cm, $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK) // visitor first name, visitor last name, visitor email, visitor subject, visitor verify, visitor message, abend code, abend exit option, abend SQL rollback option.
// function etoSQLstmtWriteRow_contact_msg(&$cn, &$ce, &$cs, &$cv, &$cm, $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK) // visitor name, visitor email, visitor subject, visitor verify, visitor message, abend code, abend exit option, abend SQL rollback option.
{
   global $sql_link;
   global $sql_query;

   global $sql_state_class;

   global $DUMMY_BIND_ARY;

   global $contact_msg_serno;
   global $contact_msg_status;
   global $contact_session_code;
   global $contact_verify_code;
   global $contact_source_serno;
   global $contact_privacy;
   global $contact_first_name;
   global $contact_last_name;
   global $contact_email_addr;
   global $contact_msg_subject;
   global $contact_message;
   global $contact_msg_init_utc;

   global $crn_dtime_utc;

// Abend code allocation ...

//  slots  function
//  -----  --------
//
//    5     etoSQLstmtWriteRow_contact_msg(...) => this function.
//
//    5     etoSQLstmtOpen(...)                 => called by this function.
//    9     etoSQLstmtDo(...)                   => called by this function.
//    2     etoSQLstmtClose(...)                => called by this function.
//  -----
//   21

// ... Abend code allocation.

   global $sys_exit_code; // $ac mapping: ($ac+0) ... ($ac+19) => 20 slots.
   global $sys_exit_msg;

   $return_val = true;

   etoSQLinitCall();

//
//  (Effect of query.)
//
//   INSERT INTO eto_sql_tb_contact_msg
//
//      (
//          contact_msg_serno,
//          contact_msg_status,
//          contact_session_code,
//          contact_verify_code,
//          contact_source_serno,
//          contact_privacy,
//          contact_first_name,
//          contact_last_name,
//          contact_email_addr,
//          contact_msg_subject,
//          contact_message,
//          contact_msg_init_utc
//      )
//
//      VALUES
//      (
//         NULL,
//         $cst,
//         $csc,
//         $cvc,
//         $csn,
//         $cpv,
//         $cfn,
//         $cln,
//         $cea,
//         $csb,
//         $cmb,
//         '$crn_dtime_utc'
//      )
//

   $sql_query = "INSERT INTO eto_sql_tb_contact_msg (contact_msg_serno, contact_msg_status, contact_session_code, contact_verify_code, contact_source_serno, contact_privacy, contact_first_name, contact_last_name, contact_email_addr, contact_msg_subject, contact_message, contact_msg_init_utc) VALUES(NULL, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)";
// $sql_query = "INSERT INTO eto_sql_tb_contact_msg (contact_msg_serno, contact_first_name, contact_last_name, contact_email_addr, contact_msg_subject, contact_verify_code, contact_message, contact_msg_init_utc) VALUES(NULL, ?, ?, ?, ?, ?, ?, ?)";
// $sql_query = "INSERT INTO eto_sql_tb_contact_msg (contact_msg_serno, contact_first_name, contact_last_name, contact_email_addr, contact_msg_subject, contact_verify_code, contact_message, contact_msg_init_utc) VALUES(NULL,'$cf','$cl','$ce','$cs','$cv','$cm','$crn_dtime_utc')";

// Test abend $ac (invalid table name.)
// $sql_query = "INSERT INTO eto_sql_tb_contact_msgX (contact_msg_serno, contact_first_name, contact_last_name, contact_email_addr, contact_msg_subject, contact_verify_code, contact_message, contact_msg_init_utc) VALUES(NULL, ?, ?, ?, ?, ?, ?, ?)";

   $query_param_bind_ary
   =
   array
   (
      0 => $cst,
      1 => $csc,
      2 => $cvc,
      3 => $csn,
      4 => $cpv,
      5 => $cfn,
      6 => $cln,
      7 => $cea,
      8 => $csb,
      9 => $cmb,
     10 => &$crn_dtime_utc
   );

// Is statement open successful?
   if
   (
      $return_val
      =
      etoSQLstmtOpen
      (
         'issiissssss',         // query parameter type specification (i=integer, s=string).
//       'sssssss',             // query parameter type specification (s=string).

         $query_param_bind_ary, // query parameter(s) bind array.

         ($ac+Xia), $xo, $ro    // abend code, abend exit option, abend SQL rollback option.
//       ($ac+4), $xo, $ro      // abend code, abend exit option, abend SQL rollback option.
      )
   )
// yes -- statement open successful.
   {
//    Is statement do successful?
      if
      (
         $return_val
         =
         etoSQLstmtDo
         (
            $DUMMY_BIND_ARY,     // result parameter(s) bind array.

            ($ac+Xia+X3), $xo, $ro   // abend code, abend exit option, abend SQL rollback option.
//          ($ac+4+5), $xo, $ro   // abend code, abend exit option, abend SQL rollback option.
         )
      )
//    yes -- statement do successful.
      {
//       Is SQLSTATE class acceptable?
         if ($sql_state_class == '00')
//       yes -- SQLSTATE class acceptable.
         {
            $tmp_contact_msg_serno = etoSQLget_mysqli_insert_id();

//          did serno of inserted row exceed int precision?
            if (!$tmp_contact_msg_serno)
//          yes - exceeded int precision.
            {
               $return_val = false;

               $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

               etoAbendSubCode($ac, 0, $xo, $ro); // Abend $ac + 0 -- etoSQLstmtDo(...) serno of inserted row exceeded int precision.
            }

   //       Is statement close successful?
            if
            (
               $return_val
               =
               etoSQLstmtClose(($ac+Xia+X3+X4), $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK)
//             etoSQLstmtClose(($ac+4+5+9), $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK)
            )
   //       yes -- statement close successful.
            {
               $contact_msg_serno    = $tmp_contact_msg_serno;
               $contact_msg_status   = $cst;
               $contact_session_code = $csc;
               $contact_verify_code  = $cvc;
               $contact_source_serno = $csn;
               $contact_privacy      = $cpv;
               $contact_first_name   = $cfn;
               $contact_last_name    = $cln;
               $contact_email_addr   = $cea;
               $contact_msg_subject  = $csb;
               $contact_message      = $cmb;
               $contact_msg_init_utc = $crn_dtime_utc;
            }
            else
   //       no -- statement close failed.
            {
   //          NOT already bending?
               if (!$sys_exit_code)
   //          yes -- NOT already abending.
               {
                  $return_val = false;

                  $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

                  etoAbendSubCode($ac, 1, $xo, $ro); // Abend $ac + 1 -- etoSQLstmtClose(...) failed.
               }
            }
         }
         else
//       no -- SQLSTATE class NOT acceptable.
         {
            $return_val = false;

            $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

            etoAbendSubCode($ac, 2, $xo, $ro); // Abend $ac + 2 -- etoSQLstmtDo(...) SQLSTATE class NOT acceptable.
         }
      }
      else
//    no -- statement do failed.
      {
//       NOT already bending?
         if (!$sys_exit_code)
//       yes -- NOT already abending.
         {
            $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

            etoAbendSubCode($ac, 3, $xo, $ro); // Abend $ac + 3 -- etoSQLstmtDo(...) failed.
         }
      }
   }
   else
// no -- statement open failed.
   {
//    NOT already bending?
      if (!$sys_exit_code)
//    yes -- NOT already abending.
      {
         $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

         etoAbendSubCode($ac, 4, $xo, $ro); // Abend $ac + 4 -- etoSQLstmtOpen(...) failed.
      }
   }

/*
// Testing ...
  global $sql_errno;
  global $sql_state;
  global $sys_exit_code;

  $tst_diag = '';
  $tst_diag .= ( '##etoSQLstmtWriteRow_contact_msg(...)##  ' );
  $tst_diag .= ( '**$cst<' . $cst . '>**  ' );
  $tst_diag .= ( '**$csc<' . $csc . '>**  ' );
  $tst_diag .= ( '**$cvc<' . $cvc. '>**  ' );
  $tst_diag .= ( '**$csn<' . $csn . '>**  ' );
  $tst_diag .= ( '**$cpv<' . $cpv . '>**  ' );
  $tst_diag .= ( '**$cfn<' . $cfn . '>**  ' );
  $tst_diag .= ( '**$cln<' . $cln . '>**  ' );
  $tst_diag .= ( '**$cea<' . $cea . '>**  ' );
  $tst_diag .= ( '**$csb<' . $csb . '>**  ' );
  $tst_diag .= ( '**$cmb<' . $cmb . '>**  ' );

  $tst_diag .= ( '**$contact_msg_serno<' . $contact_msg_serno . '>**  ' );
  $tst_diag .= ( '**$contact_msg_status<' . $contact_msg_status . '>**  ' );
  $tst_diag .= ( '**$contact_session_code<' . $contact_session_code . '>**  ' );
  $tst_diag .= ( '**$contact_verify_code<' . $contact_verify_code . '>**  ' );
  $tst_diag .= ( '**$contact_source_serno<' . $contact_source_serno . '>**  ' );
  $tst_diag .= ( '**$contact_privacy<' . $contact_privacy . '>**  ' );
  $tst_diag .= ( '**$contact_first_name<' . $contact_first_name . '>**  ' );
  $tst_diag .= ( '**$contact_last_name<' . $contact_last_name . '>**  ' );
  $tst_diag .= ( '**$contact_email_addr<' . $contact_email_addr . '>**  ' );
  $tst_diag .= ( '**$contact_msg_subject<' . $contact_msg_subject . '>**  ' );
  $tst_diag .= ( '**$contact_message<' . $contact_message . '>**  ' );
  $tst_diag .= ( '**$contact_mesg_init_utc<' . $contact_msg_init_utc . '>**  ' );

  $tst_diag .= ( '**$sql_errno<' . $sql_errno . '>**  ' );
  $tst_diag .= ( '**$sql_state<' . $sql_state . '>**  ' );

  $tst_diag .= ( '**$sys_exit_code<' . $sys_exit_code . '>**  ' );
  $tst_diag .= ( '**$return_val<' . $return_val . '>**  ' );

  echo htmlspecialchars($tst_diag, ENT_QUOTES);
// ... Testing.
*/

  return ($return_val);
}


function etoSQLreadRow_club_member($ms, $me, $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK, $lo = SQL_NOLOCK) // member serno, member email address, abend code, abend exit option, abend SQL rollback option, SQL row lock option.
// function etoSQLreadRow_club_member($ms, $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK, $lo = SQL_NOLOCK) // member serno, abend code, abend exit option, abend SQL rollback option, SQL row lock option.
{
   global $sql_query;
   global $sql_result;
	global $sql_fetch;

   global $sql_errno;
// global $sql_state;
   global $sql_state_class;

	global $club_member_serno;
	global $member_status;
	global $member_password;
   global $member_session_code;
   global $member_verify_code;
   global $member_first_name;
   global $member_last_name;
   global $member_email_addr;
   global $member_ref_by_member;
   global $member_inf_by_advert;
   global $member_reserve_coop_spot;
   global $member_request_news_email;
   global $member_block_email_login;
   global $club_member_init_utc;
   global $club_member_last_utc;
   global $club_member_expiry_utc;
   global $club_member_notified_utc;

// Abend code allocation ...

//  slots  function
//  -----  --------
//
//    2     etoSQLreadRow_club_member(...)     => this function.
//
//    7     etoSQLquery(...) => called by this function.
//  -----
//    9

// ... Abend code allocation.

   global $sys_exit_code; // $ac mapping: ($ac+0) ... ($ac+2+7-1) => 9 slots.
   global $sys_exit_msg;

   $tmp_sql_where_clause = '';

   $return_val = false;
// $return_val = true;

   etoSQLinitCall();

// set WHERE clause of SELECT statement ...

// is member number provided?
   if
   (
      ($ms != '')
      &&
      ($ms != 0)
   )
// yes - member number provided.
   {
//    is email address provided?
      if ($me != '')
//    yes - email address provided.
      {
//       attempt to read member row using member number and email address.
         $tmp_sql_where_clause = "WHERE club_member_serno = '$ms' AND member_email_addr = '$me'";
      }
      else
      {
//       attempt to read member row using member number.
         $tmp_sql_where_clause = "WHERE club_member_serno = '$ms'";
      }
    }
    else
//  no - member number NOT provided.
    {
//  is email address provided?
       if ($me != '')
//     yes - email address provided.
       {
//        attempt to read member row using email address.
          $tmp_sql_where_clause = "WHERE member_email_addr = '$me'";
       }
       else
//     no - email address NOT provided (return as "member row not found").
       {
          $return_val = false;
       }
    }

// ... set WHERE clause of SELECT statement.

   if ($tmp_sql_where_clause != '')
   {
      $sql_query = "SELECT club_member_serno, member_status, member_password, member_session_code, member_verify_code, member_first_name, member_last_name, member_email_addr, member_ref_by_member, member_inf_by_advert, member_reserve_coop_spot, member_request_news_email, member_block_email_login, club_member_init_utc, club_member_last_utc, club_member_expiry_utc, club_member_notified_utc FROM eto_sql_tb_club_member " . $tmp_sql_where_clause;
//    $sql_query = "SELECT club_member_serno, member_status, member_password, member_session_code, member_verify_code, member_first_name, member_last_name, member_email_addr, member_ref_by_member, member_inf_by_advert, member_reserve_coop_spot, member_request_news_email, member_block_email_login, club_member_init_utc, club_member_last_utc FROM eto_sql_tb_club_member " . $tmp_sql_where_clause;
//    $sql_query = "SELECT club_member_serno, member_status, member_password, member_session_code, member_verify_code, member_first_name, member_last_name, member_email_addr, member_ref_by_member, member_inf_by_advert, member_reserve_coop_spot, member_request_news_email, member_block_email_login, club_member_init_utc, club_member_last_utc FROM eto_sql_tb_club_member WHERE club_member_serno = '$ms'";
                                                                                                                                                                                                                                                                                                                                                                                                                    
//    Test abend $ac + 0 (invalid table name.)                                                                                                                                                                                                                                                                                                                                                                      
//    $sql_query = "SELECT club_member_serno, member_status, member_password, member_session_code, member_verify_code, member_first_name, member_last_name, member_email_addr, member_ref_by_member, member_reserve_coop_spot, member_request_news_email, member_block_email_login, club_member_init_utc, club_member_last_utc FROM eto_sql_tb_club_memberX WHERE club_member_serno = '$ms'";                       
                                                                                                                                                                                                                                                                                                                                                                                                                    
//    Lock the row?                                                                                                                                                                                                                                                                                                                                                                                                 
      if ($lo)                                                                                                                                                                                                                                                                                                                                                                                                      
//    yes -- lock row.                                                                                                                                                                                                                                                                                                                                                                                              
      {                                                                                                                                                                                                                                                                                                                                                                                                             
         $sql_query .= " FOR UPDATE";                                                                                                                                                                                                                                                                                                                                                                               
//                                                                                                                                                                                                                                                                                                                                                                                                                  
//       Presumably could obtain here, or stimulate subsequent occurrences of, e.g. the following MySQL errors:                                                                                                                                                                                                                                                                                                     
//         (MySQL Error: 1205 SQLSTATE: HY000 (ER_LOCK_WAIT_TIMEOUT), MySQL Message: Lock wait timeout exceeded; try restarting transaction.                                                                                                                                                                                                                                                                        
//             Saw the 1205 in a MySQL command line lock imeout test.)                                                                                                                                                                                                                                                                                                                                              
//         (MySQL Error: 1206 SQLSTATE: HY000 (ER_LOCK_TABLE_FULL),   MySQL Message: The total number of locks exceeds the lock table size).                                                                                                                                                                                                                                                                        
//         (MySQL Error: 1213 SQLSTATE: 40001 (ER_LOCK_DEADLOCK),     MySQL Message: Deadlock found when trying to get lock; try restarting transaction ).                                                                                                                                                                                                                                                          
//                                                                                                                                                                                                                                                                                                                                                                                                                  
//       See also PHP function mysqli_options(...) function                                                                                                                                                                                                                                                                                                                                                         
//          with MYSQLI_READ_DEFAULT_FILE option                                                                                                                                                                                                                                                                                                                                                                    
//          to direct MySQL to read its options from named option file instead of my.cnf                                                                                                                                                                                                                                                                                                                            
      }
                                                                                                                                                                                                                                                                                                                                                                                                         
//    Does the SELECT return at least 1 row?                                                                                                                                                                                                                                                                                                                                                                        
      if ($return_val = etoSQLquery($ac+Xka, $xo, $ro)) // Abend ($ac+2)+ -- etoSQLquery() failed to deliver row (not missing key).                                                                                                                                                                                                                                                                                 
//    yes -- row(s) available.                                                                                                                                                                                                                                                                                                                                                                                      
      {                                                                                                                                                                                                                                                                                                                                                                                                             
        $sql_fetch = mysqli_fetch_row($sql_result);                                                                                                                                                                                                                                                                                                                                                                 
                                                                                                                                                                                                                                                                                                                                                                                                                    
        mysqli_free_result($sql_result);                                                                                                                                                                                                                                                                                                                                                                            
                                                                                                                                                                                                                                                                                                                                                                                                                    
//      Test abend $ac + 1                                                                                                                                                                                                                                                                                                                                                                                          
//      (new empty variable as result parm.)                                                                                                                                                                                                                                                                                                                                                                        
//      (MUST start Apache with no PHP warning messages, to get "xxABEND" image displayed when testing eto_contact_img.php.)                                                                                                                                                                                                                                                                                        
//      $sql_fetch = mysqli_fetch_row($sql_resultX);                                                                                                                                                                                                                                                                                                                                                                
                                                                                                                                                                                                                                                                                                                                                                                                                    
//      Was the fetch row successful? (defensive programming -- should ALWAYS succeed.)                                                                                                                                                                                                                                                                                                                             
	     if ($sql_fetch)                                                                                                                                                                                                                                                                                                                                                                                             
//      yes -- fetch successful.                                                                                                                                                                                                                                                                                                                                                                                    
        {                                                                                                                                                                                                                                                                                                                                                                                                           
            $club_member_serno         = $sql_fetch[0];                                                                                                                                                                                                                                                                                                                                                             
            $member_status             = $sql_fetch[1];                                                                                                                                                                                                                                                                                                                                                             
            $member_password           = $sql_fetch[2];                                                                                                                                                                                                                                                                                                                                                             
            $member_session_code       = $sql_fetch[3];                                                                                                                                                                                                                                                                                                                                                             
            $member_verify_code        = $sql_fetch[4];                                                                                                                                                                                                                                                                                                                                                             
            $member_first_name         = $sql_fetch[5];                                                                                                                                                                                                                                                                                                                                                             
            $member_last_name          = $sql_fetch[6];                                                                                                                                                                                                                                                                                                                                                             
            $member_email_addr         = $sql_fetch[7];                                                                                                                                                                                                                                                                                                                                                             
            $member_ref_by_member      = $sql_fetch[8];                                                                                                                                                                                                                                                                                                                                                             
            $member_inf_by_advert      = $sql_fetch[9];                                                                                                                                                                                                                                                                                                                                                             
            $member_reserve_coop_spot  = $sql_fetch[10];                                                                                                                                                                                                                                                                                                                                                            
            $member_request_news_email = $sql_fetch[11];                                                                                                                                                                                                                                                                                                                                                            
            $member_block_email_login  = $sql_fetch[12];                                                                                                                                                                                                                                                                                                                                                            
            $club_member_init_utc      = $sql_fetch[13];
            $club_member_last_utc      = $sql_fetch[14];
            $club_member_expiry_utc    = $sql_fetch[15];
            $club_member_notified_utc  = $sql_fetch[16];
	     }
//      no -- fetch UNsuccessful.                                                                                                                                                                                                                                                                                                                                                                                   
	     else                                                                                                                                                                                                                                                                                                                                                                                                        
	     {                                                                                                                                                                                                                                                                                                                                                                                                           
      	  $sys_exit_msg = '(' . etoSQLformatDiag() . ')';                                                                                                                                                                                                                                                                                                                                                        
                                                                                                                                                                                                                                                                                                                                                                                                                    
      	  etoAbendSubCode($ac, 0, $xo, $ro); // Abend $ac + 0 -- Failed to fetch row from $sql_result (not missing key).                                                                                                                                                                                                                                                                                         
                                                                                                                                                                                                                                                                                                                                                                                                                    
           $return_val = false;                                                                                                                                                                                                                                                                                                                                                                                     
        }                                                                                                                                                                                                                                                                                                                                                                                                           
      }                                                                                                                                                                                                                                                                                                                                                                                                             
//    no -- NO row(s) available.                                                                                                                                                                                                                                                                                                                                                                                    
      else                                                                                                                                                                                                                                                                                                                                                                                                          
      {                                                                                                                                                                                                                                                                                                                                                                                                             
//       NOT Abending?                                                                                                                                                                                                                                                                                                                                                                                              
         if (!$sys_exit_code)                                                                                                                                                                                                                                                                                                                                                                                       
//       yes -- NOT abending.                                                                                                                                                                                                                                                                                                                                                                                       
         {                                                                                                                                                                                                                                                                                                                                                                                                          
//          Did the query complete?                                                                                                                                                                                                                                                                                                                                                                                 
//          if ($sql_errno == 0)       // true.                                                                                                                                                                                                                                                                                                                                                                     
//          if ($sql_state == '00000') // true(?).                                                                                                                                                                                                                                                                                                                                                                  
            if
            (
               ($sql_state_class == '00') // ok (but no data?)
               ||
               ($sql_state_class == '02') // No data.
            )                                                                                                                                                                                                                                                                                                                                                             
//          yes -- query complete => missing key in table.                                                                                                                                                                                                                                                                                                                                                          
            {                                                                                                                                                                                                                                                                                                                                                                                                       
	      	   etoSQLinitBuff_club_member();                                                                                                                                                                                                                                                                                                                                                                        
            }                                                                                                                                                                                                                                                                                                                                                                                                       
            else                                                                                                                                                                                                                                                                                                                                                                                                    
//          no -- query INcomplete.                                                                                                                                                                                                                                                                                                                                                                                 
            {                                                                                                                                                                                                                                                                                                                                                                                                       
                $sys_exit_msg = '(' . etoSQLformatDiag() . ')';                                                                                                                                                                                                                                                                                                                                                     
                                                                                                                                                                                                                                                                                                                                                                                                                    
      	       etoAbendSubCode($ac, 1, $xo, $ro); // Abend $ac + 1 -- Select failed on table eto_sql_tb_club_member (query INcomplete).                                                                                                                                                                                                                                                                            
            }                                                                                                                                                                                                                                                                                                                                                                                                       
         }                                                                                                                                                                                                                                                                                                                                                                                                          
      }                                                                                                                                                                                                                                                                                                                                                                                                             
   }
/*
// Testing ...
  global $sys_exit_code;
  global $sql_diag;

  $tst_diag = '';
  $tst_diag .= ( '##etoSQLreadRow_club_member(...)##  ' );
  $tst_diag .= ( '**$ms<' . $ms . '>**  ' );
  $tst_diag .= ( '**$club_member_serno<' . $club_member_serno . '>**  ' );
  $tst_diag .= ( '**$member_status<' . $member_status . '>**  ' );
  $tst_diag .= ( '**$member_session_code<' . $member_session_code . '>**  ' );
  $tst_diag .= ( '**$member_verify_code<' . $member_verify_code . '>**  ' );

  $tst_diag .= ( '**$club_member_init_utc<' . $club_member_init_utc . '>**  ' );
  $tst_diag .= ( '**$club_member_last_utc<' . $club_member_last_utc . '>**  ' );
  $tst_diag .= ( '**$club_member_expiry_utc<' . $club_member_expiry_utc . '>**  ' );
  $tst_diag .= ( '**$club_member_notified_utc<' . $club_member_notified_utc . '>**  ' );

  $tst_diag .= ( '**$sql_errno<' . $sql_errno . '>**  ' );
  $tst_diag .= ( '**$sql_state<' . $sql_state . '>**  ' );
  $tst_diag .= ( '**$sql_diag<' . $sql_diag . '>**  ' );

  $tst_diag .= ( '**$sys_exit_code<' . $sys_exit_code . '>**  ' );
  $tst_diag .= ( '**$sys_exit_msg<' . $sys_exit_msg . '>**  ' );
  $tst_diag .= ( '**$return_val<' . $return_val . '>**  ' );

  echo htmlspecialchars($tst_diag, ENT_QUOTES);
// ... Testing.
*/

  return ($return_val);
}

function etoSQLstmtWriteRow_club_member($mz, &$mp, &$sc, &$vc, &$mf, &$ml, &$me, &$mr, &$mi, &$mc, &$mw, &$mb, &$mx, $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK) // member status, member password, session code, verify code, member first name, member last name, member email addr, referred by member, informed by advert, reserve coop spot, request news email, block email login, expiry utc, abend code, abend exit option, abend SQL rollback option.
// function etoSQLstmtWriteRow_club_member($mz, &$mp, &$sc, &$vc, &$mf, &$ml, &$me, &$mr, &$mi, &$mc, &$mw, &$mb, $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK) // member status, member password, session code, verify code, member first name, member last name, member email addr, referred by member, informed by advert, reserve coop spot, request news email, block email login, abend code, abend exit option, abend SQL rollback option.
{
   global $sql_link;
   global $sql_query;

   global $sql_state_class;

   global $DUMMY_BIND_ARY;

	global $club_member_serno;
	global $member_status;
	global $member_password;
   global $member_session_code;
   global $member_verify_code;
   global $member_first_name;
   global $member_last_name;
   global $member_email_addr;
   global $member_ref_by_member;
   global $member_inf_by_advert;
   global $member_reserve_coop_spot;
   global $member_request_news_email;
   global $member_block_email_login;
   global $club_member_init_utc;
   global $club_member_last_utc;
   global $club_member_expiry_utc;
   global $club_member_notified_utc;


   global $crn_dtime_utc;

// Abend code allocation ...

//  slots  function
//  -----  --------
//
//    5     etoSQLstmtWriteRow_club_member(...) => this function.
//
//    5     etoSQLstmtOpen(...)                 => called by this function.
//    9     etoSQLstmtDo(...)                   => called by this function.
//    2     etoSQLstmtClose(...)                => called by this function.
//  -----
//   21

// ... Abend code allocation.

   global $sys_exit_code; // $ac mapping: ($ac+0) ... ($ac+19) => 20 slots.
   global $sys_exit_msg;

   $return_val = true;

   $tmp_club_member_notified_utc = CRN_DTIME_0_UTC;

/*
// Testing ...
  global $sql_errno;
  global $sql_state;
  global $sys_exit_code;

  $tst_diag = '';
  $tst_diag .= ( '##etoSQLstmtWriteRow_club_member(#0)##  ' );
  $tst_diag .= ( '**$ac<' . $ac . '>**  ' );

  $tst_diag .= ( '**$mc<' . $mc . '>**  ' );
  $tst_diag .= ( '**$mw<' . $mw . '>**  ' );
  $tst_diag .= ( '**$mb<' . $mb . '>**  ' );

  $tst_diag .= ( '**$sql_errno<' . $sql_errno . '>**  ' );
  $tst_diag .= ( '**$sql_state<' . $sql_state . '>**  ' );

  $tst_diag .= ( '**$sys_exit_code<' . $sys_exit_code . '>**  ' );
  $tst_diag .= ( '**$return_val<' . $return_val . '>**  ' );

  echo htmlspecialchars($tst_diag, ENT_QUOTES);
// ... Testing.
*/

   etoSQLinitCall();

//
//  (Effect of query.)
//
//   INSERT INTO eto_sql_tb_club_member
//
//      (
//          club_member_serno,
//          member_status,
//          member_password,
//          member_session_code,
//          member_verify_code,
//          member_first_name,
//          member_last_name,
//          member_email_addr,
//          member_ref_by_member,
//          member_inf_by_advert,
//          member_reserve_coop_spot,
//          member_request_news_email,
//          member_block_email_login,
//          club_member_init_utc,
//          club_member_last_utc,
//          club_member_expiry_utc,
//          club_member_notified_utc
//      )
//
//      VALUES
//      (
//         NULL,
//         $mz,
//         $mp,
//         $sc,
//         $vc,
//         $mf,
//         $ml,
//         $me,
//         $mr,
//         $mi,
//         $mc,
//         $mw,
//         $mb,
//         '$crn_dtime_utc',
//         '$crn_dtime_utc',
//         $mx,
//         '$tmp_club_member_notified_utc'
//      )
//

   $sql_query = "INSERT INTO eto_sql_tb_club_member (club_member_serno, member_status, member_password, member_session_code, member_verify_code, member_first_name, member_last_name, member_email_addr, member_ref_by_member, member_inf_by_advert, member_reserve_coop_spot, member_request_news_email, member_block_email_login, club_member_init_utc, club_member_last_utc, club_member_expiry_utc, club_member_notified_utc) VALUES(NULL, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)";
// $sql_query = "INSERT INTO eto_sql_tb_club_member (club_member_serno, member_status, member_password, member_session_code, member_verify_code, member_first_name, member_last_name, member_email_addr, member_ref_by_member, member_inf_by_advert, member_reserve_coop_spot, member_request_news_email, member_block_email_login, club_member_init_utc, club_member_last_utc) VALUES(NULL, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)";

// Test abend $ac + 1 (invalid table name.)
// $sql_query = "INSERT INTO eto_sql_tb_club_memberX (club_member_serno, member_status, member_password, member_session_code, member_verify_code, member_first_name, member_last_name, member_email_addr, member_ref_by_member, member_inf_by_advert, member_reserve_coop_spot, member_request_news_email, member_block_email_login, club_member_init_utc, club_member_last_utc) VALUES(NULL, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)";

   $query_param_bind_ary
   =
   array
   (
       0 => $mz,
       1 => $mp,
       2 => $sc,
       3 => $vc,
       4 => $mf,
       5 => $ml,
       6 => $me,
       7 => $mr,
       8 => $mi,
       9 => (($mc) ? 1 : 0),
      10 => (($mw) ? 1 : 0),
      11 => (($mb) ? 1 : 0),
      12 => &$crn_dtime_utc,
      13 => &$crn_dtime_utc,
      14 => $mx,
      15 => &$tmp_club_member_notified_utc
   );

// Is statement open successful?
   if
   (
      $return_val
      =
      etoSQLstmtOpen
      (
         'issssssiiiiissss',       // query parameter type specification (i=integer, s=string).
//       'issssssiiiiiss',       // query parameter type specification (i=integer, s=string).
//       'issssssiiisss',       // query parameter type specification (i=integer, s=string).

         $query_param_bind_ary, // query parameter(s) bind array.

         ($ac+Xma), $xo, $ro      // abend code, abend exit option, abend SQL rollback option.
//       ($ac+4), $xo, $ro      // abend code, abend exit option, abend SQL rollback option.
      )
   )
// yes -- statement open successful.
   {
//    Is statement do successful?
      if
      (
         $return_val
         =
         etoSQLstmtDo
         (
            $DUMMY_BIND_ARY,     // result parameter(s) bind array.

            ($ac+Xma+X3), $xo, $ro   // abend code, abend exit option, abend SQL rollback option.
//          ($ac+4+5), $xo, $ro   // abend code, abend exit option, abend SQL rollback option.
         )
      )
//    yes -- statement do successful.
      {
//       Is SQLSTATE class acceptable?
         if
         (
            ($sql_state_class == '00') // success.
            ||
            ($sql_state_class == '23') // integrity constraint violation (e.g. duplicate key).
         )
//       yes -- SQLSTATE class acceptable.
         {
//          Wes insert successful?
            if ($sql_state_class == '00')
//          yes -- insert successful.
            {
               $tmp_club_member_serno = etoSQLget_mysqli_insert_id();

//             did serno of inserted row exceed int precision?
               if (!$tmp_club_member_serno)
//             yes - exceeded int precision.
               {
                  $return_val = false;

                  $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

                  etoAbendSubCode($ac, 0, $xo, $ro); // Abend $ac + 0 -- etoSQLstmtDo(...) serno of inserted row exceeded int precision.
               }
            }
            else
//          no -- insert UNsuccessful.
            {
                $return_val = false;
            }

   //       Is statement close successful?
            if (etoSQLstmtClose(($ac+Xma+X3+X4), $xo, $ro))
//          if (etoSQLstmtClose(($ac+4+5+9), $xo, $ro))
   //       yes -- statement close successful.
            {
               $club_member_serno         = $tmp_club_member_serno;
               $member_status             = $mz;
               $member_password           = $mp;
               $member_session_code       = $sc;
               $member_verify_code        = $vc;
               $member_first_name         = $mf;
               $member_last_name          = $ml;
               $member_email_addr         = $me;
               $member_ref_by_member      = $mr;
               $member_inf_by_advert      = $mi;
               $member_reserve_coop_spot  = $mc;
               $member_request_news_email = $mw;
               $member_block_email_login  = $mb;
               $club_member_init_utc      = $crn_dtime_utc;
               $club_member_last_utc      = $crn_dtime_utc;
               $club_member_expiry_utc    = $mx;
               $club_member_notified_utc  = $tmp_club_member_notified_utc;
            }
            else
   //       no -- statement close failed.
            {
   //          NOT already bending?
               if (!$sys_exit_code)
   //          yes -- NOT already abending.
               {
                  $return_val = false;

                  $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

                  etoAbendSubCode($ac, 1, $xo, $ro); // Abend $ac + 1 -- etoSQLstmtClose(...) failed.
               }
            }
         }
         else
//       no -- SQLSTATE class NOT acceptable.
         {
            $return_val = false;

            $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

            etoAbendSubCode($ac, 2, $xo, $ro); // Abend $ac + 2 -- etoSQLstmtDo(...) SQLSTATE class NOT acceptable.
         }
      }
      else
//    no -- statement do failed.
      {
//       NOT already abending?
         if (!$sys_exit_code)
//       yes -- NOT already abending.
         {
            $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

/*
// Testing ...
  global $sql_errno;
  global $sql_state;
  global $sys_exit_code;

  $tst_diag = '';
  $tst_diag .= ( '##etoSQLstmtWriteRow_club_member(#1)##  ' );
  $tst_diag .= ( '**$mc<' . $mc . '>**  ' );
  $tst_diag .= ( '**$mw<' . $mw . '>**  ' );
  $tst_diag .= ( '**$mb<' . $mb . '>**  ' );

  $tst_diag .= ( '**$sql_errno<' . $sql_errno . '>**  ' );
  $tst_diag .= ( '**$sql_state<' . $sql_state . '>**  ' );

  $tst_diag .= ( '**$sys_exit_code<' . $sys_exit_code . '>**  ' );
  $tst_diag .= ( '**$return_val<' . $return_val . '>**  ' );

  echo htmlspecialchars($tst_diag, ENT_QUOTES);
// ... Testing.
*/

            etoAbendSubCode($ac, 3, $xo, $ro); // Abend $ac + 3 -- etoSQLstmtDo(...) failed.
         }
      }
   }
   else
// no -- statement open failed.
   {
//    NOT already bending?
      if (!$sys_exit_code)
//    yes -- NOT already abending.
      {
         $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

         etoAbendSubCode($ac, 4, $xo, $ro); // Abend $ac + 4 -- etoSQLstmtOpen(...) failed.
      }
   }

/*
// Testing ...
  global $sql_errno;
  global $sql_state;
  global $sys_exit_code;

  $tst_diag = '';
  $tst_diag .= ( '##etoSQLstmtWriteRow_club_member(#3)##  ' );
  $tst_diag .= ( '**$mz<' . $mz . '>**  ' );
  $tst_diag .= ( '**$mp<' . $mp . '>**  ' );
  $tst_diag .= ( '**$sc<' . $sc . '>**  ' );
  $tst_diag .= ( '**$vc<' . $vc . '>**  ' );
  $tst_diag .= ( '**$mf<' . $mf . '>**  ' );
  $tst_diag .= ( '**$ml<' . $ml . '>**  ' );
  $tst_diag .= ( '**$me<' . $me . '>**  ' );
  $tst_diag .= ( '**$mr<' . $mr . '>**  ' );
  $tst_diag .= ( '**$mi<' . $mi . '>**  ' );
  $tst_diag .= ( '**$mc<' . $mc . '>**  ' );
  $tst_diag .= ( '**$mw<' . $mw . '>**  ' );
  $tst_diag .= ( '**$mb<' . $mb . '>**  ' );
  $tst_diag .= ( '**$mx<' . $mx . '>**  ' );

  $tst_diag .= ( '**$club_member_serno<' . $club_member_serno . '>**  ' );
  $tst_diag .= ( '**$member_status<' . $member_status . '>**  ' );
  $tst_diag .= ( '**$member_password<' . $member_password . '>**  ' );
  $tst_diag .= ( '**$member_session_code<' . $member_session_code . '>**  ' );
  $tst_diag .= ( '**$member_verify_code<' . $member_verify_code . '>**  ' );
  $tst_diag .= ( '**$member_first_name<' . $member_first_name . '>**  ' );
  $tst_diag .= ( '**$member_last_name<' . $member_last_name . '>**  ' );
  $tst_diag .= ( '**$member_email_addr<' . $member_email_addr . '>**  ' );
  $tst_diag .= ( '**$member_inf_by_advert<' . $member_inf_by_advert . '>**  ' );
  $tst_diag .= ( '**$member_ref_by_member<' . $member_ref_by_member . '>**  ' );
  $tst_diag .= ( '**$member_reserve_coop_spot<' . $member_reserve_coop_spot . '>**  ' );
  $tst_diag .= ( '**$member_request_news_email<' . $member_request_news_email . '>**  ' );
  $tst_diag .= ( '**$member_block_email_login<' . $member_block_email_login . '>**  ' );
  $tst_diag .= ( '**$club_member_init_utc<' . $club_member_init_utc . '>**  ' );
  $tst_diag .= ( '**$club_member_last_utc<' . $club_member_last_utc . '>**  ' );
  $tst_diag .= ( '**$club_member_expiry_utc<' . $club_member_expiry_utc . '>**  ' );
  $tst_diag .= ( '**$club_member_notified_utc<' . $club_member_notified_utc . '>**  ' );

  $tst_diag .= ( '**$sql_errno<' . $sql_errno . '>**  ' );
  $tst_diag .= ( '**$sql_state<' . $sql_state . '>**  ' );

  $tst_diag .= ( '**$sys_exit_code<' . $sys_exit_code . '>**  ' );
  $tst_diag .= ( '**$return_val<' . $return_val . '>**  ' );

  echo htmlspecialchars($tst_diag, ENT_QUOTES);
// ... Testing.
*/

  return ($return_val);
}

function etoSQLstmtReWriteRow_club_member($ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK) // abend code, abend exit option, abend SQL rollback option.
{
  global $sql_query;
  global $sql_errno;
  global $sql_state_class;
  global $sql_afec_row_count;

  global $DUMMY_BIND_ARY;

  global $club_member_serno;
  global $member_status;
  global $member_password;
  global $member_session_code;
  global $member_verify_code;
  global $member_first_name;
  global $member_last_name;
  global $member_email_addr;
  global $member_ref_by_member;
  global $member_inf_by_advert;
  global $member_reserve_coop_spot;
  global $member_request_news_email;
  global $member_block_email_login;
  global $club_member_init_utc;
  global $club_member_last_utc;
  global $club_member_expiry_utc;
  global $club_member_notified_utc;

// Abend code allocation ...

//  slots  function
//  -----  --------
//
//    4     etoSQLstmtReWriteRow_club_member(...) => this function.
//
//    5     etoSQLstmtOpen(...)                   => called by this function.
//    9     etoSQLstmtDo(...)                     => called by this function.
//    2     etoSQLstmtClose(...)                  => called by this function.
//  -----
//   20

// ... Abend code allocation.

  global $sys_exit_code; // $ac mapping: ($ac+0) ... ($ac+19) => 20 slots.
  global $sys_exit_msg;

  global $crn_dtime_utc;

  $return_val = true;

  $club_member_last_utc = $crn_dtime_utc;

//
//  (Effect of query.)
//
//   UPDATE eto_sql_tb_club_member
//
//     SET
//         member_status             = $member_status,
//         member_password           = '$member_password',
//         member_session_code       = '$member_session_code',
//         member_verify_code        = '$member_verify_code',
//         member_first_name         = '$member_first_name',
//         member_last_name          = '$member_last_name',
//         member_email_addr         = '$member_email_addr',
//         member_ref_by_member      = $member_ref_by_member,
//         member_in_by_advert      = $member_inf_by_advert,
//         member_reserve_coop_spot  = $member_reserve_coop_spot,
//         member_request_news_email = $member_request_news_email,
//         member_block_email_login  = $member_block_email_login,
//         club_member_init_utc      = '$club_member_init_utc',
//         club_member_last_utc      = '$club_member_last_utc',
//         club_member_expiry_utc    = '$club_member_expiry_utc',
//         club_member_notified_utc  = '$club_member_notified_utc'
//
//     WHERE (club_member_serno = '$club_member_serno')
//

  $sql_query = "UPDATE eto_sql_tb_club_member SET member_status = ?, member_password = ?, member_session_code = ?, member_verify_code = ?, member_first_name = ?, member_last_name = ?, member_email_addr = ?, member_ref_by_member = ?, member_inf_by_advert = ?, member_reserve_coop_spot = ?, member_request_news_email = ?, member_block_email_login = ?, club_member_init_utc = ?, club_member_last_utc = ?, club_member_expiry_utc = ?, club_member_notified_utc = ? WHERE (club_member_serno = ?)";
// $sql_query = "UPDATE eto_sql_tb_club_member SET member_status = ?, member_password = ?, member_session_code = ?, member_verify_code = ?, member_first_name = ?, member_last_name = ?, member_email_addr = ?, member_ref_by_member = ?, member_inf_by_advert = ?, member_reserve_coop_spot = ?, member_request_news_email = ?, member_block_email_login = ?, club_member_init_utc = ?, club_member_last_utc = ? WHERE (club_member_serno = ?)";

// Test abend $ac + 0 (invalid table name.)
// $sql_query = "UPDATE eto_sql_tb_club_memberX SET member_status = ?, member_password = ?, member_session_code = ?, member_verify_code = ?, member_first_name = ?, member_last_name = ?, member_email_addr = ?, member_ref_by_member = ?, member_inf_by_advert = ?, member_reserve_coop_spot = ?, member_request_news_email = ?, member_block_email_login = ?, club_member_init_utc = ?, club_member_last_utc = ? WHERE (club_member_serno = ?)";

   $query_param_bind_ary
   =
   array
   (
       0 => &$member_status,
       1 => &$member_password,
       2 => &$member_session_code,
       3 => &$member_verify_code,
       4 => &$member_first_name,
       5 => &$member_last_name,
       6 => &$member_email_addr,
       7 => &$member_ref_by_member,
       8 => &$member_inf_by_advert,
       9 => &$member_reserve_coop_spot,
      10 => &$member_request_news_email,
      11 => &$member_block_email_login,
      12 => &$club_member_init_utc,
      13 => &$club_member_last_utc,
      14 => &$club_member_expiry_utc,
      15 => &$club_member_notified_utc,
      16 => &$club_member_serno
   );

// Is statement open successful?
   if
   (
      $return_val
      =
      etoSQLstmtOpen
      (
         'issssssiiiiissssi',     // query parameter type specification (i=integer, s=string)
//       'issssssiiiiissi',       // query parameter type specification (i=integer, s=string)

         $query_param_bind_ary, // query parameter(s) bind array.

         ($ac+Xna), $xo, $ro    // abend code, abend exit option, abend SQL rollback option.
//       ($ac+4), $xo, $ro      // abend code, abend exit option, abend SQL rollback option.
      )
   )
// yes -- statement open successful.
   {
//    Is statement do successful?
      if
      (
         $return_val
         =
         etoSQLstmtDo
         (
            $DUMMY_BIND_ARY,       // result parameter(s) bind array.

            ($ac+Xna+X3), $xo, $ro // abend code, abend exit option, abend SQL rollback option.
//          ($ac+4+5), $xo, $ro    // abend code, abend exit option, abend SQL rollback option.
         )
      )
//    yes -- statement do successful.
      {
//       Is SQLSTATE class acceptable?
         if ($sql_state_class == '00') // success.
//       yes -- SQLSTATE class acceptable.
         {
//          Is statement close successful?
            if
            (
               $return_val
               =
               etoSQLstmtClose(($ac+Xna+X3+X4), $xo, $ro)
//             etoSQLstmtClose(($ac+4+5+9), $xo, $ro)
            )
//          yes -- statement close successful.
            {
//             do nothing.
            }
            else
//          no -- statement close failed.
            {
//             NOT already bending?
               if (!$sys_exit_code)
//             yes -- NOT already abending.
               {
                  $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

                  etoAbendSubCode($ac, 0, $xo, $ro); // Abend $ac + 0 -- etoSQLstmtClose(...) failed.
              }
            }
         }
         else
//       no -- SQLSTATE class UNacceptable.
         {
            $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

            etoAbendSubCode($ac, 1, $xo, $ro); // Abend $ac + 1 -- etoSQLstmtDo(...) failed, SQLSTATE class UNacceptable.
         }
      }
      else
//    no -- statement do failed.
      {
//       NOT already bending?
         if (!$sys_exit_code)
//       yes -- NOT already abending.
         {
            etoSQLstmtGetMysqliDiag();

            $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

            etoAbendSubCode($ac, 2, $xo, $ro); // Abend $ac + 2 -- etoSQLstmtDo(...) failed.
         }
      }
   }
   else
// no -- statement open failed.
   {
//    NOT already bending?
      if (!$sys_exit_code)
//    yes -- NOT already abending.
      {
         etoSQLstmtGetMysqliDiag();

         $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

         etoAbendSubCode($ac, 3, $xo, $ro); // Abend $ac + 3 -- etoSQLstmtOpen(...) failed.
      }
   }

  return ($return_val);
}

function etoSQLdeleteRow_club_member($ms, $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK) // member serno, abend code, abend exit option, abend SQL rollback option.
{
  global $sql_query;

  global $sys_exit_code;
  global $sys_exit_msg;

// Abend code allocation ...

//  slots  function
//  -----  --------
//
//    1     etoSQLdeleteRow_club_member(...) => this function.
//
//    7     etoSQLquery(...)                 => called by this function.
//  -----
//    8

// ... Abend code allocation.

// global $sys_exit_code; // $ac mapping: ($ac+0) ... ($ac+1+7-1) => 8 slots.

  $return_val = true;

  etoSQLinitCall();

  $sql_query = "DELETE FROM eto_sql_tb_club_member WHERE (club_member_serno = '$ms')";

// Test abend $ac (invalid table name.)
//  $sql_query = "DELETE FROM eto_sql_tb_session_wwwX WHERE (session_www_code = '$sc')";

// Is attempt to delete row in eto_sql_tb_session_www table UNsuccessful?
   if (!etoSQLquery($ac+Xra, $xo, $ro)) // Abend ($ac+1)+ -- etoSQLquery() failed to delete row(s) in table eto_sql_tb_club_member (not missing key).
// if (!etoSQLquery($ac+1, $xo, $ro)) // Abend ($ac+1)+ -- etoSQLquery() failed to delete row(s) in table eto_sql_tb_club_member (not missing key).
// yes -- row delete UNsuccessful.
   {
      $return_val = false;

//    NOT Abending?
      if (!$sys_exit_code)
//    yes -- NOT abending.
      {
         $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

         etoAbend($ac, $xo, $ro); // Abend -- Failed to delete row in table eto_sql_tb_club_member.
      }
   }

/*
// Testing ...
  global $club_member_serno;
  global $member_session_code;
  global $member_verify_code;
  global $club_member_init_utc;
  global $club_member_last_utc;
  global $sql_errno;
  global $sql_state;
  global $sys_exit_code;

  $tst_diag = '';
  $tst_diag .= ( '##etoSQLdeleteRow_club_member(...)##  ' );
  $tst_diag .= ( '**$ms<' . $ms . '>**  ' );
  $tst_diag .= ( '**$club_member_serno<' . $club_member_serno . '>**  ' );
  $tst_diag .= ( '**$member_session_code<' . $member_session_code . '>**  ' );
  $tst_diag .= ( '**$member_verify_code<' . $member_verify_code . '>**  ' );

  $tst_diag .= ( '**$club_member_init_utc<' . $club_member_init_utc . '>**  ' );
  $tst_diag .= ( '**$club_member_last_utc<' . $club_member_last_utc . '>**  ' );

  $tst_diag .= ( '**$sql_errno<' . $sql_errno . '>**  ' );
  $tst_diag .= ( '**$sql_state<' . $sql_state . '>**  ' );

  $tst_diag .= ( '**$sys_exit_code<' . $sys_exit_code . '>**  ' );
  $tst_diag .= ( '**$return_val<' . $return_val . '>**  ' );

  echo htmlspecialchars($tst_diag, ENT_QUOTES);
// ... Testing.
*/

  return ($return_val);
}

function etoSQLsetState_club_member($mst, $ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK) // member state, abend code, abend exit option, abend SQL rollback option.
{
  global $club_member_serno;
  global $member_status;

//
// *** ABEND CODE MANAGEMENT ***
//
// Each member state target case
//  using function:
//
//    etoSQLstmtReWriteRow_club_member(), or
//
//    etoSQLdeleteRow_club_member()
//
//   maps to a unique range of abend codes,
//   allocated according to the following table:
//
//    -------------------------------------------------------------------
//                    ABEND CODE RANGE TABLE
//    -------------------------------------------------------------------
//                                        function
//                            ----------abend code range-----------
//    member state target  =>     ac_min               ac_max
//    --------------------    --------------       ----------------
//
//                                etoSQLdeleteRow_club_member()
//    ROW_STATE_NULL       =>     $ac+9       ...      $ac+9+8
//    --------------------    --------------       ----------------
//
//                               etoSQLstmtReWriteRow_club_member()
//    ROW_STATE_ACTIVE     => $ac+9+8 +(0*20)  ...  $ac+9+8 +(1*20)-1
//    ROW_STATE_EXPIRED    => $ac+9+8 +(1*20)  ...  $ac+9+8 +(2*20)-1
//    ROW_STATE_PAUSED     => $ac+9+8 +(2*20)  ...  $ac+9+8 +(3*20)-1
//    ROW_STATE_RESIGNED   => $ac+9+8 +(3*20)  ...  $ac+9+8 +(4*20)-1
//    ROW_STATE_REVOKED    => $ac+9+8 +(4*20)  ...  $ac+9+8 +(5*20)-1
//    ROW_STATE_NON_MEMBER => $ac+9+8 +(5*20)  ...  $ac+9+8 +(6*20)-1
//    -------------------------------------------------------------------
//
//  where 9 == count of etoAbendSubCode()s
//   generated by this function (+0..+8),
//
//  and 8 == count of etoAbendSubCode()s
//   generated by function etoSQLdeleteRow_club_member() (+0..+7).
//
//  and 20 == the count of etoAbendSubCode()s
//   generated by function etoSQLstmtReWriteRow_club_member() (+0..+19).
//

// global $sys_exit_code; // $ac mapping: ($ac+0) ... ($ac+136) == ($ac+9+8+(6*20)-1) => 137 slots.

  $return_val = true;

  switch ($mst)
  {
      case ROW_STATE_NULL:
      {
//       Is row in valid current state?
         if
         (
            ($member_status == ROW_STATE_EXPIRED)
            ||
            ($member_status == ROW_STATE_REVOKED)
         )
//       yes -- valid current state.
         {
//          Delete row.
            $return_val = etoSQLdeleteRow_club_member($club_member_serno, $ac+Xsa, $xo, $ro);
//          $return_val = etoSQLdeleteRow_club_member($club_member_serno, $ac+9, $xo, $ro);

//          Was delete successful?
            if ($return_val)
//          yes -- delete successful.
            {
               etoSQLinitBuff_club_member();
            }
            else
//          no -- delete UNsuccessful.
            {
//             NOT Abending?
               if (!$sys_exit_code)
//             yes -- NOT abending.
               {
                  etoAbendSubCode($ac, 0, $xo, $ro); // Abend $ac + 0 -- Failed to delete row in table eto_sql_tb_club_member.
               }
            }
         }
//       no -- INvalid current state.
         else
         {
            $return_val = false;

            etoAbendSubCode($ac, 1, $xo, $ro); // Abend $ac + 1 -- INvalid current $member_status for transition to NULL.
         }

         break;
      }

      case ROW_STATE_ACTIVE:
      {
//       Is row in valid current state?
         if
         (
            ($member_status == ROW_STATE_ACTIVE)
            ||
            ($member_status == ROW_STATE_EXPIRED)
            ||
            ($member_status == ROW_STATE_PAUSED)
            ||
            ($member_status == ROW_STATE_RESIGNED)
            ||
            ($member_status == ROW_STATE_REVOKED)
            ||
            ($member_status == ROW_STATE_NON_MEMBER)
         )
//       yes -- valid current state.
         {
//          Set member state.
            $member_status = ROW_STATE_ACTIVE;

//          Rewrite row.
            $return_val = etoSQLstmtReWriteRow_club_member($ac+Xsa+Xr+(0*Xn), $xo, $ro);
//          $return_val = etoSQLstmtReWriteRow_club_member($ac+9+8+(0*20), $xo, $ro);
         }
//       no -- INvalid current state.
         else
         {
            $return_val = false;

            etoAbendSubCode($ac, 2, $xo, $ro); // Abend $ac + 2 -- INvalid current $member_status for transition to ACTIVE.
         }

         break;
      }

      case ROW_STATE_EXPIRED:
      {
//       Is row in valid current state?
         if
         (
            ($member_status == ROW_STATE_ACTIVE)
            ||
            ($member_status == ROW_STATE_EXPIRED)
            ||
            ($member_status == ROW_STATE_PAUSED)
            ||
            ($member_status == ROW_STATE_RESIGNED)
            ||
            ($member_status == ROW_STATE_NON_MEMBER)
         )
//       yes -- valid current state.
         {
//          Set member state.
            $member_status = ROW_STATE_EXPIRED;

//          Rewrite row.
            $return_val = etoSQLstmtReWriteRow_club_member($ac+Xsa+Xr+(1*Xn), $xo, $ro);
//          $return_val = etoSQLstmtReWriteRow_club_member($ac+9+8+(1*20), $xo, $ro);
         }
//       no -- INvalid current state.
         else
         {
            $return_val = false;

            etoAbendSubCode($ac, 3, $xo, $ro); // Abend $ac + 3 -- INvalid current $member_status for transition to EXPIRED.
         }

         break;
      }

      case ROW_STATE_PAUSED:
      {
//       Is row in valid current state?
         if
         (
            ($member_status == ROW_STATE_ACTIVE)
            ||
            ($member_status == ROW_STATE_PAUSED)
            ||
            ($member_status == ROW_STATE_RESIGNED)
         )
//       yes -- valid current state.
         {
//          Set member state.
            $member_status = ROW_STATE_PAUSED;

//          Rewrite row.
            $return_val = etoSQLstmtReWriteRow_club_member($ac+Xsa+Xr+(2*Xn), $xo, $ro);
//          $return_val = etoSQLstmtReWriteRow_club_member($ac+9+8+(2*20), $xo, $ro);
         }
//       no -- INvalid current state.
         else
         {
            $return_val = false;

            etoAbendSubCode($ac, 4, $xo, $ro); // Abend $ac + 4 -- INvalid current $member_status for transition to PAUSED.
         }

         break;
      }

      case ROW_STATE_RESIGNED:
      {
//       Is row in valid current state?
         if
         (
            ($member_status == ROW_STATE_ACTIVE)
            ||
            ($member_status == ROW_STATE_PAUSED)
            ||
            ($member_status == ROW_STATE_RESIGNED)
         )
//       yes -- valid current state.
         {
//          Set member state.
            $member_status = ROW_STATE_RESIGNED;

//          Rewrite row.
            $return_val = etoSQLstmtReWriteRow_club_member($ac+Xsa+Xr+(3*Xn), $xo, $ro);
//          $return_val = etoSQLstmtReWriteRow_club_member($ac+9+8+(3*20), $xo, $ro);
         }
//       no -- INvalid current state.
         else
         {
            $return_val = false;

            etoAbendSubCode($ac, 5, $xo, $ro); // Abend $ac + 5 -- INvalid current $member_status for transition to RESIGNED.
         }

         break;
      }

      case ROW_STATE_REVOKED:
      {
//       Is row in valid current state?
         if
         (
            ($member_status == ROW_STATE_ACTIVE)
            ||
            ($member_status == ROW_STATE_EXPIRED)
            ||
            ($member_status == ROW_STATE_PAUSED)
            ||
            ($member_status == ROW_STATE_RESIGNED)
            ||
            ($member_status == ROW_STATE_REVOKED)
            ||
            ($member_status == ROW_STATE_NON_MEMBER)
         )
//       yes -- valid current state.
         {
//          Set member state.
            $member_status = ROW_STATE_REVOKED;

//          Rewrite row.
            $return_val = etoSQLstmtReWriteRow_club_member($ac+Xsa+Xr+(4*Xn), $xo, $ro);
//          $return_val = etoSQLstmtReWriteRow_club_member($ac+9+8+(4*20), $xo, $ro);
         }
//       no -- INvalid current state.
         else
         {
            $return_val = false;

            etoAbendSubCode($ac, 6, $xo, $ro); // Abend $ac + 6 -- INvalid current $member_status for transition to REVOKED.
         }

         break;
      }

      case ROW_STATE_NON_MEMBER:
      {
//       Is row in valid current state?
         if
         (
            ($member_status == ROW_STATE_ACTIVE)
            ||
            ($member_status == ROW_STATE_PAUSED)
            ||
            ($member_status == ROW_STATE_RESIGNED)
            ||
            ($member_status == ROW_STATE_NON_MEMBER)
         )
//       yes -- valid current state.
         {
//          Set member state.
            $member_status = ROW_STATE_NON_MEMBER;

//          Rewrite row.
            $return_val = etoSQLstmtReWriteRow_club_member($ac+Xsa+Xr+(5*Xn), $xo, $ro);
//          $return_val = etoSQLstmtReWriteRow_club_member($ac+9+8+(5*20), $xo, $ro);
         }
//       no -- INvalid current state.
         else
         {
            $return_val = false;

            etoAbendSubCode($ac, 7, $xo, $ro); // Abend $ac + 7 -- INvalid current $member_status for transition to NON_MEMBER.
         }

         break;
      }

      default:
      {
         $return_val = false;

         etoAbendSubCode($ac, 8, $xo, $ro); // Abend $ac + 8 -- INvalid target value for transition of $member_status.

         break;
      }
  }

  return ($return_val);
}

function etoSQLgetMaxSerno_club_member($ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK) // abend code, abend exit option, abend SQL rollback option.
{
// global $sql_errno;
// global $sql_state;
   global $sql_state_class;

   global $sql_query;
   global $sql_result;
   global $sql_fetch;

// Abend code allocation ...

//  slots  function
//  -----  --------
//
//    3     etoSQLgetMaxSerno_club_member(...) => this function.
//
//    7     etoSQLquery(...)                   => called by this function.
//  -----
//   10

// ... Abend code allocation.

   global $sys_exit_code; // $ac mapping: ($ac+0) ... ($ac+9) => 10 slots.
   global $sys_exit_msg;

   $max_club_member_serno = '';

   $sql_query = "SELECT max(club_member_serno) FROM eto_sql_tb_club_member";

// Test abend $ac + 5 (invalid table name.)
// $sql_query = "SELECT min(session_www_serno) FROM eto_sql_tb_session_wwwX";

// Does the SELECT return a value?
   if (etoSQLquery($ac+Xea, $xo, $ro)) // Abend ($ac+3)+ -- etoSQLquery() failed to deliver result from table eto_sql_tb_session_www.
// if (etoSQLquery($ac+3, $xo, $ro)) // Abend ($ac+3)+ -- etoSQLquery() failed to deliver result from table eto_sql_tb_session_www.
// yes -- value available.
   {
     $sql_fetch = mysqli_fetch_row($sql_result);

     mysqli_free_result($sql_result);

//   Test abend $ac + 0
//   (new empty variable as result parm.)
//   sql_fetch = mysqli_fetch_row($sql_resultX);

//   Was the fetch row successful? (defensive programming -- should ALWAYS succeed.)
	   if ($sql_fetch)
//   yes -- fetch successful.
     {
	     $max_club_member_serno = $sql_fetch[0];

//      MySQL returns null string if 0 rows in table eto_sql_tb_session_www.
	     if ($max_club_member_serno == '')
        {
           $max_club_member_serno = SQL_NUL_ROW_SERNO;
        }
	  }
//   no -- fetch UNsuccessful.
	   else
     {
        $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

   	    etoAbendSubCode($ac, 0, $xo, $ro); // Abend $ac + 0 -- Failed to fetch row from $sql_result.
     }
  }
// no -- NO value available.
  else
  {
//   NOT Abending?
     if (!$sys_exit_code)
//   yes -- NOT abending.
     {
//      Was the query complete?
//      if ($sql_errno == 0)
//      if ($sql_state == '00000') // true(?).
        if ($sql_state_class == '02') // No data.
//      yes -- query complete.
        {
           $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

           etoAbendSubCode($ac, 1, $xo, $ro); // Abend $ac + 1 -- SELECT min(session_www_serno) failed on table eto_sql_tb_session_www (query complete).
        }
        else
//      no -- query INcomplete.
        {
           $sys_exit_msg = '(' . etoSQLformatDiag() . ')';

           etoAbendSubCode($ac, 2, $xo, $ro); // Abend $ac + 2 -- SELECT min(session_www_serno) failed on table eto_sql_tb_session_www (query INcomplete).
        }
     }
  }

   return($max_club_member_serno);
}

function etoSQLgetRowBuf_club_member()
{
//  eto_sql_tb_club_member row buffer.
  global $club_member_serno;
  global $member_status;
  global $member_password;
  global $member_session_code;
  global $member_verify_code;
  global $member_first_name;
  global $member_last_name;
  global $member_email_addr;
  global $member_ref_by_member;
  global $member_inf_by_advert;
  global $member_reserve_coop_spot;
  global $member_request_news_email;
  global $member_block_email_login;
  global $club_member_init_utc;
  global $club_member_last_utc;
  global $club_member_expiry_utc;
  global $club_member_notified_utc;

  return
  (
     (
        addcslashes
        (
           etoExit_sys_log_indent_det
           (
              '##etoSQLgetRowBuf_club_member()<'
           ) .

           "\$club_member_serno<"         . $club_member_serno . '> ' .

           "\$member_status<"             . $member_status . '> ' .
           "\$member_password<"           . $member_password . '> ' .
           "\$member_session_code<"       . $member_session_code . '> ' .
           "\$member_verify_code<"        . $member_verify_code . '> ' .

           "\$member_first_name<"         . $member_first_name . '> ' .
           "\$member_last_name<"          . $member_last_name . '> ' .
           "\$member_email_addr<"         . $member_email_addr . '> ' .

           "\$member_ref_by_member<"      . $member_ref_by_member . '> ' .
           "\$member_inf_by_advert<"      . $member_inf_by_advert . '> ' .

           "\$member_reserve_coop_spot<"  . $member_reserve_coop_spot . '> ' .
           "\$member_request_news_email<" . $member_request_news_email . '> ' .
           "\$member_block_email_login<"  . $member_block_email_login . '> ' .

           "\$club_member_init_utc<"      . $club_member_init_utc . '>'  .
           "\$club_member_last_utc<"      . $club_member_last_utc . '>'  .
           "\$club_member_expiry_utc<"    . $club_member_expiry_utc . '>'  .
           "\$club_member_notified_utc<"  . $club_member_notified_utc . '>'  .

           '>',

           "\\\t\n\v\f\r"
        )
     )
  );
}

// ... Access to ETO database.

// ... Functions.

?>
