<?php

//	eto_session_ssi_0.php 20150802 (c) Copyright 2015 A.S.Petrie. All rights reserved.
//
//	SSI -- Session management option settings, common variables and functions.
//

//	Option settings, variables and common functions.
require '../eto_php/eto__rfc822_ssi_0.php';

// --------------------------------------------------------------------------------------------------------------------------------
//                            SESSION COMPONENTS INVENTORY
//     SESSION TYPE        MODULE                     DESCRIPTION...
// --------------------------------------------------------------------------------------------------------------------------------
//
//         ***             eto_session_ssi_0.php      Session management options, common code.
//         ***             eto_session_ssi_1.php      Display login form.
//         ***             eto_session_ssi_2.php      Display password form.
//         ***             eto_session_ssi_3.php      Display email login form.
//
//         ***             eto_session_act_1.php      Initiate a session.
//         ***             eto_session_act_2.php      Handle login form.
//         ***             eto_session_act_3.php      Handle password form.
//         ***             eto_session_act_4.php      Handle email link.
//         ***             eto_session_act_5.php      Handle email login form.
//
//         ***             eto_info_ssi_0.php         Information message management, common variables and functions.
//         ***             eto_info_ssi_1.php         Display information page.
//         ***             eto_info_ssi_2.php         Display information form.
//         ***             eto_info_act_1.php         Handle information form.
//
//    SES_TYPE_CLUB        eto_club_eto_ssi_1.php     Display club member form.
//    SES_TYPE_CLUB        eto_club_eto_ssi_2.php     Display club menu form.
//    SES_TYPE_CLUB        eto_club_eto_ssi_3.php     Display traffic statistics.
//
//    SES_TYPE_CLUB        eto_club_eto_act_1.php     Handle club ETO member form.
//    SES_TYPE_CLUB        eto_club_eto_act_2.php     Handle club ETO menu form.
//
//    SES_TYPE_CONTACT     eto_contact_ssi_1.php      Display contact message form.
//    SES_TYPE_CONTACT     eto_contact_act_1.php      Handle contact message form.
//
// --------------------------------------------------------------------------------------------------------------------------------
//


// --------------------------------------------------------------------------------------------------------------------------------
//                            SESSION COMPONENTS DOCUMENTATION TABLE
//
//     SESSION TYPE        FORM               DISPLAYED BY             HANDLER                  HANDLER DISPLAYS FORM(S)
// -----------------------------------------------------------------------------------------------------------------------
//
//  (initialize session)   eto_club_eto.htm   (static html)            eto_session_act_1.php    Login
//                                                                                              Password
//
//  (initialize session)   eto_contact.htm    (static html)            eto_session_act_1.php    Login
//                                                                                              Contact Message
// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
//
//  SES_TYPE_CLUB          Login              eto_session_ssi_1.php    eto_session_act_2.php    Club Member
//                                                                                              Club Menu
//
//  SES_TYPE_CONTACT       Login              eto_session_ssi_1.php    eto_session_act_2.php    Contact Message
//
//  SES_TYPE_CLUB          Password           eto_session_ssi_2.php    eto_session_act_3.php    Club Member
//
// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
//
//  SES_TYPE_CONTACT       Contact Message    eto_contact_ssi_1.php    eto_contact_act_1.php    Contact Message
//                                                                                              Info
// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
//
//  SES_TYPE_CLUB          Club Member        eto_club_eto_ssi_1.php   eto_club_eto_act_1.php   Club Member
//                                                                                              Info
//                                                                                              Club ETO (static html)
//
//  SES_TYPE_CLUB          Club Menu          eto_club_eto_ssi_2.php   eto_club_eto_act_2.php   Club Member
//                                                                                              Stats (static html)
//
//  SES_TYPE_CLUB          (emailed link)              ---             eto_session_act_4.php    Email Login
//
//  SES_TYPE_CLUB          Email Login        eto_session_ssi_3.php    eto_session_act_5.php    Info
//
// - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - - -
//
//       ***               Info               eto_info_ssi_2.php       eto_info_act_1.php        Club Menu
//                                                                                               Club Member
// ---------------------------------------------------------------------------------------------------------------------


// Parameters fixed by externality ...
//
// *** DO NOT CHANGE THE VALUES IN THIS SECTION!!! ***
//
//    THEY ARE DERIVED FROM FIXED EXTERNALITIES,
//     AND ARE **NOT** ARBITRARILY ADJUSTABLE.

const MD5_ID_SIZE = 32; // number of characters in e.g. session id string (MUST match md5(...) size == 32).
// const SES_ID_SIZE = 32; // number of characters in session id string (MUST match md5(...) size == 32).

const NAV_ID_CODE_SIZE = 6; // i.e. use leftmost 6 chars of 32-byte MD5 value.

const FNT_WIDTH  = 30;  // eto font width in pixels (MUST match font image files).
const FNT_HEIGHT = 30;  // eto font height in pixels (MUST match font image files).

// Used by function <gen_img_reg_font(...)> in ssi <eto_contact_img.php>.
const REG_FNT_WIDTH  = 10; // regular font width in pixels (match font size per imagestring(..., font_size=5, ..., ..., ..., ...)).
const REG_FNT_HEIGHT = 11; // regular font width in pixels (match font size per imagestring(..., font_size=5, ..., ..., ..., ...)).

const VISITOR_SERNO_SIZE        = 10; // see const SQL_MAX_ROW_SERNO = 2147483647; (in eto__sql_ssi_0.php).
const VISITOR_SERNO_SYMS        = "0123456789"; // character symbols allowed in visitor serno field.
const VISITOR_SERNO_PROMPT_SYMS = "0..9";

const VISITOR_UTC_SIZE   = 19; // see const CRN_DTIME_0_UTC = '0000-00-00 00:00:00'; (in eto__chron_ssi_0.php).

// ... Parameters fixed by externality.

//	Option settings ...

// User-settable options ...

// versions and releases ...

// o/s types.
const ETO_NUL_OS = 0;
const ETO_WIN_OS = 1;
const ETO_NIX_OS = 2;

// pseudo-constants.
$ETO_PHP_RELEASE     = '';
$ETO_PHP_MIN_RELEASE = '5.1'; // php_uname('r') -- under XAMPP for Windows.
// $ETO_PHP_MIN_RELEASE = '5.3.1'; // XAMPP for Windows -- docs.
$ETO_PHP_OS          = '';
$ETO_OS_TYPE         = ETO_NUL_OS;

// ... versions and releases.

// website http domain name.
const ETO_WWW_DOMAIN_NAME = 'localhost'; // development.
// const ETO_WWW_DOMAIN_NAME = 'www.its-eto.com'; // live production.

// session ...

const SES_NUL_SES_NO = '';

// session duration limits ...

// default session duration limits ...

// session expiry limits.
const SES_EXPIRY_MINS   = 10; // number of inactive MINUTES, since last request received from visitor client, after which visitor session becomes expireable.
const SES_HIT_COUNT_MAX = 25; // number of visitor session row rewrites, after which visitor session becomes expireable.

// session delete limit.
const SES_DELETE_MINS   = 5; // delta time in minutes, after which visitor session row becomes available for DELETION,
                             // after the absolute time that visitor session row becomes:
                             //  (1) EXPIREABLE, or
                             //  (2) COMPLETE.

// ... default session duration limits.

// password, login session duration limits ...
const SES_EXPIRY_MINS_ID   = 3;
const SES_HIT_COUNT_MAX_ID = 5;
const SES_DELETE_MINS_ID   = 1;
// ... password, login session duration limits.

// Ticktock cleanup of table eto_sql_tb_session_www ...

// session ticktock skip count.
//  ( controls ticktock cleanup of table eto_sql_tb_session_www by <eto_contact_act_1.php>:
//       (SES_TKTK_SKIP_CNT  < 0)  --> disable cleanup;
//       (SES_TKTK_SKIP_CNT == 0)  --> enable  "hard" cleanup;
//       (SES_TKTK_SKIP_CNT  > 0)  --> enable "fuzzy" cleanup).
//  )
//
// const SES_TKTK_SKIP_CNT = -1; // disable         ticktock cleanup of table eto_sql_tb_session_www.
   const SES_TKTK_SKIP_CNT = 0;  // enable  "hard"  ticktock cleanup of table eto_sql_tb_session_www => with EVERY new visitor session.
// const SES_TKTK_SKIP_CNT = 4;  // enable  "fuzzy" ticktock cleanup of table eto_sql_tb_session_www => average number of new visitor sessions SKIPPING ticktock cleanup.

// ... Ticktock cleanup of table eto_sql_tb_session_www.


// ... session duration limits.

// session verify code ...

const VER_CODE_SIZE = 7;    // number of characters in verify string.

// Default verify code <$ver_code> values for NULL, COMPLETE and EXPIRED visitor sessions.
//  (any non-null string default MUST be <VER_CODE_SIZE> characters long and contain eto verify image font symbols ONLY.)
//  (be sure to put appropriate explanation on the eto_contact_form_part_i.htm page.)
//
//  Abend verify code <$ver_code> diagnostic value generated
//    when <eto_contact_img.php> abends and cannot generate
//    a normal verification image.
//
//  $sys_abend_ver_code_sfx gets right-truncated as necessary to fit abend diagnostic string
//    into size of verification code.
const VER_CODE_NULL     = 'UNKNOWN';
const VER_CODE_COMPLETE = 'COMPLET';
const VER_CODE_EXPIRED  = 'EXPIRED';
const VER_CODE_ABENDED  = 'ABENDED';

// ... session verify code.

// ... session.

const VISITOR_STATUS_SIZE = 20; // size of text to describe member status.

const VISITOR_NAME_SIZE        = 30;
const VISITOR_NAME_SYMS        = "0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ'-_., "; // character symbols allowed in visitor name field.
const VISITOR_NAME_PROMPT_SYMS = "0..9 a..z A..Z ' - _ . , sp";                                          // prompt text describing character symbols allowed in visitor name field.

const VISITOR_PWD_SIZE         = 30; // same as name size.
const VISITOR_PWD_MAX_SIZE     = 72; // see web page <www.openwall.com -- PHP-Users-Passwords - 201008--.htm>.
const VISITOR_PWD_SYMS         = "0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ"; // character symbols allowed in visitor password field.
//const VISITOR_PWD_SYMS         = "0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ@#&?"; // character symbols allowed in visitor password field.
const VISITOR_PWD_PROMPT_SYMS  = "0..9 a..z A..Z";                                                     // prompt text describing character symbols allowed in visitor password field.
// const VISITOR_PWD_PROMPT_SYMS  = "0..9 a..z A..Z @#&?";                                             // prompt text describing character symbols allowed in visitor password field.


// const VISITOR_EMAIL_ ...

//
//   NOT FACTORED INTO VALIDATION ALGORITHM <eto__ddfm_ssi_0.php dd_is_valid_email($email)>
//   (used only to display max.size in visitor prompt).
//
//   ---------------------
//       local@domain
//   ---------------------
//      part       max.len
//   -----------   -------
//   local            64
//   @                 1
//   domain          255   (dot separated labels of 1 to 63 characters each)
//   -----------   -------
//   local@domain    256
//   -----------   -------
//
//   Example (a maximum-length email address):
//
//   -----------------------------------------------------------------------------------
//        part     len  example:
//   ------------- ---  ----------------------------------------------------------------
//   local part:    64  affffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffb
//   @               1  @
//   domain label:  63  cxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxd
//   .               1  .
//   domain label:  63  eyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyf
//   .               1  .
//   domain label:  63  gzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzh
//   ------------- ---  ----------------------------------------------------------------
//                 256
//   -----------------------------------------------------------------------------------
//
//  The example below is a single string,
//    useful for testing the maximum-length email address validation:
//
//    affffffffffffffffffffffffffffffffffffffffffffffffffffffffffffffb@cxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxd.eyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyyf.gzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzh
//
const VISITOR_EMAIL_MAX_SIZE  = 256;
const VISITOR_EMAIL_SIZE      = 30;
const VISITOR_EMAIL_PROMPT_SYMS = "0..9 a..z A..Z @#$%& ,.:;?! ()[]{} +-*<=> \|/^~_ `'\" sp"; // <en.wikipedia.org -- E-mail_address - 20130517.htm>
// const VISITOR_EMAIL_PROMPT_SYMS = "0..9 a..z A..Z @#$%& .?! []{} +-*= |/^~_ `'";

const VISITOR_EMAIL_INCLUDE = true;
const VISITOR_EMAIL_EXCLUDE = false;

// ... const VISITOR_EMAIL_.

const VISITOR_SUBJECT_SIZE    = 60;
const VISITOR_SUBJECT_DEFAULT = "ETO";

//
// ascii graphic symbols ...
//
//
//  ascii digits and letters.
//
//  decimal..range    count              graphic...
//      48 ..  58       10   ( 58 -  47)  0 .. 9
//      65 ..  90       26   ( 90 -  64)  A .. Z
//      87 .. 122       26   ( 58 -  47)  a .. z
//                     ----
//                      62 (digits and letters)
//                     ----
//
//  ascii special graphic symbols.
//
//  decimal..range    count              graphic...
//      32 ..  47       16   ( 47 -  31) sp ! " # $ % & ' ( ) * + , - . /
//      58 ..  64        7   ( 64 -  57)    : ; < = > ? @
//      91 ..  96        6   ( 96 -  90)    [ \ ] ^ _ `
//     123 .. 126        4   (126 - 122)    { | } ~
//                     ----
//                      33 (special graphic)
//                     ----
//
//
//                      62 (digits and letters)
//                      33 (special graphic)
//                     ----
//                      95 (total ascii graphic symbolss)
//                     ----
//                     ----
//
// ... ascii graphic symbols.
//

// same as VISITOR_MESSAGE_... except NO "\r\n".
const VISITOR_SUBJECT_SYMS        = "0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ @#$%&,.:;?!()[]{}+-*<=>\|/^~_`'\"";
const VISITOR_SUBJECT_PROMPT_SYMS = "0..9 a..z A..Z @#$%& ,.:;?! ()[]{} +-* <=> \|/ ^~_ `'\" sp";

// for passing by reference.
$VISITOR_SUBJECT_SYMS        = VISITOR_SUBJECT_SYMS;
$VISITOR_SUBJECT_PROMPT_SYMS = VISITOR_SUBJECT_PROMPT_SYMS;


const VISITOR_CONTROL_CHARS    = true;
const VISITOR_NO_CONTROL_CHARS = false;


const VISITOR_VERIFY_SIZE     = VER_CODE_SIZE;

const VISITOR_MESSAGE_ROWS    = 24;
// const VISITOR_MESSAGE_ROWS    = 12;
const VISITOR_MESSAGE_COLS    = 70;
const VISITOR_MESSAGE_SIZE    = 2000;

const VISITOR_MESSAGE_SYMS        = "0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ @#$%&,.:;?!()[]{}+-*<=>\|/^~_`'\"\r\n";
const VISITOR_MESSAGE_PROMPT_SYMS = "0..9 a..z A..Z @#$%& ,.:;?! ()[]{} +-* <=> \|/ ^~_ `'\" \\r \\n sp";

// for passing by reference.
$VISITOR_MESSAGE_SYMS        = VISITOR_MESSAGE_SYMS;
$VISITOR_MESSAGE_PROMPT_SYMS = VISITOR_MESSAGE_PROMPT_SYMS;
// for passing by reference.

const MSG_RECORD_HR = '---------------------------------------------------';

// message privacy explanation text strings ...

$msg_disclose_explain_text_ary
=
array
(
  MSG_DISCLOSE_NULL      => '',

  MSG_DISCLOSE_PUBLIC    => 'All message items can be disclosed.',
  MSG_DISCLOSE_ANONYMOUS => 'Message items: <number, date, time, subject, message> can be disclosed. Message items: <sender first & last names, email address, Club ETO member number, membership status> not disclosed.',
  MSG_DISCLOSE_PRIVATE   => 'No message items can be disclosed.'
);

$msg_disclose_table_hdr
=
(
   (
      '       MESSAGE DISCLOSURE SUMMARY TABLE' . "\n" .

      'Message Item              Disclosure Setting' . "\n" .

      '---------------------- ' .
      $msg_disclose_text_ary[MSG_DISCLOSE_PUBLIC] . ' ' .
      $msg_disclose_text_ary[MSG_DISCLOSE_ANONYMOUS] . ' ' .
      $msg_disclose_text_ary[MSG_DISCLOSE_PRIVATE] . "\n"
   )
);

$msg_disclose_table_body
=
(
//                              PUBLIC ANONYMOUS PRIVATE
   'Message Number:          ' . 'Y        Y        N' . "\n" .
   'Message Date/Time:       ' . 'Y        Y        N' . "\n" .
   'Club ETO Member Number:  ' . 'Y        N        N' . "\n" .
   'Membership Status:       ' . 'Y        N        N' . "\n" .
   'Sender First Name:       ' . 'Y        N        N' . "\n" .
   'Last Name:               ' . 'Y        N        N' . "\n" .
   'Email Address:           ' . 'Y        N        N' . "\n" .
   'Subject:                 ' . 'Y        Y        N' . "\n" .
   'Message:                 ' . 'Y        Y        N' . "\n"
);

$msg_disclose_table_ftr
=
(
   MSG_RECORD_HR . "\n" .

   'Y = can be disclosed, N = not disclosed.' . "\n"
);

$msg_disclose_part_1
=
(
   '  ' . "\n" .

   'Message Disclosure Explanation:' . "\n" .
   '(we assume no liability whatsoever and' . "\n" . ' are subject to court order)' . "\n\n" .

   $msg_disclose_text_ary[MSG_DISCLOSE_PUBLIC] . ': ' .
   $msg_disclose_explain_text_ary[MSG_DISCLOSE_PUBLIC] . "\n\n" .

   $msg_disclose_text_ary[MSG_DISCLOSE_ANONYMOUS] . ': ' .
   $msg_disclose_explain_text_ary[MSG_DISCLOSE_ANONYMOUS] . "\n\n" .

   $msg_disclose_text_ary[MSG_DISCLOSE_PRIVATE] . ': ' . 
   $msg_disclose_explain_text_ary[MSG_DISCLOSE_PRIVATE] . "\n\n" .

   MSG_RECORD_HR . "\n"
);

$tmp_msg_disclose_tbl
=
(
   etoHTMentiXssSafe($msg_disclose_table_hdr)
// etoHtmlSpecialChars($msg_disclose_table_hdr)
   .
   etoHTMentiXssSafe($msg_disclose_table_body)
// etoHtmlSpecialChars($msg_disclose_table_body)
);

$msg_disclose_part_2
=
(
// transform space => &nbsp;.
   str_replace
   (
      ' ',
      '&nbsp;',

       $tmp_msg_disclose_tbl
   )
   .
   etoHTMentiXssSafe($msg_disclose_table_ftr)
// etoHtmlSpecialChars($msg_disclose_table_ftr)
);

$msg_disclose_expl
=
(
   '<span class="sig_late" >'
   .
   etoHTMentiXssSafe($msg_disclose_part_1)
// etoHtmlSpecialChars($msg_disclose_part_1)
   .
    $msg_disclose_part_2
   .
   '</span>'
);

// ... message privacy explanation text strings.

const VISITOR_ADVERT_MAX = 0;

const VISITOR_AGE_MIN = 16; // minimum age in years for visitor to use: contact message / club eto.

// ... User-settable options.

//	Option dependencies ...
// Can't use computation (or even temporary variable), for source of const value.
$img_width  = (VER_CODE_SIZE * FNT_WIDTH); // verification image height.
const IMG_HEIGHT = FNT_HEIGHT;             // verification image height.

// ... Option dependencies.

// ... Option settings.

// Global variables and constants ...

$ses_code        = ''; // session id code.
$ses_src_context = ''; // script execution context.
$lnk_code        = ''; // email login link code.
$act_code        = ''; // session action sequence code.

$ver_code =	'';
$sys_abend_ver_code = '';

// visitor form fields ...

$frm_error_count        = 0;  // input form - count of errors.
$frm_button_count       = 0;  // input form - count of submit buttons.
$frm_submit_button      = ''; // input form - name of submit button.

$frm_next_form          = ''; // next_form -  name of require module.
$frm_next_submit_button = ''; // next_form -  name of submit button.
$frm_next_page_htm      = ''; // next_page -  html content.

// session id code value in html (source of value for php $ses_code).
$visitor_key_1 = "";
$visitor_key_1_size = MD5_ID_SIZE;
// $visitor_key_1_size = SES_ID_SIZE;
$visitor_key_1_size_cur = 0;
const VISITOR_KEY_1_HTM_TAG = 'a'; // e.g the 'a' in the '?a=' in: www.its-eto.com/eto_session_act_4a.php?a=106EFB8202B5973515488B0C771A30F8&c=594503&c=B8BDAE

// eto_verify_img.php -- (local variable only) session id code value in html (source of value for php $ses_code for ptogram).
// $visitor_key_2 = "";
// $visitor_key_2_size = MD5_ID_SIZE;
//// $visitor_key_2_size = SES_ID_SIZE;
// $visitor_key_2_size_cur = 0;
const VISITOR_KEY_2_HTM_TAG = 'b'; // e.g the 'b' in the '?b=' in: src="./eto_verify_imga.php?b=76A1786500583CA5425AB2F862666946"

// link code -- pure random md5 used to block use of obsolete links to session in emails (php $lnk_code) (see function getLnkCode($ac) in eto_session_ssi_0.php);
$visitor_key_3 = "";
$visitor_key_3_size = NAV_ID_CODE_SIZE;
// $visitor_key_3_size = MD5_ID_SIZE;
// $visitor_key_3_size = SES_ID_SIZE;
$visitor_key_3_size_cur = 0;
const VISITOR_KEY_3_HTM_TAG = 'c'; // e.g 

// action code -- substring of md5 of $session_www_init_utc & ($session_www_act_seqno + 1) used to detect use of browser back / reload (php $act_code) (see function getActCode($ac) in eto_session_ssi_0.php);
$visitor_key_4 = "";
$visitor_key_4_size = NAV_ID_CODE_SIZE;
// $visitor_key_4_size = MD5_ID_SIZE;
// $visitor_key_4_size = SES_ID_SIZE;
$visitor_key_4_size_cur = 0;
const VISITOR_KEY_4_HTM_TAG = 'd'; // e.g 

$visitor_verify  = "";
$visitor_verify_size_cur = 0;
$visitor_verify_prompt = "";
$visitor_verify_req = "";
$visitor_verify_prompt_req = "";
$visitor_verify_prompt_inf = "";
$visitor_verify_prompt_err = "";

$visitor_enter_password  = "";
$visitor_enter_password_size_cur = 0;
$visitor_enter_password_prompt = "";
$visitor_enter_password_req = "";
$visitor_enter_password_prompt_req = "";
$visitor_enter_password_prompt_inf = "";
$visitor_enter_password_prompt_err = "";

$visitor_confirm_password = "";
$visitor_confirm_password_size_cur = 0;
$visitor_confirm_password_prompt = "";
$visitor_confirm_password_req = "";
$visitor_confirm_password_prompt_req = "";
$visitor_confirm_password_prompt_inf = "";
$visitor_confirm_password_prompt_err = "";

$visitor_forgot_password  = false;

$visitor_pledge_1_polity = false;
$visitor_pledge_1_polity_prompt = "";
$visitor_pledge_1_polity_req = "";
$visitor_pledge_1_polity_prompt_req = "";
$visitor_pledge_1_polity_prompt_inf = "";
$visitor_pledge_1_polity_prompt_err = "";

$visitor_pledge_2_voice = false;
$visitor_pledge_2_voice_prompt = "";
$visitor_pledge_2_voice_req = "";
$visitor_pledge_2_voice_prompt_req = "";
$visitor_pledge_2_voice_prompt_inf = "";
$visitor_pledge_2_voice_prompt_err = "";

$visitor_pledge_3_age = false;
$visitor_pledge_3_age_prompt = "";
$visitor_pledge_3_age_req = "";
$visitor_pledge_3_age_prompt_req = "";
$visitor_pledge_3_age_prompt_inf = "";
$visitor_pledge_3_age_prompt_err = "";

$visitor_member_number = 0;
$visitor_member_number_size_cur = 0;
$visitor_member_number_prompt = "";
$visitor_member_number_req = "";
$visitor_member_number_prompt_req = "";
$visitor_member_number_prompt_inf = "";
$visitor_member_number_prompt_err = "";

$visitor_member_state = ROW_STATE_NULL;
$visitor_member_status = "";
$visitor_member_status_prompt = "";
$visitor_member_status_prompt_inf = "";

$visitor_first_name = "";
$visitor_first_name_size_cur = 0;
$visitor_first_name_prompt = "";
$visitor_first_name_req = "";
$visitor_first_name_prompt_req = "";
$visitor_first_name_prompt_inf = "";
$visitor_first_name_prompt_err = "";

$visitor_last_name = "";
$visitor_last_name_size_cur = 0;
$visitor_last_name_prompt = "";
$visitor_last_name_req = "";
$visitor_last_name_prompt_req = "";
$visitor_last_name_prompt_inf = "";
$visitor_last_name_prompt_err = "";

$visitor_email = "";
$visitor_email_size_cur = 0;
$visitor_email_prompt = "";
$visitor_email_req = "";
$visitor_email_prompt_req = "";
$visitor_email_xtra_prompt_ovr = "";
$visitor_email_prompt_inf = "";
$visitor_email_prompt_err = "";

$visitor_ref_by_member = 0;
$visitor_ref_by_member_size_cur = 0;
$visitor_ref_by_member_prompt = "";
$visitor_ref_by_member_req = "";
$visitor_ref_by_member_prompt_req = "";
$visitor_ref_by_member_prompt_inf = "";
$visitor_ref_by_member_prompt_err = "";

$visitor_inf_by_advert = 0;
$visitor_inf_by_advert_size_cur = 0;
$visitor_inf_by_advert_prompt = "";
$visitor_inf_by_advert_req = "";
$visitor_inf_by_advert_prompt_req = "";
$visitor_inf_by_advert_prompt_inf = "";
$visitor_inf_by_advert_prompt_err = "";

$visitor_request_news_email = true;
$visitor_request_news_email_prompt = "";
$visitor_request_news_email_prompt_inf = "";

$visitor_reserve_coop_spot  = true;
$visitor_reserve_coop_spot_prompt = "";
$visitor_reserve_coop_spot_prompt_inf = "";

$visitor_block_email_login  = false;
$visitor_block_email_login_prompt = "";
$visitor_block_email_login_prompt_inf = "";

$visitor_init_utc     = CRN_DTIME_0_UTC;
$visitor_last_utc     = CRN_DTIME_0_UTC;
$visitor_expiry_utc   = CRN_DTIME_0_UTC;
$visitor_notified_utc = CRN_DTIME_0_UTC;

$visitor_msg_status  = ROW_STATE_NULL;

$visitor_msg_privacy = MSG_DISCLOSE_NULL;

$visitor_subject = "";
$visitor_subject_size_cur = 0;
$visitor_subject_prompt = "";
$visitor_subject_req = "";
$visitor_subject_prompt_req = "";
$visitor_subject_prompt_inf = "";
$visitor_subject_prompt_err = "";

$visitor_message = "";
$visitor_message_size_cur = 0;
$visitor_message_prompt = "";
$visitor_message_req = "";
$visitor_message_prompt_req = "";
$visitor_message_prompt_inf = "";
$visitor_message_prompt_err = "";

// ... visitor form fields.

// email login ...

$email_login_url = '';

// ... email login.

// club menu html ...

$htm_name_heading_ent = '';
$htm_announce_ent     = '';

// ... club menu html.

// HTML output ...

const HTM_SUBMIT_BUTTON_LINE_FILL = '             ';

const HTM_PAGE_LINE_FILL          = '            ';
const HTM_INFO_PAGE_LINE_FILL     = '            ';
const HTM_INFO_PAGE_LINE_INDENT   = '    ';

const HTM_NO_CLICK_TO_MSG = false;

// submit buttons ...

const CHECK_FORM_SUBMIT = 'check_form_submit';
const RESET_FORM_SUBMIT = 'reset_form_submit';
const QUIT_FORM_SUBMIT  = 'quit_form_submit';
const LOGOUT_SUBMIT     = 'logout_submit';

const NEW_MESSAGE_FORM_SUBMIT = 'new_message_form_submit';
const SEND_MESSAGE_SUBMIT     = 'send_message_submit';

const CLUB_RECEPTION_SUBMIT   = 'club_reception_submit';
const CLUB_MENU_SUBMIT        = 'club_menu_submit';
const CLUB_MEMBER_FORM_SUBMIT = 'club_member_form_submit';
const JOIN_CLUB_SUBMIT        = 'join_club_submit';
const UPDATE_CLUB_SUBMIT      = 'update_club_submit';
const PAUSE_CLUB_SUBMIT       = 'pause_club_submit';
const UNPAUSE_CLUB_SUBMIT     = 'unpause_club_submit';
const RESIGN_CLUB_SUBMIT      = 'resign_club_submit';
const UNRESIGN_CLUB_SUBMIT    = 'unresign_club_submit';
const CLUB_STATS_SUBMIT       = 'club_stats_submit';

const CHANGE_CLUB_PASSWORD_SUBMIT = 'change_club_password_submit';
const FORGOT_CLUB_PASSWORD_SUBMIT = 'forgot_club_password_submit';
const CHANGE_CLUB_EMAIL_SUBMIT    = 'change_club_email_submit';

$htm_submit_button_val_ary
= array
(
  CHECK_FORM_SUBMIT => 'Check Form',
  RESET_FORM_SUBMIT => 'Reset Form',
  QUIT_FORM_SUBMIT  => 'Quit Form',
  LOGOUT_SUBMIT     => 'Logout',

  NEW_MESSAGE_FORM_SUBMIT => 'New Message Form',
  SEND_MESSAGE_SUBMIT     => 'Send Message',

  CLUB_RECEPTION_SUBMIT   => 'Club ETO Reception',
  CLUB_MENU_SUBMIT        => 'Club ETO Menu',
  CLUB_MEMBER_FORM_SUBMIT => 'Club ETO Member Form',
  JOIN_CLUB_SUBMIT        => 'Join Club ETO',
  UPDATE_CLUB_SUBMIT      => 'Update Membership',
  PAUSE_CLUB_SUBMIT       => 'Pause Membership',
  UNPAUSE_CLUB_SUBMIT     => 'Un-Pause Membership',
  RESIGN_CLUB_SUBMIT      => 'Resign Membership',
  UNRESIGN_CLUB_SUBMIT    => 'Un-Resign Membership',
  CLUB_STATS_SUBMIT       => 'Traffic Statistics',

  CHANGE_CLUB_PASSWORD_SUBMIT => 'Change Password',
  FORGOT_CLUB_PASSWORD_SUBMIT => 'Forgot Password',
  CHANGE_CLUB_EMAIL_SUBMIT    => 'Change Email Address'
);

// array (of arrays) of submit button names ...
//
// dynamic structure depends on structure of HTML form:
//
//          button
//  button  line
//  count   count   dynamic array structure...
//  ------  ------  -----------------------
//     1       1
//                  $htm_submit_buttons_ary[0] = array(0 => 'submit_button_name');
//
//     2+      1
//                  $htm_submit_buttons_ary[0] = array(0 => 'submit_button_name_1', 1 => 'submit_button_name_2', ...);
//
//     2+      2+
//                  $htm_submit_buttons_ary[0] = array(0 => 'submit_button_name_1.1', 1 => 'submit_button_name_1.2', ...);
//                  $htm_submit_buttons_ary[1] = array(0 => 'submit_button_name_2.1', 1 => 'submit_button_name_2.2', ...);
//                             ...
//                  $htm_submit_buttons_ary[n] = array(0 => 'submit_button_name_n.1', 1 => 'submit_button_name_n.2', ...);
//  ------  ------  -----------------------
//

$htm_submit_buttons_ary = array();

// ... array (of arrays) of submit button names.

// constructed html for button groups.
$submit_button_groups = '';

// ... submit buttons.

// visitor field required flags ...
const VISITOR_FIELD_OPTIONAL_FLAG      = '';
const VISITOR_FIELD_REQUIRED_FLAG      = '*';
const VISITOR_FIELD_1OR2_REQUIRED_FLAG = '**';
const VISITOR_FIELD_OK_FLAG            = 'OK';
// visitor field required flags ...

// ... HTML output fragments.

const HTM_VISITOR_PROMPT_OK_PREFIX = " &nbsp <span class=\"sys_ok_color\" > <span class=\"visitor_prompt_ok\"> <span class=\"sig_ok_back\"> ";
const HTM_VISITOR_PROMPT_OK_SUFFIX = " </span> </span> </span> &nbsp;";

const HTM_VISITOR_PROMPT_REQUIRED_PREFIX = "<span class=\"fld_required_flag\">";
const HTM_VISITOR_PROMPT_REQUIRED_SUFFIX = " </span>";

const HTM_VISITOR_PROMPT_ERROR_PREFIX = "<span class=\"sys_error_color\" > ";
const HTM_VISITOR_PROMPT_ERROR_SUFFIX = " </span>";

const HTM_VISITOR_PROMPT_SMALLCAPS_PREFIX = "<span class=\"small_caps\" style=\"#font-size: small;\"> ";
const HTM_VISITOR_PROMPT_SMALLCAPS_SUFFIX = " </span>";

const VISITOR_VERIFY_PROMPT_SRC = "key in all symbols from image";

const VISITOR_PLEDGE_1_PROMPT_SRC = "i want to see governments supporting eto (finance, logistics, outreach).";
const VISITOR_PLEDGE_2_PROMPT_SRC = "to add my say (talk, text, show) to a growing call for eto public support.";
$VISITOR_PLEDGE_3_PROMPT_SRC      = "i am " . VISITOR_AGE_MIN . " years of age or older.";

// ... HTML output fragments.

// ... HTML output.

// ... Global variables and constants.

// Executables ...
initializeVisitorFields();
refreshVisitorDependencies();
// ... Executables.

// Functions ...

// preg_match(...) borrowed from Dagon Design www.dagondesign.com.
function controlCharacters($s)
{
// Test string for control characters
  return (preg_match('/[\x00-\x1F\x7F-\xFF]/', $s)) ? true : false;
}

// get visitor formt fields ...

function getForm_visitor_key_1($ac)
{
   global $visitor_key_1;

// does array key exist?
   if (array_key_exists(VISITOR_KEY_1_HTM_TAG, $_POST))
// if (array_key_exists('visitor_key_1', $_POST))
// yes - array key exist.
   {
//    non-NULL data value?
      $visitor_key_1 = (isset($_POST[VISITOR_KEY_1_HTM_TAG]) ? $_POST[VISITOR_KEY_1_HTM_TAG] : etoAbendSubCode($ac, 0)); // Abend $ac -- (isset($_POST['visitor_key_1'] == false).
//    $visitor_key_1 = (isset($_POST['visitor_key_1']) ? $_POST['visitor_key_1'] : etoAbendSubCode($ac, 0)); // Abend $ac -- (isset($_POST['visitor_key_1'] == false).
//    $visitor_key_1 = (isset($_POST['visitor_key_1']) ? $_POST['visitor_key_1'] : etoAbend($ac)); // Abend $ac -- (isset($_POST['visitor_key_1'] == false).
   }
   else
// no - array key does NOT exist.
   {
      etoAbendSubCode($ac, 1); // Abend $ac+1 -- array_key_exists('visitor_key_1', $_POST) == false).
   }

   return;
}

function getForm_visitor_key_3($ac)
{
   global $visitor_key_3;

// does array key exist?
   if (array_key_exists(VISITOR_KEY_3_HTM_TAG, $_POST))
// if (array_key_exists('visitor_key_3', $_POST))
// yes - array key exist.
   {
//    non-NULL data value?
      $visitor_key_3 = (isset($_POST[VISITOR_KEY_3_HTM_TAG]) ? $_POST[VISITOR_KEY_3_HTM_TAG] : etoAbendSubCode($ac, 0)); // Abend $ac -- (isset($_POST['visitor_key_3'] == false).
//    $visitor_key_3 = (isset($_POST['visitor_key_3']) ? $_POST['visitor_key_3'] : etoAbendSubCode($ac, 0)); // Abend $ac -- (isset($_POST['visitor_key_3'] == false).
   }
   else
// no - array key does NOT exist.
   {
      etoAbendSubCode($ac, 1); // Abend $ac+1 -- array_key_exists('visitor_key_3', $_POST) == false).
   }

   return;
}

/* obsolete ...
function getForm_visitor_key_3($ac)
{
   global $visitor_key_3;

   $visitor_key_3 = (isset($_POST['visitor_key_3']) ? $_POST['visitor_key_3'] : etoAbend($ac)); // Abend $ac -- (isset($_POST['visitor_key_3'] == false).

   return;
}
 ... obsolete */

function getForm_visitor_key_4($ac)
{
   global $visitor_key_4;

// does array key exist?
   if (array_key_exists(VISITOR_KEY_4_HTM_TAG, $_POST))
// if (array_key_exists('visitor_key_4', $_POST))
// yes - array key exist.
   {
//    non-NULL data value?
      $visitor_key_4 = (isset($_POST[VISITOR_KEY_4_HTM_TAG]) ? $_POST[VISITOR_KEY_4_HTM_TAG] : etoAbendSubCode($ac, 0)); // Abend $ac -- (isset($_POST['visitor_key_4'] == false).
//    $visitor_key_4 = (isset($_POST['visitor_key_4']) ? $_POST['visitor_key_4'] : etoAbendSubCode($ac, 0)); // Abend $ac -- (isset($_POST['visitor_key_4'] == false).
   }
   else
// no - array key does NOT exist.
   {
      etoAbendSubCode($ac, 1); // Abend $ac+1 -- array_key_exists('visitor_key_1', $_POST) == false).
   }

   return;
}

function getForm_visitor_verify($ac)
{
   global $visitor_verify;

// does array key exist?
   if (array_key_exists('visitor_verify', $_POST))
// yes - array key exist.
   {
//    non-NULL data value?
      $visitor_verify = (isset($_POST['visitor_verify']) ? $_POST['visitor_verify'] : etoAbendSubCode($ac, 0)); // Abend $ac -- (isset($_POST['visitor_verify'] == false).
   }
   else
// no - array key does NOT exist.
   {
      etoAbendSubCode($ac, 1); // Abend $ac+1 -- array_key_exists('visitor_verify', $_POST) == false).
   }

// Trim leading and trailing whitespace.
   $visitor_verify = trim($visitor_verify);

   return;
}

/* obsolete ...
function getForm_visitor_verify($ac)
{
   global $visitor_verify;

   $visitor_verify = (isset($_POST['visitor_verify']) ? $_POST['visitor_verify'] : etoAbend($ac)); // Abend $ac -- (isset($_POST['visitor_verify'] == false).

// Trim leading and trailing whitespace.
   $visitor_verify = trim($visitor_verify);

   return;
}
 ... obsolete */

function getForm_visitor_enter_password($ac)
{
   global $visitor_enter_password;

// does array key exist?
   if (array_key_exists('visitor_enter_password', $_POST))
// yes - array key exist.
   {
//    non-NULL data value?
      $visitor_enter_password = (isset($_POST['visitor_enter_password']) ? $_POST['visitor_enter_password'] : etoAbendSubCode($ac, 0)); // Abend $ac -- (isset($_POST['visitor_enter_password'] == false).
   }
   else
// no - array key does NOT exist.
   {
      etoAbendSubCode($ac, 1); // Abend $ac+1 -- array_key_exists('visitor_enter_password', $_POST) == false).
   }

// INTERNAL test for _enter_password too long error condition.
// $visitor_enter_password .= 'X'; // enter a maximum-length password, into the html page field.

   return;
}

/* obsolete ...
function getForm_visitor_enter_password($ac)
{
   global $visitor_enter_password;

   $visitor_enter_password = (isset($_POST['visitor_enter_password'])  ? $_POST['visitor_enter_password']  : etoAbend($ac));   // Abend $ac -- (isset($_POST['visitor_enter_password'] == false).

// INTERNAL test for _enter_password too long error condition.
// $visitor_enter_password .= 'X'; // enter a maximum-length password, into the html page field.

   return;
}
 ... obsolete */

function getForm_visitor_pledge_3_age()
{
   global $visitor_pledge_3_age;

   $visitor_pledge_3_age = (isset($_POST['visitor_pledge_3_checkbox'])  ? (($_POST['visitor_pledge_3_checkbox']  == 'pledge_3_y')  ? true : false) : false); // missing POST key means box unchecked.

   return;
}

function getForm_visitor_member_number($ac)
{
   global $visitor_member_number;

// does array key exist?
   if (array_key_exists('visitor_member_number', $_POST))
// yes - array key exist.
   {
//    non-NULL data value?
      $visitor_member_number = (isset($_POST['visitor_member_number']) ? $_POST['visitor_member_number'] : etoAbendSubCode($ac, 0)); // Abend $ac -- (isset($_POST['visitor_member_number'] == false).
   }
   else
// no - array key does NOT exist.
   {
      etoAbendSubCode($ac, 1); // Abend $ac+1 -- array_key_exists('visitor_member_number', $_POST) == false).
   }

   return;
}

/* obsolete ...
function getForm_visitor_member_number($ac)
{
   global $visitor_member_number;

   $visitor_member_number = (isset($_POST['visitor_member_number']) ? $_POST['visitor_member_number'] : etoAbend($ac)); // Abend $ac -- (isset($_POST['visitor_member_number'] == false).

   return;
}
 ... obsolete */

function getForm_visitor_first_name($ac)
{
   global $visitor_first_name;

// does array key exist?
   if (array_key_exists('visitor_first_name', $_POST))
// yes - array key exist.
   {
//    non-NULL data value?
      $visitor_first_name = (isset($_POST['visitor_first_name']) ? trim($_POST['visitor_first_name']) : etoAbendSubCode($ac, 0)); // Abend $ac -- (isset($_POST['visitor_first_name'] == false).
//    $visitor_first_name = (isset($_POST['visitor_first_name']) ? $_POST['visitor_first_name'] : etoAbendSubCode($ac, 0)); // Abend $ac -- (isset($_POST['visitor_first_name'] == false).
   }
   else
// no - array key does NOT exist.
   {
      etoAbendSubCode($ac, 1); // Abend $ac+1 -- array_key_exists('visitor_first_name', $_POST) == false).
   }

   return;
}

/* obsolete ...
function getForm_visitor_first_name($ac)
{
   global $visitor_first_name;

   $visitor_first_name = (isset($_POST['visitor_first_name']) ? $_POST['visitor_first_name'] : etoAbend($ac)); // Abend $ac -- (isset($_POST['visitor_first_name'] == false).

   return;
}
 ... obsolete */

function getForm_visitor_last_name($ac)
{
   global $visitor_last_name;

// does array key exist?
   if (array_key_exists('visitor_last_name', $_POST))
// yes - array key exist.
   {
//    non-NULL data value?
      $visitor_last_name = (isset($_POST['visitor_last_name']) ? trim($_POST['visitor_last_name']) : etoAbendSubCode($ac, 0)); // Abend $ac -- (isset($_POST['visitor_last_name'] == false).
//    $visitor_last_name = (isset($_POST['visitor_last_name']) ? $_POST['visitor_last_name'] : etoAbendSubCode($ac, 0)); // Abend $ac -- (isset($_POST['visitor_last_name'] == false).
   }
   else
// no - array key does NOT exist.
   {
      etoAbendSubCode($ac, 1); // Abend $ac+1 -- array_key_exists('visitor_last_name', $_POST) == false).
   }

   return;
}

/* obsolete ...
function getForm_visitor_last_name($ac)
{
   global $visitor_last_name;

   $visitor_last_name = (isset($_POST['visitor_last_name']) ? $_POST['visitor_last_name'] : etoAbend($ac)); // Abend $ac -- (isset($_POST['visitor_last_name'] == false).

   return;
}
 ... obsolete */

function getForm_visitor_email($ac)
{
   global $visitor_email;

// does array key exist?
   if (array_key_exists('visitor_email', $_POST))
// yes - array key exist.
   {
//    non-NULL data value?
      $visitor_email = (isset($_POST['visitor_email']) ? trim($_POST['visitor_email']) : etoAbendSubCode($ac, 0)); // Abend $ac -- (isset($_POST['visitor_email'] == false).
//    $visitor_email = (isset($_POST['visitor_email']) ? $_POST['visitor_email'] : etoAbendSubCode($ac, 0)); // Abend $ac -- (isset($_POST['visitor_email'] == false).
   }
   else
// no - array key does NOT exist.
   {
      etoAbendSubCode($ac, 1); // Abend $ac+1 -- array_key_exists('visitor_email', $_POST) == false).
   }

   return;
}

/* obsolete ...
function getForm_visitor_email($ac)
{
   global $visitor_email;

   $visitor_email = (isset($_POST['visitor_email']) ? $_POST['visitor_email'] : etoAbend($ac)); // Abend $ac -- (isset($_POST['visitor_email'] == false.)

   return;
}
 ... obsolete */

// ... get visitor form fields.

// visitor field prompts ...

// visitor field error prompts ...

function promptForm_ERROR($e) // error message.
{
   return
   (
      HTM_VISITOR_PROMPT_ERROR_PREFIX
      .
      etoHTMentiXssSafe($e)
//    etoHtmlSpecialChars($e)
      .
      HTM_VISITOR_PROMPT_ERROR_SUFFIX
   );
}

function promptForm_HAS_MORE_CHARS($os, $ms) // overflow size, max size.
{
   return (promptForm_ERROR("HAS $os MORE THAN $ms CHARACTERS"));
}

function promptForm_HAS_OTHER_CHARS($sa) // symbols allowed.
{
   return (promptForm_ERROR("HAS OTHER THAN $sa"));
}

function promptForm_NOT_ALL_SPACES()
{
   return (promptForm_ERROR("MUST NOT BE ALL SPACES"));
}

function promptForm_REQUIRED()
{
   return (promptForm_ERROR("REQUIRED"));
}

function promptForm_CONTROL()
{
   return (promptForm_ERROR("CONTROL CHARACTERS NOT ALLOWED"));
}

function promptForm_EXCEEDS_MAX($nm, $vm) // name.max, value.max.
{
   return (promptForm_ERROR("EXCEEEDS CURRENT MAX. $nm NO. $vm"));
}

// ... visitor field error prompts.

// visitor field info prompts ...

function promptForm_INFO_SYMS($ms, $sa) // max size, symbols allowed.
{
   return(" (max " . $ms . ", " . $sa . ")");
}

function promptForm_INFO($ms) // max size.
{
   return(" (max " . $ms . ")");
}

function promptForm_INFO_SIZES_SYMS($cs, $ms, $sa) // cur size, max size, symbols allowed.
{
   return("(" . "size " . $cs . ", max " . $ms . ", " . $sa . ")");
}

function promptForm_INFO_SIZES($cs, $ms) // cur size, max size.
{
   return("(" . "size " . $cs . ", max " . $ms. ")");
}

function promptForm_INFO_SIZE($cs) // cur size, max size.
{
   return("(" . "size " . $cs . ")");
}

function promptForm_SMALL_CAPS($t) // info text (string).
{
   return(HTM_VISITOR_PROMPT_SMALLCAPS_PREFIX . "$t" . HTM_VISITOR_PROMPT_SMALLCAPS_SUFFIX);
}

// ... visitor field info prompts.

// ... visitor field prompts.

function checkForm_visitor_verify()
{
   global $frm_error_count;

   global $visitor_verify;
   global $visitor_verify_size_cur;
   global $visitor_verify_prompt_req;
   global $visitor_verify_prompt_err;

   global $ver_code;

   $tmp_verify_err_count = 0;
   $tmp_verify_err_bool  = false;

   if ($visitor_verify_size_cur == 0)
   {
      $visitor_verify_prompt_err = promptForm_REQUIRED();

  	   ++$tmp_verify_err_count;
   }
   else if  ($visitor_verify != $ver_code)
   {
      $visitor_verify_prompt_err = promptForm_ERROR("DOES NOT MATCH SYMBOLS IN IMAGE");

  	   ++$tmp_verify_err_count;
   }
/*
   else if ()
   {
//  @@@
   }
*/
   else
   {
  	   $visitor_verify_prompt_req = refreshVisitorReqPrompt(VISITOR_FIELD_OK_FLAG);
//	   $visitor_verify_prompt_req = @@@HTM_VISITOR_PROMPT_OK;
   }

// error(s) detected?
  if ($tmp_verify_err_count)
// yes - error(s) detected.
  {
     $tmp_verify_err_bool = true;

     $frm_error_count     += $tmp_verify_err_count;
  }

   return $tmp_verify_err_bool;
}

function checkForm_visitor_password($p, $s, &$ep) // password, password size, error prompt.
{
  global $frm_error_count;

  $tmp_password_oflow     = 0;
  $tmp_password_err_count = 0;
  $tmp_password_err_bool  = false;

  if ($s > VISITOR_PWD_MAX_SIZE)
// if ($s > VISITOR_PWD_SIZE)
  {
  	  $tmp_password_oflow = ($s - VISITOR_PWD_MAX_SIZE);
//	  $tmp_password_oflow = ($s - VISITOR_PWD_SIZE);

     $ep = promptForm_HAS_MORE_CHARS($tmp_password_oflow, VISITOR_PWD_MAX_SIZE);
//   $ep = promptForm_HAS_MORE_CHARS($tmp_password_oflow, VISITOR_PWD_SIZE);

  	 ++$tmp_password_err_count;
  }
  else if ($s == 0)
  {
     $ep = promptForm_REQUIRED();

  	  ++$tmp_password_err_count;
  }

  else if ($s != strspn($p, VISITOR_PWD_SYMS))
//  else if ($s != strspn(($p . "\r"), VISITOR_PWD_SYMS))
  {
     $ep = promptForm_HAS_OTHER_CHARS(VISITOR_PWD_PROMPT_SYMS);

  	  ++$tmp_password_err_count;
  }
/*
  else if ()
  {
//  @@@
  }
*/

// error(s) detected?
  if ($tmp_password_err_count)
// yes - error(s) detected.
  {
     $tmp_password_err_bool = true;

     $frm_error_count += $tmp_password_err_count;
  }

  return $tmp_password_err_bool;
}

function checkForm_visitor_enter_password()
{
  global $session_www_state;

  global $visitor_enter_password;
  global $visitor_enter_password_size_cur;
  global $visitor_enter_password_prompt_err;

  $tmp_return_code
  =
  checkForm_visitor_password
  (
     $visitor_enter_password,
     $visitor_enter_password_size_cur,
     $visitor_enter_password_prompt_err
  );

// password OK?
  if (!$tmp_return_code)
  {
     if ($session_www_state != ROW_STATE_LOGIN)
     {
        $visitor_enter_password_prompt_req = refreshVisitorReqPrompt(VISITOR_FIELD_OK_FLAG);
     }
  }

  return($tmp_return_code);
}

function checkForm_visitor_confirm_password()
{
  global $visitor_confirm_password;
  global $visitor_confirm_password_size_cur;
  global $visitor_confirm_password_prompt_err;

  return
  (
     checkForm_visitor_password
     (
        $visitor_confirm_password,
        $visitor_confirm_password_size_cur,
        $visitor_confirm_password_prompt_err
     )
  );
}

function checkForm_visitor_name($n, $s, $rf, &$rp, &$ep) // name, name size, required flag, required prompt, error prompt.
// function checkForm_visitor_name($n, $s, &$rp, &$ep) // name, name size, required prompt, error prompt.
{
  global $frm_error_count;

  $tmp_name_oflow     = 0;
  $tmp_name_err_count = 0;
  $tmp_name_err_bool  = false;

  if ($s > VISITOR_NAME_SIZE)
  {
  	  $tmp_name_oflow = ($s - VISITOR_NAME_SIZE);
     $ep = promptForm_HAS_MORE_CHARS($tmp_name_oflow, VISITOR_NAME_SIZE);

  	 ++$frm_error_count;
  }
  else if (($rf == VISITOR_FIELD_REQUIRED_FLAG) && ($s == 0))
  {
     $ep = promptForm_REQUIRED();

  	 ++$frm_error_count;
  }
  else if (controlCharacters($n))
//  else if (controlCharacters($visitor_first_name . "\r")) // test injection character detection.
  {
      $ep = promptForm_CONTROL();

  	 ++$frm_error_count;
  }

  else if ($s != strspn($n, VISITOR_NAME_SYMS))
//  else if ($visitor_first_name_size_cur != strspn(($visitor_first_namee . "\r"), VISITOR_NAME_SYMS))
  {
     $ep = promptForm_HAS_OTHER_CHARS(VISITOR_NAME_PROMPT_SYMS);

  	  ++$frm_error_count;
  }
  else if ($s == strspn($n, " "))
  {
     $ep = promptForm_NOT_ALL_SPACES();

  	  ++$frm_error_count;
  }
/*
  else if ()
  {
//  @@@
  }
*/
  else
  {
  	 $rp = refreshVisitorReqPrompt(VISITOR_FIELD_OK_FLAG);
  }
/*
  else if ()
  {
//  @@@
  }
*/

// error(s) detected?
  if ($tmp_name_err_count)
// yes - error(s) detected.
  {
     $tmp_name_err_bool = true;

     $frm_error_count += $tmp_name_err_count;
  }

  return $tmp_name_err_bool;
}

function checkForm_visitor_pledge_3_age()
{
   global $frm_error_count;

   global $visitor_pledge_3_age;
   global $visitor_pledge_3_age_req;

   global $visitor_pledge_3_age_prompt_req;
   global $visitor_pledge_3_age_prompt_err;

   if
   (
      ($visitor_pledge_3_age_req == VISITOR_FIELD_REQUIRED_FLAG)
      &&
      (!$visitor_pledge_3_age)
   )
   {
      $visitor_pledge_3_age_prompt_err = promptForm_REQUIRED();

  	   ++$frm_error_count;
   }
   else
   {
  	   $visitor_pledge_3_age_prompt_req = refreshVisitorReqPrompt(VISITOR_FIELD_OK_FLAG);
   }

   return;
}

function checkForm_visitor_first_name()
{
   global $frm_error_count;
   global $htm_visitor_prompt_required;

   global $visitor_first_name;
   global $visitor_first_name_size_cur;
   global $visitor_first_name_req;
   global $visitor_first_name_prompt_req;
   global $visitor_first_name_prompt_err;

   checkForm_visitor_name
   (
      $visitor_first_name,
      $visitor_first_name_size_cur,
      $visitor_first_name_req,
      $visitor_first_name_prompt_req,
      $visitor_first_name_prompt_err
   );

   return;
}

function checkForm_visitor_last_name()
{
   global $frm_error_count;
   global $htm_visitor_prompt_required;

   global $visitor_last_name;
   global $visitor_last_name_size_cur;
   global $visitor_last_name_req;
   global $visitor_last_name_prompt_req;
   global $visitor_last_name_prompt_err;

   checkForm_visitor_name
   (
      $visitor_last_name,
      $visitor_last_name_size_cur,
      $visitor_last_name_req,
      $visitor_last_name_prompt_req,
      $visitor_last_name_prompt_err
   );

   return;
}

function checkForm_visitor_email()
{
   global $session_www_state;

   global $frm_error_count;
   global $htm_visitor_prompt_required;

   global $visitor_email;
   global $visitor_email_size_cur;
   global $visitor_email_req;
   global $visitor_email_prompt_req;
   global $visitor_email_prompt_err;

   $tmp_email_err_count = 0;
   $tmp_email_err_bool  = false;

  if ($visitor_email_size_cur > VISITOR_EMAIL_MAX_SIZE)
  {
     $visitor_email_oflow  = ($visitor_email_size_cur - VISITOR_EMAIL_MAX_SIZE);
     $visitor_email_prompt_err = promptForm_HAS_MORE_CHARS($visitor_email_oflow, VISITOR_EMAIL_MAX_SIZE);

  	 ++$tmp_email_err_count;
  }
  else if
  (
     ($visitor_email_req == VISITOR_FIELD_REQUIRED_FLAG)
     &&
     ($visitor_email_size_cur == 0))
  {
     $visitor_email_prompt_err = promptForm_REQUIRED();

  	  ++$tmp_email_err_count;
  }
  else if (controlCharacters($visitor_email))
//  else if (controlCharacters("\n" . $visitor_email)) // test injection character detection.
  {
     $visitor_email_prompt_err = promptForm_CONTROL();

     ++$tmp_email_err_count;
  }
  else if (($visitor_email_size_cur > 0) && !is_valid_email_address($visitor_email))
// else if (($visitor_email_size_cur > 0) && !(filter_var($visitor_email, FILTER_VALIDATE_EMAIL) === false))
// else if (($visitor_email_size_cur > 0) && !dd_is_valid_email($visitor_email))
  {
     $visitor_email_prompt_err = promptForm_ERROR("NOT A VALID EMAIL ADDRESS");

     ++$tmp_email_err_count;
  }
/*
  else if ()
  {
//  @@@
  }
*/
  else
  {
/*
// Testing ...

   $tst_diag = '';
   $tst_diag .= ( '##checkForm_visitor_email(#0)##  ' );
   $tst_diag .= ( '**$session_www_state<' . $session_www_state . '>**  ' );
   $tst_diag .= ( '**ROW_STATE_LOGIN<' . ROW_STATE_LOGIN . '>**  ' );
   $tst_diag .= ( '**$visitor_email_prompt_req<' . $visitor_email_prompt_req . '>**  ' );
   $tst_diag .= ( '**$tmp_email_err_count;<' . $tmp_email_err_count . '>**  ' );

   echo htmlspecialchars($tst_diag, ENT_QUOTES);
// ... Testing.
*/
     if ($session_www_state != ROW_STATE_LOGIN)
     {
  	     $visitor_email_prompt_req = refreshVisitorReqPrompt(VISITOR_FIELD_OK_FLAG);
     }
  }

// error(s) detected?
  if ($tmp_email_err_count)
// yes - error(s) detected.
  {
     $tmp_email_err_bool = true;

     $frm_error_count += $tmp_email_err_count;
  }

   return $tmp_email_err_bool;
}

function castForm_visitor_int($s) // int value (string rep).
{
   return
   (
      ($s != '')
      ? (int) $s
      : 0
   );
}

function checkForm_visitor_int($i, $s, $rf, &$rp, &$ep) // int value (string rep), int size, required flag, required prompt, error prompt.
// function checkForm_visitor_int($i, $s, &$rp, &$ep) // int value (string rep), int size, required prompt, error prompt.
{
  global $session_www_state;

  global $frm_error_count;

  $tmp_int_oflow     = 0;
  $tmp_int_err_count = 0;
  $tmp_int_err_bool  = false;

/*
// Testing ...

  $tst_diag = '';
  $tst_diag .= ( '##checkForm_visitor_int(#1)##  ' );

  $tst_diag .= ( '**$i<' . $i . '>**  ' );
  $tst_diag .= ( '**is_string($i)<' . is_string($i) . '>**  ' );
  $tst_diag .= ( '**$s<' . $s . '>**  ' );

  echo htmlspecialchars($tst_diag, ENT_QUOTES);

// ... Testing.
*/

  if ($s > VISITOR_SERNO_SIZE)
  {
  	  $tmp_int_oflow = ($s - VISITOR_SERNO_SIZE);

     $ep = promptForm_HAS_MORE_CHARS($tmp_int_oflow, VISITOR_SERNO_SIZE);

  	 ++$tmp_int_err_count;
  }
  else if ($s != strspn((string)$i, VISITOR_SERNO_SYMS))
  {
     $ep = promptForm_HAS_OTHER_CHARS(VISITOR_SERNO_PROMPT_SYMS);

  	  ++$tmp_int_err_count;
  }
// required and missing?
  else if
  (
     ($rf == VISITOR_FIELD_REQUIRED_FLAG)
     &&
     ($s == 0)
  )
// yes - requried and missing.
  {
     $ep = promptForm_REQUIRED();

  	  ++$tmp_int_err_count;
  }
/*
  else if ()
  {
//  @@@
  }
*/

// NO error(s) detected?
  if (!$tmp_int_err_count)
// yes - NO error(s) detected.
  {
     $tmp_sql_max_row_serno_str     = (string)SQL_MAX_ROW_SERNO;
     $tmp_sql_max_row_serno_str_len = strlen($tmp_sql_max_row_serno_str);

//   is value > SQL_MAX_ROW_SERNO?
     if
     (
        ($s > $tmp_sql_max_row_serno_str_len) // has more digits than max ser no.
        ||
        (                                     // same no. of digits, but larger value.
           ($s == $tmp_sql_max_row_serno_str_len)
           &&
           ($i > $tmp_sql_max_row_serno_str)
        )
     )
//   yes - value > SQL_MAX_ROW_SERNO.
     {
        $ep = promptForm_ERROR("EXCEEDS MAX. ALLOWED VALUE $tmp_sql_max_row_serno_str");
//      $ep = "<span class=\"sys_error_color\" > EXCEEDS MAX. ALLOWED VALUE $tmp_sql_max_row_serno</span>";

  	     ++$tmp_int_err_count;
     }
  }

// error(s) detected?
  if ($tmp_int_err_count)
// yes - error(s) detected.
  {
     $tmp_int_err_bool = true;

     $frm_error_count += $tmp_int_err_count;
  }
  else
// no - NO error(s) detected.
  {
     if ($session_www_state != ROW_STATE_LOGIN)
     {
        $rp = refreshVisitorReqPrompt(VISITOR_FIELD_OK_FLAG);
//      $rp = HTM_VISITOR_PROMPT_OK;
     }
  }

  return $tmp_int_err_bool;
}

function checkForm_visitor_text
(
   $ts,  // text string.
   $tl,  // text length.

   &$sa, // symbols allowed string.
   &$sp, // symbols allowed prompt string.
   $ml,  // max length.
   $cc = VISITOR_NO_CONTROL_CHARS, // control chars allowed (bool).
   $rf = VISITOR_FIELD_OPTIONAL_FLAG, // required flag.

   &$rp,  // required prompt.
   &$ep   // error prompt.
)
{
  global $frm_error_count;

  $tmp_text_oflow     = 0;
  $tmp_text_err_count = 0;
  $tmp_text_err_bool  = false;

  if ($tl > $ml)
  {
  	  $tmp_text_oflow = ($tl - $ml);
     $ep = promptForm_HAS_MORE_CHARS($tmp_text_oflow, $ml);

  	 ++$tmp_text_err_count;
  }
  else if (($rf == VISITOR_FIELD_REQUIRED_FLAG) && ($tl == 0))
  {
     $ep = promptForm_REQUIRED();

  	 ++$tmp_text_err_count;
  }
  else if ((!$cc) && (controlCharacters($ts)))
//  else if (controlCharacters($visitor_first_name . "\r")) // test injection character detection.
  {
      $ep = promptForm_CONTROL();

  	 ++$tmp_text_err_count;
  }

  else if ($tl != strspn($ts, $sa))
//  else if ($visitor_first_name_size_cur != strspn(($visitor_first_namee . "\r"), VISITOR_NAME_SYMS))
  {
     $ep = promptForm_HAS_OTHER_CHARS($sp);

  	  ++$tmp_text_err_count;
  }
  else if ($tl == strspn($ts, " "))
  {
     $ep = promptForm_NOT_ALL_SPACES();

  	  ++$tmp_text_err_count;
  }
/*
  else if ()
  {
//  @@@
  }
*/
  else
  {
  	 $rp = refreshVisitorReqPrompt(VISITOR_FIELD_OK_FLAG);
  }
/*
  else if ()
  {
//  @@@
  }
*/

// error(s) detected?
  if ($tmp_text_err_count)
// yes - error(s) detected.
  {
     $tmp_text_err_bool = true;

     $frm_error_count += $tmp_text_err_count;
  }

  return $tmp_text_err_bool;
}

/* obsolete ...
function checkMbrForm($ac)
// function checkForm($ac)
// function checkForm()
{
// Abend code allocation ...

//  slots  function
//  -----  --------
//
//    0     checkMbrForm(...)                  => this function.
//
//   10     etoSQLgetMaxSerno_club_member(...) => called by this function.
//  -----
//   10

// ... Abend code allocation.

// global $sys_exit_code; // $ac mapping: ($ac+0) ... ($ac+9) => 10 slots.

   global $frm_error_count;

   global $ses_src_context;

   global $visitor_pledge_1_polity;
   global $visitor_pledge_1_polity_prompt_req;
   global $visitor_pledge_1_polity_prompt_err;

   global $visitor_pledge_2_voice;
   global $visitor_pledge_2_voice_prompt_req;
   global $visitor_pledge_2_voice_prompt_err;


   global $visitor_ref_by_member;
   global $visitor_ref_by_member_size_cur;
   global $visitor_ref_by_member_req;
   global $visitor_ref_by_member_prompt_req;
   global $visitor_ref_by_member_prompt_err;

   global $visitor_inf_by_advert;
   global $visitor_inf_by_advert_size_cur;
   global $visitor_inf_by_advert_req;
   global $visitor_inf_by_advert_prompt_req;
   global $visitor_inf_by_advert_prompt_err;

   $frm_error_count = 0;

   $ses_src_context = SCRIPT_CHECK_CONTEXT;

   $tmp_max_serno_club_member = 0;

   initializeVisitorReqs();

// $visitor_pledge_ ...
   if
   (
      isset($_POST[CHECK_FORM_SUBMIT])
      ||
      isset($_POST[JOIN_CLUB_SUBMIT])
   )
   {
//    pledge 1 confirmed?
      if ($visitor_pledge_1_polity)
//    yes - pledge 1 confirmed.
      {
        $visitor_pledge_1_polity_prompt_req = refreshVisitorReqPrompt(VISITOR_FIELD_OK_FLAG);
      }
      else
//    no - pledge 1 NOT confirmed.
      {
         $visitor_pledge_1_polity_prompt_err = promptForm_REQUIRED();
   
         ++$frm_error_count;
      }
   
//    pledge 2 confirmed?
      if ($visitor_pledge_2_voice)
//    yes - pledge 2 confirmed.
      {
        $visitor_pledge_2_voice_prompt_req = refreshVisitorReqPrompt(VISITOR_FIELD_OK_FLAG);
      }
      else
//    no - pledge 2 NOT confirmed.
      {
         $visitor_pledge_2_voice_prompt_err = promptForm_REQUIRED();
   
         ++$frm_error_count;
      }
   }

// ... $visitor_pledge_.

   checkForm_visitor_first_name();
   checkForm_visitor_last_name();
   checkForm_visitor_email();

// $visitor_ref_by_member ...

// is ref_by_member a valid integer?
   if (!checkForm_visitor_int($visitor_ref_by_member, $visitor_ref_by_member_size_cur, $visitor_ref_by_member_req, $visitor_ref_by_member_prompt_req, $visitor_ref_by_member_prompt_err))
// yes -- valid integer.
   {
//    ref_by_member > zero?
      if ($visitor_ref_by_member)
//    yes -- ref_by_member > zero.
      {
         $tmp_max_serno_club_member = etoSQLgetMaxSerno_club_member($ac, ABEND_EXIT, ABEND_ROLLBACK);

//       ref_by_member > max member serno?
         if ($visitor_ref_by_member > $tmp_max_serno_club_member)
//       yes -- ref_by_member > max member serno.
         {
            $visitor_ref_by_member_prompt_err = promptForm_EXCEEDS_MAX("MEMBER", $tmp_max_serno_club_member);

            ++$frm_error_count;

//          reset "OK" from checkForm_visitor_int().
            $visitor_ref_by_member_req        = VISITOR_FIELD_OPTIONAL_FLAG;
            $visitor_ref_by_member_prompt_req = refreshVisitorReqPrompt($visitor_ref_by_member_req);
         }
      }
   }

// ... $visitor_ref_by_member.

// $visitor_inf_by_advert ...

// is inf_by_advert a valid integer?
   if (!checkForm_visitor_int($visitor_inf_by_advert, $visitor_inf_by_advert_size_cur, $visitor_inf_by_advert_req, $visitor_inf_by_advert_prompt_req, $visitor_inf_by_advert_prompt_err))
// yes -- valid integer.
   {
//    inf_by_advert > zero?
      if ($visitor_inf_by_advert)
//    yes -- inf_by_advert > zero.
      {
//       inf_by_advert > max advert no?
         if ($visitor_inf_by_advert > VISITOR_ADVERT_MAX)
//       yes -- inf_by_advert > max advert no.
         {
            $visitor_inf_by_advert_prompt_err = promptForm_EXCEEDS_MAX("ADVERT.", VISITOR_ADVERT_MAX);

            ++$frm_error_count;

//          reset "OK" from checkForm_visitor_int().
            $visitor_inf_by_advert_req        = VISITOR_FIELD_OPTIONAL_FLAG;
            $visitor_inf_by_advert_prompt_req = refreshVisitorReqPrompt($visitor_inf_by_advert_req);
         }
      }
   }

// ... $visitor_inf_by_advert.

   refreshVisitorPrompts();

   return;
}
... obsolete */

function getNavIdCode(&$cs, &$ct, $ac) // code source, code target, abend code.
{
// global $sys_exit_code; // $ac mapping: (0+0) ... (0+1) => 2 slots.

// source code non-null value given?
   if ($cs != '')
// yes - non-null value given.
   {
//    validate source code ...

      if (!NavIdCodeSizeOk($cs))
      {
        etoAbend($ac); // Abend $ac -- invalid $cs (nav id).

//      Test abend => See ssi <eto_contact_act_1.php> -- creates erroneous condition.
      }
      else if (!NavIdCodeSymbolsOk($cs))
      {
        etoAbend($ac+1); // $ac+1 -- invalid symbol(s) in $cs (nav id).
      }

//    ... validate source code.

   }

   $ct = $cs;

   return;
}

function getMd5Code(&$cs, &$ct, $ac) // code source, code target, abend code.
{
// global $sys_exit_code; // $ac mapping: (0+0) ... (0+1) => 2 slots.

// source code non-null value given?
   if ($cs != '')
// yes - non-null value given.
   {
//    validate source code ...

      if (!Md5CodeSizeOk($cs))
      {
        etoAbend($ac); // Abend $ac -- invalid $cs (md5).

//      Test abend => See ssi <eto_contact_act_1.php> -- creates erroneous condition.
      }
      else if (!Md5CodeSymbolsOk($cs))
      {
        etoAbend($ac+1); // $ac+1 -- invalid symbol(s) in $cs (md5).
      }

//    ... validate source code.

   }

   $ct = $cs;

   return;
}

function getSesCode($ac) // abend code.
{
// Abend code allocation ...

//  slots  function
//  -----  --------
//
//    0     getSesCode(...) => this function.
//
//    2     getMd5Code(...) => called by this function.
//  -----
//    2

// ... Abend code allocation.

// global $sys_exit_code; // $ac mapping: (0+0) ... (0+1) => 2 slots.

   global $visitor_key_1;

   global $ses_code;

/*
// INTERNAL tests for  $visitor_key_1 abend conditions below).
//
// $visitor_key_1 = $visitor_key_1 . "X";                      // abend XIT_1 -- field too long.
// $visitor_key_1 = chunk_split($visitor_key_1, 31);           // abend XIT_1 -- field too short.
// $search = array('0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'A', 'B', 'C', 'D', 'E', 'F');
// $visitor_key_1 = str_replace($search, '@', $visitor_key_1); // abend XIT_2 -- invalid symbol(s).
//
*/

//
// BETTER tests for $visitor_key_1 abend conditions below).
//  See => ssi <eto_contact_act_1.php> for creating EXTERNAL test conditions for abends XIT_1 and XIT_2.
//

   getMd5Code($visitor_key_1, $ses_code, $ac);

   return;
}

function getLnkCode($ac) // abend code.
{
// Abend code allocation ...

//  slots  function
//  -----  --------
//
//    0     getLnkCode(...) => this function.
//
//    2     getNavIdCode(...) => called by this function.
//  -----
//    2

// ... Abend code allocation.

// global $sys_exit_code; // $ac mapping: (0+0) ... (0+1) => 2 slots.

   global $visitor_key_3;

   global $lnk_code;

/*
// INTERNAL tests for  $visitor_key_3 abend conditions below).
//
// $visitor_key_3 = $visitor_key_3 . "X";                      // abend XIT_1 -- field too long.
// $visitor_key_3 = chunk_split($visitor_key_3, 31);           // abend XIT_1 -- field too short.
// $search = array('0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'A', 'B', 'C', 'D', 'E', 'F');
// $visitor_key_3 = str_replace($search, '@', $visitor_key_3); // abend XIT_2 -- invalid symbol(s).
//
*/

//
// BETTER tests for $visitor_key_3 abend conditions below).
//  See => ssi <eto_contact_act_1.php> for creating EXTERNAL test conditions for abends XIT_1 and XIT_2.
//

/*
// Testing ...

  $tst_diag = '';
  $tst_diag .= ( '##getLnkCode(#0)##  ' );
  $tst_diag .= ( '**$visitor_key_3<' . $visitor_key_3 . '>**  ' );
  $tst_diag .= ( '**$lnk_code<' . $lnk_code . '>**  ' );

  echo htmlspecialchars($tst_diag, ENT_QUOTES);

// ... Testing.
*/

   getNavIdCode($visitor_key_3, $lnk_code, $ac);
// getMd5Code($visitor_key_3, $lnk_code, $ac);

   return;
}

function getActCode($ac) // abend code.
{
// Abend code allocation ...

//  slots  function
//  -----  --------
//
//    0     getActCode(...) => this function.
//
//    2     getNavIdCode(...) => called by this function.
//  -----
//    2

// ... Abend code allocation.

// global $sys_exit_code; // $ac mapping: (0+0) ... (0+1) => 2 slots.


   global $visitor_key_4;

   global $act_code;

/*
// INTERNAL tests for  $visitor_key_4 abend conditions below).
//
// $visitor_key_4 = $visitor_key_4 . "X";                      // abend XIT_1 -- field too long.
// $visitor_key_4 = chunk_split($visitor_key_4, 31);           // abend XIT_1 -- field too short.
// $search = array('0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'A', 'B', 'C', 'D', 'E', 'F');
// $visitor_key_4 = str_replace($search, '@', $visitor_key_4); // abend XIT_2 -- invalid symbol(s).
//
*/

//
// BETTER tests for $visitor_key_4 abend conditions below).
//  See => ssi <eto_contact_act_1.php> for creating EXTERNAL test conditions for abends XIT_1 and XIT_2.
//

   getNavIdCode($visitor_key_4, $act_code, $ac);
// getMd5Code($visitor_key_4, $act_code, $ac);

/*
// Testing ...

  $tst_diag = '';
  $tst_diag .= ( '##getActCode(#1)##  ' );
  $tst_diag .= ( '**$visitor_key_4<' . $visitor_key_4 . '>**  ' );
  $tst_diag .= ( '**$act_code<' . $act_code . '>**  ' );

  echo htmlspecialchars($tst_diag, ENT_QUOTES);

// ... Testing.
*/

   return;
}

function initializeVisitorFields()
{
   initializeVisitorInputs();

   initializeVisitorReqs();

   return;
}

// function initializeVisitorFields()
function initializeVisitorInputs()
{
  global $visitor_key_1;
  global $visitor_key_3;
  global $visitor_key_4;

  global $visitor_verify;

  global $visitor_enter_password;
  global $visitor_confirm_password;

  global $visitor_pledge_1_polity;
  global $visitor_pledge_2_voice;
  global $visitor_pledge_3_age;

  global $visitor_member_number;
  global $visitor_first_name;
  global $visitor_last_name;
  global $visitor_email;
  global $visitor_ref_by_member;
  global $visitor_inf_by_advert;
  global $visitor_reserve_coop_spot;
  global $visitor_request_news_email;
  global $visitor_block_email_login;

  global $visitor_msg_status;
  global $visitor_msg_privacy;
  global $visitor_subject;
  global $visitor_message;

  global $visitor_init_utc;
  global $visitor_last_utc;
  global $visitor_expiry_utc;
  global $visitor_notified_utc;

  $visitor_key_1              = "";
  $visitor_key_3              = "";
  $visitor_key_4              = "";

  $visitor_verify             = "";

  $visitor_enter_password     = "";
  $visitor_confirm_password   = "";

  $visitor_pledge_1_polity    = false;
  $visitor_pledge_2_voice     = false;
  $visitor_pledge_3_age       = false;

  $visitor_member_number      = 0;
  $visitor_first_name         = "";
  $visitor_last_name          = "";
  $visitor_email              = "";
  $visitor_ref_by_member      = 0;
  $visitor_inf_by_advert      = 0;
  $visitor_reserve_coop_spot  = true;
  $visitor_request_news_email = true;
  $visitor_block_email_login  = false;

  $visitor_msg_status         = ROW_STATE_NULL;
  $visitor_msg_privacy        = MSG_DISCLOSE_NULL;
  $visitor_subject            = VISITOR_SUBJECT_DEFAULT;
  $visitor_message            = "";

  $visitor_init_utc           = CRN_DTIME_0_UTC;
  $visitor_last_utc           = CRN_DTIME_0_UTC;
  $visitor_expiry_utc         = CRN_DTIME_0_UTC;
  $visitor_notified_utc       = CRN_DTIME_0_UTC;

  refreshVisitorSizes();

  return;
}

function initializeVisitorReqs()
{
  global $session_www_type;

  global $visitor_verify_req;
  global $visitor_enter_password_req;
  global $visitor_confirm_password_req;

  global $visitor_pledge_1_polity_req;
  global $visitor_pledge_2_voice_req;
  global $visitor_pledge_3_age_req;

  global $visitor_member_number_req;
  global $visitor_first_name_req;
  global $visitor_last_name_req;
  global $visitor_email_req;
  global $visitor_ref_by_member_req;
  global $visitor_inf_by_advert_req;

  global $visitor_subject_req;
  global $visitor_message_req;

  $visitor_verify_req           = VISITOR_FIELD_REQUIRED_FLAG;

  $visitor_enter_password_req   = VISITOR_FIELD_REQUIRED_FLAG;
  $visitor_confirm_password_req = VISITOR_FIELD_REQUIRED_FLAG;

  $visitor_pledge_1_polity_req  = VISITOR_FIELD_REQUIRED_FLAG;
  $visitor_pledge_2_voice_req   = VISITOR_FIELD_REQUIRED_FLAG;
  $visitor_pledge_3_age_req     = VISITOR_FIELD_REQUIRED_FLAG;

  $visitor_member_number_req    = VISITOR_FIELD_OPTIONAL_FLAG;
  $visitor_first_name_req       = VISITOR_FIELD_REQUIRED_FLAG;
  $visitor_last_name_req        = VISITOR_FIELD_REQUIRED_FLAG;

  $visitor_ref_by_member_req    = VISITOR_FIELD_OPTIONAL_FLAG;
  $visitor_inf_by_advert_req    = VISITOR_FIELD_OPTIONAL_FLAG;

  $visitor_subject_req = VISITOR_FIELD_REQUIRED_FLAG;
  $visitor_message_req = VISITOR_FIELD_REQUIRED_FLAG;

  switch($session_www_type)
  {
     case SES_TYPE_CLUB:
     {
        $visitor_email_req = VISITOR_FIELD_REQUIRED_FLAG;

        break;
     }

     case SES_TYPE_CONTACT:
     {
        $visitor_email_req = VISITOR_FIELD_OPTIONAL_FLAG;

        break;
     }

     default:
     {
        $visitor_email_req = VISITOR_FIELD_OPTIONAL_FLAG;

        break;
     }
  }

  initialzeVisitorPrompts();
//refreshVisitorPrompts();

  return;
}

function initialzeVisitorPrompts()
{
  global $visitor_verify_req;
  global $visitor_enter_password_req;
  global $visitor_confirm_password_req;
  global $visitor_pledge_1_polity_req;
  global $visitor_pledge_2_voice_req;
  global $visitor_pledge_3_age_req;
  global $visitor_member_number_req;
  global $visitor_first_name_req;
  global $visitor_last_name_req;
  global $visitor_email_req;
  global $visitor_ref_by_member_req;
  global $visitor_inf_by_advert_req;
  global $visitor_subject_req;
  global $visitor_message_req;

  global $visitor_verify_prompt_req;
  global $visitor_enter_password_prompt_req;
  global $visitor_confirm_password_prompt_req;
  global $visitor_pledge_1_polity_prompt_req;
  global $visitor_pledge_2_voice_prompt_req;
  global $visitor_pledge_3_age_prompt_req;
  global $visitor_member_number_prompt_req;
  global $visitor_first_name_prompt_req;
  global $visitor_last_name_prompt_req;
  global $visitor_email_prompt_req;
  global $visitor_ref_by_member_prompt_req;
  global $visitor_inf_by_advert_prompt_req;
  global $visitor_subject_prompt_req;
  global $visitor_message_prompt_req;

  $visitor_verify_prompt_req           = refreshVisitorReqPrompt($visitor_verify_req);
  $visitor_enter_password_prompt_req   = refreshVisitorReqPrompt($visitor_enter_password_req);
  $visitor_confirm_password_prompt_req = refreshVisitorReqPrompt($visitor_confirm_password_req);
  $visitor_pledge_1_polity_prompt_req  = refreshVisitorReqPrompt($visitor_pledge_1_polity_req);
  $visitor_pledge_2_voice_prompt_req   = refreshVisitorReqPrompt($visitor_pledge_2_voice_req);
  $visitor_pledge_3_age_prompt_req     = refreshVisitorReqPrompt($visitor_pledge_3_age_req);
  $visitor_member_number_prompt_req    = refreshVisitorReqPrompt($visitor_member_number_req);
  $visitor_first_name_prompt_req       = refreshVisitorReqPrompt($visitor_first_name_req);
  $visitor_last_name_prompt_req        = refreshVisitorReqPrompt($visitor_last_name_req);
  $visitor_email_prompt_req            = refreshVisitorReqPrompt($visitor_email_req);
  $visitor_ref_by_member_prompt_req    = refreshVisitorReqPrompt($visitor_ref_by_member_req);
  $visitor_inf_by_advert_prompt_req    = refreshVisitorReqPrompt($visitor_inf_by_advert_req);
  $visitor_subject_prompt_req          = refreshVisitorReqPrompt($visitor_subject_req);
  $visitor_message_prompt_req          = refreshVisitorReqPrompt($visitor_message_req);

  return;
}

function refreshVisitorDependencies()
{
  refreshVisitorSizes();

  refreshVisitorReqs();
  initialzeVisitorPrompts();

/*
// Testing ..

   global $visitor_member_number_req;
   global $visitor_email_req;
   global $visitor_enter_password_req;

   $tst_diag = '';
   $tst_diag .= ( '##refreshVisitorDependencies(#1)##  ' );

   $tst_diag .= ( '**$visitor_member_number_req<' . $visitor_member_number_req . '>**  ' );
   $tst_diag .= ( '**$visitor_email_req<' . $visitor_email_req . '>**  ' );
   $tst_diag .= ( '**$visitor_enter_password_req<' . $visitor_enter_password_req . '>**  ' );

   echo htmlspecialchars($tst_diag, ENT_QUOTES);

// ... Testing.
*/

  refreshVisitorPrompts();

  return;
}

function refreshVisitorSizes()
{
  global $visitor_key_1;
  global $visitor_key_3;
  global $visitor_key_4;

  global $visitor_verify;

  global $visitor_enter_password;
  global $visitor_confirm_password;

  global $visitor_member_number;
  global $visitor_first_name;
  global $visitor_last_name;
  global $visitor_email;
  global $visitor_ref_by_member;
  global $visitor_inf_by_advert;

  global $visitor_subject;
  global $visitor_message;

  global $visitor_key_1_size_cur;
  global $visitor_key_3_size_cur;
  global $visitor_key_4_size_cur;
  global $visitor_verify_size_cur;
  global $visitor_enter_password_size_cur;
  global $visitor_confirm_password_size_cur;
  global $visitor_member_number_size_cur;
  global $visitor_first_name_size_cur;
  global $visitor_last_name_size_cur;
  global $visitor_email_size_cur;
  global $visitor_ref_by_member_size_cur;
  global $visitor_inf_by_advert_size_cur;
  global $visitor_subject_size_cur;
  global $visitor_message_size_cur;

  $visitor_key_1_size_cur            = strlen($visitor_key_1);
  $visitor_key_3_size_cur            = strlen($visitor_key_3);
  $visitor_key_4_size_cur            = strlen($visitor_key_4);

  $visitor_verify_size_cur           = strlen($visitor_verify);

  $visitor_enter_password_size_cur   = strlen($visitor_enter_password);
  $visitor_confirm_password_size_cur = strlen($visitor_confirm_password);

  $visitor_member_number_size_cur    = strlen($visitor_member_number);
  $visitor_first_name_size_cur       = strlen($visitor_first_name);
  $visitor_last_name_size_cur        = strlen($visitor_last_name);
  $visitor_email_size_cur            = strlen($visitor_email);
  $visitor_ref_by_member_size_cur    = strlen($visitor_ref_by_member);
  $visitor_inf_by_advert_size_cur    = strlen($visitor_inf_by_advert);

  $visitor_subject_size_cur          = strlen($visitor_subject);
  $visitor_message_size_cur          = strlen($visitor_message);

  return;
}

function refreshVisitorReqs()
{
  global $session_www_type;
  global $session_www_state;

  global $visitor_member_number_req;
  global $visitor_email_req;
  global $visitor_enter_password_req;

  switch($session_www_type)
  {
     case SES_TYPE_CLUB:
     {
        if ($session_www_state == ROW_STATE_LOGIN)
        {
           $visitor_member_number_req  = VISITOR_FIELD_1OR2_REQUIRED_FLAG;
           $visitor_email_req          = VISITOR_FIELD_1OR2_REQUIRED_FLAG;
           $visitor_enter_password_req = VISITOR_FIELD_REQUIRED_FLAG;
        }
        else
        {
           $visitor_member_number_req = VISITOR_FIELD_OPTIONAL_FLAG;
           $visitor_email_req         = VISITOR_FIELD_REQUIRED_FLAG;
        }

        break;
     }

     case SES_TYPE_CONTACT:
     {
        if ($session_www_state == ROW_STATE_LOGIN)
        {
           $visitor_member_number_req  = VISITOR_FIELD_1OR2_REQUIRED_FLAG;
           $visitor_email_req          = VISITOR_FIELD_1OR2_REQUIRED_FLAG;
           $visitor_enter_password_req = VISITOR_FIELD_REQUIRED_FLAG;
        }
        else
        {
           $visitor_member_number_req = VISITOR_FIELD_OPTIONAL_FLAG;
           $visitor_email_req         = VISITOR_FIELD_OPTIONAL_FLAG;
        }

        break;
     }

     default:
     {
        $visitor_member_number_req = VISITOR_FIELD_OPTIONAL_FLAG;
        $visitor_email_req         = VISITOR_FIELD_OPTIONAL_FLAG;

        break;
     }
  }

  return;
}

function refreshVisitorPrompts()
{
//  *** NOTE ***    MUST call refreshVisitorSizes(),
// *** BEFORE ***   calling this function refreshVisitorPrompts().

  refreshVisitorVerifyPrompt();
  refreshVisitorEnterPasswordPrompt();
  refreshVisitorConfirmPasswordPrompt();
  refreshVisitorPledge1PolityPrompt();
  refreshVisitorPledge2VoicePrompt();
  refreshVisitorPledge3AgePrompt();
  refreshVisitorMemberNumberPrompt();
  refreshVisitorFirstNamePrompt();
  refreshVisitorLastNamePrompt();
  refreshVisitorEmailPrompt();
  refreshVisitorRefByMemberPrompt();
  refreshVisitorInfByAdvertPrompt();
  refreshVisitorSubjectPrompt();
  refreshVisitorMessagePrompt();

  return;
}

function refreshVisitorReqPrompt($r) // visitor req flag.
{
  $tmp_required_prompt = '';

  switch ($r)
  {
     case VISITOR_FIELD_OPTIONAL_FLAG:
     {
        break;
     }

     case VISITOR_FIELD_REQUIRED_FLAG:
     {
        $tmp_required_prompt
        =
        (
           HTM_VISITOR_PROMPT_REQUIRED_PREFIX .
           $r .
           HTM_VISITOR_PROMPT_REQUIRED_SUFFIX
        );

        break;
     }

     case VISITOR_FIELD_1OR2_REQUIRED_FLAG:
     {
        $tmp_required_prompt
        =
        (
           HTM_VISITOR_PROMPT_REQUIRED_PREFIX .
           $r .
           HTM_VISITOR_PROMPT_REQUIRED_SUFFIX
        );

        break;
     }

     case VISITOR_FIELD_OK_FLAG:
     {
        $tmp_required_prompt
        =
        (
           HTM_VISITOR_PROMPT_OK_PREFIX .
           $r .
           HTM_VISITOR_PROMPT_OK_SUFFIX
        );

        break;
     }

     default:
     {
        break;
     }
  }

  return $tmp_required_prompt;
}

function refreshVisitorPrompt(&$pr, &$pi, &$pe) // $visitor_..._prompt_req, $visitor_..._prompt_inf, $visitor_..._prompt_err.
{
//
// ($pr . /* cond ' ' */ . $pe . /* cond ' ' */ . $pi).
//
  $s = $pr;

  $s .= ((strlen($s) && strlen($pe)) ? ' ' : '');

  $s .= $pe;

  $s .= ((strlen($s) && strlen($pi)) ? ' ' : '');

  $s .= $pi;

  return($s);
}

/*
function refreshVisitorPrompt($r, $i, $e) // $visitor_..._req, $visitor_..._prompt_inf, $visitor_..._prompt_err.
{
  $s = (strlen($e)) ? ' ' : '';

  return
  (
     refreshVisitorReqPrompt($r)
//   $r
     .
     $e
     .
     $s
     .
     $i
  );
}
*/

function refreshVisitorVerifyPrompt()
{
  global $visitor_verify_prompt;
  global $visitor_verify_prompt_req;
  global $visitor_verify_prompt_inf;
  global $visitor_verify_prompt_err;

  $visitor_verify_prompt_inf = "(" . VISITOR_VERIFY_PROMPT_SRC . ")";

  $visitor_verify_prompt     = refreshVisitorPrompt($visitor_verify_prompt_req, $visitor_verify_prompt_inf, $visitor_verify_prompt_err);

  return;
}

/* obsolete ...

function refreshVisitorVerifyPrompt()
{
  global $visitor_verify_prompt;
  global $visitor_verify_prompt_inf;

  $visitor_verify_prompt_inf = HTM_VISITOR_PROMPT_REQUIRED_NOSP;
  $visitor_verify_prompt     = $visitor_verify_prompt_inf;

  return;
}

function refreshVisitorVerifyPrompt()
{
  global $visitor_verify_prompt;
  global $visitor_verify_prompt_inf;

  $visitor_verify_prompt_inf = HTM_VISITOR_PROMPT_REQUIRED_NOSP;
  $visitor_verify_prompt     = $visitor_verify_prompt_inf;

  return;
}
  ... obsolete. */

// function refreshVisitorCreatePasswordPrompt()
function refreshVisitorEnterPasswordPrompt()
{
  global $visitor_enter_password_size_cur;
  global $visitor_enter_password_prompt;
  global $visitor_enter_password_prompt_req;
  global $visitor_enter_password_prompt_inf;
  global $visitor_enter_password_prompt_err;

  $visitor_enter_password_prompt_inf = promptForm_INFO_SIZES_SYMS($visitor_enter_password_size_cur, VISITOR_PWD_MAX_SIZE, VISITOR_PWD_PROMPT_SYMS);
// $visitor_enter_password_prompt_inf = promptForm_INFO_SIZES_SYMS($visitor_enter_password_size_cur, VISITOR_PWD_SIZE, VISITOR_PWD_PROMPT_SYMS);

  $visitor_enter_password_prompt     = refreshVisitorPrompt($visitor_enter_password_prompt_req, $visitor_enter_password_prompt_inf, $visitor_enter_password_prompt_err);

  return;
}

function refreshVisitorConfirmPasswordPrompt()
{
  global $visitor_confirm_password_size_cur;
  global $visitor_confirm_password_prompt;
  global $visitor_confirm_password_prompt_req;
  global $visitor_confirm_password_prompt_inf;
  global $visitor_confirm_password_prompt_err;

  $visitor_confirm_password_prompt_inf = promptForm_INFO_SIZES_SYMS($visitor_confirm_password_size_cur, VISITOR_PWD_MAX_SIZE, VISITOR_PWD_PROMPT_SYMS);
// $visitor_confirm_password_prompt_inf = promptForm_INFO_SIZES_SYMS($visitor_confirm_password_size_cur, VISITOR_PWD_SIZE, VISITOR_PWD_PROMPT_SYMS);

  $visitor_confirm_password_prompt     = refreshVisitorPrompt($visitor_confirm_password_prompt_req, $visitor_confirm_password_prompt_inf, $visitor_confirm_password_prompt_err);

  return;
}

function refreshVisitorPledge1PolityPrompt()
{
  global $visitor_pledge_1_polity_prompt;
  global $visitor_pledge_1_polity_prompt_req;
  global $visitor_pledge_1_polity_prompt_inf;
  global $visitor_pledge_1_polity_prompt_err;

  $visitor_pledge_1_polity_prompt_inf = promptForm_SMALL_CAPS(VISITOR_PLEDGE_1_PROMPT_SRC);

  $visitor_pledge_1_polity_prompt     = refreshVisitorPrompt($visitor_pledge_1_polity_prompt_req, $visitor_pledge_1_polity_prompt_inf, $visitor_pledge_1_polity_prompt_err);

  return;
}

function refreshVisitorPledge2VoicePrompt()
{
  global $visitor_pledge_2_voice_prompt;
  global $visitor_pledge_2_voice_prompt_req;
  global $visitor_pledge_2_voice_prompt_inf;
  global $visitor_pledge_2_voice_prompt_err;

  $visitor_pledge_2_voice_prompt_inf = promptForm_SMALL_CAPS(VISITOR_PLEDGE_2_PROMPT_SRC);

  $visitor_pledge_2_voice_prompt     = refreshVisitorPrompt($visitor_pledge_2_voice_prompt_req, $visitor_pledge_2_voice_prompt_inf, $visitor_pledge_2_voice_prompt_err);

  return;
}

function refreshVisitorPledge3AgePrompt()
{
  global $VISITOR_PLEDGE_3_PROMPT_SRC;

  global $session_www_type;

  global $visitor_pledge_3_age_prompt;
  global $visitor_pledge_3_age_prompt_req;
  global $visitor_pledge_3_age_prompt_inf;
  global $visitor_pledge_3_age_prompt_err;

// club eto session?
  if ($session_www_type == SES_TYPE_CLUB)
// yes -- club eto session.
   {
      $visitor_pledge_3_age_prompt_inf = promptForm_SMALL_CAPS($VISITOR_PLEDGE_3_PROMPT_SRC);
   }
   else
// no -- contact message session.
   {
      $visitor_pledge_3_age_prompt_inf = "(" . ucfirst($VISITOR_PLEDGE_3_PROMPT_SRC) . ")";
   }

   $visitor_pledge_3_age_prompt = refreshVisitorPrompt($visitor_pledge_3_age_prompt_req, $visitor_pledge_3_age_prompt_inf, $visitor_pledge_3_age_prompt_err);

  return;
}

function refreshVisitorMemberNumberPrompt()
{
  global $visitor_member_number_size_cur;
  global $visitor_member_number_prompt;
  global $visitor_member_number_prompt_req;
  global $visitor_member_number_prompt_inf;
  global $visitor_member_number_prompt_err;

  $visitor_member_number_prompt_inf  = promptForm_INFO_SIZES_SYMS($visitor_member_number_size_cur, VISITOR_SERNO_SIZE, VISITOR_SERNO_PROMPT_SYMS);

  $visitor_member_number_prompt      = refreshVisitorPrompt($visitor_member_number_prompt_req, $visitor_member_number_prompt_inf, $visitor_member_number_prompt_err);

  return;
}

function refreshVisitorFirstNamePrompt()
{
  global $visitor_first_name_size_cur;
  global $visitor_first_name_prompt;
  global $visitor_first_name_prompt_req;
  global $visitor_first_name_prompt_inf;
  global $visitor_first_name_prompt_err;

  $visitor_first_name_prompt_inf  = promptForm_INFO_SIZES_SYMS($visitor_first_name_size_cur, VISITOR_NAME_SIZE, VISITOR_NAME_PROMPT_SYMS);

  $visitor_first_name_prompt      = refreshVisitorPrompt($visitor_first_name_prompt_req, $visitor_first_name_prompt_inf, $visitor_first_name_prompt_err);

  return;
}

/* obsolete ...
function refreshVisitorFirstNamePrompt()
{
  global $visitor_first_name_size_cur;
  global $visitor_first_name_prompt;
  global $visitor_first_name_xtra_prompt;
  global $visitor_first_name_prompt_inf;

  $visitor_first_name_xtra_prompt = HTM_VISITOR_PROMPT_REQUIRED_FLAG;
  $visitor_first_name_prompt_inf  = promptForm_INFO_SIZES_SYMS($visitor_first_name_size_cur, VISITOR_NAME_SIZE, VISITOR_NAME_PROMPT_SYMS);
  $visitor_first_name_prompt      = $visitor_first_name_xtra_prompt . $visitor_first_name_prompt_inf;

  return;
}
... obsolete. */

function refreshVisitorLastNamePrompt()
{
  global $visitor_last_name_size_cur;
  global $visitor_last_name_prompt;
  global $visitor_last_name_prompt_req;
  global $visitor_last_name_prompt_inf;
  global $visitor_last_name_prompt_err;

  $visitor_last_name_prompt_inf  = promptForm_INFO_SIZES_SYMS($visitor_last_name_size_cur, VISITOR_NAME_SIZE, VISITOR_NAME_PROMPT_SYMS);

  $visitor_last_name_prompt      = refreshVisitorPrompt($visitor_last_name_prompt_req, $visitor_last_name_prompt_inf, $visitor_last_name_prompt_err);

  return;
}

/* obsolete ...
function refreshVisitorLastNamePrompt()
{
  global $visitor_last_name_size_cur;
  global $visitor_last_name_prompt;
  global $visitor_last_name_xtra_prompt;
  global $visitor_last_name_prompt_req;
  global $visitor_last_name_prompt_inf;
  global $visitor_last_name_prompt_err;

  $visitor_last_name_xtra_prompt = HTM_VISITOR_PROMPT_REQUIRED_FLAG;
  $visitor_last_name_prompt_inf  = promptForm_INFO_SIZES_SYMS($visitor_last_name_size_cur, VISITOR_NAME_SIZE, VISITOR_NAME_PROMPT_SYMS);
  $visitor_last_name_prompt      = $visitor_last_name_xtra_prompt . $visitor_last_name_prompt_inf;

  return;
}
... obsolete. */

function refreshVisitorEmailPrompt()
{
  global $visitor_email_size_cur;
  global $visitor_email_prompt;
  global $visitor_email_prompt_req;
  global $visitor_email_prompt_inf;
  global $visitor_email_prompt_err;

  $visitor_email_prompt_inf = promptForm_INFO_SIZE($visitor_email_size_cur);
// $visitor_email_prompt_inf = promptForm_INFO_SIZES_SYMS($visitor_email_size_cur, VISITOR_EMAIL_MAX_SIZE, VISITOR_EMAIL_PROMPT_SYMS);

  $visitor_email_prompt     = refreshVisitorPrompt($visitor_email_prompt_req, $visitor_email_prompt_inf, $visitor_email_prompt_err);
  
  return;
}

/* obsolete ...
function refreshVisitorEmailPrompt()
{
  global $visitor_email_size_cur;
  global $visitor_email_prompt;
  global $visitor_email_xtra_prompt;
  global $visitor_email_xtra_prompt_ovr;
  global $visitor_email_prompt_inf;

  $visitor_email_xtra_prompt = (($visitor_email_xtra_prompt_ovr != '') ? $visitor_email_xtra_prompt_ovr : '');
  $visitor_email_prompt_inf  = promptForm_INFO_SIZES($visitor_email_size_cur, VISITOR_EMAIL_MAX_SIZE);
  $visitor_email_prompt      = $visitor_email_xtra_prompt . $visitor_email_prompt_inf;

  return;
}
... obsolete. */

function refreshVisitorRefByMemberPrompt()
{
  global $visitor_ref_by_member_size_cur;
  global $visitor_ref_by_member_prompt;
  global $visitor_ref_by_member_prompt_req;
  global $visitor_ref_by_member_prompt_inf;
  global $visitor_ref_by_member_prompt_err;

  $visitor_ref_by_member_prompt_inf  = promptForm_INFO_SIZES_SYMS($visitor_ref_by_member_size_cur, VISITOR_SERNO_SIZE, VISITOR_SERNO_PROMPT_SYMS);

  $visitor_ref_by_member_prompt      = refreshVisitorPrompt($visitor_ref_by_member_prompt_req, $visitor_ref_by_member_prompt_inf, $visitor_ref_by_member_prompt_err);

  return;
}

/* obsolete ...
function refreshVisitorRefByMemberPrompt()
{
  global $visitor_ref_by_member_size_cur;
  global $visitor_ref_by_member_prompt;
  global $visitor_ref_by_member_xtra_prompt;
  global $visitor_ref_by_member_prompt_inf;

  $visitor_ref_by_member_prompt      = '';
  $visitor_ref_by_member_prompt_inf  = promptForm_INFO_SIZES_SYMS($visitor_ref_by_member_size_cur, VISITOR_SERNO_SIZE, VISITOR_SERNO_PROMPT_SYMS);
  $visitor_ref_by_member_xtra_prompt = $visitor_ref_by_member_prompt_inf;

  return;
}
... obsolete. */

function refreshVisitorInfByAdvertPrompt()
{
  global $visitor_inf_by_advert_size_cur;
  global $visitor_inf_by_advert_prompt;
  global $visitor_inf_by_advert_prompt_req;
  global $visitor_inf_by_advert_prompt_inf;
  global $visitor_inf_by_advert_prompt_err;

  $visitor_inf_by_advert_prompt_inf  = promptForm_INFO_SIZES_SYMS($visitor_inf_by_advert_size_cur, VISITOR_SERNO_SIZE, VISITOR_SERNO_PROMPT_SYMS);

  $visitor_inf_by_advert_prompt      = refreshVisitorPrompt($visitor_inf_by_advert_prompt_req, $visitor_inf_by_advert_prompt_inf, $visitor_inf_by_advert_prompt_err);

  return;
}

/* obsolete ...
function refreshVisitorInfByAdvertPrompt()
{
  global $visitor_inf_by_advert_size_cur;
  global $visitor_inf_by_advert_prompt;
  global $visitor_inf_by_advert_xtra_prompt;
  global $visitor_inf_by_advert_prompt_inf;

  $visitor_inf_by_advert_prompt      = '';
  $visitor_inf_by_advert_prompt_inf  = promptForm_INFO_SIZES_SYMS($visitor_inf_by_advert_size_cur, VISITOR_SERNO_SIZE, VISITOR_SERNO_PROMPT_SYMS);
  $visitor_inf_by_advert_xtra_prompt = $visitor_inf_by_advert_prompt_inf;

  return;
}
... obsolete. */

function refreshVisitorSubjectPrompt()
{
  global $visitor_subject_size_cur;
  global $visitor_subject_prompt;
  global $visitor_subject_prompt_req;
  global $visitor_subject_prompt_inf;
  global $visitor_subject_prompt_err;

  $visitor_subject_prompt_inf = promptForm_INFO_SIZES_SYMS($visitor_subject_size_cur, VISITOR_SUBJECT_SIZE, VISITOR_SUBJECT_PROMPT_SYMS);

  $visitor_subject_prompt     = refreshVisitorPrompt($visitor_subject_prompt_req, $visitor_subject_prompt_inf, $visitor_subject_prompt_err);
 
  return;
}

function refreshVisitorMessagePrompt()
{
  global $visitor_message_size_cur;
  global $visitor_message_prompt;
  global $visitor_message_prompt_req;
  global $visitor_message_prompt_inf;
  global $visitor_message_prompt_err;

  $visitor_message_prompt_inf = promptForm_INFO_SIZES_SYMS($visitor_message_size_cur, VISITOR_MESSAGE_SIZE, VISITOR_MESSAGE_PROMPT_SYMS);

  $visitor_message_prompt     = refreshVisitorPrompt($visitor_message_prompt_req, $visitor_message_prompt_inf, $visitor_message_prompt_err);

  return;
}

function etoVerCodeAbend($ac = null)
{

  global $sys_abend_ver_code;

	global $sys_exit_code;

// Was an abend code parm supplied?
   if ($ac)
// yes -- abend code parm - set <$sys_exit_code>.
	{
	   etoAbend($ac, ABEND_NOEXIT);
  }

  return
  (
     $sys_abend_ver_code = chunk_split( ($sys_exit_code . VER_CODE_ABENDED), VER_CODE_SIZE, '')
  );
}

function NavIdCodeSizeOk($nc) // nav id code candidate string;
{
   return( (strlen($nc) == NAV_ID_CODE_SIZE) );
}

function NavIdCodeSymbolsOk($nc) // nav id code candidate string;
{
   return( (strspn($nc, "0123456789ABCDEF") == NAV_ID_CODE_SIZE) );
}

function Md5CodeSizeOk($sc) // md5 code candidate string;
// function SesCodeSizeOk($sc) // session code candidate string;
{
   return( (strlen($sc) == MD5_ID_SIZE) );
}

function Md5CodeSymbolsOk($sc) // md5 code candidate string;
// function SesCodeSymbolsOk($sc) // session code candidate string;
{
   return( (strspn($sc, "0123456789ABCDEF") == MD5_ID_SIZE) );
}

function SesCodeFormatOk($sc) // session code candidate string;
{
   return( Md5CodeSizeOk($sc) && Md5CodeSymbolsOk($sc) );
// return( SesCodeSizeOk($sc) && SesCodeSymbolsOk($sc) );
}

function getSesExpireDeltaMins($ss) // session state.
{
   $tmp_ses_expire_mins = 0;

   switch ($ss)
   {
       case ROW_STATE_LOGIN:
       {
          $tmp_ses_expire_mins = SES_EXPIRY_MINS_ID;

          break;
       }

       case ROW_STATE_PASSWORD:
       {
          $tmp_ses_expire_mins = SES_EXPIRY_MINS_ID;

          break;
       }

       case ROW_STATE_EMAIL_LINK:
       {
          $tmp_ses_expire_mins = SES_EXPIRY_MINS;

          break;
       }

       case ROW_STATE_EMAIL_LOGIN:
       {
          $tmp_ses_expire_mins = SES_EXPIRY_MINS_ID;

          break;
       }

       case ROW_STATE_INFO:
       {
          $tmp_ses_expire_mins = SES_EXPIRY_MINS_ID;

          break;
       }

       case ROW_STATE_ACTIVE:
       {
          $tmp_ses_expire_mins = SES_EXPIRY_MINS; // default.

          break;
       }

       case ROW_STATE_COMPLETE:
       {
          $tmp_ses_expire_mins = SES_EXPIRY_MINS; // default.

          break;
       }

       case ROW_STATE_EXPIRED:
       {
          $tmp_ses_expire_mins = 0;

          break;
       }

       default:
       {
          $tmp_ses_expire_mins = 0;

          break;
       }
   }

   return( $tmp_ses_expire_mins );
}

function getSesDeleteDeltaMins($ss) // session state.
{
   $tmp_ses_delete_mins = 0;

   switch ($ss)
   {
       case ROW_STATE_LOGIN:
       {
          $tmp_ses_delete_mins = SES_DELETE_MINS_ID;

          break;
       }

       case ROW_STATE_PASSWORD:
       {
          $tmp_ses_delete_mins = SES_DELETE_MINS_ID;

          break;
       }

       case ROW_STATE_EMAIL_LINK:
       {
          $tmp_ses_delete_mins = SES_DELETE_MINS_ID;

          break;
       }

       case ROW_STATE_EMAIL_LOGIN:
       {
          $tmp_ses_delete_mins = SES_DELETE_MINS_ID;

          break;
       }

       case ROW_STATE_INFO:
       {
          $tmp_ses_delete_mins = SES_DELETE_MINS_ID;

          break;
       }

       case ROW_STATE_ACTIVE:
       {
          $tmp_ses_delete_mins = SES_DELETE_MINS; // default.

          break;
       }

       case ROW_STATE_COMPLETE:
       {
          $tmp_ses_delete_mins = SES_DELETE_MINS; // default.

          break;
       }

       case ROW_STATE_EXPIRED:
       {
          $tmp_ses_expire_mins = SES_DELETE_MINS; // default.

          break;
       }

       default:
       {
          $tmp_ses_delete_mins = 0;

          break;
       }
   }

   return( $tmp_ses_delete_mins );
}

function getSesMaxHitCount($ss) // session state.
{
   $tmp_ses_hit_max = 0;

   switch ($ss)
   {
       case ROW_STATE_LOGIN:
       {
          $tmp_ses_hit_max = SES_HIT_COUNT_MAX_ID;

          break;
       }

       case ROW_STATE_PASSWORD:
       {
          $tmp_ses_hit_max = SES_HIT_COUNT_MAX_ID;

          break;
       }

       case ROW_STATE_PENDING:
       {
          $tmp_ses_hit_max = SES_HIT_COUNT_MAX; // default.

          break;
       }

       case ROW_STATE_ACTIVE:
       {
          $tmp_ses_hit_max = SES_HIT_COUNT_MAX; // default.

          break;
       }

       default:
       {
          $tmp_ses_hit_max = 0;

          break;
       }
   }

   return( $tmp_ses_hit_max );
}

function getSesRow($ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK, $lo = SQL_NOLOCK) // abend code, abend exit option, abend SQL rollback option, SQL row lock option.
{
   global $sys_script_id;

   global $ses_expiry_secs;
   global $ses_delete_secs;

	global $session_www_code;
   global $session_www_type;
   global $session_www_state;
   global $session_www_init_utc;
   global $session_www_expiry_utc;
   global $session_www_delete_utc;
	global $session_www_hit_count;
	global $session_www_act_seqno;

   global $crn_dtime_utc;

   global $ses_code;
   global $act_code;

// Abend code allocation ...

//  slots  function
//  -----  --------
//
//     2   getSesRow(...)                  => this function.
//
//     9   etoSQLreadRow_session_www(...)  => called by this function.
//   199   etoSQLsetState_session_www(...) => called by this function.
//   199   etoSQLsetState_session_www(...) => called by this function.
//  -----
//   409

// ... Abend code allocation.

   global $sys_exit_code; // $ac mapping: ($ac+0) ... ($ac+408) => 409 slots.

   $tmp_session_www_act_seqno = -1;

   $return_val = true;

   $return_val = etoSQLreadRow_session_www($ses_code, $ac+Xja, $xo, $ro, $lo); // Abend ($ac + 2)+ -- etoSQLreadRow_session_www() failed.
// $return_val = etoSQLreadRow_session_www($ses_code, $ac+3, $xo, $ro, $lo); // Abend ($ac + 2)+ -- etoSQLreadRow_session_www() failed.

// Did session row read deliver 1+ rows?
   if ($return_val)
// yes -- delivered 1+ rows.
   {
//    Is current eto_sql_tb_session_www table row for $ses_code key (did we get a real row)?
      if ($session_www_code == $ses_code)
//    yes - $ses_code key match => check for session expiry and deletability.
      {
//       save action seq no (session expiry can bump value in session row).
         $tmp_session_www_act_seqno = $session_www_act_seqno;

//       Is current eto_sql_tb_session_www table row locked?
         if ($lo == SQL_LOCK)
//       yes -- row (should be) locked.
         {
//          Is session state: login, password, email link, email login, info, active?
            if
            (
               ($session_www_state == ROW_STATE_LOGIN)
               ||
               ($session_www_state == ROW_STATE_PASSWORD)
               ||
               ($session_www_state == ROW_STATE_EMAIL_LINK)
               ||
               ($session_www_state == ROW_STATE_EMAIL_LOGIN)
               ||
               ($session_www_state == ROW_STATE_INFO)
               ||
               ($session_www_state == ROW_STATE_ACTIVE)
            )
//          yes -- session state: login, password, email link, email login, info, active.
            {
//             See <eto__chron_ssi_0.php> for setting forced value of <$crn_dtime_utc>
//               to test expiry and delete conditions.

//             Has session expired?
               if
               (
                  ($session_www_expiry_utc < $crn_dtime_utc)
                  ||
                  ($session_www_hit_count < 1)
               )
//             yes -- session has expired.
               {
                  $return_val = etoSQLsetState_session_www(ROW_STATE_EXPIRED, getSesExpireDeltaMins(ROW_STATE_EXPIRED), getSesDeleteDeltaMins(ROW_STATE_EXPIRED), $ac+Xja+X9, $xo, $ro);
//                $return_val = etoSQLsetState_session_www($ses_code, ROW_STATE_EXPIRED, getSesExpireDeltaMins($session_www_type), getSesDeleteDeltaMins($session_www_type), $ac+Xja+X9, $xo, $ro); // session code, session state, session expiry delta time, session delete delta time, abend code, abend exit option, abend SQL rollback option.
//                $return_val = etoSQLsetState_session_www($ses_code, ROW_STATE_EXPIRED, getSesExpireDeltaMins($session_www_type), getSesDeleteDeltaMins($session_www_type), $ac+3+5, $xo, $ro); // session code, session state, session expiry delta time, session delete delta time, abend code, abend exit option, abend SQL rollback option.

//                Was set state UNsuccessful?
                  if (!$return_val)
//                yes -- set state UNsuccessful.
                  {
//                   NOT abending?
                     if (!$sys_exit_code)
//                   yes -- NOT abending.
                     {
                        etoAbendSubCode($ac, 0, $xo, $ro); // Abend $ac +0 -- etoSQLsetState_session_www() failed.
                     }
                  }
               }
            }

//          Is session complete or expired?
            if
            (
               ($session_www_state == ROW_STATE_COMPLETE)
               ||
               ($session_www_state == ROW_STATE_EXPIRED)
            )
//          yes -- session complete or expired.
            {
//             Is session deletable?
               if ( $session_www_delete_utc < $crn_dtime_utc)
//             yes -- session deletable.
               {
                  $return_val = etoSQLsetState_session_www(ROW_STATE_NULL, getSesExpireDeltaMins(ROW_STATE_NULL), getSesDeleteDeltaMins(ROW_STATE_NULL), $ac+Xja+X9+Xd, $xo, $ro);
//                $return_val = etoSQLsetState_session_www($ses_code, ROW_STATE_NULL, getSesExpireDeltaMins($session_www_type), getSesDeleteDeltaMins($session_www_type), $ac+Xja+X9, $xo, $ro); // session code, session state, session expiry delta time, session delete delta time, abend code, abend exit option, abend SQL rollback option.
//                $return_val = etoSQLsetState_session_www($ses_code, ROW_STATE_NULL, getSesExpireDeltaMins($session_www_type), getSesDeleteDeltaMins($session_www_type), $ac+3+5, $xo, $ro); // session code, session state, session expiry delta time, session delete delta time, abend code, abend exit option, abend SQL rollback option.

//                Was set state UNsuccessful?
                  if (!$return_val)
//                yes -- set state UNsuccessful.
                  {
//                    NOT abending?
                     if (!$sys_exit_code)
//                   yes -- NOT abending.
                     {
                        etoAbendSubCode($ac, 1, $xo, $ro); // Abend $ac + 1 -- etoSQLsetState_session_www() failed.
                     }
                  }
               }
            }
         }

//       Is session row still NOT null?
         if ($session_www_state != ROW_STATE_NULL)
//       yes -- ssession row still NOT null.
         {
//          protect against browser back /reload button use ...
            (
//             did visitor provide INcorrect action sequence hash?
               (
                  $act_code != etoSQLhashSeqnoDate_session_www($tmp_session_www_act_seqno, $session_www_init_utc)
               )
//             yes - INcorrect action sequence hash
               ? $return_val = false
               : false
            );
//          ... protect against browser back /reload button use.

/*
// Testing ...

	global $session_www_serno;
	global $visitor_key_4;

if ($sys_script_id != 'eto_verify_img.php')
{
  $tst_diag = '';
  $tst_diag .= ( '##getSesRow(#1)##  ' );

  $tst_diag .= ( '**$session_www_serno<' . $session_www_serno . '>**  ' );
  $tst_diag .= ( '**$session_www_state<' . $session_www_state . '>**  ' );
  $tst_diag .= ( '**$session_www_code<' . $session_www_code . '>**  ' );

  $tst_diag .= ( '**$visitor_key_4<' . $visitor_key_4 . '>**  ' );
  $tst_diag .= ( '**$act_code<' . $act_code . '>**  ' );

  $tst_diag .= ( '**$session_www_act_seqno<' . $session_www_act_seqno . '>**  ' );
  $tst_diag .= ( '**$session_www_init_utc<' . $session_www_init_utc . '>**  ' );
  $tst_diag .= ( '**etoSQLhashSeqnoDate_session_www(...)<' . etoSQLhashSeqnoDate_session_www($session_www_act_seqno, $session_www_init_utc) . '>**  ' );

  $tst_diag .= ( '**$return_val<' . $return_val . '>**  ' );

  echo htmlspecialchars($tst_diag, ENT_QUOTES);
}

// ... Testing.
*/
         }
      }
   }
   else
// no -- did NOT deliver 1+ rows.
   {
//    NOT abending?
      if (!$sys_exit_code)
//    yes -- NOT abending.
      {
//       it's ok if no row was delivered.
         $return_val = true;

//       etoAbendSubCode($ac, 2, $xo, $ro); // Abend $ac + 2 -- etoSQLreadRow_session_www() - did NOT deliver 1+ rows.
      }
   }

/*
// Testing ...

	global $session_www_serno;
	global $visitor_key_4;

if ($sys_script_id != 'eto_verify_img.php')
{
  $tst_diag = '';
  $tst_diag .= ( '##getSesRow(#2)##  ' );

  $tst_diag .= ( '**$session_www_serno<' . $session_www_serno . '>**  ' );
  $tst_diag .= ( '**$session_www_state<' . $session_www_state . '>**  ' );
  $tst_diag .= ( '**$session_www_code<' . $session_www_code . '>**  ' );

  $tst_diag .= ( '**$visitor_key_4<' . $visitor_key_4 . '>**  ' );

  $tst_diag .= ( '**$session_www_act_seqno<' . $session_www_act_seqno . '>**  ' );
  $tst_diag .= ( '**$session_www_init_utc<' . $session_www_init_utc . '>**  ' );
  $tst_diag .= ( '**etoSQLhashSeqnoDate_session_www(...)<' . etoSQLhashSeqnoDate_session_www($session_www_act_seqno, $session_www_init_utc) . '>**  ' );

  $tst_diag .= ( '**$return_val<' . $return_val . '>**  ' );

  echo htmlspecialchars($tst_diag, ENT_QUOTES);
}

// ... Testing.
*/

   return($return_val);
}

// Generate	a new session (row in eto_sql_tb_visitor_ses table)
//   (after advancing ticktock cleanup clock on table eto_sql_tb_visitor_ses).
function genSes($st, $ss, $sd, $ac) // session type, session state, session target data, abend code.
// function genSes($st, $ss, $ac) // session type, session state, abend code.
{
   global $ver_code;
   global $ses_code;

   global $sys_exit_msg;

// Abend code allocation ...

//  slots  function
//  -----  --------
//
//    0     genSes(...)                         => this function.
//
//   58     etoSQLtickTock_session_www(...)     => called by this function.
//   58     etoSQLtickTock_session_www(...)     => called by this function.
//   21     etoSQLstmtWriteRow_session_www(...) => called by this function.
//  -----
//  137

// ... Abend code allocation.

// global $sys_exit_code; // $ac mapping: ($ac+0) ... ($ac+136) => 137 slots.

/*
// Testing ...
  $tst_diag = '';
  $tst_diag .= ( '##genSes(#1)##  ' );

  $tst_diag .= ( '**$st<' . $st . '>**  ' );
  $tst_diag .= ( '**$ss<' . $ss . '>**  ' );
  $tst_diag .= ( '**$sd<' . $sd . '>**  ' );
  $tst_diag .= ( '**$ac<' . $ac . '>**  ' );

  echo htmlspecialchars($tst_diag, ENT_QUOTES);

// ... Testing.
*/

// Ticktock cleanup of table eto_sql_tb_session_www.
   (
//    Cleanup enabled?
      (SES_TKTK_SKIP_CNT >= 0)

//    yes - cleanup enabled.
      ?
      (
//       Hard launch?
         (SES_TKTK_SKIP_CNT == 0)

//       yes - hard launch.
         ?
         (
            etoSQLtickTock_session_www(SES_TKTK_SKIP_CNT, $ac) // Abend $ac+ -- etoSQLtickTock_session_www() failed.
         )

//       no - fuzzy launch.
         :
         (
//          Probability approx. == 1 / (SES_TKTK_SKIP_CNT+1).
            (mt_rand(0,SES_TKTK_SKIP_CNT) == 0)
            ?
            (
               etoSQLtickTock_session_www(SES_TKTK_SKIP_CNT, $ac+(1*Xh)) // Abend $ac+(1*Xh)+ -- etoSQLtickTock_session_www() failed.
            )
            :
            (false)
          )
      )
//    no - cleanup DISabled.
      :
      (false)

   );

// Make 5 attempts to generate session (row in table <eto_sql_tb_session_www>) ...
   for ($i=0; $i<5; ++$i)
   {
//    Generate a 32-char md5 random string from a random integer (two randomizations).
      $ses_code = strtoupper(md5(mt_rand()));

//    Test for abend -- 5 attempts failed to generate session id (duplicate key detection).
//    (set to the value of an existing visitor_session_code key in table eto_sql_tb_session_www.)
//    e.g. $ses_code = "3308155BE5AFBB665E55FFD66B0A8A59";
//    e.g. $ses_code = "F1BDD100379FF5437682D4F5A3844FDF";

      $tmp_zero     = 0;
      $tmp_null_str = '';

//    Is attempt to insert row into eto_sql_tb_session_www table successful?
      if (etoSQLstmtWriteRow_session_www($ses_code, $st, $ss, $ver_code, $tmp_zero, $sd, getSesExpireDeltaMins($ss), getSesDeleteDeltaMins($ss), getSesMaxHitCount($ss), $ac+(2*Xh))) // ($ac+(2*Xh)+ == abend code).
//	   yes -- row insert successful.
      {
         break;
      }
//	   no -- row insert UNsuccessful (e.g. duplicate key).
      else
      {
//        Invalidate the session code.
         	$ses_code = '';

//        Test for proof of duplicate key detection.
//        (turn on also test above "Test for duplicate key detection".)
//        (inspect source of served page for ses_code value.)
//        $ses_code = 'FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF';

          continue;
      }
   }
// ... Make 5 attempts to generate session id.

// Test abend - failed to generate session row.
// $ses_code = '';

   return( ($ses_code == '') ? (false) : (true));
}

// check for resource availability.
function etoResAvail($ac) // abend code.
{
//
// checks for the following resources:
//
//    php         -- version (5.1 or later is the minimum required XAMPP Win XP).
//    php         -- magicquotes must be disabled..
//
//
//    o/s        -- win / nix (if nix use real pwqcheck, else use proxy pwqcheck).
//
//    encryption -- blowfish (must be available).
//
//    sql        -- minimum version for sql database server:
//                  -- now set in php module specific to sql api used:
//                     -- pg     -- eto__sql_pg_ssi_0.php;
//                     -- mysqli -- eto__sql_myi_ssi_0.php;
//

// Abend code allocation ...

//  slots  function
//  -----  --------
//
//     8    etoResAvail(...) => this function.
//  -----
//     8

// ... Abend code allocation.

// global $sys_exit_code; // $ac mapping: ($ac+0) ... ($ac+7) => 8 slots.

// predefined constants used ...

//
// non-core:
// CRYPT_BLOWFISH
//

// ... predefined constants used.

// pseudo-constants.
   global $ETO_PHP_RELEASE;
   global $ETO_PHP_MIN_RELEASE;
   global $ETO_PHP_OS;

   global $use_pwqcheck;
   global $sql_min_version;

// fetch the pseudo-constant values ...

/*
// Testing ...
  $tst_diag = '';
  $tst_diag .= ( '##etoResAvail(#1)##  ' );

  $tst_diag .= ( 'function_exists(\'php_uname\')<' . function_exists('php_uname') . '>**  ' );

  echo htmlspecialchars($tst_diag, ENT_QUOTES);

// ... Testing.
*/

   if (function_exists('php_uname'))
// if (function_exists('php_unameX')) // test abend.
   {
      $ETO_PHP_RELEASE = php_uname('r'); // release name. eg. 5.1.2-RELEASE.
      $ETO_PHP_OS      = php_uname('s'); // operating system name. eg. FreeBSD.
   }
   else
   {
      etoAbendSubCode($ac, 0); // function_exists('php_uname') == false. 
   }
// ... fetch the pseudo-constant values.

/*
// Testing ...
  $tst_diag = '';
  $tst_diag .= ( '##etoResAvail(#2)##  ' );

  $tst_diag .= ( 'function_exists(\'version_compare\')<' . function_exists('version_compare') . '>**  ' );

  $tst_diag .= ( '$ETO_PHP_RELEASE<' . $ETO_PHP_RELEASE . '>**  ' );
  $tst_diag .= ( '$ETO_PHP_MIN_RELEASE<' . $ETO_PHP_MIN_RELEASE . '>**  ' );

  $tst_diag .= ( 'version_compare($ETO_PHP_RELEASE, $ETO_PHP_MIN_RELEASE, \'<\')<' . version_compare($ETO_PHP_RELEASE, $ETO_PHP_MIN_RELEASE, '<') . '>**  ' );

  echo htmlspecialchars($tst_diag, ENT_QUOTES);

// ... Testing.
*/

   if (function_exists('version_compare'))
// if (function_exists('version_compareX')) // test abend.
   {
//    check php version ...
      if (version_compare($ETO_PHP_RELEASE, $ETO_PHP_MIN_RELEASE, '<'))
      {
         etoAbendSubCode($ac, 1); // version_compare($ETO_PHP_RELEASE, $ETO_PHP_MIN_RELEASE, '<') == true. 
      }
//    ... check php version.
   }
   else
   {
      etoAbendSubCode($ac, 2);// function_exists('version_compare') == false. 
   }

// check maficquotes ...

   if (function_exists('get_magic_quotes_gpc'))
// if (function_exists('get_magic_quotes_gpcX')) // test abend.
   {
      if (get_magic_quotes_gpc())
//    if (!get_magic_quotes_gpc()) // test abend.
      {
         etoAbendSubCode($ac, 3); // get_magic_quotes_gpc() == true. 
      }
//    ... check php version.
   }
   else
   {
      etoAbendSubCode($ac, 4);// function_exists('get_magic_quotes_gpc') == false. 
   }

// ... check maficquotes.

// check o/s ...

// $ETO_PHP_OS = ''; // test abend.

   if
   ($ETO_PHP_OS != '')
   {
//    running under windows?
      if (strncasecmp($ETO_PHP_OS, 'WIN', 3) == 0)// e.g. 
//    yes -- running under windows.
      {
         $ETO_OS_TYPE = ETO_WIN_OS;
      }
      else
//    no -- NOT running under windows.
      {
//       *** CAUTION ***
//
//       This will default Mac DARWIN to *nix.
//
         $ETO_OS_TYPE = ETO_NIX_OS; // assume *nix.
      }
   }
   else
   {
      etoAbendSubCode($ac, 5); // $ETO_PHP_OS == ''.
   }
// ... check o/s.

// check blowfish ...

   if (defined('CRYPT_BLOWFISH'))
   {
      if (!CRYPT_BLOWFISH)
//    if (CRYPT_BLOWFISH) // test abend.
      {
         etoAbendSubCode($ac, 6); // CRYPT_BLOWFISH == false.
      }
   }
   else
   {
      etoAbendSubCode($ac, 7); // defined('CRYPT_BLOWFISH') == false.
   }

// ... check blowfish.

// set minimum sql database server version required.
//    now set in php module specific to sql api used:
//       pg     -- eto__sql_pg_ssi_0.php;
//       mysqli -- eto__sql_myi_ssi_0.php;

// set pwqcheck version to use (real / fallback).
   $use_pwqcheck
   =
   (
      ($ETO_OS_TYPE == ETO_NIX_OS)
      ? true  // real.
      : false // fallback.
   );

/*
// Testing ...
  $tst_diag = '';
  $tst_diag .= ( '##etoResAvail(#3)##  ' );

  $tst_diag .= ( '$ETO_PHP_RELEASE<' . $ETO_PHP_RELEASE . '>**  ' );
  $tst_diag .= ( '$ETO_PHP_MIN_RELEASE<' . $ETO_PHP_MIN_RELEASE . '>**  ' );

  $tst_diag .= ( '$ETO_PHP_OS<' . $ETO_PHP_OS . '>**  ' );

  $tst_diag .= ( '$ETO_OS_TYPE<' . $ETO_OS_TYPE . '>**  ' );
  $tst_diag .= ( '$use_pwqcheck<' . $use_pwqcheck . '>**  ' );

  $tst_diag .= ( 'defined(\'CRYPT_BLOWFISH\')<' . defined('CRYPT_BLOWFISH') . '>**  ' );
  $tst_diag .= (defined('CRYPT_BLOWFISH')) ? ( 'CRYPT_BLOWFISH<' . CRYPT_BLOWFISH . '>**  ' ) : '';

  echo htmlspecialchars($tst_diag, ENT_QUOTES);

// ... Testing.
*/

   return;
}


// make session context available.
function openSes($st, $ac, $ss = ROW_STATE_NULL, $sd = '') // session type, abend code, session state, target data:
{
   global $sys_script_id;

   global $ses_code;

   global $session_www_type;
   global $session_www_state;
   global $session_target_serno;

   global $info_msg_map_oops_ary;

// Abend code allocation ...

// Note: 2 calls to function etoSQLsetState_session_www(...)
//   overlap abend code range, to save slots.

//  slots  function
//  -----  --------
//
//     2   openSes(...)      => this function.
//
//     8   etoResAvail(...)  => called by this function.
//     2   getSesCode(...)   => called by this function.
//    12   etoSQLdbOpen(...) => called by this function.
//   137   genSes(...)       => called by this function.
//     2   getActCode(...)   => called by this function.
//   409   getSesRow(...)    => called by this function.
//   432   getMbrRow((...)   => called by this function.
//  -----
//  1004

// ... Abend code allocation.

// global $sys_exit_code; // $ac mapping: ($ac+0) ... ($ac+1003) => 1004 slots.

   $return_val = true;

   etoResAvail($ac+Y3a);

   getSesCode($ac+Y3a+Yc);

   etoSQLdbOpen($ac+Y3a+Yc+Xq, ABEND_EXIT, ABEND_NOROLLBACK); // Abend $ac+Y3a+Yc+Xq+ -- etoSQLdbOpen() failed.

/*
// Testing ...
  $tst_diag = '';
  $tst_diag .= ( '##openSes(#1)##  ' );

  $tst_diag .= ( '**$st<' . $st . '>**  ' );
  $tst_diag .= ( '**$ss<' . $ss . '>**  ' );
  $tst_diag .= ( '**$sd<' . $sd . '>**  ' );
  $tst_diag .= ( '**$ac<' . $ac . '>**  ' );

  $tst_diag .= ( '**$ses_code<' . $ses_code . '>**  ' );
  $tst_diag .= ( '**$session_www_state<' . $session_www_state . '>**  ' );
  $tst_diag .= ( '**$session_www_type<' . $session_www_type . '>**  ' );

  echo htmlspecialchars($tst_diag, ENT_QUOTES);

// ... Testing.
*/

// initiate new session?
   if ($ses_code == '')
// yes - initiate new session.
   {
      $return_val = genSes($st, $ss, $sd, $ac+Y3a+Yc+Xq+X0);
   }
   else
// no - open existing session.
   {
      getActCode($ac+Y3a+Yc+Xq+X0+Y2);

//    got real session row with expected action sequence hash (or null row)?
      if (getSesRow($ac+Y3a+Yc+Xq+X0+Y2+Y5, ABEND_EXIT, ABEND_ROLLBACK, SQL_LOCK)) // Abend $ac+Y3a+Xq+X0+Y2+Y5+ -- getSesRow() Failed.;
//    yes - got real session row with expected action sequence hash (or null row).
      {
//       got real session row?
         if ($session_www_state != ROW_STATE_NULL)
//       yes - got real session row.
         {
//          does caller know session type?
            if ($st != SES_TYPE_UNKNOWN)
//          yes - knows session type.
            {
//             is session of UNexpected type?
               if ($session_www_type != $st)
//             yes - UNexpected session type.
               {
                  $sys_exit_msg = '(' . "UNexpected \$session_www_type<" . "$session_www_type" . '> in row buffer of table eto_sql_tb_session_www.' . ')';
            
                  etoAbendSubCode($ac, 0); // Abend $ac + 0 -- UNexpected $session_www_type<...> in row buffer of table eto_sql_tb_session_www.
               }
            }
         }

         switch ($session_www_state)
         {
//           valid session states intercepteded by openSes(...).
             case ROW_STATE_NULL:
             case ROW_STATE_COMPLETE:
             case ROW_STATE_EXPIRED:
             case ROW_STATE_ABENDED:
             {
//              indicate no row found.
                $return_val = false;

//              Serve session unknown information page.
                etoInfoPage();
         
                break;
             }

//           valid session states returned to caller.
             case ROW_STATE_LOGIN:
             case ROW_STATE_PASSWORD:
             case ROW_STATE_EMAIL_LINK:
             case ROW_STATE_EMAIL_LOGIN:
             case ROW_STATE_INFO:
             case ROW_STATE_ACTIVE:
             {
//              does session row point to a real member row?
                if ($session_target_serno != SQL_NUL_ROW_SERNO)
//              yes - session row points to a real member row.
                {
//                 member row (owned by this session) found?
                   $return_val = getMbrRow($ac+Y3a+Yc+Xq+X0+Y2+Y5+Xj); // Abend $ac+Y3a+Yc+Xq+X0+Y2+Y5+Xj+ -- getMbrRow() Failed.
                }

                break;
             }
         
             default:
             {
                $sys_exit_msg = '(' . "INvalid \$session_www_state value <" . "$session_www_state" . '> in row buffer of table eto_sql_tb_session_www.' . ')';
         
                etoAbendSubCode($ac, 1); // Abend $ac +1 -- INvalid $session_www_state value in row buffer of table eto_sql_tb_session_www.
         
                break;
             }
         }
      }
      else
//    no - failed to get real session row with expected action sequence hash (or null row).
      {
         $return_val = false;

//       activating an emailed www link?
         if ($session_www_state == ROW_STATE_EMAIL_LINK)
//       yes - activating an emailed www link.
         {
 //         "It appears that you have used your web browser to activate a now-out-of-date www link, in an email the ETO website sent to you earlier.".
            etoHTMoopsLnkMsg
            (
               $info_msg_map_oops_ary
                [
                   $sys_script_id
                ]
            );
         }
         else
//       no - NOT activating an emailed www link (activating a submit button).
         {
 //         "Did you use your web browser \"Back\" or \"Reload\" button?".
            etoHTMoopsSesMsg
            (
               $info_msg_map_oops_ary
                [
                   $sys_script_id
                ]
            );
         }
      }
   }

   return($return_val);
}

//release session context.
function closeSes($ac) // abend code.
{
   global $frm_next_page_htm;

   global $sys_log_details;
   global $sys_log_det_val;

// Abend code allocation ...

// Note: 2 calls to function etoSQLsetState_session_www(...)
//   overlap abend code range, to save slots.

//  slots  function
//  -----  --------
//
//     0   closeSes(...)      => this function.
//
//     3   etoSQLdbClose(...) => called by this function.
//  -----
//     3

// ... Abend code allocation.

// global $sys_exit_code; // $ac mapping: ($ac+0) ... ($ac+2) => 3 slots.

// generate log details.
   $sys_log_det_val = $sys_log_details();

// close access to ETO database.
   etoSQLdbClose($ac); //Abend $ac+ -- etoSQLdbClose() failed. (See eto__sql_ssi_0.php for setting abend 26 test condition).

// display next page on visitor's browser.
   echo $frm_next_page_htm;
   
   return;
}

function etoSeizeMbrRow($ac) // abend code.
{
//
//   *** IMPORTANT NOTE ***
//
// It is the RESPONSIBILITY of the caller
//  to ensure that the member row:
//
//    1. is NOT currently owned by an OTHER session (if this protection is desired), and
//    2. has been read and is in a state suitable for a rewrite.
//

// Abend code allocation ...

//  slots  function
//  -----  --------
//
//    0     etoSeizeMbrRow(...)             => this function.
//
//  137     etoSQLsetState_club_member(...) => called by this function.
//  -----
//  137

// ... Abend code allocation.

// global $sys_exit_code; // $ac mapping: ($ac+0) ... ($ac+136) => 137 slots.

   global $ses_code;

   global $member_status;
   global $member_session_code;

//    seize ownership of the club member row for THIS session ...

      $member_session_code = $ses_code;

      etoSQLsetState_club_member
      (
         (
//          has membership expired?
            (checkMemberExpiry())
            ? ROW_STATE_EXPIRED // yes - expired (change row state to expired).
            : $member_status    // no - NOT expired (keep same row state).
         ),

         $ac // Abend $ac+ -- etoSQLsetState_club_member() Failed.
      );
//    etoSQLsetState_club_member($member_status, $ac); // Abend $ac+ -- etoSQLsetState_club_member() Failed.

//    ... seize ownership of the club member row for THIS session.

   return;
}

function getMbrRow($ac) // abend code.
{
   global $sql_query;
   global $sql_result;
	global $sql_fetch;

   global $sql_errno;
   global $sql_state;
   global $sql_state_class;

   global $sql_row_count;

   global $ses_code;

   global $session_target_serno;

   global $club_member_serno;
   global $member_session_code;

// Abend code allocation ...

//  slots  function
//  -----  --------
//
//    5     getMbrRow(...)                 => this function.
//
//    9     etoSQLreadRow_club_member(...) => called by this function.
//    7     etoSQLquery(...)               => called by this function.
//  137     etoSeizeMbrRow(...)            => called by this function.
//  137     etoSeizeMbrRow(...)            => called by this function.
//  137     etoSeizeMbrRow(...)            => called by this function.
//  -----
//  432

// ... Abend code allocation.

   global $sys_exit_code; // $ac mapping: ($ac+0) ... ($ac+431) => 432 slots.

   global $sys_exit_msg;
   global $sys_script_id;

   global $info_msg_map_mbr_oops_ary;

	$tmp_session_www_code       = '';
	$tmp_session_www_type       = SES_TYPE_NULL;
	$tmp_session_www_state      = ROW_STATE_NULL;
   $tmp_session_target_serno   = SQL_NUL_ROW_SERNO;

   $return_val = true;

   etoSQLinitCall();

// 1+ member rows found?
   if (etoSQLreadRow_club_member($session_target_serno, '', $ac+Y8a, ABEND_EXIT, ABEND_ROLLBACK, SQL_LOCK)) // Abend $ac+Y8a+ -- etoSQLreadRow_club_member() Failed.
// yes -- 1+ member rows found
   {
//    exactly one member member row found?
      if ($sql_row_count == 1)
//    yes -- one member row found.
      {
//       is member row associated with a session?
         if ($member_session_code != '')
//       yes - associated with a session.
         {
//          is member row NOT associated with THIS session (i.e. associated with an OTHER sesaion)?
            if ($member_session_code != $ses_code)
//          yes - NOT associated with THIS session (i.e associated with an OTHER sesaion).
            {
//             *** DO NOT USE FUNCTION etoSQLreadRow_session_www(...) HERE ***
//
//             (it will destroy the session row buffer values of THIS session.)
//
//             use a sql query instead - see e.g. function etoSQLreadRow_session_www(...).

               $sql_query = "SELECT session_www_code, session_www_type, session_www_state, session_target_serno FROM eto_sql_tb_session_www WHERE session_www_code = '$member_session_code'";

               etoSQLinitCall();

//             Does the SELECT return at least 1 row?
               if ($return_val = etoSQLquery($ac+Y8a+Xk, $xo, $ro)) // Abend ($ac+Y8a+Xk)+ -- etoSQLquery() failed to deliver row (not missing key).
//             if ($return_val = etoSQLquery($ac+2, $xo, $ro)) // Abend ($ac+2)+ -- etoSQLquery() failed to deliver row from $sql_result (not missing key).
//             yes -- row(s) available.
               {
                 $sql_fetch = mysqli_fetch_row($sql_result);
               
                 mysqli_free_result($sql_result);
               
//               Test abend $ac + 1
//               (new empty variable as result parm.)
//               (MUST start Apache with no PHP warning messages, to get "xxABEND" image displayed when testing eto_contact_img.php.)
//               $sql_fetch = mysqli_fetch_row($sql_resultX);
               
//               Was the fetch row successful? (defensive programming -- should ALWAYS succeed.)
	              if ($sql_fetch)
//               yes -- fetch successful.
                 {
	               	$tmp_session_www_code       =      $sql_fetch[0];
	               	$tmp_session_www_type       = (int)$sql_fetch[1];
	               	$tmp_session_www_state      = (int)$sql_fetch[2];
                     $tmp_session_target_serno   = (int)$sql_fetch[3];
	              }
//               no -- fetch UNsuccessful.
	              else
	              {
                    $return_val = false;

               	  $sys_exit_msg = '(' . etoSQLformatDiag() . ')';
               
               	  etoAbendSubCode($ac, 0); // Abend $ac + 0 -- Failed to fetch row from $sql_result (not missing key).
               
                 }

//               obteined expected OTHER sesaion code?
                 if ($tmp_session_www_code == $member_session_code)
//               yes - obteined expected OTHER sesaion code.
                 {
//                  does OTHER session own the member row?
                    if
                    (
                       (
	                       ($tmp_session_www_type == SES_TYPE_CLUB)
                          &&
                          ($tmp_session_target_serno == $club_member_serno)
                       )
                       &&
                       (
                          ($tmp_session_www_state != ROW_STATE_NULL)
                          &&
                          ($tmp_session_www_state != ROW_STATE_COMPLETE)
                          &&
                          ($tmp_session_www_state != ROW_STATE_EXPIRED)
                          &&
                          ($tmp_session_www_state != ROW_STATE_ABENDED)
                       )
                    )
//                  yes - OTHER sesaion owns the member row.
                    {
                       $return_val = false;

//                     generate oooops msg html "Oooops!! Your session has been preempted by another one.".
                       etoHTMoopsMbrMsg
                       (
                          $info_msg_map_mbr_oops_ary
                          [
                             $sys_script_id
                          ]
                       );
                    }
                    else
//                  no -  OTHER sesaion DOES NOT own the member row.
                    {
//                     seize ownership of the member row for THIS session.
                       etoSeizeMbrRow($ac+Y8a+Xk+X2);
                    }
                 }
                 else
//               no - obteined UNexpected session code.
                 {
               	   $sys_exit_msg = '(' . etoSQLformatDiag() . ')';
               
               	   etoAbendSubCode($ac, 1); // Abend $ac + 1 -- ($tmp_session_www_code == $member_session_code) == false.
               
                     $return_val = false;
                 }
               }
               else
//             no -- NO row(s) available.
               {
//                NOT Abending?
                  if (!$sys_exit_code)
//                yes -- NOT abending.
                  {
//                   Did the query complete?
//                   if ($sql_errno == 0)       // true.
//                   if ($sql_state == '00000') // true(?).
//                   if ($sql_state_class == '02') // No data.
                     if
                     (
                        ($sql_state == '00000')
                        ||
                        ($sql_state_class == '02') // No data.
                     )
//                   yes -- query complete => missing key in table.
                     {
//                     seize ownership of the member row for THIS session.
                       etoSeizeMbrRow($ac+Y8a+Xk+X2+Y7);
                     }
                     else
//                   no -- query INcomplete.
                     {
                         $sys_exit_msg = '(' . etoSQLformatDiag() . ')';
               
               	       etoAbendSubCode($ac, 2); // Abend $ac + 2 -- Select failed on table eto_sql_tb_session_www (query INcomplete).
                     }
                  }
               }
            }
         }
         else
//       mo - NOT associated with a session.
         {
//          seize ownership of the member row for THIS session.
            etoSeizeMbrRow($ac+Y8a+Xk+X2+(2*Y7));
         }
      }             
      else
//    no -- MORE than one member row found.
      {
         $return_val = false;

         $sys_exit_msg = '(' . etoSQLformatDiag() . ')';
               
         etoAbendSubCode($ac, 3); // Abend $ac + 3 -- MORE than one member row found in table eto_sql_tb_club_member.
      } 
   }
// no -- NO member row(s) found.
   else
   {
      $return_val = false;

      $sys_exit_msg = '(' . etoSQLformatDiag() . ')';
               
      etoAbendSubCode($ac, 4); // Abend $ac + 4 -- NO member row(s) found in table eto_sql_tb_club_member.
   }

   return ($return_val);
}

function getMemberExpiryUtc($dt) // member row init dtime (date/time in ISO 'yyyy-mm-dd hh:mm:ss' format).
{
   global $crn_dtime_utc;

// ===================================================================================================
//
//                          EXPIRY YEAR MAPPING EXAMPLE
//                          ---------------------------
//
//        19470329 = anniversary date in initial year.
//        03/29    = annivesary month & day.
//        1948     = current year.
//        19480329 = anniversary date in current year.
//        X        = expiry date (19490329 / 19500329)
//
//    current date range                    expiry date
//   ---------------------              ------------------
//
//   (19480101...19480329) -----------> X = 19490329
//                                      |
//   (19480401...19481231) ----------------------------> X = 19500329
//                                      |                |
//      anniversary date                |                |
//       in current year                |                |
//                     |                |                |
//                     |                |                |
// |______1947______|__|___1948______|__|___1949______|__|___1950______|
//                     |                |                |
//                     |                |                |
//    |________________|________________|________________|________________|
//  03/29            03/29            03/29            03/29            03/29
//    |                |                |                |
//    annivesary       |                |                |
//    month & day      |                |                |
//                     |                |                |
//    (...............aa)-------------->X = 1948 + 1     |
//                    |                     |            |
//                    |                     19490329     |
//                    |                                  |
//                    }(bbbbbbbbbbbbb....)-------------->X = 1948 + 2 
//                    |                                      |
//                    |   |                                  19500329
//                    |   |
//                    |   b = current date (19480401...19481231)  > 19480329 -- is AFTER         anniversary date in current year.
//                    |
//                    a     = current date (19480101...19480329) <= 19480329 -- is PRIOR TO / ON anniversary date in current year.
//
// ===================================================================================================

   $tmp_crn_year_str   = etoDateYear($crn_dtime_utc);

   $tmp_init_month_str = etoDateMonth($dt);
   $tmp_init_day_str   =   etoDateDay($dt);

   $tmp_expiry_year_str
   =
   etoBumpYear
   (
//    year to bump.
      $tmp_crn_year_str,

//    years to add (1 or 2).
      (
         !etoAfterDate
         (
//          current date.
            $crn_dtime_utc,

//          renewal anniversary date in current year.
            etoBuildDate
            (
               $tmp_crn_year_str,

               $tmp_init_month_str,

               $tmp_init_day_str
            )
         )
         ? 1 // current date is prior to renewal anniversary date in current year.
         : 2 // current date is on / after renewal anniversary date in current year.
      )
   );

// is expiry year NOT a leap year?
   if (!etoIsLeapYear($tmp_expiry_year_str))
// yes -- expiry year NOT a leap year.
   {
//    is anniversary on a leap day?
      if
      (
         ($tmp_init_month_str == '02')
         &&
         ($tmp_init_day_str   == '29')
      )
//    yes -- anniversary on a leap day.
      {
//       advance one day to a (the equivalent) non-leap day (1. prevent erroneous expiry date, 2. advancing maintains correct expiry time span).
         $tmp_init_month_str = '03';
         $tmp_init_day_str   = '01';
      }
   }

   return
   (
      etoBuildDate
      (
         $tmp_expiry_year_str,

         $tmp_init_month_str,

         $tmp_init_day_str
      )
   );
}

function checkMemberExpiry()
{
   global $member_status;
   global $club_member_expiry_utc;

   global $crn_dtime_utc;

   return
   (
//    has membership expired?
      (
         (
            ($member_status == ROW_STATE_ACTIVE)
            ||
            ($member_status == ROW_STATE_PAUSED)
         )
         &&
         ($club_member_expiry_utc <= $crn_dtime_utc)
      )
      ? true   // yes - membership has expired.
      : false  // no - membership has NOT expired.
   );
}

// Make 5 attempts to generate verify code (not == VER_CODE_DEFAULT) ...
function genVerCode()
{
   global $ver_code;

   $ver_code = "";

   // ETO verify font pool -- array of 34 eto font symbols used in verify code
   //  (excludes "0" (zero) and "O" (oh))
   //  (eto font supplies only digits and uc letter symbols).
   //  ( key => symbol mapping patterns are purposely obscurant)
  $ver_syms = array
               (  1 => "9", 2 => "8", 3 => "7", 4 => "6", 5 => "5",
                  6 => "4", 7 => "3", 8 => "2", 9 => "1",

                   0 => "A", 10 => "F", 11 => "K", 12 => "Q", 13 => "V",
                  14 => "B", 15 => "G", 16 => "L", 17 => "R", 18 => "W",
                  19 => "C", 20 => "H", 21 => "M", 22 => "S", 23 => "X",
                  24 => "D", 25 => "I", 26 => "N", 27 => "T", 28 => "Y",
                  29 => "E", 30 => "J", 31 => "P", 32 => "U", 33 => "Z" );

   for ($i=0; $i<5; ++$i)
   {
   // Pick chars at random from the eto verify font pool.
      for	($i =	0;	$i	< VER_CODE_SIZE;	$i++){
      $j =	mt_rand(0, 33);
      $ver_code = ($ver_code . $ver_syms[$j]);
      }
//    Test abend XIT_20.
//    $ver_code = VER_CODE_COMPLETE;

      if
      (
         ($ver_code != VER_CODE_NULL)
         &&
         ($ver_code != VER_CODE_COMPLETE)
         &&
         ($ver_code != VER_CODE_EXPIRED)
         &&
         ($ver_code != VER_CODE_ABENDED)
      )
      {
      	break;
      }
      else
      {
      	$ver_code = '';
      }
   }

   return(($ver_code == '') ? (false) :  (true));
}

function getVerCode($ac, $xo = ABEND_EXIT, $ro = ABEND_ROLLBACK) // abend code, abend exit option, abend SQL rollback option.
// function getVerCode()
{
  global $session_www_state;
  global $session_verify_code;

	global $ver_code;

	global $sys_exit_code; // $ac mapping: ($ac+0) ... ($ac+0) => 1 slot.

	$return_val = true;

// Abending?
  if ($sys_exit_code)
// yes -- abending.
  {
     $ver_code = etoVerCodeAbend();

     $return_val = false;
  }
  else
// no -- NOT abending.
  {
     switch ($session_www_state)
     {
        case ROW_STATE_NULL:           {$ver_code = VER_CODE_NULL;        break;}

        case ROW_STATE_LOGIN:          {$ver_code = $session_verify_code; break;}
        case ROW_STATE_PASSWORD:       {$ver_code = $session_verify_code; break;}
        case ROW_STATE_EMAIL_LOGIN:    {$ver_code = $session_verify_code; break;}
        case ROW_STATE_EMAIL_PASSWORD: {$ver_code = $session_verify_code; break;}
        case ROW_STATE_ACTIVE:         {$ver_code = $session_verify_code; break;}
        case ROW_STATE_INFO:           {$ver_code = $session_verify_code; break;}

        case ROW_STATE_COMPLETE:       {$ver_code = VER_CODE_COMPLETE;    break;}

        case ROW_STATE_EXPIRED:        {$ver_code = VER_CODE_EXPIRED;     break;}

        case ROW_STATE_ABENDED:        {$ver_code = VER_CODE_ABENDED;     break;}

        default:
        {
           $sys_exit_msg = '(' . "INvalid \$session_www_state value <" . "$session_www_state" . '> in row buffer of table eto_sql_tb_session_www.' . ')';

           etoAbend($ac, $xo, $ro); // Abend $ac -- INvalid $session_www_state value in row buffer of table eto_sql_tb_session_www.

           $ver_code = etoVerCodeAbend();

           $return_val = false;

           break;
        }
     }
  }

   return($return_val);
}

function etoHTMsetClubMemberFormButtons()
{
   global $member_status;
// global $visitor_member_state;

   global $htm_submit_buttons_ary;

   $htm_submit_buttons_ary = array(0 => array(), 1 => array(), 2 => array());

// Generate submit button name groups ...

   if ($member_status == ROW_STATE_REVOKED)
// if ($visitor_member_state == ROW_STATE_REVOKED)
//  yes - visitor membership is REVOKED.
   {
      $htm_submit_buttons_ary[2][0] = QUIT_FORM_SUBMIT;
   }
   else
   {
     $htm_submit_buttons_ary[1][0] = CHECK_FORM_SUBMIT;
     $htm_submit_buttons_ary[1][1] = RESET_FORM_SUBMIT;
 
//   Is visitor NOT a Club ETO member?
     if ($member_status == ROW_STATE_NULL)
//   if ($visitor_member_state == ROW_STATE_NULL)
//   yes -  visitor is NOT a Club ETO member?
     {
        $htm_submit_buttons_ary[0][0] = JOIN_CLUB_SUBMIT;

        $htm_submit_buttons_ary[2][0] = QUIT_FORM_SUBMIT;
     }
     else
     {
        $htm_submit_buttons_ary[0][0] = UPDATE_CLUB_SUBMIT;
        $htm_submit_buttons_ary[0][1] = ($member_status == ROW_STATE_PAUSED)   ? UNPAUSE_CLUB_SUBMIT  : PAUSE_CLUB_SUBMIT;
//      $htm_submit_buttons_ary[0][1] = ($visitor_member_state == ROW_STATE_PAUSED)   ? UNPAUSE_CLUB_SUBMIT  : PAUSE_CLUB_SUBMIT;
        $htm_submit_buttons_ary[0][2] = ($member_status == ROW_STATE_RESIGNED) ? UNRESIGN_CLUB_SUBMIT : RESIGN_CLUB_SUBMIT;
//      $htm_submit_buttons_ary[0][2] = ($visitor_member_state == ROW_STATE_RESIGNED) ? UNRESIGN_CLUB_SUBMIT : RESIGN_CLUB_SUBMIT;

        $htm_submit_buttons_ary[2][0] = LOGOUT_SUBMIT;
        $htm_submit_buttons_ary[2][1] = CLUB_MENU_SUBMIT;
     }
   }

// ... Generate submit button groups.

     etoHTMgenFormButtons();
//   etoHTMgenClubMemberFormButtons();

   return;
}

function etoHTMsetClubMenuFormButtons()
{
   global $member_status;
// global $visitor_member_state;

   global $htm_submit_buttons_ary;

   $htm_submit_buttons_ary = array(0 => array(), 1 => array());

   if ($member_status == ROW_STATE_REVOKED)
// if ($visitor_member_state == ROW_STATE_REVOKED)
//  yes - visitor membership is REVOKED.
   {
      $htm_submit_buttons_ary[0][0] = CLUB_MEMBER_FORM_SUBMIT;

      $htm_submit_buttons_ary[1][0] = QUIT_FORM_SUBMIT;
   }
   else
   {
      $htm_submit_buttons_ary[0][0] = CLUB_STATS_SUBMIT;
      $htm_submit_buttons_ary[0][1] = CLUB_MEMBER_FORM_SUBMIT;

      $htm_submit_buttons_ary[1][0] = CHANGE_CLUB_PASSWORD_SUBMIT;
      $htm_submit_buttons_ary[1][1] = LOGOUT_SUBMIT;
   }

   etoHTMgenFormButtons();

   return;
}

function etoHTMsetPasswordFormButtons()
{
   global $htm_submit_buttons_ary;

   $htm_submit_buttons_ary = array(0 => array(), 1 => array());

   $htm_submit_buttons_ary[0][0] = CHANGE_CLUB_PASSWORD_SUBMIT;

   $htm_submit_buttons_ary[1][0] = CLUB_MENU_SUBMIT;
   $htm_submit_buttons_ary[1][1] = LOGOUT_SUBMIT;

   return;
}

function etoHTMsetContactFormButtons()
{
   global $htm_submit_buttons_ary;

   $htm_submit_buttons_ary = array(0 => array(), 1 => array(), 2 => array());

   $htm_submit_buttons_ary[0][0] = SEND_MESSAGE_SUBMIT;

   $htm_submit_buttons_ary[1][0] = CHECK_FORM_SUBMIT;
   $htm_submit_buttons_ary[1][1] = RESET_FORM_SUBMIT;

   $htm_submit_buttons_ary[2][0] = QUIT_FORM_SUBMIT;

   etoHTMgenFormButtons();

   return;
}

function etoHTMgenFormButtons()
// function etoHTMgenClubMemberFormButtons()
{
   global $htm_submit_button_val_ary;
   global $htm_submit_buttons_ary;
   global $submit_button_groups;

   $tmp_open_centered_menu
   =
   array
   (
      0 => '<div id="centeredmenu">',
      1 => '   <ul>'
   );

   $tmp_close_centered_menu
   =
   array
   (
      0 => '   </ul>',
      1 => '</div>'
   );

   $submit_button_groups = '';

   foreach ($htm_submit_buttons_ary as $button_group_ndx => $button_group_ary)
   {
      if (count($button_group_ary))
      {
         appendButtonHTML_ary($tmp_open_centered_menu);

         foreach ($button_group_ary as $button_ndx => $button_name)
         {
            appendButtonHTML_lin
            (
               '      <li> <input type="submit" name="'
                .
                $button_name
                .
                '" value="'
                .
                $htm_submit_button_val_ary[$button_name]
                .
                '" /> </li>'
             );
         }

         appendButtonHTML_ary($tmp_close_centered_menu);
      }
   }

// trim leading spaces from first line.
   $submit_button_groups
   =
   substr
   (
      $submit_button_groups,
      strlen(HTM_SUBMIT_BUTTON_LINE_FILL)
   );

// trim trailing newline from last line.
   $submit_button_groups
   =
   substr
   (
      $submit_button_groups,
      0,
      (strlen($submit_button_groups) - 1)
   );

   return;
}

function appendButtonHTML_lin($h) // HTML line.
{
   global $submit_button_groups;

   $submit_button_groups
   .=
   (
      HTM_SUBMIT_BUTTON_LINE_FILL
      .
      $h
      .
      "\n"
   );

   return;
}

function appendButtonHTML_ary($a) // array of HTML lines.
{
   foreach ($a as $i => $value)
   {
/*
// Testing ...

  $tst_diag = '';
  $tst_diag .= ( '##appendButtonHTML_ary(#1)##  ' );

  $tst_diag .= ( '**$i<' . $i . '>**  ' );
  $tst_diag .= ( '**$value<' . $value . '>**  ' );

  echo htmlspecialchars($tst_diag, ENT_QUOTES);

// ... Testing.
*/

      appendButtonHTML_lin($value);
   }

   return;
}

function etoHTMdisplayPage($fn) // page source file name.
{
// php module?
   if (substr($fn, (strlen($fn) - 3)) == 'php')
// yes - php (it MUST supply all its own global variables).
   {
      require "../eto_php/$fn";
   }
// no - NOT php (assume htm).
   else
   {
      echo file_get_contents("../eto/$fn");
   }

   return;
}

function etoHTMdisplayPageHttp($fn) // page source file name.
{
// html header redirects browser to page using http.
   header('Content-type: text/html');
   header('Location: http://' . ETO_WWW_DOMAIN_NAME . '/' . "$fn");

   return;
}

// translate a URI hfvalue coded in IS0-9959-1 character set => XSS-Safe format.
function etoHTMhfvalXssSafe($s) // uri string.
// function etoHTMhfvalXssSafe(&$s) // uri string.
{
//
// Mapping of character in &$s to URI character.
//
//
// ---------------------------------------------------       -----------------------------------------
//                        ISO-8849-1 character coding             etoHTMhfvalXssSafe((&s) mapping 
// --------------------  -----------------------------       -----------------------------------------
//     character                                                           percent   cr-lf     utf-8
//    english name             name  dec      bin      hex    strip  pass  -encode  %-encode  %-encode
// --------------------------  ----- ---  ----- ----  ------  -----  ----  -------  --------  --------
//  null                       NUL    0   0000 0000  "\x00"     Y
//                                                              -     -       -        -         -
//  start of header            SOH    1   0000 0001  "\x01"     Y
//  start of text              STX    2   0000 0010  "\x02"     Y
//  end of text                ETX    3   0000 0011  "\x03"     Y
//  end of transmission        EOT    4   0000 0100  "\x04"     Y
//  enquiry                    ENQ    5   0000 0101  "\x05"     Y
//  acknowledgement            ACK    6   0000 0110  "\x06"     Y
//                                                              -     -       -        -         -
//  bell                       BEL    7   0000 0111  "\x07"     Y
//                                                              -     -       -        -         -
//  backspace                  BS     8   0000 1000  "\x08"     Y
//  horizontal tab             TAB    9   0000 1001  "\x09"                   Y
//  line feed, new line        LF    10   0000 1010  "\x0A"                            Y
//  vettical tab               VT    11   0000 1011  "\x0B"     Y
//  form feed                  FF    12   0000 1100  "\x0C"     Y
//  carriage return            CR    13   0000 1101  "\x0D"                            Y
//                                                              -     -       -        -         -
//  shift out                  SO    14   0000 1110  "\x0E"     Y
//  shift in                   SI    15   0000 1111  "\x0F"     Y
//  data link escape           DLE   16   0001 0000  "\x10"     Y
//  device control 1           DC1   17   0001 0001  "\x11"     Y
//  device control 2           DC2   18   0001 0010  "\x12"     Y
//  device control 3           DC3   19   0001 0011  "\x13"     Y
//  device control 4           DC4   20   0001 0100  "\x14"     Y
//  negative acknowledge       NAK   21   0001 0101  "\x15"     Y
//  synchronous idle           SYN   22   0001 0110  "\x16"     Y
//  end of transmission block  ETB   23   0001 0111  "\x17"     Y
//  cancel                     CAN   24   0001 1000  "\x18"     Y
//  end of medium              EM    25   0001 1001  "\x19"     Y
//  substitute                 SUB   26   0001 1010  "\x1A"     Y
//  escape                     ESC   27   0001 1011  "\x1B"     Y
//                                                              -     -       -        -         -
//  file separator             FS    28   0001 1100  "\x1C"     Y
//  group separator            GS    29   0000 1101  "\x1D"     Y
//  record separator           RS    30   0001 1110  "\x1E"     Y
//  unit separator             US    31   0001 1111  "\x1F"     Y
//                                                              -     -       -        -         -
//  space                      SP    32   0010 0000  "\x20"                   Y
//                                                              -     -       -        -         -
//  exclamation                !     33   0010 0001  "\x21"           Y
//  double quote               "     34   0010 0010  "\x22"                   Y
//  octothorpe                 #     35   0010 0011  "\x23"                   Y
//  dollar sign                $     36   0010 0100  "\x24"                   Y
//  percent sign               %     37   0010 0101  "\x25"                   Y
//  ampersand                  &     38   0010 0110  "\x26"                   Y
//  single quote               '     39   0010 0111  "\x27"           Y
//                                                              -     -       -        -         -
//  left parenthesis           (     40   0010 1000  "\x28"           Y
//  right parenthesis          )     41   0010 1001  "\x29"           Y
//                                                              -     -       -        -         -
//  asterisk                   *     42   0010 1010  "\x2A"           Y
//  plus sign                  +     43   0010 1011  "\x2B"                   Y
//  comma                      ,     44   0010 1100  "\x2C"                   Y
//  hyphen                     -     45   0010 1101  "\x2D"           Y
//  dot                        .     46   0010 1110  "\x2E"           Y
//  forward slash              /     47   0010 1111  "\x2F"                   Y
//                                                              -     -       -        -         -
//  digit zero                 0     48   0011 0000  "\x30"           Y
//                             *     *    *    *     *                Y
//  digit nine                 9     57   0011 1001  "\x39"           Y
//                                                              -     -       -        -         -
//  colon                      :     58   0011 1010  "\x3A"                   Y
//  semicolon                  ;     59   0011 1011  "\x3B"                   Y
//  less than                  <     60   0011 1100  "\x3C"                   Y
//  equal sign                 =     61   0011 1101  "\x3D"                   Y
//  greater than               >     62   0011 1110  "\x3E"                   Y
//  question mark              ?     63   0011 1111  "\x3F"                   Y
//  at sign                    @     64   0100 0000  "\x40"                   Y
//                                                              -     -       -        -         -
//  appercase letter a         A     65   0100 0001  "\x41"           Y
//  *                          *     *    *    *     *                Y
//  appercase letter z         Z     90   0101 1010  "\x5A"           Y
//                                                              -     -       -        -         -
//  left bracket               [     91   0101 1011  "\x5B"                   Y
//  backslash                  \     92   0101 1100  "\x5C"                   Y
//  right bracket              ]     93   0101 1101  "\x5D"                   Y
//  caret                      ^     94   0101 1110  "\x5E"                   Y
//  underscore                 _     95   0101 1111  "\x5F"           Y
//  back quote                 `     96   0110 0000  "\x60"                   Y
//                                                              -     -       -        -         -
//  lowercase letter a         a     97   0110 0001  "\x61"           Y
//  *                          *     *    *    *     *                Y
//  lowercase letter z         z     122  0111 1010  "\x7A"           Y
//                                                              -     -       -        -         -
//  left brace                 {     123  0111 1011  "\x7B"                   Y
//  vertical bar               |     124  0111 1100  "\x7C"                   Y
//  right brace                }     125  0111 1101  "\x7D"                   Y
//  tilde                      ~     126  0111 1110  "\x7E"           Y
//  delete                     DEL   127  0111 1111  "\x7F"     Y
//                                                              -     -       -        -         -
//  UNDEF                            128  1000 0000  "\x80"     Y
//  *                                *    *    *     *          Y
//  UNDEF                            159  1001 1111  "\x9F"     Y
//                                                              -     -       -        -         -
//  XTEND                            160  1010 0000  "\xA0"                                      Y
//  *                                *    *    *     *                                           Y
//  XTEND                            255  1111 1111  "\xFF"                                      Y
// ---------------------------------------------------------------------------------------------------
// ---------------------------------------------------------------------------------------------------
//

//
//  References:
//
// See <shadow2531.com -- mailto_uri_scheme_idea - 20120925.html> in <J:\U S R\A S P\I T S\ITS-ETO Consortium\www.ITS-ETO.com\_XHTML CSS\_web pages\>
//
//   -- strip out all:         "\x00...\x08", "\x0B...\x0C", "\x0E...\x1F" (unsafe)
//
//   -- replace:               "\x0D" NOT followed immediately by "\0A" with "\x0D\x0A"
//   -- replace:               "\x0A"  "  preceded     "       by "\0D" with "\x0D\x0A"
//
//   -- DO NOT percent-encode: "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789-_.!~*'()"
//   -- DO percent-encode:     "... EVERYTHING ELSE ..."
//
//
// @@@need a comprehensive list of the ASCII characters to be percent-encoded.
//
//
// apply the shadow2531.com rules to pure ASCII "\x00"..."\x1F" (0 ... 127).
//
// for non-ASCII "\x20"..."\xFF" (128 ... 255):
//
//    first -- UTF-8 encode the ISO-8859-1 character,
//     then -- percent-encode the hex byte values in the UTF-8 encoding string.
//
// 
// ---------
// 
// RFC6068 "The 'mailto' URI Scheme"
// 
//       hfvalue      = *qchar
// 
//       qchar        = unreserved / pct-encoded / some-delims
// 
// some-delims  = "!" / "$" / "'" / "(" / ")" / "*"
//                    / "+" / "," / ";" / ":" / "@"
// 
// ...
// 
//    Non-ASCII characters can be encoded in <hfvalue> as follows:
// 
//    1.  MIME encoded words (as defined in [RFC2047]) are permitted in
//        header field values, but not in an <hfvalue> of a "body"
//        <hfname>.  Sequences of characters that look like MIME encoded
//        words can appear in an <hfvalue> of a "body" <hfname>, but in
//        that case have no special meaning.  Please note that the '=' and
//        '?' characters used as delimiters in MIME encoded words have to
//        be percent-encoded.  Also note that the use of MIME encoded words
//        differs slightly for so-called structured and unstructured header
//        fields.
// 
//    2.  Non-ASCII characters can be encoded according to UTF-8 [STD63],
//        and then each octet of the corresponding UTF-8 sequence is
//        percent-encoded to be represented as URI characters.  When header
//        field values encoded in this way are used to compose a message,
//        the <hfvalue> has to be suitably encoded (transformed into MIME
//        encoded words [RFC2047]), except for an <hfvalue> of a "body"
//        <hfname>, which has to be encoded according to [RFC2045].  Please
//        note that for MIME encoded words and for bodies in composed email
//        messages, encodings other than UTF-8 MAY be used as long as the
//        characters are properly transcoded.
// 
// ---------
// 
// RFC3986 "Uniform Resource Identifier (URI): Generic Syntax"
// 
// reserved    = gen-delims / sub-delims
// 
//       gen-delims  = ":" / "/" / "?" / "#" / "[" / "]" / "@"
// 
//       sub-delims  = "!" / "$" / "&" / "'" / "(" / ")"
//                   / "*" / "+" / "," / ";" / "="
// 
// ...
// 
// unreserved  = ALPHA / DIGIT / "-" / "." / "_" / "~"

//
// ** EXECUTABLE CODE BEGINS HERE **
//

   $tmp_uri_safe_str = '';

   $tmp_strlen = strlen($s);

   for ($i = 0; $i < $tmp_strlen; ++$i)
   {
      $s_chr = $s[$i];      // get the character as a 1-character string         ==> string is 1-byte long (byte is one 8-bit octet bbbbbbbb = 00000000 ... 11111111).
      $s_ord = ord($s_chr); // get the integer (decimal) value of the character  ==> 8-bit octet bbbbbbbb treated as an 8-bit unsigned binary number  ==>  converted to decimal integer = 0 ... 255.

//                                --------------------------------------------
//                                -   numeric range        characters    map -
//                                -----------------------  -----------  ------
      if      ($s_ord <   0) /*    -ve ...  -1.             UNDEF       strip */ { $tmp_uri_safe_str .=       ''; }
      else if ($s_ord <   9) /*   "\x00...\x08" (0...8).    NUL ... BS  strip */ { $tmp_uri_safe_str .=       ''; }
      else if ($s_ord <  10) /*   "\x09.        (9).        TAB         %     */ { $tmp_uri_safe_str .= ('%'. strtoupper(str_pad(dechex($s_ord), 2, '0', STR_PAD_LEFT))); }
      else if ($s_ord <  11) /*   "\x0A.        (10).       LF          cr-lf */ { if ($i > 0)                 { if ($s[$i-1] == "\x0D") { $tmp_uri_safe_str .= "%0A"; } else { $tmp_uri_safe_str .= "%0D%0A"; } } else { $tmp_uri_safe_str .= "%0D%0A"; } }
      else if ($s_ord <  13) /*   "\x0B...\x0C" (11...12).  VT  ... FF  strip */ { $tmp_uri_safe_str .=       ''; }
      else if ($s_ord <  14) /*   "\x0D"        (13).       CR          cr-lf */ { if ($i < ($tmp_strlen - 1)) { if ($s[$i+1] == "\x0A") { $tmp_uri_safe_str .= "%0D"; } else { $tmp_uri_safe_str .= "%0D%0A"; } } else { $tmp_uri_safe_str .= "%0D%0A"; } }
      else if ($s_ord <  32) /*   "\x0E...\x1F" (14...31).  SO  ... US  strip */ { $tmp_uri_safe_str .=       ''; }
      else if ($s_ord <  33) /*   "\x20"        (32).       SP          %     */ { $tmp_uri_safe_str .= ('%'. strtoupper(dechex($s_ord))); }
      else if ($s_ord <  34) /*   "\x21"        (33).       !           pass  */ { $tmp_uri_safe_str .=       $s_chr; }
      else if ($s_ord <  39) /*   "\x22...\x26" (34...38).  "#$%&       %     */ { $tmp_uri_safe_str .= ('%'. strtoupper(dechex($s_ord))); }
      else if ($s_ord <  43) /*   "\x27...\x2A" (39...42).  '()*        pass  */ { $tmp_uri_safe_str .=       $s_chr; }
      else if ($s_ord <  45) /*   "\x2B...\x2C" (43...44).  +,          %     */ { $tmp_uri_safe_str .= ('%'. strtoupper(dechex($s_ord))); }
      else if ($s_ord <  47) /*   "\x2D...\x2E" (45...46).  -.          pass  */ { $tmp_uri_safe_str .=       $s_chr; }
      else if ($s_ord <  48) /*   "\x2F"        (47).       /           %     */ { $tmp_uri_safe_str .= ('%'. strtoupper(dechex($s_ord))); }
      else if ($s_ord <  58) /*   "\x30...\x39" (48...57).  0   ... 9   pass  */ { $tmp_uri_safe_str .=       $s_chr; }
      else if ($s_ord <  65) /*   "\x3A...\x40" (58...64).  :;<=>?@     %     */ { $tmp_uri_safe_str .= ('%'. strtoupper(dechex($s_ord))); }
      else if ($s_ord <  91) /*   "\x41...\x5A" (65...90).  A   ... Z   pass  */ { $tmp_uri_safe_str .=       $s_chr; }
      else if ($s_ord <  95) /*   "\x5B...\x5E" (91...94).  [\]^        %     */ { $tmp_uri_safe_str .= ('%'. strtoupper(dechex($s_ord))); }
      else if ($s_ord <  96) /*   "\x5F"        (95).       _           pass  */ { $tmp_uri_safe_str .=       $s_chr; }
      else if ($s_ord <  97) /*   "\x60"        (96).       `           %     */ { $tmp_uri_safe_str .= ('%'. strtoupper(dechex($s_ord))); }
      else if ($s_ord < 123) /*   "\x61...\x7A" (97...122). a   ... z   pass  */ { $tmp_uri_safe_str .=       $s_chr; }
      else if ($s_ord < 126) /*   "\x7B...\x7D" (123...125) {|}         %     */ { $tmp_uri_safe_str .= ('%'. strtoupper(dechex($s_ord))); }
      else if ($s_ord < 127) /*   "\x7E"        (126).      ~           pass  */ { $tmp_uri_safe_str .=       $s_chr; }
      else if ($s_ord < 128) /*   "\x7F"        (127).      DEL         strip */ { $tmp_uri_safe_str .=       ''; }
      else if ($s_ord < 160) /*   "\x80...\x9F" (128...159) UNDEF       strip */ { $tmp_uri_safe_str .=       ''; }
      else if ($s_ord < 256) /*   "\xA0...\xFF" (160...255) XTEND       %     */ { $tmp_uri_safe_str .= ('%'. strtoupper(dechex($s_ord))); }
//    else if ($s_ord < 256) /*   "\xA0...\xFF" (160...255) XTEND       utf-8 */ { $tmp_utf8_str = utf8_encode($s_chr); for ($j = 0; $j < strlen($tmp_utf8_str); ++$j) { $tmp_uri_safe_str .= ('%'. strtoupper(dechex(ord($tmp_utf8_str[$j])))); } }
      else                   /*    >255.                    UNDEF       strip */ { $tmp_uri_safe_str .=       ''; }
   }

   return $tmp_uri_safe_str;
}

// create mailto link.
function etoHTMgenMailtoUri($es, $eb, $sf = '', $sl = '') // email subject, email body, sig first name, sig last name.
{
//      *** NOTE ***
//
// Using hard-coded examples of email addresses ONLY,
//    need to encode special characters e.g. @@@
//    to safely include externally-supplied email addresses
//    e.g. $member_email_addr for using in a mailto: construct.
//
// See sections 6.1, 6.2 in <tools.ietf.org -- The _mailto_ URI Scheme - rfc6068 - 20121231.htm>.
//

//
// See section 6.3. Examples Using UTF-8-Based Percent-Encoding:
//
//    Using explicit indication of  ISO-8859-1 encoding for:
//
//       subject=
//

   return
   (
      '<a ' .
      (
         'href=' .
         
         '"mailto:' .
         'afriend@example.com,anotherfriend@example.com' . 
         
         '?cc=' .
         'accfriend@example.com,anotherccfriend@example.com' .
         
         '&amp;subject=' .
//       '%3D%3Futf-8%3FQ%3F' . // '=?utf-8?Q?'
//       '%3D%3Fiso-8859-1%3FQ%3F' . // '=?iso-8859-1?Q?'
         
         etoHTMhfvalXssSafe('ITS-ETO -' . ((substr($es, 0, 1) != ' ') ? ' ' : '') . "$es") .
         
//       '%3F%3D' . // '?='
         
         '&amp;body=' .
         
         etoHTMhfvalXssSafe("$eb" . "\n\n") .

// test insertion of double quotes to inject dangerous code.
//    etoHTMhfvalXssSafe('"' . '**injected**' . '"' . "$eb" . "\n\n") .

// test ISO-8859-1 extended translation.
// "\xA2" (cents sign), "\xA2" (UK pound sign), "\xFF" (Y with 2 dots on top).
//    etoHTMhfvalXssSafe("\xA2\xA3\xFF" . "\n\n" . "$eb" . "\n\n") .

         etoHTMhfvalXssSafe
         (
            "$sf"
            .
            (
               ($sf != '')
               ?
               ' '
               :
               ''
            )
            .
            "$sl"
         ) .
         '" '
      ) .
      (
         'title=' .
         
         '"mailto:' .
         'afriend@example.com,anotherfriend@example.com' . 
         
         '?cc=' .
         'accfriend@example.com,anotherccfriend@example.com' .
         
         '&amp;subject=' .
//       '%3D%3Futf-8%3FQ%3F' . // '=?utf-8?Q?'
//       '%3D%3Fiso-8859-1%3FQ%3F' . // '=?iso-8859-1?Q?'
         
         ('ITS-ETO -' . ((substr($es, 0, 1) != ' ') ? ' ' : '') . "$es")
//       etoHTMhfvalXssSafe('ITS-ETO -' . ((substr($es, 0, 1) != ' ') ? ' ' : '') . "$es")
      ) .
      '" >' .

      'Create Email' .

      '</a>'
   );
}

/* obsolete ...

// escape binary (i.e. non-graphic) char values for debug HTML display.
function encodeUriChars($ms) // href string.
{
  return
  (
      str_replace
      (
         array( 0 => ' ',     1 => "\n"     ),
         array( 0 => '%20',   1 => '%0D%0A' ),

         $ms
       )
   );
}

// create mailto link.
function etoHTMgenMailtoUri($es, $eb, $sf = '', $sl = '') // email subject, email body, sig first name, sig last name.
{
//      *** NOTE ***
//
// Using hard-coded examples of email addresses ONLY,
//    need to encode special characters e.g. @@@
//    to safely include externally-supplied email addresses
//    e.g. $member_email_addr for using in a mailto: construct.
//
// See sections 6.1, 6.2 in <tools.ietf.org -- The _mailto_ URI Scheme - rfc6068 - 20121231.htm>.
//

   return
   (
      '<a href=' .

      '"mailto:' .
      'afriend@example.com,anotherfriend@example.com' . 

      '?cc=' .
      'accfriend@example.com,anotherccfriend@example.com' .

      '&amp;subject=' .
      encodeUriChars('ITS-ETO -' . ((substr($es, 0, 1) != ' ') ? ' ' : '') . "$es") . 

      '&amp;body=' .
      encodeUriChars("$eb" . "\n\n") .

      encodeUriChars
      (
         "$sf"
         .
         (
            ($sf != '')
            ?
            ' '
            :
            ''
         )
         .
         "$sl"
      ) .

      '" >' .

      'Create Email' .

      '</a>'
   );
}
... obsolete */

// create email login html link.
function etoHTMgenEmailloginUrl($k1, $k3, $k4) // visitor_key_1, visitor_key_3, visitor_key_4.
{
   return
   (
      'https://' . ETO_WWW_DOMAIN_NAME .
//    'http://' . ETO_WWW_DOMAIN_NAME .
      '/'       . 'eto_session_act_4a.php' .
      '?'       . VISITOR_KEY_1_HTM_TAG . "=$k1" .
      '&'       . VISITOR_KEY_3_HTM_TAG . "=$k3" .
      '&'       . VISITOR_KEY_4_HTM_TAG . "=$k4"
//    '?'       . "visitor_key_1=$k1" .
//    '&'       . "visitor_key_3=$k3" .
//    '&'       . "visitor_key_4=$k4"
   );
}

function etoReleaseMbrRow($ac) // abend code.
// function etoRlsMbrRow($ac) // abend code.
{
//
//   *** IMPORTANT NOTE ***
//
// It is the RESPONSIBILITY of the caller
//  to ensure that the member row
//   has been READ and is in a state SUITABLE for a rewrite.
//

   global $ses_code;

   global $session_target_serno;

   global $club_member_serno;
   global $member_status;
   global $member_session_code;

// Abend code allocation ...
//  slots  function
//  -----  --------
//
//     0   etoReleaseMbrRow(...)           => this function.
//
//   137   etoSQLsetState_club_member(...) => called by this function.
//  -----
//   137
// ... Abend code allocation.

// global $sys_exit_code; // $ac mapping: (0+0) ... (0+136) => 137 slots.

/*
// Testing ...

  global $session_www_code;

  $tst_diag = '';
  $tst_diag .= ( '##etoReleaseMbrRow(#1)##  ' );

  $tst_diag .= ( '**$session_target_serno<' . $session_target_serno . '>**  ' );
  $tst_diag .= ( '**$club_member_serno<' . $club_member_serno . '>**  ' );

  $tst_diag .= ( '**SQL_NUL_ROW_SERNO<' . SQL_NUL_ROW_SERNO . '>**  ' );

  $tst_diag .= ( '**$ses_code<' . $ses_code . '>**  ' );
  $tst_diag .= ( '**$session_www_code<' . $session_www_code . '>**  ' );
  $tst_diag .= ( '**$member_session_code<' . $member_session_code . '>**  ' );

  echo htmlspecialchars($tst_diag, ENT_QUOTES);

// ... Testing.
*/

// does THIS session still own the member row?

// does the session row point to a club member row?
   if ($session_target_serno != SQL_NUL_ROW_SERNO)
// yes - the session row points to a club member row.
   {
//    has that member row been read?
      if ($club_member_serno == $session_target_serno)
//    yes - that member row has been read.
      {
//       does that member row's session code match THIS session code (is the member row is still owned by THIS session.).
         if ($member_session_code  == $ses_code)
//       yes - that member row's session code matches THIS session code.
         {
//          release THIS session's club member row ownership ...

            $member_session_code = '';

            etoSQLsetState_club_member($member_status, ac); // Abend ac+ -- etoSQLsetState_club_member() Failed.

//    ... release THIS session's club member row ownership.
         }
      }
   }

   return;
}

function etoLogout($ac) // abend code.
{
   global $session_target_serno;
   global $session_www_hit_count;

   global $club_member_serno;

// Abend code allocation ...
//  slots  function
//  -----  --------
//
//     0   etoLogout(...)                  => this function.
//
//   137   etoReleaseMbrRow(...)           => called by this function.
//   432   getMbrRow(...)                  => called by this function.
//   137   etoReleaseMbrRow(...)           => called by this function.
//   199   etoSQLsetState_session_www(...) => called by this function.
//  -----
//   905
// ... Abend code allocation.

// global $sys_exit_code; // $ac mapping: (0+0) ... (0+904) => 905 slots.

// does the session row point to a club member row?
   if ($session_target_serno !=  SQL_NUL_ROW_SERNO)
// yes - points to a club member row.
   {
//    has a member row been read?
      if ($club_member_serno != SQL_NUL_ROW_SERNO)
//    yes -- a member row has been read.
      {
         etoReleaseMbrRow($ac+Y0a);
      }
      else
//    no -- member row has NOT been read.
      {
//       member row (owned by this session) found?
         if (getMbrRow($session_target_serno, '', $ac+Y0a+Y9)) // Abend Y0a+$ac+Y9+ -- getMbrRow() Failed.
//       yes --member row (owned by this session) found
         {
            etoReleaseMbrRow($ac+Y0a+Y9+Y8);
         }
      }
   }

   $session_www_hit_count = 1;

// list of buttons expected.
   etoSQLgetNullTargGrp0_session_www();

   etoSQLsetState_session_www(ROW_STATE_COMPLETE, getSesExpireDeltaMins(ROW_STATE_COMPLETE), getSesDeleteDeltaMins(ROW_STATE_COMPLETE), $ac+Y0a+(2*Y9)+Y8);

   return;
}

function etoHTMsesHasExpiresGrp($xm = 0, $ct = true) // expiry minutes (int), "click to ...." message switch (bool).
// function etoHTMsesHasExpiresGrp($xm = 0) // expiry_minutes (int).
// function etoHTMsesHasExpires($fs = '', $xm = 0, $xu = 0, $hc = 0) // line left margin fill (string), expiry_minutes (int), expiry_utc (string), hits left count (int).
{
//
//    generate html for "Session Has: ... Expires: ..." group
//      on pages with session-active button(s).
//
//    logic modeled on (previous) hard-coded version in eto_info_ssi_2.php.
//

global $session_www_expiry_utc;
global $session_www_hit_count;

// the model html.
   $tmp_htm_has_expires_model
   =
   (
                           '<div style="text-align: center; font-style: italic;">' . "\n" .
//    HTM_PAGE_LINE_FILL . '<div style="text-align: center; font-style: italic;">' . "\n" .
      HTM_PAGE_LINE_FILL . '   <p>' . "\n" .
      HTM_PAGE_LINE_FILL . '      You Have: $session_www_hits_left button click' . (($session_www_hit_count != 1) ? 's' : '') . ' and ' . $xm . ' minute' . (($xm != 1) ? 's' : '') . '.<br />' . "\n" .
      HTM_PAGE_LINE_FILL . '      Session Expires: $session_www_expiry_utc UTC/GMT.<br />' .

      (($ct) ? ("\n" . HTM_PAGE_LINE_FILL . '      (button click relaxes expires time)<br /><br />' . "\n") : ('<br />' . "\n")) .
//    (($ct) ? ("\n" . HTM_PAGE_LINE_FILL . '      (click to advance expires time)<br /><br />' . "\n") : ('<br />' . "\n")) .


      HTM_PAGE_LINE_FILL . '   </p>' . "\n" .
      HTM_PAGE_LINE_FILL . '</div>'
   );

// generate has expires group.
   $tmp_has_expires_group = str_replace('SES_EXPIRY_MINS',          $xm,                     $tmp_htm_has_expires_model);
   $tmp_has_expires_group = str_replace("\$session_www_expiry_utc", $session_www_expiry_utc, $tmp_has_expires_group);
   $tmp_has_expires_group = str_replace("\$session_www_hits_left",  $session_www_hit_count,  $tmp_has_expires_group);

   return ($tmp_has_expires_group);
}

function etoHTMoopsMsg($mc, $ms0, $ms1 = '') // message code, message string 0, message string 1.
{
   global $submit_button_groups;

   global $visitor_info_code;
   global $visitor_info_msg;

   global $session_www_hit_count;

   $submit_button_groups = '';

/* not used ...
//
// put Club ETO Reception button & radio buttons on info page.
//
// html fragment copied from eto_club_eto_htm.ssp:
//   1. wrap lines in '...',
//   2. escape any embedded ',
//   3.'' => '\n\n',
//   4. comment out outer <div> ... </div> wrapper,
//   5. add <p>Are you a Club ETO member?</p> from 4.
//
   $tmp_radio_button_group
   =
   (
      str_replace
      (
         "\n",

         ("\n" . HTM_INFO_PAGE_LINE_FILL),

         (
            "\n" .
            
            '<div style="clear:left; float:left; margin-bottom:+1%; margin-bottom:+0%; #margin-top:-2%">' . "\n" .
            '   <p>Are you a Club ETO member?</p>' . "\n" .
            '</div>' . "\n" .
            
            '<div style="clear:left; float:left; margin-bottom:+2%;%;">' . "\n" .
            
            '  <div style="clear:left; float:left;">' . "\n" .
            '     <input type="radio" name="club_member_radio" value="member_y" checked="checked" />' . "\n" .
            '  </div>' . "\n" .
            
            '  <div style="clear:none; float:left;"><p>Yes&nbsp;&nbsp;</p></div>' . "\n" .
            
            '  <div style="clear:none; float:left;">' . "\n" .
            '     <input type="radio" name="club_member_radio" value="member_n" />' . "\n" .
            '  </div>' . "\n" .
            
            '  <div style="clear:none; float:left;"><p>No&nbsp;&nbsp;</p></div>' . "\n" .
            
            '  <div style="clear:none; float:left;">' . "\n" .
            '     <input type="radio" name="club_member_radio" value="member_dk" />' . "\n" .
            '  </div>' . "\n" .
            
            '   <div style="clear:right; float:left;"><p>Don\'t Know</p></div>' . "\n" .
            
            '</div>' . "\n" .
            
            '<div style="clear:left; float:left; margin-left:+10%; #margin-left:+2%; margin-top:+0%; #margin-top:+0%; margin-bottom:+1%; #margin-bottom:-1%;">' . "\n" .
            '  <input type="submit" name="club_reception_submit" value="Club ETO Reception" />' . "\n"
         ) .
           '</div>' . "\n"
      )
   );
... not used. */

 //suppress "Has: ... Expires: ..." lines on info form.
   $session_www_hit_count = -1;

// Serve incorrect action sequence information form.

   $visitor_info_code = $mc;

   $visitor_info_msg = '';

   $submit_button_groups
   =
   etoInfoMsg
   (
      'Oooops!!' . "\n\n" .

      "$ms0" .

      "$ms1" .

      'Or click the  Club ETO  www link above to start again.' . "\n\n\r"

/* not used ...
      'Or click the  Club ETO Reception  button below to start again.' . "\n\n\r" .

      $tmp_radio_button_group . "\6"
... not used. */
   );

   require '../eto_php/eto_info_ssi_2.php';

   return;
}

function etoHTMoopsSesMsg($mc) // message code.
{
   etoHTMoopsMsg
   (
      $mc,

      (
         "Did you use your web browser \"Back\" or \"Reload\" button?" . "\n\n" .

         "The browser \"Back\" and \"Reload\" buttons cannot be used with Club ETO web pages." . "\n\n"
      ),

      'Please use only the submit buttons provided on the main body of the most recent Club ETO web page you have.' . "\n\n"
   );

   return;
}

function etoHTMoopsMbrMsg($mc) // message code.
{
   etoHTMoopsMsg
   (
      $mc,

      "Your session has been preempted by another one." . "\n\n",

      'Please use the most recent Club ETO web page you have.' . "\n\n"

   );

   return;
}

function etoHTMoopsLnkMsg($mc) // message code.
{
   etoHTMoopsMsg
   (
      $mc,

      "It appears that you have used your web browser to activate a now-out-of-date www link, in an email the ETO website sent to you earlier." . "\n\n",

      "Please use the www link in the most recent email that was sent to you by the ETO website." . "\n\n"
   );

   return;
}

function etoHTMgetVisitorClubMemberSqlFields()
{
   global $visitor_pledge_1_polity;
   global $visitor_pledge_2_voice;
   global $visitor_pledge_3_age;

   global $visitor_member_number;
   global $visitor_member_state;
   global $visitor_first_name;
   global $visitor_last_name;
   global $visitor_email;
   global $visitor_ref_by_member;
   global $visitor_inf_by_advert;
   global $visitor_request_news_email;
   global $visitor_reserve_coop_spot;
   global $visitor_block_email_login;
   global $visitor_init_utc;
   global $visitor_last_utc;
   global $visitor_expiry_utc;
   global $visitor_notified_utc;

   global $club_member_serno;
   global $member_status;
   global $member_first_name;
   global $member_last_name;
   global $member_email_addr;
   global $member_ref_by_member;
   global $member_inf_by_advert;
   global $member_reserve_coop_spot;
   global $member_request_news_email;
   global $member_block_email_login;
   global $club_member_init_utc;
   global $club_member_last_utc;
   global $club_member_expiry_utc;
   global $club_member_notified_utc;

   $visitor_pledge_1_polity    = false;
   $visitor_pledge_2_voice     = false;
   $visitor_pledge_3_age       = false;

   $visitor_member_number      = $club_member_serno;
   $visitor_member_state       = $member_status;
   $visitor_first_name         = $member_first_name;
   $visitor_last_name          = $member_last_name;
   $visitor_email              = $member_email_addr;
   $visitor_ref_by_member      = $member_ref_by_member;
   $visitor_inf_by_advert      = $member_inf_by_advert;
   $visitor_request_news_email = $member_request_news_email;
   $visitor_reserve_coop_spot  = $member_reserve_coop_spot;
   $visitor_block_email_login  = $member_block_email_login;
   $visitor_init_utc           = $club_member_init_utc;
   $visitor_last_utc           = $club_member_last_utc;
   $visitor_expiry_utc         = $club_member_expiry_utc;
   $visitor_notified_utc       = $club_member_notified_utc;

   return;
}

function etoHTMputVisitorClubMemberSqlFields($em) // include / exclude email address (bool).
// function etoHTMputVisitorClubMemberSqlFields()
{
   global $visitor_member_state;
   global $visitor_first_name;
   global $visitor_last_name;
   global $visitor_email;
   global $visitor_ref_by_member;
   global $visitor_inf_by_advert;
   global $visitor_request_news_email;
   global $visitor_reserve_coop_spot;
   global $visitor_block_email_login;
   global $visitor_init_utc;
   global $visitor_expiry_utc;

   global $visitor_pledge_1_polity;
   global $visitor_pledge_2_voice;
   global $visitor_pledge_3_age;

   global $member_status;
   global $member_first_name;
   global $member_last_name;
   global $member_email_addr;
   global $member_ref_by_member;
   global $member_inf_by_advert;
   global $member_reserve_coop_spot;
   global $member_request_news_email;
   global $member_block_email_login;
   global $club_member_expiry_utc;

   $member_status              = $visitor_member_state;            
   $member_first_name          = $visitor_first_name;
   $member_last_name           = $visitor_last_name;

   ($em) ? ($member_email_addr = $visitor_email) : false;

   $member_ref_by_member       = $visitor_ref_by_member;
   $member_inf_by_advert       = $visitor_inf_by_advert;
   $member_request_news_email  = $visitor_request_news_email;
   $member_reserve_coop_spot   = $visitor_reserve_coop_spot;
   $member_block_email_login   = $visitor_block_email_login;

// are all pledges checked?
   if
   (
      $visitor_pledge_1_polity
      &&
      $visitor_pledge_2_voice
      &&
      $visitor_pledge_3_age
   )
// yes -- both pledges checked.
   {
//    reflect visitor pledges in visitor expiry date.
      $visitor_expiry_utc     = getMemberExpiryUtc($visitor_init_utc);

//    update sql field from visitor field.
      $club_member_expiry_utc = $visitor_expiry_utc;
   }

   return;
}

function etoHTMgetVisitorClubMemberTargFields()
{
   global $visitor_pledge_1_polity;
   global $visitor_pledge_2_voice;
   global $visitor_pledge_3_age;

   global $visitor_member_number;
   global $visitor_member_state;
   global $visitor_first_name;
   global $visitor_last_name;
   global $visitor_email;
   global $visitor_ref_by_member;
   global $visitor_inf_by_advert;
   global $visitor_request_news_email;
   global $visitor_reserve_coop_spot;
   global $visitor_block_email_login;

   global $session_target_serno;

   global $ses_targ_status;
   global $ses_targ_first_name;
   global $ses_targ_last_name;
   global $ses_targ_email_addr;
   global $ses_targ_ref_by_member;
   global $ses_targ_inf_by_advert;
   global $ses_targ_reserve_coop_spot;
   global $ses_targ_request_news_email;
   global $ses_targ_block_email_login;

   $visitor_pledge_1_polity    = false;
   $visitor_pledge_2_voice     = false;
   $visitor_pledge_3_age       = false;

   $visitor_member_number      = $session_target_serno;
   $visitor_member_state       = $ses_targ_status;
   $visitor_first_name         = $ses_targ_first_name;
   $visitor_last_name          = $ses_targ_last_name;
   $visitor_email              = $ses_targ_email_addr;
   $visitor_ref_by_member      = $ses_targ_ref_by_member;
   $visitor_inf_by_advert      = $ses_targ_inf_by_advert;
   $visitor_request_news_email = $ses_targ_request_news_email;
   $visitor_reserve_coop_spot  = $ses_targ_reserve_coop_spot;
   $visitor_block_email_login  = $ses_targ_block_email_login;

   return;
}

function etoHtmlSpecialChars(&$s) // string to be converted.
{
// Convert a string **NOT** containing any special HTML coding) for insertion into HTML,
//  so characters with special meta-significance in HTML,
//  are represented by HTML-coded entities.
//

   return
   (
//
//     protect caller-supplied html-significant chars.
//
//            translate:
//     --------------------------
//     " (double quote) => &quot;
//     ' (single quote) => &#039;
//     & (ampersand)    => &amp;
//     < (less than)    => &lt;
//     > (greater than) => &gt;

       htmlspecialchars
       (
          $s,          // string to be converted.
          ENT_QUOTES,  // convert both double and single quotes.
          'ISO-8859-1' // string encoding (default internal PHP encoding).
       )
   );

}

function etoHtmlEntities(&$s) // string to be converted.
{
// Convert a string **NOT** containing any special HTML coding) for insertion into HTML,
//  so characters with special meta-significance in HTML,
//  are represented by HTML-coded entities.
//

   return
   (
       htmlentities
       (
          $s,               // string to be converted.

          (
             ENT_QUOTES     // convert both double and single quotes.
/*
//
//           php 5.4.0 required for the following options:
//
             |              //    (note: binary mask operator, NOT logical or operator.)
//           php 5.4.0
             ENT_SUBSTITUTE // replace invalid code unit sequences with unicode replacement character.
             |              //    (note: binary mask operator, NOT logical or operator.)
//           php 5.4.0
             ENT_DISALLOWED // replace invalid code points for the given document type with a unicode replacement character (instead of leaving them as is).
             |              //    (note: binary mask operator, NOT logical or operator.)
//           php 5.4.0
             ENT_XHTML      // handle code as XHTML.
*/
          ),

          'ISO-8859-1'      // string encoding (default internal PHP encoding, all eto web pages use this).
       )
   );

}

// OWASP RULE #1 --  convert visitor-supplied (i.e. untrusted) 1-byte-per-symbol encoded (e.g. ISO-8859-1) string to be XSS-safe for HTML body element entity output.
function etoHTMentiXssSafe(&$is)
{

   return
   (
//    make XSS-Safe: '/'.

//     This str_replace is necessary with function htmlentities(...).
//       See test script <eto__test_get_html_translation_table.php>
//       that lists the translate table used by function  htmlentities(...)
//       NO '/' in the translate table.
      str_replace
      (
         '/',      // search for.

         '&#x2F;', // replace with.

         etoHtmlEntities
//       etoHtmlSpecialChars
         (
            $is
         )
      )
   );
}

// OWASP RULE #2 -- convert visitor-saupplied (i.e. untrusted) 1-byte-per-symbol encoded (e.g. ISO-8859-1) string to be XSS-safe for HTML attribute value="...$os..." output.
function etoHTMattrXssSafe(&$is) // untrusted input string.
{
// See <www.owasp.org -- XSS_(Cross_Site_Scripting)_Prevention_Cheat_Sheet - 20130511.htm>:
//
//// Rule #2 is for putting untrusted data into typical attribute values like width, name, value, etc.
//
//   This should not be used for complex attributes like href, src, style, or any of the event handlers like onmouseover.
//      It is extremely important that event handler attributes should follow Rule #3 for HTML JavaScript Data Values.
// 
//  <div attr=...ESCAPE UNTRUSTED DATA BEFORE PUTTING HERE...>content</div>     inside UNquoted attribute
//  
//  <div attr='...ESCAPE UNTRUSTED DATA BEFORE PUTTING HERE...'>content</div>   inside single quoted attribute
//  
//  <div attr="...ESCAPE UNTRUSTED DATA BEFORE PUTTING HERE...">content</div>   inside double quoted attribute
// 
// Except for alphanumeric characters,
//    escape all characters with ASCII values less than 256 with the &#xHH; format (or a named entity if available)
//    to prevent switching out of the attribute.
//    The reason this rule is so broad is that developers frequently leave attributes unquoted.
//    Properly quoted attributes can only be escaped with the corresponding quote.
//    Unquoted attributes can be broken out of with many characters, including [space] % * + , - / ; < = > ^ and |.
//

// This function is used (for extra protection) even though ALL attributes in the ETO web pages ae properly quoted.

// See <www.asciitable.com -- Ascii Table - ASCII character codes and html, octal, hex and decimal chart conversion - 20130306.htm>.

   $tmp_xss_safe_str = '';

   for ($i = 0; $i < strlen($is); ++$i)
   {
      $is_chr = $is[$i];

      switch ($is_chr)
      {
         case '"': { $tmp_xss_safe_str .= '&quot;'; break; } // double quote.
         case '&': { $tmp_xss_safe_str .= '&amp;';  break; } // ampersand.
         case '<': { $tmp_xss_safe_str .= '&lt;';   break; } // less than.
         case '>': { $tmp_xss_safe_str .= '&gt;';   break; } // greater than

         default:
         {
            $is_ord = ord($is_chr);

            if      ($is_ord <   0) { $tmp_xss_safe_str .= '?'; }                            //  -ve ...  -1.
            else if ($is_ord <  48) { $tmp_xss_safe_str .= ('&#x'. strtoupper(dechex($is_ord)) . ';'); } //    0 ...  47.
            else if ($is_ord <  58) { $tmp_xss_safe_str .= $is_chr; }                        //   48 ...  57 ('0' ... '9').
            else if ($is_ord <  65) { $tmp_xss_safe_str .= ('&#x'. strtoupper(dechex($is_ord)) . ';'); } //   58 ...  64.
            else if ($is_ord <  91) { $tmp_xss_safe_str .= $is_chr; }                        //   65 ...  90 ('A' ... 'Z').
            else if ($is_ord <  97) { $tmp_xss_safe_str .= ('&#x'. strtoupper(dechex($is_ord)) . ';'); } //   91 ...  96.
            else if ($is_ord < 123) { $tmp_xss_safe_str .= $is_chr; }                        //   97 ... 122 ('a' ... 'z').
            else if ($is_ord < 256) { $tmp_xss_safe_str .= ('&#x'. strtoupper(dechex($is_ord)) . ';'); } //  123 ... 255.
            else                    { $tmp_xss_safe_str .= '?'; }                            // >255 ... +ve.

            break;
         }
      }
   }

   return $tmp_xss_safe_str;
}

function etoHTMsernoXssSafe(&$sn) // serno (int rep or string rep)..
{
   $tmp_sn_str = (string)$sn;

   return
   (
      ($tmp_sn_str != '0')
      ? etoHTMattrXssSafe($tmp_sn_str)
      : ''
   );
}

?>
